import{r as l,j as e,i as s,a as n,b as d,c as p,o as u}from"../chunks/chunk-CF7PZJR8.js";import{W as f,i as h}from"../chunks/chunk-lnINHodG.js";import{e as m,p as c}from"../chunks/chunk-DH9VFE1A.js";import{W as y}from"../chunks/chunk-BkH1NuDA.js";import{I as S,a as T}from"../chunks/chunk-Q1j31JH2.js";import{S as v}from"../chunks/chunk-CzzCbAGm.js";import"../chunks/chunk-BdvozYt0.js";/* empty css                      */import"../chunks/chunk-SmZMj1n8.js";import"../chunks/chunk-ChHTQ4Sk.js";import"../chunks/chunk-BjlBHbb1.js";import"../chunks/chunk-BmLiMrPg.js";import"../chunks/chunk-4_gci6_w.js";import"../chunks/chunk-DS1GWtHl.js";function x(){const{data:t,loading:a,error:o}=m(c,{fetchPolicy:"network-only"}),i=l.useMemo(()=>t?.publicWorkspaces.map(r=>r.id)||[],[t?.publicWorkspaces]);return e.jsxs("div",{className:"space-y-xl",children:[e.jsxs("div",{className:"flex items-center gap-4",children:[e.jsx("h1",{className:"flex-1 text-uk-lg leading-uk-lg font-medium text-text-highlight",children:"Community"}),e.jsx(S,{placeholder:"Search",children:e.jsx(T,{children:e.jsx(v,{})})})]}),e.jsx(f,{data:i,error:o,loading:a,Content:y})]})}function g(){return e.jsx(x,{})}const P=Object.freeze(Object.defineProperty({__proto__:null,default:g},Symbol.toStringTag,{value:"Module"})),W={hasServerOnlyHook:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:!0}},isClientRuntimeLoaded:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:!0}},onBeforeRenderEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:null}},dataEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:{server:!0}}},guardEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:null}},onRenderClient:{type:"standard",definedAtData:{filePathToShowToUser:"vike-react/__internal/integration/onRenderClient",fileExportPathToShowToUser:[]},valueSerialized:{type:"pointer-import",value:u}},onPageTransitionStart:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/+onPageTransitionStart.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:p}},onPageTransitionEnd:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/+onPageTransitionEnd.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:d}},Page:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/(profile)/community/+Page.tsx",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:P}},hydrationCanBeAborted:{type:"standard",definedAtData:{filePathToShowToUser:"vike-react/config",fileExportPathToShowToUser:["default","hydrationCanBeAborted"]},valueSerialized:{type:"js-serialized",value:!0}},Layout:{type:"cumulative",definedAtData:[{filePathToShowToUser:"/pages/(profile)/+Layout.tsx",fileExportPathToShowToUser:[]},{filePathToShowToUser:"/pages/+Layout.tsx",fileExportPathToShowToUser:[]}],valueSerialized:[{type:"plus-file",exportValues:h},{type:"plus-file",exportValues:n}]},title:{type:"standard",definedAtData:{filePathToShowToUser:"/+config.ts",fileExportPathToShowToUser:["default","title"]},valueSerialized:{type:"js-serialized",value:"Vuer UIKit | FortyFive Labs"}},Loading:{type:"standard",definedAtData:{filePathToShowToUser:"vike-react/__internal/integration/Loading",fileExportPathToShowToUser:[]},valueSerialized:{type:"pointer-import",value:s}}};export{W as configValuesSerialized};
