import{j as e}from"./chunk-CF7PZJR8.js";var t=({size:i=24,...s})=>e.jsxs("svg",{height:i,stroke:"currentColor",viewBox:"0 0 44 44",width:i,xmlns:"http://www.w3.org/2000/svg",...s,children:[e.jsx("title",{children:"Loading..."}),e.jsxs("g",{fill:"none",fillRule:"evenodd",strokeWidth:"2",children:[e.jsxs("circle",{cx:"22",cy:"22",r:"1",children:[e.jsx("animate",{attributeName:"r",begin:"0s",calcMode:"spline",dur:"1.8s",keySplines:"0.165, 0.84, 0.44, 1",keyTimes:"0; 1",repeatCount:"indefinite",values:"1; 20"}),e.jsx("animate",{attributeName:"stroke-opacity",begin:"0s",calcMode:"spline",dur:"1.8s",keySplines:"0.3, 0.61, 0.355, 1",keyTimes:"0; 1",repeatCount:"indefinite",values:"1; 0"})]}),e.jsxs("circle",{cx:"22",cy:"22",r:"1",children:[e.jsx("animate",{attributeName:"r",begin:"-0.9s",calcMode:"spline",dur:"1.8s",keySplines:"0.165, 0.84, 0.44, 1",keyTimes:"0; 1",repeatCount:"indefinite",values:"1; 20"}),e.jsx("animate",{attributeName:"stroke-opacity",begin:"-0.9s",calcMode:"spline",dur:"1.8s",keySplines:"0.3, 0.61, 0.355, 1",keyTimes:"0; 1",repeatCount:"indefinite",values:"1; 0"})]})]})]}),r=i=>e.jsx(t,{...i});export{r as S};
