import{j as e,i as l,a as s,b as n,c as d,o as p}from"../chunks/chunk-CF7PZJR8.js";import{W as u,i as f}from"../chunks/chunk-lnINHodG.js";import{u as h,W as m}from"../chunks/chunk-DatzjgAv.js";import{c}from"../chunks/chunk-DH9VFE1A.js";import{B as S}from"../chunks/chunk-ChHTQ4Sk.js";import{P as T}from"../chunks/chunk-CcncIH-T.js";import{I as y,a as x}from"../chunks/chunk-Q1j31JH2.js";import{S as v}from"../chunks/chunk-CzzCbAGm.js";import"../chunks/chunk-BdvozYt0.js";/* empty css                      */import"../chunks/chunk-SmZMj1n8.js";import"../chunks/chunk-BjlBHbb1.js";import"../chunks/chunk-BmLiMrPg.js";import"../chunks/chunk-4_gci6_w.js";import"../chunks/chunk-DS1GWtHl.js";function g(){const t=c(i=>i.username),{ids:a,loading:o,error:r}=h(t);return e.jsxs("div",{className:"space-y-xl",children:[e.jsxs("div",{className:"flex items-center gap-4",children:[e.jsx("h1",{className:"flex-1 text-uk-lg leading-uk-lg font-medium text-text-highlight",children:"Recents"}),e.jsx(S,{asChild:!0,children:e.jsxs("a",{href:"/workspace",children:[e.jsx(T,{})," Create workspace"]})}),e.jsx(y,{placeholder:"Search",children:e.jsx(x,{children:e.jsx(v,{})})})]}),e.jsx(u,{data:a,error:r,loading:o,Content:m})]})}const P=Object.freeze(Object.defineProperty({__proto__:null,default:g},Symbol.toStringTag,{value:"Module"})),W={hasServerOnlyHook:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:!0}},isClientRuntimeLoaded:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:!0}},onBeforeRenderEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:null}},dataEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:{server:!0}}},guardEnv:{type:"computed",definedAtData:null,valueSerialized:{type:"js-serialized",value:null}},onRenderClient:{type:"standard",definedAtData:{filePathToShowToUser:"vike-react/__internal/integration/onRenderClient",fileExportPathToShowToUser:[]},valueSerialized:{type:"pointer-import",value:p}},onPageTransitionStart:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/+onPageTransitionStart.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:d}},onPageTransitionEnd:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/+onPageTransitionEnd.ts",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:n}},Page:{type:"standard",definedAtData:{filePathToShowToUser:"/pages/(profile)/@username/recents/+Page.tsx",fileExportPathToShowToUser:[]},valueSerialized:{type:"plus-file",exportValues:P}},hydrationCanBeAborted:{type:"standard",definedAtData:{filePathToShowToUser:"vike-react/config",fileExportPathToShowToUser:["default","hydrationCanBeAborted"]},valueSerialized:{type:"js-serialized",value:!0}},Layout:{type:"cumulative",definedAtData:[{filePathToShowToUser:"/pages/(profile)/+Layout.tsx",fileExportPathToShowToUser:[]},{filePathToShowToUser:"/pages/+Layout.tsx",fileExportPathToShowToUser:[]}],valueSerialized:[{type:"plus-file",exportValues:f},{type:"plus-file",exportValues:s}]},title:{type:"standard",definedAtData:{filePathToShowToUser:"/+config.ts",fileExportPathToShowToUser:["default","title"]},valueSerialized:{type:"js-serialized",value:"Vuer UIKit | FortyFive Labs"}},Loading:{type:"standard",definedAtData:{filePathToShowToUser:"vike-react/__internal/integration/Loading",fileExportPathToShowToUser:[]},valueSerialized:{type:"pointer-import",value:l}}};export{W as configValuesSerialized};
