const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/chunks/chunk-BQRi4MCL.js","assets/chunks/chunk-DvrnVFXc.js","assets/chunks/chunk-CF7PZJR8.js","assets/chunks/chunk-BdvozYt0.js","assets/static/pages_index-c6b9ae3c.CWSrK-Yb.css"])))=>i.map(i=>d[i]);
import{_ as u}from"./chunk-BXl3LOEh.js";import{r as e,j as m}from"./chunk-CF7PZJR8.js";import{e as c}from"./chunk-2B0sFjzh.js";import"./chunk-BdvozYt0.js";/* empty css              */import"./chunk-ChHTQ4Sk.js";import"./chunk-SmZMj1n8.js";import"./chunk-DvrnVFXc.js";const l={all:255,foregrounds:2,backgrounds:1};let o=!1;async function p(s=t=>{o=t}){if(typeof window>"u")return;const{LumaSplatsThree:t}=await u(async()=>{const{LumaSplatsThree:r}=await import("./chunk-BQRi4MCL.js");return{LumaSplatsThree:r}},__vite__mapDeps([0,1,2,3,4]));c({LumaSplats:t}),s(!0)}function w({src:s,semantics:t="all",...r}){const[n,i]=e.useState(o);return e.useEffect(()=>{o||(async()=>(console.log("registering LumaSplats component. This should occur only once."),await p(a=>{i(a),o=a})))()},[]),n?m.jsx("lumaSplats",{semanticsMask:l[t],source:s,...r}):null}export{w as default};
