import{r as g}from"./chunk-CF7PZJR8.js";import{G as j}from"./chunk-BgWqmYCh.js";import{a as S}from"./chunk-2B0sFjzh.js";import"./chunk-BdvozYt0.js";/* empty css              */import"./chunk-DvrnVFXc.js";import"./chunk-ChHTQ4Sk.js";import"./chunk-SmZMj1n8.js";function k({premultipliedAlpha:o,clock:l,autoUpdate:r,preUpdate:n,originDistance:d,maxStdDev:p,minPixelRadius:u,maxPixelRadius:m,minAlpha:c,enable2DGS:s,preBlurAmount:v,blurAmount:f,focalDistance:a,apertureSize:h,falloff:A,clipXY:x,focalAdjustment:D,view:B}){const b=S(i=>i.gl),P=S(i=>i.scene),R=S(i=>i.invalidate),U=(i,t)=>i===void 0||t===void 0||t<=0?0:2*Math.atan(.5*i/t),e=g.useMemo(()=>{let i=null;if(P.traverse(G=>{G instanceof j&&(i=G)}),i)return i;const t=new j({renderer:b,premultipliedAlpha:o,clock:l,autoUpdate:r,preUpdate:n,originDistance:d,maxStdDev:p,minPixelRadius:u,maxPixelRadius:m,minAlpha:c,enable2DGS:s,preBlurAmount:v,blurAmount:f,focalDistance:a,apertureAngle:U(h,a),falloff:A,clipXY:x,focalAdjustment:D,view:B});return P.add(t),t},[b]);return g.useEffect(()=>{o!==void 0&&(e.premultipliedAlpha=o),l!==void 0&&(e.clock=l),r!==void 0&&(e.autoUpdate=r),n!==void 0&&(e.preUpdate=n),d!==void 0&&(e.originDistance=d),p!==void 0&&(e.maxStdDev=p),u!==void 0&&(e.minPixelRadius=u),m!==void 0&&(e.maxPixelRadius=m),c!==void 0&&(e.minAlpha=c),s!==void 0&&(e.enable2DGS=s),v!==void 0&&(e.preBlurAmount=v),f!==void 0&&(e.blurAmount=f),a!==void 0&&(e.focalDistance=a),e.apertureAngle=U(h,a),A!==void 0&&(e.falloff=A),x!==void 0&&(e.clipXY=x),D!==void 0&&(e.focalAdjustment=D),R()},[e,R,o,l,r,n,d,p,u,m,c,s,v,f,a,h,A,x,D]),null}export{k as default};
