import{j as e}from"./chunk-CF7PZJR8.js";import{u as n,g as m,A as o,b as l,a as i}from"./chunk-DH9VFE1A.js";import{n as c}from"./chunk-BmLiMrPg.js";import"./chunk-BdvozYt0.js";function u({id:r}){const{data:s}=n({fragment:m,fragmentName:"FWorkspace",from:{__typename:"Workspace",id:r}}),a=s.owner;return e.jsxs(e.Fragment,{children:[e.jsx("div",{className:"w-full overflow-hidden text-uk-md/uk-md font-medium overflow-ellipsis whitespace-nowrap",children:s.name}),e.jsxs("div",{className:"flex items-center gap-sm",onClick:t=>{t.preventDefault(),c(`/${a.__typename==="User"?a.username:a.slug}`).then()},children:[e.jsxs(o,{className:"size-4",children:[a?.avatarUrl&&e.jsx(l,{src:a?.avatarUrl}),e.jsx(i,{className:"text-uk-xxs",children:a?.name?.charAt(0)})]}),e.jsx("div",{className:"flex-1 overflow-hidden text-uk-sm/uk-sm overflow-ellipsis whitespace-nowrap text-text-secondary",children:a?.name})]})]})}export{u as W};
