import{p as bS}from"./chunk-BdvozYt0.js";/* empty css              */function Yf(i,n){for(var r=0;r<n.length;r++){const s=n[r];if(typeof s!="string"&&!Array.isArray(s)){for(const o in s)if(o!=="default"&&!(o in i)){const f=Object.getOwnPropertyDescriptor(s,o);f&&Object.defineProperty(i,o,f.get?f:{enumerable:!0,get:()=>s[o]})}}}return Object.freeze(Object.defineProperty(i,Symbol.toStringTag,{value:"Module"}))}function ii(i){return i&&i.__esModule&&Object.prototype.hasOwnProperty.call(i,"default")?i.default:i}var Yc={exports:{}},ul={},Gc={exports:{}},Xc={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ip;function SS(){return ip||(ip=1,(function(i){function n(R,Q){var W=R.length;R.push(Q);e:for(;0<W;){var pe=W-1>>>1,fe=R[pe];if(0<o(fe,Q))R[pe]=Q,R[W]=fe,W=pe;else break e}}function r(R){return R.length===0?null:R[0]}function s(R){if(R.length===0)return null;var Q=R[0],W=R.pop();if(W!==Q){R[0]=W;e:for(var pe=0,fe=R.length,_=fe>>>1;pe<_;){var L=2*(pe+1)-1,V=R[L],G=L+1,Z=R[G];if(0>o(V,W))G<fe&&0>o(Z,V)?(R[pe]=Z,R[G]=W,pe=G):(R[pe]=V,R[L]=W,pe=L);else if(G<fe&&0>o(Z,W))R[pe]=Z,R[G]=W,pe=G;else break e}}return Q}function o(R,Q){var W=R.sortIndex-Q.sortIndex;return W!==0?W:R.id-Q.id}if(i.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var f=performance;i.unstable_now=function(){return f.now()}}else{var d=Date,y=d.now();i.unstable_now=function(){return d.now()-y}}var m=[],h=[],b=1,v=null,E=3,S=!1,O=!1,N=!1,M=!1,D=typeof setTimeout=="function"?setTimeout:null,U=typeof clearTimeout=="function"?clearTimeout:null,Y=typeof setImmediate<"u"?setImmediate:null;function X(R){for(var Q=r(h);Q!==null;){if(Q.callback===null)s(h);else if(Q.startTime<=R)s(h),Q.sortIndex=Q.expirationTime,n(m,Q);else break;Q=r(h)}}function K(R){if(N=!1,X(R),!O)if(r(m)!==null)O=!0,ee||(ee=!0,ae());else{var Q=r(h);Q!==null&&He(K,Q.startTime-R)}}var ee=!1,$=-1,we=5,rt=-1;function dt(){return M?!0:!(i.unstable_now()-rt<we)}function ht(){if(M=!1,ee){var R=i.unstable_now();rt=R;var Q=!0;try{e:{O=!1,N&&(N=!1,U($),$=-1),S=!0;var W=E;try{t:{for(X(R),v=r(m);v!==null&&!(v.expirationTime>R&&dt());){var pe=v.callback;if(typeof pe=="function"){v.callback=null,E=v.priorityLevel;var fe=pe(v.expirationTime<=R);if(R=i.unstable_now(),typeof fe=="function"){v.callback=fe,X(R),Q=!0;break t}v===r(m)&&s(m),X(R)}else s(m);v=r(m)}if(v!==null)Q=!0;else{var _=r(h);_!==null&&He(K,_.startTime-R),Q=!1}}break e}finally{v=null,E=W,S=!1}Q=void 0}}finally{Q?ae():ee=!1}}}var ae;if(typeof Y=="function")ae=function(){Y(ht)};else if(typeof MessageChannel<"u"){var Se=new MessageChannel,mt=Se.port2;Se.port1.onmessage=ht,ae=function(){mt.postMessage(null)}}else ae=function(){D(ht,0)};function He(R,Q){$=D(function(){R(i.unstable_now())},Q)}i.unstable_IdlePriority=5,i.unstable_ImmediatePriority=1,i.unstable_LowPriority=4,i.unstable_NormalPriority=3,i.unstable_Profiling=null,i.unstable_UserBlockingPriority=2,i.unstable_cancelCallback=function(R){R.callback=null},i.unstable_forceFrameRate=function(R){0>R||125<R?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):we=0<R?Math.floor(1e3/R):5},i.unstable_getCurrentPriorityLevel=function(){return E},i.unstable_next=function(R){switch(E){case 1:case 2:case 3:var Q=3;break;default:Q=E}var W=E;E=Q;try{return R()}finally{E=W}},i.unstable_requestPaint=function(){M=!0},i.unstable_runWithPriority=function(R,Q){switch(R){case 1:case 2:case 3:case 4:case 5:break;default:R=3}var W=E;E=R;try{return Q()}finally{E=W}},i.unstable_scheduleCallback=function(R,Q,W){var pe=i.unstable_now();switch(typeof W=="object"&&W!==null?(W=W.delay,W=typeof W=="number"&&0<W?pe+W:pe):W=pe,R){case 1:var fe=-1;break;case 2:fe=250;break;case 5:fe=1073741823;break;case 4:fe=1e4;break;default:fe=5e3}return fe=W+fe,R={id:b++,callback:Q,priorityLevel:R,startTime:W,expirationTime:fe,sortIndex:-1},W>pe?(R.sortIndex=W,n(h,R),r(m)===null&&R===r(h)&&(N?(U($),$=-1):N=!0,He(K,W-pe))):(R.sortIndex=fe,n(m,R),O||S||(O=!0,ee||(ee=!0,ae()))),R},i.unstable_shouldYield=dt,i.unstable_wrapCallback=function(R){var Q=E;return function(){var W=E;E=Q;try{return R.apply(this,arguments)}finally{E=W}}}})(Xc)),Xc}var rp;function ES(){return rp||(rp=1,Gc.exports=SS()),Gc.exports}var Fc={exports:{}},re={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var lp;function TS(){if(lp)return re;lp=1;var i=Symbol.for("react.transitional.element"),n=Symbol.for("react.portal"),r=Symbol.for("react.fragment"),s=Symbol.for("react.strict_mode"),o=Symbol.for("react.profiler"),f=Symbol.for("react.consumer"),d=Symbol.for("react.context"),y=Symbol.for("react.forward_ref"),m=Symbol.for("react.suspense"),h=Symbol.for("react.memo"),b=Symbol.for("react.lazy"),v=Symbol.for("react.activity"),E=Symbol.iterator;function S(_){return _===null||typeof _!="object"?null:(_=E&&_[E]||_["@@iterator"],typeof _=="function"?_:null)}var O={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},N=Object.assign,M={};function D(_,L,V){this.props=_,this.context=L,this.refs=M,this.updater=V||O}D.prototype.isReactComponent={},D.prototype.setState=function(_,L){if(typeof _!="object"&&typeof _!="function"&&_!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,_,L,"setState")},D.prototype.forceUpdate=function(_){this.updater.enqueueForceUpdate(this,_,"forceUpdate")};function U(){}U.prototype=D.prototype;function Y(_,L,V){this.props=_,this.context=L,this.refs=M,this.updater=V||O}var X=Y.prototype=new U;X.constructor=Y,N(X,D.prototype),X.isPureReactComponent=!0;var K=Array.isArray;function ee(){}var $={H:null,A:null,T:null,S:null},we=Object.prototype.hasOwnProperty;function rt(_,L,V){var G=V.ref;return{$$typeof:i,type:_,key:L,ref:G!==void 0?G:null,props:V}}function dt(_,L){return rt(_.type,L,_.props)}function ht(_){return typeof _=="object"&&_!==null&&_.$$typeof===i}function ae(_){var L={"=":"=0",":":"=2"};return"$"+_.replace(/[=:]/g,function(V){return L[V]})}var Se=/\/+/g;function mt(_,L){return typeof _=="object"&&_!==null&&_.key!=null?ae(""+_.key):L.toString(36)}function He(_){switch(_.status){case"fulfilled":return _.value;case"rejected":throw _.reason;default:switch(typeof _.status=="string"?_.then(ee,ee):(_.status="pending",_.then(function(L){_.status==="pending"&&(_.status="fulfilled",_.value=L)},function(L){_.status==="pending"&&(_.status="rejected",_.reason=L)})),_.status){case"fulfilled":return _.value;case"rejected":throw _.reason}}throw _}function R(_,L,V,G,Z){var ne=typeof _;(ne==="undefined"||ne==="boolean")&&(_=null);var he=!1;if(_===null)he=!0;else switch(ne){case"bigint":case"string":case"number":he=!0;break;case"object":switch(_.$$typeof){case i:case n:he=!0;break;case b:return he=_._init,R(he(_._payload),L,V,G,Z)}}if(he)return Z=Z(_),he=G===""?"."+mt(_,0):G,K(Z)?(V="",he!=null&&(V=he.replace(Se,"$&/")+"/"),R(Z,L,V,"",function(dn){return dn})):Z!=null&&(ht(Z)&&(Z=dt(Z,V+(Z.key==null||_&&_.key===Z.key?"":(""+Z.key).replace(Se,"$&/")+"/")+he)),L.push(Z)),1;he=0;var ce=G===""?".":G+":";if(K(_))for(var Ce=0;Ce<_.length;Ce++)G=_[Ce],ne=ce+mt(G,Ce),he+=R(G,L,V,ne,Z);else if(Ce=S(_),typeof Ce=="function")for(_=Ce.call(_),Ce=0;!(G=_.next()).done;)G=G.value,ne=ce+mt(G,Ce++),he+=R(G,L,V,ne,Z);else if(ne==="object"){if(typeof _.then=="function")return R(He(_),L,V,G,Z);throw L=String(_),Error("Objects are not valid as a React child (found: "+(L==="[object Object]"?"object with keys {"+Object.keys(_).join(", ")+"}":L)+"). If you meant to render a collection of children, use an array instead.")}return he}function Q(_,L,V){if(_==null)return _;var G=[],Z=0;return R(_,G,"","",function(ne){return L.call(V,ne,Z++)}),G}function W(_){if(_._status===-1){var L=_._result;L=L(),L.then(function(V){(_._status===0||_._status===-1)&&(_._status=1,_._result=V)},function(V){(_._status===0||_._status===-1)&&(_._status=2,_._result=V)}),_._status===-1&&(_._status=0,_._result=L)}if(_._status===1)return _._result.default;throw _._result}var pe=typeof reportError=="function"?reportError:function(_){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var L=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof _=="object"&&_!==null&&typeof _.message=="string"?String(_.message):String(_),error:_});if(!window.dispatchEvent(L))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",_);return}console.error(_)},fe={map:Q,forEach:function(_,L,V){Q(_,function(){L.apply(this,arguments)},V)},count:function(_){var L=0;return Q(_,function(){L++}),L},toArray:function(_){return Q(_,function(L){return L})||[]},only:function(_){if(!ht(_))throw Error("React.Children.only expected to receive a single React element child.");return _}};return re.Activity=v,re.Children=fe,re.Component=D,re.Fragment=r,re.Profiler=o,re.PureComponent=Y,re.StrictMode=s,re.Suspense=m,re.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=$,re.__COMPILER_RUNTIME={__proto__:null,c:function(_){return $.H.useMemoCache(_)}},re.cache=function(_){return function(){return _.apply(null,arguments)}},re.cacheSignal=function(){return null},re.cloneElement=function(_,L,V){if(_==null)throw Error("The argument must be a React element, but you passed "+_+".");var G=N({},_.props),Z=_.key;if(L!=null)for(ne in L.key!==void 0&&(Z=""+L.key),L)!we.call(L,ne)||ne==="key"||ne==="__self"||ne==="__source"||ne==="ref"&&L.ref===void 0||(G[ne]=L[ne]);var ne=arguments.length-2;if(ne===1)G.children=V;else if(1<ne){for(var he=Array(ne),ce=0;ce<ne;ce++)he[ce]=arguments[ce+2];G.children=he}return rt(_.type,Z,G)},re.createContext=function(_){return _={$$typeof:d,_currentValue:_,_currentValue2:_,_threadCount:0,Provider:null,Consumer:null},_.Provider=_,_.Consumer={$$typeof:f,_context:_},_},re.createElement=function(_,L,V){var G,Z={},ne=null;if(L!=null)for(G in L.key!==void 0&&(ne=""+L.key),L)we.call(L,G)&&G!=="key"&&G!=="__self"&&G!=="__source"&&(Z[G]=L[G]);var he=arguments.length-2;if(he===1)Z.children=V;else if(1<he){for(var ce=Array(he),Ce=0;Ce<he;Ce++)ce[Ce]=arguments[Ce+2];Z.children=ce}if(_&&_.defaultProps)for(G in he=_.defaultProps,he)Z[G]===void 0&&(Z[G]=he[G]);return rt(_,ne,Z)},re.createRef=function(){return{current:null}},re.forwardRef=function(_){return{$$typeof:y,render:_}},re.isValidElement=ht,re.lazy=function(_){return{$$typeof:b,_payload:{_status:-1,_result:_},_init:W}},re.memo=function(_,L){return{$$typeof:h,type:_,compare:L===void 0?null:L}},re.startTransition=function(_){var L=$.T,V={};$.T=V;try{var G=_(),Z=$.S;Z!==null&&Z(V,G),typeof G=="object"&&G!==null&&typeof G.then=="function"&&G.then(ee,pe)}catch(ne){pe(ne)}finally{L!==null&&V.types!==null&&(L.types=V.types),$.T=L}},re.unstable_useCacheRefresh=function(){return $.H.useCacheRefresh()},re.use=function(_){return $.H.use(_)},re.useActionState=function(_,L,V){return $.H.useActionState(_,L,V)},re.useCallback=function(_,L){return $.H.useCallback(_,L)},re.useContext=function(_){return $.H.useContext(_)},re.useDebugValue=function(){},re.useDeferredValue=function(_,L){return $.H.useDeferredValue(_,L)},re.useEffect=function(_,L){return $.H.useEffect(_,L)},re.useEffectEvent=function(_){return $.H.useEffectEvent(_)},re.useId=function(){return $.H.useId()},re.useImperativeHandle=function(_,L,V){return $.H.useImperativeHandle(_,L,V)},re.useInsertionEffect=function(_,L){return $.H.useInsertionEffect(_,L)},re.useLayoutEffect=function(_,L){return $.H.useLayoutEffect(_,L)},re.useMemo=function(_,L){return $.H.useMemo(_,L)},re.useOptimistic=function(_,L){return $.H.useOptimistic(_,L)},re.useReducer=function(_,L,V){return $.H.useReducer(_,L,V)},re.useRef=function(_){return $.H.useRef(_)},re.useState=function(_){return $.H.useState(_)},re.useSyncExternalStore=function(_,L,V){return $.H.useSyncExternalStore(_,L,V)},re.useTransition=function(){return $.H.useTransition()},re.version="19.2.3",re}var sp;function Gf(){return sp||(sp=1,Fc.exports=TS()),Fc.exports}var Zc={exports:{}},vt={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var up;function OS(){if(up)return vt;up=1;var i=Gf();function n(m){var h="https://react.dev/errors/"+m;if(1<arguments.length){h+="?args[]="+encodeURIComponent(arguments[1]);for(var b=2;b<arguments.length;b++)h+="&args[]="+encodeURIComponent(arguments[b])}return"Minified React error #"+m+"; visit "+h+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function r(){}var s={d:{f:r,r:function(){throw Error(n(522))},D:r,C:r,L:r,m:r,X:r,S:r,M:r},p:0,findDOMNode:null},o=Symbol.for("react.portal");function f(m,h,b){var v=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:o,key:v==null?null:""+v,children:m,containerInfo:h,implementation:b}}var d=i.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function y(m,h){if(m==="font")return"";if(typeof h=="string")return h==="use-credentials"?h:""}return vt.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=s,vt.createPortal=function(m,h){var b=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!h||h.nodeType!==1&&h.nodeType!==9&&h.nodeType!==11)throw Error(n(299));return f(m,h,null,b)},vt.flushSync=function(m){var h=d.T,b=s.p;try{if(d.T=null,s.p=2,m)return m()}finally{d.T=h,s.p=b,s.d.f()}},vt.preconnect=function(m,h){typeof m=="string"&&(h?(h=h.crossOrigin,h=typeof h=="string"?h==="use-credentials"?h:"":void 0):h=null,s.d.C(m,h))},vt.prefetchDNS=function(m){typeof m=="string"&&s.d.D(m)},vt.preinit=function(m,h){if(typeof m=="string"&&h&&typeof h.as=="string"){var b=h.as,v=y(b,h.crossOrigin),E=typeof h.integrity=="string"?h.integrity:void 0,S=typeof h.fetchPriority=="string"?h.fetchPriority:void 0;b==="style"?s.d.S(m,typeof h.precedence=="string"?h.precedence:void 0,{crossOrigin:v,integrity:E,fetchPriority:S}):b==="script"&&s.d.X(m,{crossOrigin:v,integrity:E,fetchPriority:S,nonce:typeof h.nonce=="string"?h.nonce:void 0})}},vt.preinitModule=function(m,h){if(typeof m=="string")if(typeof h=="object"&&h!==null){if(h.as==null||h.as==="script"){var b=y(h.as,h.crossOrigin);s.d.M(m,{crossOrigin:b,integrity:typeof h.integrity=="string"?h.integrity:void 0,nonce:typeof h.nonce=="string"?h.nonce:void 0})}}else h==null&&s.d.M(m)},vt.preload=function(m,h){if(typeof m=="string"&&typeof h=="object"&&h!==null&&typeof h.as=="string"){var b=h.as,v=y(b,h.crossOrigin);s.d.L(m,b,{crossOrigin:v,integrity:typeof h.integrity=="string"?h.integrity:void 0,nonce:typeof h.nonce=="string"?h.nonce:void 0,type:typeof h.type=="string"?h.type:void 0,fetchPriority:typeof h.fetchPriority=="string"?h.fetchPriority:void 0,referrerPolicy:typeof h.referrerPolicy=="string"?h.referrerPolicy:void 0,imageSrcSet:typeof h.imageSrcSet=="string"?h.imageSrcSet:void 0,imageSizes:typeof h.imageSizes=="string"?h.imageSizes:void 0,media:typeof h.media=="string"?h.media:void 0})}},vt.preloadModule=function(m,h){if(typeof m=="string")if(h){var b=y(h.as,h.crossOrigin);s.d.m(m,{as:typeof h.as=="string"&&h.as!=="script"?h.as:void 0,crossOrigin:b,integrity:typeof h.integrity=="string"?h.integrity:void 0})}else s.d.m(m)},vt.requestFormReset=function(m){s.d.r(m)},vt.unstable_batchedUpdates=function(m,h){return m(h)},vt.useFormState=function(m,h,b){return d.H.useFormState(m,h,b)},vt.useFormStatus=function(){return d.H.useHostTransitionStatus()},vt.version="19.2.3",vt}var op;function Hv(){if(op)return Zc.exports;op=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(n){console.error(n)}}return i(),Zc.exports=OS(),Zc.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var cp;function _S(){if(cp)return ul;cp=1;var i=ES(),n=Gf(),r=Hv();function s(e){var t="https://react.dev/errors/"+e;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function o(e){return!(!e||e.nodeType!==1&&e.nodeType!==9&&e.nodeType!==11)}function f(e){var t=e,a=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do t=e,(t.flags&4098)!==0&&(a=t.return),e=t.return;while(e)}return t.tag===3?a:null}function d(e){if(e.tag===13){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function y(e){if(e.tag===31){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function m(e){if(f(e)!==e)throw Error(s(188))}function h(e){var t=e.alternate;if(!t){if(t=f(e),t===null)throw Error(s(188));return t!==e?null:e}for(var a=e,l=t;;){var u=a.return;if(u===null)break;var c=u.alternate;if(c===null){if(l=u.return,l!==null){a=l;continue}break}if(u.child===c.child){for(c=u.child;c;){if(c===a)return m(u),e;if(c===l)return m(u),t;c=c.sibling}throw Error(s(188))}if(a.return!==l.return)a=u,l=c;else{for(var p=!1,g=u.child;g;){if(g===a){p=!0,a=u,l=c;break}if(g===l){p=!0,l=u,a=c;break}g=g.sibling}if(!p){for(g=c.child;g;){if(g===a){p=!0,a=c,l=u;break}if(g===l){p=!0,l=c,a=u;break}g=g.sibling}if(!p)throw Error(s(189))}}if(a.alternate!==l)throw Error(s(190))}if(a.tag!==3)throw Error(s(188));return a.stateNode.current===a?e:t}function b(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e;for(e=e.child;e!==null;){if(t=b(e),t!==null)return t;e=e.sibling}return null}var v=Object.assign,E=Symbol.for("react.element"),S=Symbol.for("react.transitional.element"),O=Symbol.for("react.portal"),N=Symbol.for("react.fragment"),M=Symbol.for("react.strict_mode"),D=Symbol.for("react.profiler"),U=Symbol.for("react.consumer"),Y=Symbol.for("react.context"),X=Symbol.for("react.forward_ref"),K=Symbol.for("react.suspense"),ee=Symbol.for("react.suspense_list"),$=Symbol.for("react.memo"),we=Symbol.for("react.lazy"),rt=Symbol.for("react.activity"),dt=Symbol.for("react.memo_cache_sentinel"),ht=Symbol.iterator;function ae(e){return e===null||typeof e!="object"?null:(e=ht&&e[ht]||e["@@iterator"],typeof e=="function"?e:null)}var Se=Symbol.for("react.client.reference");function mt(e){if(e==null)return null;if(typeof e=="function")return e.$$typeof===Se?null:e.displayName||e.name||null;if(typeof e=="string")return e;switch(e){case N:return"Fragment";case D:return"Profiler";case M:return"StrictMode";case K:return"Suspense";case ee:return"SuspenseList";case rt:return"Activity"}if(typeof e=="object")switch(e.$$typeof){case O:return"Portal";case Y:return e.displayName||"Context";case U:return(e._context.displayName||"Context")+".Consumer";case X:var t=e.render;return e=e.displayName,e||(e=t.displayName||t.name||"",e=e!==""?"ForwardRef("+e+")":"ForwardRef"),e;case $:return t=e.displayName||null,t!==null?t:mt(e.type)||"Memo";case we:t=e._payload,e=e._init;try{return mt(e(t))}catch{}}return null}var He=Array.isArray,R=n.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Q=r.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,W={pending:!1,data:null,method:null,action:null},pe=[],fe=-1;function _(e){return{current:e}}function L(e){0>fe||(e.current=pe[fe],pe[fe]=null,fe--)}function V(e,t){fe++,pe[fe]=e.current,e.current=t}var G=_(null),Z=_(null),ne=_(null),he=_(null);function ce(e,t){switch(V(ne,t),V(Z,e),V(G,null),t.nodeType){case 9:case 11:e=(e=t.documentElement)&&(e=e.namespaceURI)?Dy(e):0;break;default:if(e=t.tagName,t=t.namespaceURI)t=Dy(t),e=My(t,e);else switch(e){case"svg":e=1;break;case"math":e=2;break;default:e=0}}L(G),V(G,e)}function Ce(){L(G),L(Z),L(ne)}function dn(e){e.memoizedState!==null&&V(he,e);var t=G.current,a=My(t,e.type);t!==a&&(V(Z,e),V(G,a))}function wn(e){Z.current===e&&(L(G),L(Z)),he.current===e&&(L(he),il._currentValue=W)}var hn,Nl;function nn(e){if(hn===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\n( *(at )?)/);hn=t&&t[1]||"",Nl=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+hn+e+Nl}var hr=!1;function li(e,t){if(!e||hr)return"";hr=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var l={DetermineComponentFrameRoot:function(){try{if(t){var H=function(){throw Error()};if(Object.defineProperty(H.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(H,[])}catch(j){var z=j}Reflect.construct(e,[],H)}else{try{H.call()}catch(j){z=j}e.call(H.prototype)}}else{try{throw Error()}catch(j){z=j}(H=e())&&typeof H.catch=="function"&&H.catch(function(){})}}catch(j){if(j&&z&&typeof j.stack=="string")return[j.stack,z.stack]}return[null,null]}};l.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var u=Object.getOwnPropertyDescriptor(l.DetermineComponentFrameRoot,"name");u&&u.configurable&&Object.defineProperty(l.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var c=l.DetermineComponentFrameRoot(),p=c[0],g=c[1];if(p&&g){var T=p.split(`
`),x=g.split(`
`);for(u=l=0;l<T.length&&!T[l].includes("DetermineComponentFrameRoot");)l++;for(;u<x.length&&!x[u].includes("DetermineComponentFrameRoot");)u++;if(l===T.length||u===x.length)for(l=T.length-1,u=x.length-1;1<=l&&0<=u&&T[l]!==x[u];)u--;for(;1<=l&&0<=u;l--,u--)if(T[l]!==x[u]){if(l!==1||u!==1)do if(l--,u--,0>u||T[l]!==x[u]){var k=`
`+T[l].replace(" at new "," at ");return e.displayName&&k.includes("<anonymous>")&&(k=k.replace("<anonymous>",e.displayName)),k}while(1<=l&&0<=u);break}}}finally{hr=!1,Error.prepareStackTrace=a}return(a=e?e.displayName||e.name:"")?nn(a):""}function Ca(e,t){switch(e.tag){case 26:case 27:case 5:return nn(e.type);case 16:return nn("Lazy");case 13:return e.child!==t&&t!==null?nn("Suspense Fallback"):nn("Suspense");case 19:return nn("SuspenseList");case 0:case 15:return li(e.type,!1);case 11:return li(e.type.render,!1);case 1:return li(e.type,!0);case 31:return nn("Activity");default:return""}}function mr(e){try{var t="",a=null;do t+=Ca(e,a),a=e,e=e.return;while(e);return t}catch(l){return`
Error generating stack: `+l.message+`
`+l.stack}}var Ut=Object.prototype.hasOwnProperty,yr=i.unstable_scheduleCallback,pr=i.unstable_cancelCallback,bt=i.unstable_shouldYield,$n=i.unstable_requestPaint,St=i.unstable_now,xu=i.unstable_getCurrentPriorityLevel,xa=i.unstable_ImmediatePriority,jl=i.unstable_UserBlockingPriority,Ra=i.unstable_NormalPriority,vr=i.unstable_LowPriority,An=i.unstable_IdlePriority,Ul=i.log,Wn=i.unstable_setDisableYieldValue,za=null,Et=null;function an(e){if(typeof Ul=="function"&&Wn(e),Et&&typeof Et.setStrictMode=="function")try{Et.setStrictMode(za,e)}catch{}}var yt=Math.clz32?Math.clz32:mn,Ru=Math.log,gr=Math.LN2;function mn(e){return e>>>=0,e===0?32:31-(Ru(e)/gr|0)|0}var si=256,ui=262144,Na=4194304;function yn(e){var t=e&42;if(t!==0)return t;switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return e&261888;case 262144:case 524288:case 1048576:case 2097152:return e&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return e&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return e}}function ie(e,t,a){var l=e.pendingLanes;if(l===0)return 0;var u=0,c=e.suspendedLanes,p=e.pingedLanes;e=e.warmLanes;var g=l&134217727;return g!==0?(l=g&~c,l!==0?u=yn(l):(p&=g,p!==0?u=yn(p):a||(a=g&~e,a!==0&&(u=yn(a))))):(g=l&~c,g!==0?u=yn(g):p!==0?u=yn(p):a||(a=l&~e,a!==0&&(u=yn(a)))),u===0?0:t!==0&&t!==u&&(t&c)===0&&(c=u&-u,a=t&-t,c>=a||c===32&&(a&4194048)!==0)?t:u}function qe(e,t){return(e.pendingLanes&~(e.suspendedLanes&~e.pingedLanes)&t)===0}function et(e,t){switch(e){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function pt(){var e=Na;return Na<<=1,(Na&62914560)===0&&(Na=4194304),e}function Pn(e){for(var t=[],a=0;31>a;a++)t.push(e);return t}function Be(e,t){e.pendingLanes|=t,t!==268435456&&(e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0)}function Ot(e,t,a,l,u,c){var p=e.pendingLanes;e.pendingLanes=a,e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0,e.expiredLanes&=a,e.entangledLanes&=a,e.errorRecoveryDisabledLanes&=a,e.shellSuspendCounter=0;var g=e.entanglements,T=e.expirationTimes,x=e.hiddenUpdates;for(a=p&~a;0<a;){var k=31-yt(a),H=1<<k;g[k]=0,T[k]=-1;var z=x[k];if(z!==null)for(x[k]=null,k=0;k<z.length;k++){var j=z[k];j!==null&&(j.lane&=-536870913)}a&=~H}l!==0&&ja(e,l,0),c!==0&&u===0&&e.tag!==0&&(e.suspendedLanes|=c&~(p&~t))}function ja(e,t,a){e.pendingLanes|=t,e.suspendedLanes&=~t;var l=31-yt(t);e.entangledLanes|=t,e.entanglements[l]=e.entanglements[l]|1073741824|a&261930}function _t(e,t){var a=e.entangledLanes|=t;for(e=e.entanglements;a;){var l=31-yt(a),u=1<<l;u&t|e[l]&t&&(e[l]|=t),a&=~u}}function wt(e,t){var a=t&-t;return a=(a&42)!==0?1:oi(a),(a&(e.suspendedLanes|t))!==0?0:a}function oi(e){switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=128;break;case 268435456:e=134217728;break;default:e=0}return e}function rn(e){return e&=-e,2<e?8<e?(e&134217727)!==0?32:268435456:8:2}function zu(){var e=Q.p;return e!==0?e:(e=window.event,e===void 0?32:$y(e.type))}function hd(e,t){var a=Q.p;try{return Q.p=e,t()}finally{Q.p=a}}var ea=Math.random().toString(36).slice(2),lt="__reactFiber$"+ea,At="__reactProps$"+ea,ci="__reactContainer$"+ea,Nu="__reactEvents$"+ea,u0="__reactListeners$"+ea,o0="__reactHandles$"+ea,md="__reactResources$"+ea,br="__reactMarker$"+ea;function ju(e){delete e[lt],delete e[At],delete e[Nu],delete e[u0],delete e[o0]}function fi(e){var t=e[lt];if(t)return t;for(var a=e.parentNode;a;){if(t=a[ci]||a[lt]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(e=Uy(e);e!==null;){if(a=e[lt])return a;e=Uy(e)}return t}e=a,a=e.parentNode}return null}function di(e){if(e=e[lt]||e[ci]){var t=e.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return e}return null}function Sr(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e.stateNode;throw Error(s(33))}function hi(e){var t=e[md];return t||(t=e[md]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function tt(e){e[br]=!0}var yd=new Set,pd={};function Ua(e,t){mi(e,t),mi(e+"Capture",t)}function mi(e,t){for(pd[e]=t,e=0;e<t.length;e++)yd.add(t[e])}var c0=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),vd={},gd={};function f0(e){return Ut.call(gd,e)?!0:Ut.call(vd,e)?!1:c0.test(e)?gd[e]=!0:(vd[e]=!0,!1)}function kl(e,t,a){if(f0(t))if(a===null)e.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":e.removeAttribute(t);return;case"boolean":var l=t.toLowerCase().slice(0,5);if(l!=="data-"&&l!=="aria-"){e.removeAttribute(t);return}}e.setAttribute(t,""+a)}}function ql(e,t,a){if(a===null)e.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(t);return}e.setAttribute(t,""+a)}}function Dn(e,t,a,l){if(l===null)e.removeAttribute(a);else{switch(typeof l){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(a);return}e.setAttributeNS(t,a,""+l)}}function Yt(e){switch(typeof e){case"bigint":case"boolean":case"number":case"string":case"undefined":return e;case"object":return e;default:return""}}function bd(e){var t=e.type;return(e=e.nodeName)&&e.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function d0(e,t,a){var l=Object.getOwnPropertyDescriptor(e.constructor.prototype,t);if(!e.hasOwnProperty(t)&&typeof l<"u"&&typeof l.get=="function"&&typeof l.set=="function"){var u=l.get,c=l.set;return Object.defineProperty(e,t,{configurable:!0,get:function(){return u.call(this)},set:function(p){a=""+p,c.call(this,p)}}),Object.defineProperty(e,t,{enumerable:l.enumerable}),{getValue:function(){return a},setValue:function(p){a=""+p},stopTracking:function(){e._valueTracker=null,delete e[t]}}}}function Uu(e){if(!e._valueTracker){var t=bd(e)?"checked":"value";e._valueTracker=d0(e,t,""+e[t])}}function Sd(e){if(!e)return!1;var t=e._valueTracker;if(!t)return!0;var a=t.getValue(),l="";return e&&(l=bd(e)?e.checked?"true":"false":e.value),e=l,e!==a?(t.setValue(e),!0):!1}function Ll(e){if(e=e||(typeof document<"u"?document:void 0),typeof e>"u")return null;try{return e.activeElement||e.body}catch{return e.body}}var h0=/[\n"\\]/g;function Gt(e){return e.replace(h0,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function ku(e,t,a,l,u,c,p,g){e.name="",p!=null&&typeof p!="function"&&typeof p!="symbol"&&typeof p!="boolean"?e.type=p:e.removeAttribute("type"),t!=null?p==="number"?(t===0&&e.value===""||e.value!=t)&&(e.value=""+Yt(t)):e.value!==""+Yt(t)&&(e.value=""+Yt(t)):p!=="submit"&&p!=="reset"||e.removeAttribute("value"),t!=null?qu(e,p,Yt(t)):a!=null?qu(e,p,Yt(a)):l!=null&&e.removeAttribute("value"),u==null&&c!=null&&(e.defaultChecked=!!c),u!=null&&(e.checked=u&&typeof u!="function"&&typeof u!="symbol"),g!=null&&typeof g!="function"&&typeof g!="symbol"&&typeof g!="boolean"?e.name=""+Yt(g):e.removeAttribute("name")}function Ed(e,t,a,l,u,c,p,g){if(c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(e.type=c),t!=null||a!=null){if(!(c!=="submit"&&c!=="reset"||t!=null)){Uu(e);return}a=a!=null?""+Yt(a):"",t=t!=null?""+Yt(t):a,g||t===e.value||(e.value=t),e.defaultValue=t}l=l??u,l=typeof l!="function"&&typeof l!="symbol"&&!!l,e.checked=g?e.checked:!!l,e.defaultChecked=!!l,p!=null&&typeof p!="function"&&typeof p!="symbol"&&typeof p!="boolean"&&(e.name=p),Uu(e)}function qu(e,t,a){t==="number"&&Ll(e.ownerDocument)===e||e.defaultValue===""+a||(e.defaultValue=""+a)}function yi(e,t,a,l){if(e=e.options,t){t={};for(var u=0;u<a.length;u++)t["$"+a[u]]=!0;for(a=0;a<e.length;a++)u=t.hasOwnProperty("$"+e[a].value),e[a].selected!==u&&(e[a].selected=u),u&&l&&(e[a].defaultSelected=!0)}else{for(a=""+Yt(a),t=null,u=0;u<e.length;u++){if(e[u].value===a){e[u].selected=!0,l&&(e[u].defaultSelected=!0);return}t!==null||e[u].disabled||(t=e[u])}t!==null&&(t.selected=!0)}}function Td(e,t,a){if(t!=null&&(t=""+Yt(t),t!==e.value&&(e.value=t),a==null)){e.defaultValue!==t&&(e.defaultValue=t);return}e.defaultValue=a!=null?""+Yt(a):""}function Od(e,t,a,l){if(t==null){if(l!=null){if(a!=null)throw Error(s(92));if(He(l)){if(1<l.length)throw Error(s(93));l=l[0]}a=l}a==null&&(a=""),t=a}a=Yt(t),e.defaultValue=a,l=e.textContent,l===a&&l!==""&&l!==null&&(e.value=l),Uu(e)}function pi(e,t){if(t){var a=e.firstChild;if(a&&a===e.lastChild&&a.nodeType===3){a.nodeValue=t;return}}e.textContent=t}var m0=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function _d(e,t,a){var l=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?l?e.setProperty(t,""):t==="float"?e.cssFloat="":e[t]="":l?e.setProperty(t,a):typeof a!="number"||a===0||m0.has(t)?t==="float"?e.cssFloat=a:e[t]=(""+a).trim():e[t]=a+"px"}function wd(e,t,a){if(t!=null&&typeof t!="object")throw Error(s(62));if(e=e.style,a!=null){for(var l in a)!a.hasOwnProperty(l)||t!=null&&t.hasOwnProperty(l)||(l.indexOf("--")===0?e.setProperty(l,""):l==="float"?e.cssFloat="":e[l]="");for(var u in t)l=t[u],t.hasOwnProperty(u)&&a[u]!==l&&_d(e,u,l)}else for(var c in t)t.hasOwnProperty(c)&&_d(e,c,t[c])}function Lu(e){if(e.indexOf("-")===-1)return!1;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var y0=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),p0=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Hl(e){return p0.test(""+e)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":e}function Mn(){}var Hu=null;function Bu(e){return e=e.target||e.srcElement||window,e.correspondingUseElement&&(e=e.correspondingUseElement),e.nodeType===3?e.parentNode:e}var vi=null,gi=null;function Ad(e){var t=di(e);if(t&&(e=t.stateNode)){var a=e[At]||null;e:switch(e=t.stateNode,t.type){case"input":if(ku(e,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=e;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+Gt(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var l=a[t];if(l!==e&&l.form===e.form){var u=l[At]||null;if(!u)throw Error(s(90));ku(l,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name)}}for(t=0;t<a.length;t++)l=a[t],l.form===e.form&&Sd(l)}break e;case"textarea":Td(e,a.value,a.defaultValue);break e;case"select":t=a.value,t!=null&&yi(e,!!a.multiple,t,!1)}}}var Vu=!1;function Dd(e,t,a){if(Vu)return e(t,a);Vu=!0;try{var l=e(t);return l}finally{if(Vu=!1,(vi!==null||gi!==null)&&(As(),vi&&(t=vi,e=gi,gi=vi=null,Ad(t),e)))for(t=0;t<e.length;t++)Ad(e[t])}}function Er(e,t){var a=e.stateNode;if(a===null)return null;var l=a[At]||null;if(l===null)return null;a=l[t];e:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(l=!l.disabled)||(e=e.type,l=!(e==="button"||e==="input"||e==="select"||e==="textarea")),e=!l;break e;default:e=!1}if(e)return null;if(a&&typeof a!="function")throw Error(s(231,t,typeof a));return a}var Cn=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Qu=!1;if(Cn)try{var Tr={};Object.defineProperty(Tr,"passive",{get:function(){Qu=!0}}),window.addEventListener("test",Tr,Tr),window.removeEventListener("test",Tr,Tr)}catch{Qu=!1}var ta=null,Yu=null,Bl=null;function Md(){if(Bl)return Bl;var e,t=Yu,a=t.length,l,u="value"in ta?ta.value:ta.textContent,c=u.length;for(e=0;e<a&&t[e]===u[e];e++);var p=a-e;for(l=1;l<=p&&t[a-l]===u[c-l];l++);return Bl=u.slice(e,1<l?1-l:void 0)}function Vl(e){var t=e.keyCode;return"charCode"in e?(e=e.charCode,e===0&&t===13&&(e=13)):e=t,e===10&&(e=13),32<=e||e===13?e:0}function Ql(){return!0}function Cd(){return!1}function Dt(e){function t(a,l,u,c,p){this._reactName=a,this._targetInst=u,this.type=l,this.nativeEvent=c,this.target=p,this.currentTarget=null;for(var g in e)e.hasOwnProperty(g)&&(a=e[g],this[g]=a?a(c):c[g]);return this.isDefaultPrevented=(c.defaultPrevented!=null?c.defaultPrevented:c.returnValue===!1)?Ql:Cd,this.isPropagationStopped=Cd,this}return v(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=Ql)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=Ql)},persist:function(){},isPersistent:Ql}),t}var ka={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Yl=Dt(ka),Or=v({},ka,{view:0,detail:0}),v0=Dt(Or),Gu,Xu,_r,Gl=v({},Or,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Zu,button:0,buttons:0,relatedTarget:function(e){return e.relatedTarget===void 0?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==_r&&(_r&&e.type==="mousemove"?(Gu=e.screenX-_r.screenX,Xu=e.screenY-_r.screenY):Xu=Gu=0,_r=e),Gu)},movementY:function(e){return"movementY"in e?e.movementY:Xu}}),xd=Dt(Gl),g0=v({},Gl,{dataTransfer:0}),b0=Dt(g0),S0=v({},Or,{relatedTarget:0}),Fu=Dt(S0),E0=v({},ka,{animationName:0,elapsedTime:0,pseudoElement:0}),T0=Dt(E0),O0=v({},ka,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),_0=Dt(O0),w0=v({},ka,{data:0}),Rd=Dt(w0),A0={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},D0={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},M0={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function C0(e){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(e):(e=M0[e])?!!t[e]:!1}function Zu(){return C0}var x0=v({},Or,{key:function(e){if(e.key){var t=A0[e.key]||e.key;if(t!=="Unidentified")return t}return e.type==="keypress"?(e=Vl(e),e===13?"Enter":String.fromCharCode(e)):e.type==="keydown"||e.type==="keyup"?D0[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Zu,charCode:function(e){return e.type==="keypress"?Vl(e):0},keyCode:function(e){return e.type==="keydown"||e.type==="keyup"?e.keyCode:0},which:function(e){return e.type==="keypress"?Vl(e):e.type==="keydown"||e.type==="keyup"?e.keyCode:0}}),R0=Dt(x0),z0=v({},Gl,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),zd=Dt(z0),N0=v({},Or,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Zu}),j0=Dt(N0),U0=v({},ka,{propertyName:0,elapsedTime:0,pseudoElement:0}),k0=Dt(U0),q0=v({},Gl,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),L0=Dt(q0),H0=v({},ka,{newState:0,oldState:0}),B0=Dt(H0),V0=[9,13,27,32],Ju=Cn&&"CompositionEvent"in window,wr=null;Cn&&"documentMode"in document&&(wr=document.documentMode);var Q0=Cn&&"TextEvent"in window&&!wr,Nd=Cn&&(!Ju||wr&&8<wr&&11>=wr),jd=" ",Ud=!1;function kd(e,t){switch(e){case"keyup":return V0.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function qd(e){return e=e.detail,typeof e=="object"&&"data"in e?e.data:null}var bi=!1;function Y0(e,t){switch(e){case"compositionend":return qd(t);case"keypress":return t.which!==32?null:(Ud=!0,jd);case"textInput":return e=t.data,e===jd&&Ud?null:e;default:return null}}function G0(e,t){if(bi)return e==="compositionend"||!Ju&&kd(e,t)?(e=Md(),Bl=Yu=ta=null,bi=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Nd&&t.locale!=="ko"?null:t.data;default:return null}}var X0={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Ld(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t==="input"?!!X0[e.type]:t==="textarea"}function Hd(e,t,a,l){vi?gi?gi.push(l):gi=[l]:vi=l,t=Ns(t,"onChange"),0<t.length&&(a=new Yl("onChange","change",null,a,l),e.push({event:a,listeners:t}))}var Ar=null,Dr=null;function F0(e){Ey(e,0)}function Xl(e){var t=Sr(e);if(Sd(t))return e}function Bd(e,t){if(e==="change")return t}var Vd=!1;if(Cn){var Ku;if(Cn){var Iu="oninput"in document;if(!Iu){var Qd=document.createElement("div");Qd.setAttribute("oninput","return;"),Iu=typeof Qd.oninput=="function"}Ku=Iu}else Ku=!1;Vd=Ku&&(!document.documentMode||9<document.documentMode)}function Yd(){Ar&&(Ar.detachEvent("onpropertychange",Gd),Dr=Ar=null)}function Gd(e){if(e.propertyName==="value"&&Xl(Dr)){var t=[];Hd(t,Dr,e,Bu(e)),Dd(F0,t)}}function Z0(e,t,a){e==="focusin"?(Yd(),Ar=t,Dr=a,Ar.attachEvent("onpropertychange",Gd)):e==="focusout"&&Yd()}function J0(e){if(e==="selectionchange"||e==="keyup"||e==="keydown")return Xl(Dr)}function K0(e,t){if(e==="click")return Xl(t)}function I0(e,t){if(e==="input"||e==="change")return Xl(t)}function $0(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var kt=typeof Object.is=="function"?Object.is:$0;function Mr(e,t){if(kt(e,t))return!0;if(typeof e!="object"||e===null||typeof t!="object"||t===null)return!1;var a=Object.keys(e),l=Object.keys(t);if(a.length!==l.length)return!1;for(l=0;l<a.length;l++){var u=a[l];if(!Ut.call(t,u)||!kt(e[u],t[u]))return!1}return!0}function Xd(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function Fd(e,t){var a=Xd(e);e=0;for(var l;a;){if(a.nodeType===3){if(l=e+a.textContent.length,e<=t&&l>=t)return{node:a,offset:t-e};e=l}e:{for(;a;){if(a.nextSibling){a=a.nextSibling;break e}a=a.parentNode}a=void 0}a=Xd(a)}}function Zd(e,t){return e&&t?e===t?!0:e&&e.nodeType===3?!1:t&&t.nodeType===3?Zd(e,t.parentNode):"contains"in e?e.contains(t):e.compareDocumentPosition?!!(e.compareDocumentPosition(t)&16):!1:!1}function Jd(e){e=e!=null&&e.ownerDocument!=null&&e.ownerDocument.defaultView!=null?e.ownerDocument.defaultView:window;for(var t=Ll(e.document);t instanceof e.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)e=t.contentWindow;else break;t=Ll(e.document)}return t}function $u(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t&&(t==="input"&&(e.type==="text"||e.type==="search"||e.type==="tel"||e.type==="url"||e.type==="password")||t==="textarea"||e.contentEditable==="true")}var W0=Cn&&"documentMode"in document&&11>=document.documentMode,Si=null,Wu=null,Cr=null,Pu=!1;function Kd(e,t,a){var l=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Pu||Si==null||Si!==Ll(l)||(l=Si,"selectionStart"in l&&$u(l)?l={start:l.selectionStart,end:l.selectionEnd}:(l=(l.ownerDocument&&l.ownerDocument.defaultView||window).getSelection(),l={anchorNode:l.anchorNode,anchorOffset:l.anchorOffset,focusNode:l.focusNode,focusOffset:l.focusOffset}),Cr&&Mr(Cr,l)||(Cr=l,l=Ns(Wu,"onSelect"),0<l.length&&(t=new Yl("onSelect","select",null,t,a),e.push({event:t,listeners:l}),t.target=Si)))}function qa(e,t){var a={};return a[e.toLowerCase()]=t.toLowerCase(),a["Webkit"+e]="webkit"+t,a["Moz"+e]="moz"+t,a}var Ei={animationend:qa("Animation","AnimationEnd"),animationiteration:qa("Animation","AnimationIteration"),animationstart:qa("Animation","AnimationStart"),transitionrun:qa("Transition","TransitionRun"),transitionstart:qa("Transition","TransitionStart"),transitioncancel:qa("Transition","TransitionCancel"),transitionend:qa("Transition","TransitionEnd")},eo={},Id={};Cn&&(Id=document.createElement("div").style,"AnimationEvent"in window||(delete Ei.animationend.animation,delete Ei.animationiteration.animation,delete Ei.animationstart.animation),"TransitionEvent"in window||delete Ei.transitionend.transition);function La(e){if(eo[e])return eo[e];if(!Ei[e])return e;var t=Ei[e],a;for(a in t)if(t.hasOwnProperty(a)&&a in Id)return eo[e]=t[a];return e}var $d=La("animationend"),Wd=La("animationiteration"),Pd=La("animationstart"),P0=La("transitionrun"),eb=La("transitionstart"),tb=La("transitioncancel"),eh=La("transitionend"),th=new Map,to="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");to.push("scrollEnd");function ln(e,t){th.set(e,t),Ua(t,[e])}var Fl=typeof reportError=="function"?reportError:function(e){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof e=="object"&&e!==null&&typeof e.message=="string"?String(e.message):String(e),error:e});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",e);return}console.error(e)},Xt=[],Ti=0,no=0;function Zl(){for(var e=Ti,t=no=Ti=0;t<e;){var a=Xt[t];Xt[t++]=null;var l=Xt[t];Xt[t++]=null;var u=Xt[t];Xt[t++]=null;var c=Xt[t];if(Xt[t++]=null,l!==null&&u!==null){var p=l.pending;p===null?u.next=u:(u.next=p.next,p.next=u),l.pending=u}c!==0&&nh(a,u,c)}}function Jl(e,t,a,l){Xt[Ti++]=e,Xt[Ti++]=t,Xt[Ti++]=a,Xt[Ti++]=l,no|=l,e.lanes|=l,e=e.alternate,e!==null&&(e.lanes|=l)}function ao(e,t,a,l){return Jl(e,t,a,l),Kl(e)}function Ha(e,t){return Jl(e,null,null,t),Kl(e)}function nh(e,t,a){e.lanes|=a;var l=e.alternate;l!==null&&(l.lanes|=a);for(var u=!1,c=e.return;c!==null;)c.childLanes|=a,l=c.alternate,l!==null&&(l.childLanes|=a),c.tag===22&&(e=c.stateNode,e===null||e._visibility&1||(u=!0)),e=c,c=c.return;return e.tag===3?(c=e.stateNode,u&&t!==null&&(u=31-yt(a),e=c.hiddenUpdates,l=e[u],l===null?e[u]=[t]:l.push(t),t.lane=a|536870912),c):null}function Kl(e){if(50<$r)throw $r=0,hc=null,Error(s(185));for(var t=e.return;t!==null;)e=t,t=e.return;return e.tag===3?e.stateNode:null}var Oi={};function nb(e,t,a,l){this.tag=e,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=l,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function qt(e,t,a,l){return new nb(e,t,a,l)}function io(e){return e=e.prototype,!(!e||!e.isReactComponent)}function xn(e,t){var a=e.alternate;return a===null?(a=qt(e.tag,t,e.key,e.mode),a.elementType=e.elementType,a.type=e.type,a.stateNode=e.stateNode,a.alternate=e,e.alternate=a):(a.pendingProps=t,a.type=e.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=e.flags&65011712,a.childLanes=e.childLanes,a.lanes=e.lanes,a.child=e.child,a.memoizedProps=e.memoizedProps,a.memoizedState=e.memoizedState,a.updateQueue=e.updateQueue,t=e.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=e.sibling,a.index=e.index,a.ref=e.ref,a.refCleanup=e.refCleanup,a}function ah(e,t){e.flags&=65011714;var a=e.alternate;return a===null?(e.childLanes=0,e.lanes=t,e.child=null,e.subtreeFlags=0,e.memoizedProps=null,e.memoizedState=null,e.updateQueue=null,e.dependencies=null,e.stateNode=null):(e.childLanes=a.childLanes,e.lanes=a.lanes,e.child=a.child,e.subtreeFlags=0,e.deletions=null,e.memoizedProps=a.memoizedProps,e.memoizedState=a.memoizedState,e.updateQueue=a.updateQueue,e.type=a.type,t=a.dependencies,e.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),e}function Il(e,t,a,l,u,c){var p=0;if(l=e,typeof e=="function")io(e)&&(p=1);else if(typeof e=="string")p=sS(e,a,G.current)?26:e==="html"||e==="head"||e==="body"?27:5;else e:switch(e){case rt:return e=qt(31,a,t,u),e.elementType=rt,e.lanes=c,e;case N:return Ba(a.children,u,c,t);case M:p=8,u|=24;break;case D:return e=qt(12,a,t,u|2),e.elementType=D,e.lanes=c,e;case K:return e=qt(13,a,t,u),e.elementType=K,e.lanes=c,e;case ee:return e=qt(19,a,t,u),e.elementType=ee,e.lanes=c,e;default:if(typeof e=="object"&&e!==null)switch(e.$$typeof){case Y:p=10;break e;case U:p=9;break e;case X:p=11;break e;case $:p=14;break e;case we:p=16,l=null;break e}p=29,a=Error(s(130,e===null?"null":typeof e,"")),l=null}return t=qt(p,a,t,u),t.elementType=e,t.type=l,t.lanes=c,t}function Ba(e,t,a,l){return e=qt(7,e,l,t),e.lanes=a,e}function ro(e,t,a){return e=qt(6,e,null,t),e.lanes=a,e}function ih(e){var t=qt(18,null,null,0);return t.stateNode=e,t}function lo(e,t,a){return t=qt(4,e.children!==null?e.children:[],e.key,t),t.lanes=a,t.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},t}var rh=new WeakMap;function Ft(e,t){if(typeof e=="object"&&e!==null){var a=rh.get(e);return a!==void 0?a:(t={value:e,source:t,stack:mr(t)},rh.set(e,t),t)}return{value:e,source:t,stack:mr(t)}}var _i=[],wi=0,$l=null,xr=0,Zt=[],Jt=0,na=null,pn=1,vn="";function Rn(e,t){_i[wi++]=xr,_i[wi++]=$l,$l=e,xr=t}function lh(e,t,a){Zt[Jt++]=pn,Zt[Jt++]=vn,Zt[Jt++]=na,na=e;var l=pn;e=vn;var u=32-yt(l)-1;l&=~(1<<u),a+=1;var c=32-yt(t)+u;if(30<c){var p=u-u%5;c=(l&(1<<p)-1).toString(32),l>>=p,u-=p,pn=1<<32-yt(t)+u|a<<u|l,vn=c+e}else pn=1<<c|a<<u|l,vn=e}function so(e){e.return!==null&&(Rn(e,1),lh(e,1,0))}function uo(e){for(;e===$l;)$l=_i[--wi],_i[wi]=null,xr=_i[--wi],_i[wi]=null;for(;e===na;)na=Zt[--Jt],Zt[Jt]=null,vn=Zt[--Jt],Zt[Jt]=null,pn=Zt[--Jt],Zt[Jt]=null}function sh(e,t){Zt[Jt++]=pn,Zt[Jt++]=vn,Zt[Jt++]=na,pn=t.id,vn=t.overflow,na=e}var st=null,je=null,Ee=!1,aa=null,Kt=!1,oo=Error(s(519));function ia(e){var t=Error(s(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Rr(Ft(t,e)),oo}function uh(e){var t=e.stateNode,a=e.type,l=e.memoizedProps;switch(t[lt]=e,t[At]=l,a){case"dialog":ye("cancel",t),ye("close",t);break;case"iframe":case"object":case"embed":ye("load",t);break;case"video":case"audio":for(a=0;a<Pr.length;a++)ye(Pr[a],t);break;case"source":ye("error",t);break;case"img":case"image":case"link":ye("error",t),ye("load",t);break;case"details":ye("toggle",t);break;case"input":ye("invalid",t),Ed(t,l.value,l.defaultValue,l.checked,l.defaultChecked,l.type,l.name,!0);break;case"select":ye("invalid",t);break;case"textarea":ye("invalid",t),Od(t,l.value,l.defaultValue,l.children)}a=l.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||l.suppressHydrationWarning===!0||wy(t.textContent,a)?(l.popover!=null&&(ye("beforetoggle",t),ye("toggle",t)),l.onScroll!=null&&ye("scroll",t),l.onScrollEnd!=null&&ye("scrollend",t),l.onClick!=null&&(t.onclick=Mn),t=!0):t=!1,t||ia(e,!0)}function oh(e){for(st=e.return;st;)switch(st.tag){case 5:case 31:case 13:Kt=!1;return;case 27:case 3:Kt=!0;return;default:st=st.return}}function Ai(e){if(e!==st)return!1;if(!Ee)return oh(e),Ee=!0,!1;var t=e.tag,a;if((a=t!==3&&t!==27)&&((a=t===5)&&(a=e.type,a=!(a!=="form"&&a!=="button")||Mc(e.type,e.memoizedProps)),a=!a),a&&je&&ia(e),oh(e),t===13){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(s(317));je=jy(e)}else if(t===31){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(s(317));je=jy(e)}else t===27?(t=je,ga(e.type)?(e=Nc,Nc=null,je=e):je=t):je=st?$t(e.stateNode.nextSibling):null;return!0}function Va(){je=st=null,Ee=!1}function co(){var e=aa;return e!==null&&(Rt===null?Rt=e:Rt.push.apply(Rt,e),aa=null),e}function Rr(e){aa===null?aa=[e]:aa.push(e)}var fo=_(null),Qa=null,zn=null;function ra(e,t,a){V(fo,t._currentValue),t._currentValue=a}function Nn(e){e._currentValue=fo.current,L(fo)}function ho(e,t,a){for(;e!==null;){var l=e.alternate;if((e.childLanes&t)!==t?(e.childLanes|=t,l!==null&&(l.childLanes|=t)):l!==null&&(l.childLanes&t)!==t&&(l.childLanes|=t),e===a)break;e=e.return}}function mo(e,t,a,l){var u=e.child;for(u!==null&&(u.return=e);u!==null;){var c=u.dependencies;if(c!==null){var p=u.child;c=c.firstContext;e:for(;c!==null;){var g=c;c=u;for(var T=0;T<t.length;T++)if(g.context===t[T]){c.lanes|=a,g=c.alternate,g!==null&&(g.lanes|=a),ho(c.return,a,e),l||(p=null);break e}c=g.next}}else if(u.tag===18){if(p=u.return,p===null)throw Error(s(341));p.lanes|=a,c=p.alternate,c!==null&&(c.lanes|=a),ho(p,a,e),p=null}else p=u.child;if(p!==null)p.return=u;else for(p=u;p!==null;){if(p===e){p=null;break}if(u=p.sibling,u!==null){u.return=p.return,p=u;break}p=p.return}u=p}}function Di(e,t,a,l){e=null;for(var u=t,c=!1;u!==null;){if(!c){if((u.flags&524288)!==0)c=!0;else if((u.flags&262144)!==0)break}if(u.tag===10){var p=u.alternate;if(p===null)throw Error(s(387));if(p=p.memoizedProps,p!==null){var g=u.type;kt(u.pendingProps.value,p.value)||(e!==null?e.push(g):e=[g])}}else if(u===he.current){if(p=u.alternate,p===null)throw Error(s(387));p.memoizedState.memoizedState!==u.memoizedState.memoizedState&&(e!==null?e.push(il):e=[il])}u=u.return}e!==null&&mo(t,e,a,l),t.flags|=262144}function Wl(e){for(e=e.firstContext;e!==null;){if(!kt(e.context._currentValue,e.memoizedValue))return!0;e=e.next}return!1}function Ya(e){Qa=e,zn=null,e=e.dependencies,e!==null&&(e.firstContext=null)}function ut(e){return ch(Qa,e)}function Pl(e,t){return Qa===null&&Ya(e),ch(e,t)}function ch(e,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},zn===null){if(e===null)throw Error(s(308));zn=t,e.dependencies={lanes:0,firstContext:t},e.flags|=524288}else zn=zn.next=t;return a}var ab=typeof AbortController<"u"?AbortController:function(){var e=[],t=this.signal={aborted:!1,addEventListener:function(a,l){e.push(l)}};this.abort=function(){t.aborted=!0,e.forEach(function(a){return a()})}},ib=i.unstable_scheduleCallback,rb=i.unstable_NormalPriority,Ze={$$typeof:Y,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function yo(){return{controller:new ab,data:new Map,refCount:0}}function zr(e){e.refCount--,e.refCount===0&&ib(rb,function(){e.controller.abort()})}var Nr=null,po=0,Mi=0,Ci=null;function lb(e,t){if(Nr===null){var a=Nr=[];po=0,Mi=bc(),Ci={status:"pending",value:void 0,then:function(l){a.push(l)}}}return po++,t.then(fh,fh),t}function fh(){if(--po===0&&Nr!==null){Ci!==null&&(Ci.status="fulfilled");var e=Nr;Nr=null,Mi=0,Ci=null;for(var t=0;t<e.length;t++)(0,e[t])()}}function sb(e,t){var a=[],l={status:"pending",value:null,reason:null,then:function(u){a.push(u)}};return e.then(function(){l.status="fulfilled",l.value=t;for(var u=0;u<a.length;u++)(0,a[u])(t)},function(u){for(l.status="rejected",l.reason=u,u=0;u<a.length;u++)(0,a[u])(void 0)}),l}var dh=R.S;R.S=function(e,t){Km=St(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&lb(e,t),dh!==null&&dh(e,t)};var Ga=_(null);function vo(){var e=Ga.current;return e!==null?e:Ne.pooledCache}function es(e,t){t===null?V(Ga,Ga.current):V(Ga,t.pool)}function hh(){var e=vo();return e===null?null:{parent:Ze._currentValue,pool:e}}var xi=Error(s(460)),go=Error(s(474)),ts=Error(s(542)),ns={then:function(){}};function mh(e){return e=e.status,e==="fulfilled"||e==="rejected"}function yh(e,t,a){switch(a=e[a],a===void 0?e.push(t):a!==t&&(t.then(Mn,Mn),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,vh(e),e;default:if(typeof t.status=="string")t.then(Mn,Mn);else{if(e=Ne,e!==null&&100<e.shellSuspendCounter)throw Error(s(482));e=t,e.status="pending",e.then(function(l){if(t.status==="pending"){var u=t;u.status="fulfilled",u.value=l}},function(l){if(t.status==="pending"){var u=t;u.status="rejected",u.reason=l}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,vh(e),e}throw Fa=t,xi}}function Xa(e){try{var t=e._init;return t(e._payload)}catch(a){throw a!==null&&typeof a=="object"&&typeof a.then=="function"?(Fa=a,xi):a}}var Fa=null;function ph(){if(Fa===null)throw Error(s(459));var e=Fa;return Fa=null,e}function vh(e){if(e===xi||e===ts)throw Error(s(483))}var Ri=null,jr=0;function as(e){var t=jr;return jr+=1,Ri===null&&(Ri=[]),yh(Ri,e,t)}function Ur(e,t){t=t.props.ref,e.ref=t!==void 0?t:null}function is(e,t){throw t.$$typeof===E?Error(s(525)):(e=Object.prototype.toString.call(t),Error(s(31,e==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":e)))}function gh(e){function t(A,w){if(e){var C=A.deletions;C===null?(A.deletions=[w],A.flags|=16):C.push(w)}}function a(A,w){if(!e)return null;for(;w!==null;)t(A,w),w=w.sibling;return null}function l(A){for(var w=new Map;A!==null;)A.key!==null?w.set(A.key,A):w.set(A.index,A),A=A.sibling;return w}function u(A,w){return A=xn(A,w),A.index=0,A.sibling=null,A}function c(A,w,C){return A.index=C,e?(C=A.alternate,C!==null?(C=C.index,C<w?(A.flags|=67108866,w):C):(A.flags|=67108866,w)):(A.flags|=1048576,w)}function p(A){return e&&A.alternate===null&&(A.flags|=67108866),A}function g(A,w,C,q){return w===null||w.tag!==6?(w=ro(C,A.mode,q),w.return=A,w):(w=u(w,C),w.return=A,w)}function T(A,w,C,q){var P=C.type;return P===N?k(A,w,C.props.children,q,C.key):w!==null&&(w.elementType===P||typeof P=="object"&&P!==null&&P.$$typeof===we&&Xa(P)===w.type)?(w=u(w,C.props),Ur(w,C),w.return=A,w):(w=Il(C.type,C.key,C.props,null,A.mode,q),Ur(w,C),w.return=A,w)}function x(A,w,C,q){return w===null||w.tag!==4||w.stateNode.containerInfo!==C.containerInfo||w.stateNode.implementation!==C.implementation?(w=lo(C,A.mode,q),w.return=A,w):(w=u(w,C.children||[]),w.return=A,w)}function k(A,w,C,q,P){return w===null||w.tag!==7?(w=Ba(C,A.mode,q,P),w.return=A,w):(w=u(w,C),w.return=A,w)}function H(A,w,C){if(typeof w=="string"&&w!==""||typeof w=="number"||typeof w=="bigint")return w=ro(""+w,A.mode,C),w.return=A,w;if(typeof w=="object"&&w!==null){switch(w.$$typeof){case S:return C=Il(w.type,w.key,w.props,null,A.mode,C),Ur(C,w),C.return=A,C;case O:return w=lo(w,A.mode,C),w.return=A,w;case we:return w=Xa(w),H(A,w,C)}if(He(w)||ae(w))return w=Ba(w,A.mode,C,null),w.return=A,w;if(typeof w.then=="function")return H(A,as(w),C);if(w.$$typeof===Y)return H(A,Pl(A,w),C);is(A,w)}return null}function z(A,w,C,q){var P=w!==null?w.key:null;if(typeof C=="string"&&C!==""||typeof C=="number"||typeof C=="bigint")return P!==null?null:g(A,w,""+C,q);if(typeof C=="object"&&C!==null){switch(C.$$typeof){case S:return C.key===P?T(A,w,C,q):null;case O:return C.key===P?x(A,w,C,q):null;case we:return C=Xa(C),z(A,w,C,q)}if(He(C)||ae(C))return P!==null?null:k(A,w,C,q,null);if(typeof C.then=="function")return z(A,w,as(C),q);if(C.$$typeof===Y)return z(A,w,Pl(A,C),q);is(A,C)}return null}function j(A,w,C,q,P){if(typeof q=="string"&&q!==""||typeof q=="number"||typeof q=="bigint")return A=A.get(C)||null,g(w,A,""+q,P);if(typeof q=="object"&&q!==null){switch(q.$$typeof){case S:return A=A.get(q.key===null?C:q.key)||null,T(w,A,q,P);case O:return A=A.get(q.key===null?C:q.key)||null,x(w,A,q,P);case we:return q=Xa(q),j(A,w,C,q,P)}if(He(q)||ae(q))return A=A.get(C)||null,k(w,A,q,P,null);if(typeof q.then=="function")return j(A,w,C,as(q),P);if(q.$$typeof===Y)return j(A,w,C,Pl(w,q),P);is(w,q)}return null}function J(A,w,C,q){for(var P=null,Oe=null,I=w,oe=w=0,ge=null;I!==null&&oe<C.length;oe++){I.index>oe?(ge=I,I=null):ge=I.sibling;var _e=z(A,I,C[oe],q);if(_e===null){I===null&&(I=ge);break}e&&I&&_e.alternate===null&&t(A,I),w=c(_e,w,oe),Oe===null?P=_e:Oe.sibling=_e,Oe=_e,I=ge}if(oe===C.length)return a(A,I),Ee&&Rn(A,oe),P;if(I===null){for(;oe<C.length;oe++)I=H(A,C[oe],q),I!==null&&(w=c(I,w,oe),Oe===null?P=I:Oe.sibling=I,Oe=I);return Ee&&Rn(A,oe),P}for(I=l(I);oe<C.length;oe++)ge=j(I,A,oe,C[oe],q),ge!==null&&(e&&ge.alternate!==null&&I.delete(ge.key===null?oe:ge.key),w=c(ge,w,oe),Oe===null?P=ge:Oe.sibling=ge,Oe=ge);return e&&I.forEach(function(Oa){return t(A,Oa)}),Ee&&Rn(A,oe),P}function te(A,w,C,q){if(C==null)throw Error(s(151));for(var P=null,Oe=null,I=w,oe=w=0,ge=null,_e=C.next();I!==null&&!_e.done;oe++,_e=C.next()){I.index>oe?(ge=I,I=null):ge=I.sibling;var Oa=z(A,I,_e.value,q);if(Oa===null){I===null&&(I=ge);break}e&&I&&Oa.alternate===null&&t(A,I),w=c(Oa,w,oe),Oe===null?P=Oa:Oe.sibling=Oa,Oe=Oa,I=ge}if(_e.done)return a(A,I),Ee&&Rn(A,oe),P;if(I===null){for(;!_e.done;oe++,_e=C.next())_e=H(A,_e.value,q),_e!==null&&(w=c(_e,w,oe),Oe===null?P=_e:Oe.sibling=_e,Oe=_e);return Ee&&Rn(A,oe),P}for(I=l(I);!_e.done;oe++,_e=C.next())_e=j(I,A,oe,_e.value,q),_e!==null&&(e&&_e.alternate!==null&&I.delete(_e.key===null?oe:_e.key),w=c(_e,w,oe),Oe===null?P=_e:Oe.sibling=_e,Oe=_e);return e&&I.forEach(function(gS){return t(A,gS)}),Ee&&Rn(A,oe),P}function ze(A,w,C,q){if(typeof C=="object"&&C!==null&&C.type===N&&C.key===null&&(C=C.props.children),typeof C=="object"&&C!==null){switch(C.$$typeof){case S:e:{for(var P=C.key;w!==null;){if(w.key===P){if(P=C.type,P===N){if(w.tag===7){a(A,w.sibling),q=u(w,C.props.children),q.return=A,A=q;break e}}else if(w.elementType===P||typeof P=="object"&&P!==null&&P.$$typeof===we&&Xa(P)===w.type){a(A,w.sibling),q=u(w,C.props),Ur(q,C),q.return=A,A=q;break e}a(A,w);break}else t(A,w);w=w.sibling}C.type===N?(q=Ba(C.props.children,A.mode,q,C.key),q.return=A,A=q):(q=Il(C.type,C.key,C.props,null,A.mode,q),Ur(q,C),q.return=A,A=q)}return p(A);case O:e:{for(P=C.key;w!==null;){if(w.key===P)if(w.tag===4&&w.stateNode.containerInfo===C.containerInfo&&w.stateNode.implementation===C.implementation){a(A,w.sibling),q=u(w,C.children||[]),q.return=A,A=q;break e}else{a(A,w);break}else t(A,w);w=w.sibling}q=lo(C,A.mode,q),q.return=A,A=q}return p(A);case we:return C=Xa(C),ze(A,w,C,q)}if(He(C))return J(A,w,C,q);if(ae(C)){if(P=ae(C),typeof P!="function")throw Error(s(150));return C=P.call(C),te(A,w,C,q)}if(typeof C.then=="function")return ze(A,w,as(C),q);if(C.$$typeof===Y)return ze(A,w,Pl(A,C),q);is(A,C)}return typeof C=="string"&&C!==""||typeof C=="number"||typeof C=="bigint"?(C=""+C,w!==null&&w.tag===6?(a(A,w.sibling),q=u(w,C),q.return=A,A=q):(a(A,w),q=ro(C,A.mode,q),q.return=A,A=q),p(A)):a(A,w)}return function(A,w,C,q){try{jr=0;var P=ze(A,w,C,q);return Ri=null,P}catch(I){if(I===xi||I===ts)throw I;var Oe=qt(29,I,null,A.mode);return Oe.lanes=q,Oe.return=A,Oe}finally{}}}var Za=gh(!0),bh=gh(!1),la=!1;function bo(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function So(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,callbacks:null})}function sa(e){return{lane:e,tag:0,payload:null,callback:null,next:null}}function ua(e,t,a){var l=e.updateQueue;if(l===null)return null;if(l=l.shared,(Ae&2)!==0){var u=l.pending;return u===null?t.next=t:(t.next=u.next,u.next=t),l.pending=t,t=Kl(e),nh(e,null,a),t}return Jl(e,l,t,a),Kl(e)}function kr(e,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194048)!==0)){var l=t.lanes;l&=e.pendingLanes,a|=l,t.lanes=a,_t(e,a)}}function Eo(e,t){var a=e.updateQueue,l=e.alternate;if(l!==null&&(l=l.updateQueue,a===l)){var u=null,c=null;if(a=a.firstBaseUpdate,a!==null){do{var p={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};c===null?u=c=p:c=c.next=p,a=a.next}while(a!==null);c===null?u=c=t:c=c.next=t}else u=c=t;a={baseState:l.baseState,firstBaseUpdate:u,lastBaseUpdate:c,shared:l.shared,callbacks:l.callbacks},e.updateQueue=a;return}e=a.lastBaseUpdate,e===null?a.firstBaseUpdate=t:e.next=t,a.lastBaseUpdate=t}var To=!1;function qr(){if(To){var e=Ci;if(e!==null)throw e}}function Lr(e,t,a,l){To=!1;var u=e.updateQueue;la=!1;var c=u.firstBaseUpdate,p=u.lastBaseUpdate,g=u.shared.pending;if(g!==null){u.shared.pending=null;var T=g,x=T.next;T.next=null,p===null?c=x:p.next=x,p=T;var k=e.alternate;k!==null&&(k=k.updateQueue,g=k.lastBaseUpdate,g!==p&&(g===null?k.firstBaseUpdate=x:g.next=x,k.lastBaseUpdate=T))}if(c!==null){var H=u.baseState;p=0,k=x=T=null,g=c;do{var z=g.lane&-536870913,j=z!==g.lane;if(j?(ve&z)===z:(l&z)===z){z!==0&&z===Mi&&(To=!0),k!==null&&(k=k.next={lane:0,tag:g.tag,payload:g.payload,callback:null,next:null});e:{var J=e,te=g;z=t;var ze=a;switch(te.tag){case 1:if(J=te.payload,typeof J=="function"){H=J.call(ze,H,z);break e}H=J;break e;case 3:J.flags=J.flags&-65537|128;case 0:if(J=te.payload,z=typeof J=="function"?J.call(ze,H,z):J,z==null)break e;H=v({},H,z);break e;case 2:la=!0}}z=g.callback,z!==null&&(e.flags|=64,j&&(e.flags|=8192),j=u.callbacks,j===null?u.callbacks=[z]:j.push(z))}else j={lane:z,tag:g.tag,payload:g.payload,callback:g.callback,next:null},k===null?(x=k=j,T=H):k=k.next=j,p|=z;if(g=g.next,g===null){if(g=u.shared.pending,g===null)break;j=g,g=j.next,j.next=null,u.lastBaseUpdate=j,u.shared.pending=null}}while(!0);k===null&&(T=H),u.baseState=T,u.firstBaseUpdate=x,u.lastBaseUpdate=k,c===null&&(u.shared.lanes=0),ha|=p,e.lanes=p,e.memoizedState=H}}function Sh(e,t){if(typeof e!="function")throw Error(s(191,e));e.call(t)}function Eh(e,t){var a=e.callbacks;if(a!==null)for(e.callbacks=null,e=0;e<a.length;e++)Sh(a[e],t)}var zi=_(null),rs=_(0);function Th(e,t){e=Qn,V(rs,e),V(zi,t),Qn=e|t.baseLanes}function Oo(){V(rs,Qn),V(zi,zi.current)}function _o(){Qn=rs.current,L(zi),L(rs)}var Lt=_(null),It=null;function oa(e){var t=e.alternate;V(Ge,Ge.current&1),V(Lt,e),It===null&&(t===null||zi.current!==null||t.memoizedState!==null)&&(It=e)}function wo(e){V(Ge,Ge.current),V(Lt,e),It===null&&(It=e)}function Oh(e){e.tag===22?(V(Ge,Ge.current),V(Lt,e),It===null&&(It=e)):ca()}function ca(){V(Ge,Ge.current),V(Lt,Lt.current)}function Ht(e){L(Lt),It===e&&(It=null),L(Ge)}var Ge=_(0);function ls(e){for(var t=e;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||Rc(a)||zc(a)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var jn=0,ue=null,xe=null,Je=null,ss=!1,Ni=!1,Ja=!1,us=0,Hr=0,ji=null,ub=0;function Ve(){throw Error(s(321))}function Ao(e,t){if(t===null)return!1;for(var a=0;a<t.length&&a<e.length;a++)if(!kt(e[a],t[a]))return!1;return!0}function Do(e,t,a,l,u,c){return jn=c,ue=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,R.H=e===null||e.memoizedState===null?lm:Qo,Ja=!1,c=a(l,u),Ja=!1,Ni&&(c=wh(t,a,l,u)),_h(e),c}function _h(e){R.H=Qr;var t=xe!==null&&xe.next!==null;if(jn=0,Je=xe=ue=null,ss=!1,Hr=0,ji=null,t)throw Error(s(300));e===null||Ke||(e=e.dependencies,e!==null&&Wl(e)&&(Ke=!0))}function wh(e,t,a,l){ue=e;var u=0;do{if(Ni&&(ji=null),Hr=0,Ni=!1,25<=u)throw Error(s(301));if(u+=1,Je=xe=null,e.updateQueue!=null){var c=e.updateQueue;c.lastEffect=null,c.events=null,c.stores=null,c.memoCache!=null&&(c.memoCache.index=0)}R.H=sm,c=t(a,l)}while(Ni);return c}function ob(){var e=R.H,t=e.useState()[0];return t=typeof t.then=="function"?Br(t):t,e=e.useState()[0],(xe!==null?xe.memoizedState:null)!==e&&(ue.flags|=1024),t}function Mo(){var e=us!==0;return us=0,e}function Co(e,t,a){t.updateQueue=e.updateQueue,t.flags&=-2053,e.lanes&=~a}function xo(e){if(ss){for(e=e.memoizedState;e!==null;){var t=e.queue;t!==null&&(t.pending=null),e=e.next}ss=!1}jn=0,Je=xe=ue=null,Ni=!1,Hr=us=0,ji=null}function Tt(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Je===null?ue.memoizedState=Je=e:Je=Je.next=e,Je}function Xe(){if(xe===null){var e=ue.alternate;e=e!==null?e.memoizedState:null}else e=xe.next;var t=Je===null?ue.memoizedState:Je.next;if(t!==null)Je=t,xe=e;else{if(e===null)throw ue.alternate===null?Error(s(467)):Error(s(310));xe=e,e={memoizedState:xe.memoizedState,baseState:xe.baseState,baseQueue:xe.baseQueue,queue:xe.queue,next:null},Je===null?ue.memoizedState=Je=e:Je=Je.next=e}return Je}function os(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Br(e){var t=Hr;return Hr+=1,ji===null&&(ji=[]),e=yh(ji,e,t),t=ue,(Je===null?t.memoizedState:Je.next)===null&&(t=t.alternate,R.H=t===null||t.memoizedState===null?lm:Qo),e}function cs(e){if(e!==null&&typeof e=="object"){if(typeof e.then=="function")return Br(e);if(e.$$typeof===Y)return ut(e)}throw Error(s(438,String(e)))}function Ro(e){var t=null,a=ue.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var l=ue.alternate;l!==null&&(l=l.updateQueue,l!==null&&(l=l.memoCache,l!=null&&(t={data:l.data.map(function(u){return u.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=os(),ue.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(e),l=0;l<e;l++)a[l]=dt;return t.index++,a}function Un(e,t){return typeof t=="function"?t(e):t}function fs(e){var t=Xe();return zo(t,xe,e)}function zo(e,t,a){var l=e.queue;if(l===null)throw Error(s(311));l.lastRenderedReducer=a;var u=e.baseQueue,c=l.pending;if(c!==null){if(u!==null){var p=u.next;u.next=c.next,c.next=p}t.baseQueue=u=c,l.pending=null}if(c=e.baseState,u===null)e.memoizedState=c;else{t=u.next;var g=p=null,T=null,x=t,k=!1;do{var H=x.lane&-536870913;if(H!==x.lane?(ve&H)===H:(jn&H)===H){var z=x.revertLane;if(z===0)T!==null&&(T=T.next={lane:0,revertLane:0,gesture:null,action:x.action,hasEagerState:x.hasEagerState,eagerState:x.eagerState,next:null}),H===Mi&&(k=!0);else if((jn&z)===z){x=x.next,z===Mi&&(k=!0);continue}else H={lane:0,revertLane:x.revertLane,gesture:null,action:x.action,hasEagerState:x.hasEagerState,eagerState:x.eagerState,next:null},T===null?(g=T=H,p=c):T=T.next=H,ue.lanes|=z,ha|=z;H=x.action,Ja&&a(c,H),c=x.hasEagerState?x.eagerState:a(c,H)}else z={lane:H,revertLane:x.revertLane,gesture:x.gesture,action:x.action,hasEagerState:x.hasEagerState,eagerState:x.eagerState,next:null},T===null?(g=T=z,p=c):T=T.next=z,ue.lanes|=H,ha|=H;x=x.next}while(x!==null&&x!==t);if(T===null?p=c:T.next=g,!kt(c,e.memoizedState)&&(Ke=!0,k&&(a=Ci,a!==null)))throw a;e.memoizedState=c,e.baseState=p,e.baseQueue=T,l.lastRenderedState=c}return u===null&&(l.lanes=0),[e.memoizedState,l.dispatch]}function No(e){var t=Xe(),a=t.queue;if(a===null)throw Error(s(311));a.lastRenderedReducer=e;var l=a.dispatch,u=a.pending,c=t.memoizedState;if(u!==null){a.pending=null;var p=u=u.next;do c=e(c,p.action),p=p.next;while(p!==u);kt(c,t.memoizedState)||(Ke=!0),t.memoizedState=c,t.baseQueue===null&&(t.baseState=c),a.lastRenderedState=c}return[c,l]}function Ah(e,t,a){var l=ue,u=Xe(),c=Ee;if(c){if(a===void 0)throw Error(s(407));a=a()}else a=t();var p=!kt((xe||u).memoizedState,a);if(p&&(u.memoizedState=a,Ke=!0),u=u.queue,ko(Ch.bind(null,l,u,e),[e]),u.getSnapshot!==t||p||Je!==null&&Je.memoizedState.tag&1){if(l.flags|=2048,Ui(9,{destroy:void 0},Mh.bind(null,l,u,a,t),null),Ne===null)throw Error(s(349));c||(jn&127)!==0||Dh(l,t,a)}return a}function Dh(e,t,a){e.flags|=16384,e={getSnapshot:t,value:a},t=ue.updateQueue,t===null?(t=os(),ue.updateQueue=t,t.stores=[e]):(a=t.stores,a===null?t.stores=[e]:a.push(e))}function Mh(e,t,a,l){t.value=a,t.getSnapshot=l,xh(t)&&Rh(e)}function Ch(e,t,a){return a(function(){xh(t)&&Rh(e)})}function xh(e){var t=e.getSnapshot;e=e.value;try{var a=t();return!kt(e,a)}catch{return!0}}function Rh(e){var t=Ha(e,2);t!==null&&zt(t,e,2)}function jo(e){var t=Tt();if(typeof e=="function"){var a=e;if(e=a(),Ja){an(!0);try{a()}finally{an(!1)}}}return t.memoizedState=t.baseState=e,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Un,lastRenderedState:e},t}function zh(e,t,a,l){return e.baseState=a,zo(e,xe,typeof l=="function"?l:Un)}function cb(e,t,a,l,u){if(ms(e))throw Error(s(485));if(e=t.action,e!==null){var c={payload:u,action:e,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(p){c.listeners.push(p)}};R.T!==null?a(!0):c.isTransition=!1,l(c),a=t.pending,a===null?(c.next=t.pending=c,Nh(t,c)):(c.next=a.next,t.pending=a.next=c)}}function Nh(e,t){var a=t.action,l=t.payload,u=e.state;if(t.isTransition){var c=R.T,p={};R.T=p;try{var g=a(u,l),T=R.S;T!==null&&T(p,g),jh(e,t,g)}catch(x){Uo(e,t,x)}finally{c!==null&&p.types!==null&&(c.types=p.types),R.T=c}}else try{c=a(u,l),jh(e,t,c)}catch(x){Uo(e,t,x)}}function jh(e,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(l){Uh(e,t,l)},function(l){return Uo(e,t,l)}):Uh(e,t,a)}function Uh(e,t,a){t.status="fulfilled",t.value=a,kh(t),e.state=a,t=e.pending,t!==null&&(a=t.next,a===t?e.pending=null:(a=a.next,t.next=a,Nh(e,a)))}function Uo(e,t,a){var l=e.pending;if(e.pending=null,l!==null){l=l.next;do t.status="rejected",t.reason=a,kh(t),t=t.next;while(t!==l)}e.action=null}function kh(e){e=e.listeners;for(var t=0;t<e.length;t++)(0,e[t])()}function qh(e,t){return t}function Lh(e,t){if(Ee){var a=Ne.formState;if(a!==null){e:{var l=ue;if(Ee){if(je){t:{for(var u=je,c=Kt;u.nodeType!==8;){if(!c){u=null;break t}if(u=$t(u.nextSibling),u===null){u=null;break t}}c=u.data,u=c==="F!"||c==="F"?u:null}if(u){je=$t(u.nextSibling),l=u.data==="F!";break e}}ia(l)}l=!1}l&&(t=a[0])}}return a=Tt(),a.memoizedState=a.baseState=t,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:qh,lastRenderedState:t},a.queue=l,a=am.bind(null,ue,l),l.dispatch=a,l=jo(!1),c=Vo.bind(null,ue,!1,l.queue),l=Tt(),u={state:t,dispatch:null,action:e,pending:null},l.queue=u,a=cb.bind(null,ue,u,c,a),u.dispatch=a,l.memoizedState=e,[t,a,!1]}function Hh(e){var t=Xe();return Bh(t,xe,e)}function Bh(e,t,a){if(t=zo(e,t,qh)[0],e=fs(Un)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var l=Br(t)}catch(p){throw p===xi?ts:p}else l=t;t=Xe();var u=t.queue,c=u.dispatch;return a!==t.memoizedState&&(ue.flags|=2048,Ui(9,{destroy:void 0},fb.bind(null,u,a),null)),[l,c,e]}function fb(e,t){e.action=t}function Vh(e){var t=Xe(),a=xe;if(a!==null)return Bh(t,a,e);Xe(),t=t.memoizedState,a=Xe();var l=a.queue.dispatch;return a.memoizedState=e,[t,l,!1]}function Ui(e,t,a,l){return e={tag:e,create:a,deps:l,inst:t,next:null},t=ue.updateQueue,t===null&&(t=os(),ue.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=e.next=e:(l=a.next,a.next=e,e.next=l,t.lastEffect=e),e}function Qh(){return Xe().memoizedState}function ds(e,t,a,l){var u=Tt();ue.flags|=e,u.memoizedState=Ui(1|t,{destroy:void 0},a,l===void 0?null:l)}function hs(e,t,a,l){var u=Xe();l=l===void 0?null:l;var c=u.memoizedState.inst;xe!==null&&l!==null&&Ao(l,xe.memoizedState.deps)?u.memoizedState=Ui(t,c,a,l):(ue.flags|=e,u.memoizedState=Ui(1|t,c,a,l))}function Yh(e,t){ds(8390656,8,e,t)}function ko(e,t){hs(2048,8,e,t)}function db(e){ue.flags|=4;var t=ue.updateQueue;if(t===null)t=os(),ue.updateQueue=t,t.events=[e];else{var a=t.events;a===null?t.events=[e]:a.push(e)}}function Gh(e){var t=Xe().memoizedState;return db({ref:t,nextImpl:e}),function(){if((Ae&2)!==0)throw Error(s(440));return t.impl.apply(void 0,arguments)}}function Xh(e,t){return hs(4,2,e,t)}function Fh(e,t){return hs(4,4,e,t)}function Zh(e,t){if(typeof t=="function"){e=e();var a=t(e);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return e=e(),t.current=e,function(){t.current=null}}function Jh(e,t,a){a=a!=null?a.concat([e]):null,hs(4,4,Zh.bind(null,t,e),a)}function qo(){}function Kh(e,t){var a=Xe();t=t===void 0?null:t;var l=a.memoizedState;return t!==null&&Ao(t,l[1])?l[0]:(a.memoizedState=[e,t],e)}function Ih(e,t){var a=Xe();t=t===void 0?null:t;var l=a.memoizedState;if(t!==null&&Ao(t,l[1]))return l[0];if(l=e(),Ja){an(!0);try{e()}finally{an(!1)}}return a.memoizedState=[l,t],l}function Lo(e,t,a){return a===void 0||(jn&1073741824)!==0&&(ve&261930)===0?e.memoizedState=t:(e.memoizedState=a,e=$m(),ue.lanes|=e,ha|=e,a)}function $h(e,t,a,l){return kt(a,t)?a:zi.current!==null?(e=Lo(e,a,l),kt(e,t)||(Ke=!0),e):(jn&42)===0||(jn&1073741824)!==0&&(ve&261930)===0?(Ke=!0,e.memoizedState=a):(e=$m(),ue.lanes|=e,ha|=e,t)}function Wh(e,t,a,l,u){var c=Q.p;Q.p=c!==0&&8>c?c:8;var p=R.T,g={};R.T=g,Vo(e,!1,t,a);try{var T=u(),x=R.S;if(x!==null&&x(g,T),T!==null&&typeof T=="object"&&typeof T.then=="function"){var k=sb(T,l);Vr(e,t,k,Qt(e))}else Vr(e,t,l,Qt(e))}catch(H){Vr(e,t,{then:function(){},status:"rejected",reason:H},Qt())}finally{Q.p=c,p!==null&&g.types!==null&&(p.types=g.types),R.T=p}}function hb(){}function Ho(e,t,a,l){if(e.tag!==5)throw Error(s(476));var u=Ph(e).queue;Wh(e,u,t,W,a===null?hb:function(){return em(e),a(l)})}function Ph(e){var t=e.memoizedState;if(t!==null)return t;t={memoizedState:W,baseState:W,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Un,lastRenderedState:W},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Un,lastRenderedState:a},next:null},e.memoizedState=t,e=e.alternate,e!==null&&(e.memoizedState=t),t}function em(e){var t=Ph(e);t.next===null&&(t=e.alternate.memoizedState),Vr(e,t.next.queue,{},Qt())}function Bo(){return ut(il)}function tm(){return Xe().memoizedState}function nm(){return Xe().memoizedState}function mb(e){for(var t=e.return;t!==null;){switch(t.tag){case 24:case 3:var a=Qt();e=sa(a);var l=ua(t,e,a);l!==null&&(zt(l,t,a),kr(l,t,a)),t={cache:yo()},e.payload=t;return}t=t.return}}function yb(e,t,a){var l=Qt();a={lane:l,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},ms(e)?im(t,a):(a=ao(e,t,a,l),a!==null&&(zt(a,e,l),rm(a,t,l)))}function am(e,t,a){var l=Qt();Vr(e,t,a,l)}function Vr(e,t,a,l){var u={lane:l,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null};if(ms(e))im(t,u);else{var c=e.alternate;if(e.lanes===0&&(c===null||c.lanes===0)&&(c=t.lastRenderedReducer,c!==null))try{var p=t.lastRenderedState,g=c(p,a);if(u.hasEagerState=!0,u.eagerState=g,kt(g,p))return Jl(e,t,u,0),Ne===null&&Zl(),!1}catch{}finally{}if(a=ao(e,t,u,l),a!==null)return zt(a,e,l),rm(a,t,l),!0}return!1}function Vo(e,t,a,l){if(l={lane:2,revertLane:bc(),gesture:null,action:l,hasEagerState:!1,eagerState:null,next:null},ms(e)){if(t)throw Error(s(479))}else t=ao(e,a,l,2),t!==null&&zt(t,e,2)}function ms(e){var t=e.alternate;return e===ue||t!==null&&t===ue}function im(e,t){Ni=ss=!0;var a=e.pending;a===null?t.next=t:(t.next=a.next,a.next=t),e.pending=t}function rm(e,t,a){if((a&4194048)!==0){var l=t.lanes;l&=e.pendingLanes,a|=l,t.lanes=a,_t(e,a)}}var Qr={readContext:ut,use:cs,useCallback:Ve,useContext:Ve,useEffect:Ve,useImperativeHandle:Ve,useLayoutEffect:Ve,useInsertionEffect:Ve,useMemo:Ve,useReducer:Ve,useRef:Ve,useState:Ve,useDebugValue:Ve,useDeferredValue:Ve,useTransition:Ve,useSyncExternalStore:Ve,useId:Ve,useHostTransitionStatus:Ve,useFormState:Ve,useActionState:Ve,useOptimistic:Ve,useMemoCache:Ve,useCacheRefresh:Ve};Qr.useEffectEvent=Ve;var lm={readContext:ut,use:cs,useCallback:function(e,t){return Tt().memoizedState=[e,t===void 0?null:t],e},useContext:ut,useEffect:Yh,useImperativeHandle:function(e,t,a){a=a!=null?a.concat([e]):null,ds(4194308,4,Zh.bind(null,t,e),a)},useLayoutEffect:function(e,t){return ds(4194308,4,e,t)},useInsertionEffect:function(e,t){ds(4,2,e,t)},useMemo:function(e,t){var a=Tt();t=t===void 0?null:t;var l=e();if(Ja){an(!0);try{e()}finally{an(!1)}}return a.memoizedState=[l,t],l},useReducer:function(e,t,a){var l=Tt();if(a!==void 0){var u=a(t);if(Ja){an(!0);try{a(t)}finally{an(!1)}}}else u=t;return l.memoizedState=l.baseState=u,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:u},l.queue=e,e=e.dispatch=yb.bind(null,ue,e),[l.memoizedState,e]},useRef:function(e){var t=Tt();return e={current:e},t.memoizedState=e},useState:function(e){e=jo(e);var t=e.queue,a=am.bind(null,ue,t);return t.dispatch=a,[e.memoizedState,a]},useDebugValue:qo,useDeferredValue:function(e,t){var a=Tt();return Lo(a,e,t)},useTransition:function(){var e=jo(!1);return e=Wh.bind(null,ue,e.queue,!0,!1),Tt().memoizedState=e,[!1,e]},useSyncExternalStore:function(e,t,a){var l=ue,u=Tt();if(Ee){if(a===void 0)throw Error(s(407));a=a()}else{if(a=t(),Ne===null)throw Error(s(349));(ve&127)!==0||Dh(l,t,a)}u.memoizedState=a;var c={value:a,getSnapshot:t};return u.queue=c,Yh(Ch.bind(null,l,c,e),[e]),l.flags|=2048,Ui(9,{destroy:void 0},Mh.bind(null,l,c,a,t),null),a},useId:function(){var e=Tt(),t=Ne.identifierPrefix;if(Ee){var a=vn,l=pn;a=(l&~(1<<32-yt(l)-1)).toString(32)+a,t="_"+t+"R_"+a,a=us++,0<a&&(t+="H"+a.toString(32)),t+="_"}else a=ub++,t="_"+t+"r_"+a.toString(32)+"_";return e.memoizedState=t},useHostTransitionStatus:Bo,useFormState:Lh,useActionState:Lh,useOptimistic:function(e){var t=Tt();t.memoizedState=t.baseState=e;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=Vo.bind(null,ue,!0,a),a.dispatch=t,[e,t]},useMemoCache:Ro,useCacheRefresh:function(){return Tt().memoizedState=mb.bind(null,ue)},useEffectEvent:function(e){var t=Tt(),a={impl:e};return t.memoizedState=a,function(){if((Ae&2)!==0)throw Error(s(440));return a.impl.apply(void 0,arguments)}}},Qo={readContext:ut,use:cs,useCallback:Kh,useContext:ut,useEffect:ko,useImperativeHandle:Jh,useInsertionEffect:Xh,useLayoutEffect:Fh,useMemo:Ih,useReducer:fs,useRef:Qh,useState:function(){return fs(Un)},useDebugValue:qo,useDeferredValue:function(e,t){var a=Xe();return $h(a,xe.memoizedState,e,t)},useTransition:function(){var e=fs(Un)[0],t=Xe().memoizedState;return[typeof e=="boolean"?e:Br(e),t]},useSyncExternalStore:Ah,useId:tm,useHostTransitionStatus:Bo,useFormState:Hh,useActionState:Hh,useOptimistic:function(e,t){var a=Xe();return zh(a,xe,e,t)},useMemoCache:Ro,useCacheRefresh:nm};Qo.useEffectEvent=Gh;var sm={readContext:ut,use:cs,useCallback:Kh,useContext:ut,useEffect:ko,useImperativeHandle:Jh,useInsertionEffect:Xh,useLayoutEffect:Fh,useMemo:Ih,useReducer:No,useRef:Qh,useState:function(){return No(Un)},useDebugValue:qo,useDeferredValue:function(e,t){var a=Xe();return xe===null?Lo(a,e,t):$h(a,xe.memoizedState,e,t)},useTransition:function(){var e=No(Un)[0],t=Xe().memoizedState;return[typeof e=="boolean"?e:Br(e),t]},useSyncExternalStore:Ah,useId:tm,useHostTransitionStatus:Bo,useFormState:Vh,useActionState:Vh,useOptimistic:function(e,t){var a=Xe();return xe!==null?zh(a,xe,e,t):(a.baseState=e,[e,a.queue.dispatch])},useMemoCache:Ro,useCacheRefresh:nm};sm.useEffectEvent=Gh;function Yo(e,t,a,l){t=e.memoizedState,a=a(l,t),a=a==null?t:v({},t,a),e.memoizedState=a,e.lanes===0&&(e.updateQueue.baseState=a)}var Go={enqueueSetState:function(e,t,a){e=e._reactInternals;var l=Qt(),u=sa(l);u.payload=t,a!=null&&(u.callback=a),t=ua(e,u,l),t!==null&&(zt(t,e,l),kr(t,e,l))},enqueueReplaceState:function(e,t,a){e=e._reactInternals;var l=Qt(),u=sa(l);u.tag=1,u.payload=t,a!=null&&(u.callback=a),t=ua(e,u,l),t!==null&&(zt(t,e,l),kr(t,e,l))},enqueueForceUpdate:function(e,t){e=e._reactInternals;var a=Qt(),l=sa(a);l.tag=2,t!=null&&(l.callback=t),t=ua(e,l,a),t!==null&&(zt(t,e,a),kr(t,e,a))}};function um(e,t,a,l,u,c,p){return e=e.stateNode,typeof e.shouldComponentUpdate=="function"?e.shouldComponentUpdate(l,c,p):t.prototype&&t.prototype.isPureReactComponent?!Mr(a,l)||!Mr(u,c):!0}function om(e,t,a,l){e=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,l),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,l),t.state!==e&&Go.enqueueReplaceState(t,t.state,null)}function Ka(e,t){var a=t;if("ref"in t){a={};for(var l in t)l!=="ref"&&(a[l]=t[l])}if(e=e.defaultProps){a===t&&(a=v({},a));for(var u in e)a[u]===void 0&&(a[u]=e[u])}return a}function cm(e){Fl(e)}function fm(e){console.error(e)}function dm(e){Fl(e)}function ys(e,t){try{var a=e.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(l){setTimeout(function(){throw l})}}function hm(e,t,a){try{var l=e.onCaughtError;l(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(u){setTimeout(function(){throw u})}}function Xo(e,t,a){return a=sa(a),a.tag=3,a.payload={element:null},a.callback=function(){ys(e,t)},a}function mm(e){return e=sa(e),e.tag=3,e}function ym(e,t,a,l){var u=a.type.getDerivedStateFromError;if(typeof u=="function"){var c=l.value;e.payload=function(){return u(c)},e.callback=function(){hm(t,a,l)}}var p=a.stateNode;p!==null&&typeof p.componentDidCatch=="function"&&(e.callback=function(){hm(t,a,l),typeof u!="function"&&(ma===null?ma=new Set([this]):ma.add(this));var g=l.stack;this.componentDidCatch(l.value,{componentStack:g!==null?g:""})})}function pb(e,t,a,l,u){if(a.flags|=32768,l!==null&&typeof l=="object"&&typeof l.then=="function"){if(t=a.alternate,t!==null&&Di(t,a,u,!0),a=Lt.current,a!==null){switch(a.tag){case 31:case 13:return It===null?Ds():a.alternate===null&&Qe===0&&(Qe=3),a.flags&=-257,a.flags|=65536,a.lanes=u,l===ns?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([l]):t.add(l),pc(e,l,u)),!1;case 22:return a.flags|=65536,l===ns?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([l])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([l]):a.add(l)),pc(e,l,u)),!1}throw Error(s(435,a.tag))}return pc(e,l,u),Ds(),!1}if(Ee)return t=Lt.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=u,l!==oo&&(e=Error(s(422),{cause:l}),Rr(Ft(e,a)))):(l!==oo&&(t=Error(s(423),{cause:l}),Rr(Ft(t,a))),e=e.current.alternate,e.flags|=65536,u&=-u,e.lanes|=u,l=Ft(l,a),u=Xo(e.stateNode,l,u),Eo(e,u),Qe!==4&&(Qe=2)),!1;var c=Error(s(520),{cause:l});if(c=Ft(c,a),Ir===null?Ir=[c]:Ir.push(c),Qe!==4&&(Qe=2),t===null)return!0;l=Ft(l,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,e=u&-u,a.lanes|=e,e=Xo(a.stateNode,l,e),Eo(a,e),!1;case 1:if(t=a.type,c=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||c!==null&&typeof c.componentDidCatch=="function"&&(ma===null||!ma.has(c))))return a.flags|=65536,u&=-u,a.lanes|=u,u=mm(u),ym(u,e,a,l),Eo(a,u),!1}a=a.return}while(a!==null);return!1}var Fo=Error(s(461)),Ke=!1;function ot(e,t,a,l){t.child=e===null?bh(t,null,a,l):Za(t,e.child,a,l)}function pm(e,t,a,l,u){a=a.render;var c=t.ref;if("ref"in l){var p={};for(var g in l)g!=="ref"&&(p[g]=l[g])}else p=l;return Ya(t),l=Do(e,t,a,p,c,u),g=Mo(),e!==null&&!Ke?(Co(e,t,u),kn(e,t,u)):(Ee&&g&&so(t),t.flags|=1,ot(e,t,l,u),t.child)}function vm(e,t,a,l,u){if(e===null){var c=a.type;return typeof c=="function"&&!io(c)&&c.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=c,gm(e,t,c,l,u)):(e=Il(a.type,null,l,t,t.mode,u),e.ref=t.ref,e.return=t,t.child=e)}if(c=e.child,!ec(e,u)){var p=c.memoizedProps;if(a=a.compare,a=a!==null?a:Mr,a(p,l)&&e.ref===t.ref)return kn(e,t,u)}return t.flags|=1,e=xn(c,l),e.ref=t.ref,e.return=t,t.child=e}function gm(e,t,a,l,u){if(e!==null){var c=e.memoizedProps;if(Mr(c,l)&&e.ref===t.ref)if(Ke=!1,t.pendingProps=l=c,ec(e,u))(e.flags&131072)!==0&&(Ke=!0);else return t.lanes=e.lanes,kn(e,t,u)}return Zo(e,t,a,l,u)}function bm(e,t,a,l){var u=l.children,c=e!==null?e.memoizedState:null;if(e===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),l.mode==="hidden"){if((t.flags&128)!==0){if(c=c!==null?c.baseLanes|a:a,e!==null){for(l=t.child=e.child,u=0;l!==null;)u=u|l.lanes|l.childLanes,l=l.sibling;l=u&~c}else l=0,t.child=null;return Sm(e,t,c,a,l)}if((a&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},e!==null&&es(t,c!==null?c.cachePool:null),c!==null?Th(t,c):Oo(),Oh(t);else return l=t.lanes=536870912,Sm(e,t,c!==null?c.baseLanes|a:a,a,l)}else c!==null?(es(t,c.cachePool),Th(t,c),ca(),t.memoizedState=null):(e!==null&&es(t,null),Oo(),ca());return ot(e,t,u,a),t.child}function Yr(e,t){return e!==null&&e.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function Sm(e,t,a,l,u){var c=vo();return c=c===null?null:{parent:Ze._currentValue,pool:c},t.memoizedState={baseLanes:a,cachePool:c},e!==null&&es(t,null),Oo(),Oh(t),e!==null&&Di(e,t,l,!0),t.childLanes=u,null}function ps(e,t){return t=gs({mode:t.mode,children:t.children},e.mode),t.ref=e.ref,e.child=t,t.return=e,t}function Em(e,t,a){return Za(t,e.child,null,a),e=ps(t,t.pendingProps),e.flags|=2,Ht(t),t.memoizedState=null,e}function vb(e,t,a){var l=t.pendingProps,u=(t.flags&128)!==0;if(t.flags&=-129,e===null){if(Ee){if(l.mode==="hidden")return e=ps(t,l),t.lanes=536870912,Yr(null,e);if(wo(t),(e=je)?(e=Ny(e,Kt),e=e!==null&&e.data==="&"?e:null,e!==null&&(t.memoizedState={dehydrated:e,treeContext:na!==null?{id:pn,overflow:vn}:null,retryLane:536870912,hydrationErrors:null},a=ih(e),a.return=t,t.child=a,st=t,je=null)):e=null,e===null)throw ia(t);return t.lanes=536870912,null}return ps(t,l)}var c=e.memoizedState;if(c!==null){var p=c.dehydrated;if(wo(t),u)if(t.flags&256)t.flags&=-257,t=Em(e,t,a);else if(t.memoizedState!==null)t.child=e.child,t.flags|=128,t=null;else throw Error(s(558));else if(Ke||Di(e,t,a,!1),u=(a&e.childLanes)!==0,Ke||u){if(l=Ne,l!==null&&(p=wt(l,a),p!==0&&p!==c.retryLane))throw c.retryLane=p,Ha(e,p),zt(l,e,p),Fo;Ds(),t=Em(e,t,a)}else e=c.treeContext,je=$t(p.nextSibling),st=t,Ee=!0,aa=null,Kt=!1,e!==null&&sh(t,e),t=ps(t,l),t.flags|=4096;return t}return e=xn(e.child,{mode:l.mode,children:l.children}),e.ref=t.ref,t.child=e,e.return=t,e}function vs(e,t){var a=t.ref;if(a===null)e!==null&&e.ref!==null&&(t.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(s(284));(e===null||e.ref!==a)&&(t.flags|=4194816)}}function Zo(e,t,a,l,u){return Ya(t),a=Do(e,t,a,l,void 0,u),l=Mo(),e!==null&&!Ke?(Co(e,t,u),kn(e,t,u)):(Ee&&l&&so(t),t.flags|=1,ot(e,t,a,u),t.child)}function Tm(e,t,a,l,u,c){return Ya(t),t.updateQueue=null,a=wh(t,l,a,u),_h(e),l=Mo(),e!==null&&!Ke?(Co(e,t,c),kn(e,t,c)):(Ee&&l&&so(t),t.flags|=1,ot(e,t,a,c),t.child)}function Om(e,t,a,l,u){if(Ya(t),t.stateNode===null){var c=Oi,p=a.contextType;typeof p=="object"&&p!==null&&(c=ut(p)),c=new a(l,c),t.memoizedState=c.state!==null&&c.state!==void 0?c.state:null,c.updater=Go,t.stateNode=c,c._reactInternals=t,c=t.stateNode,c.props=l,c.state=t.memoizedState,c.refs={},bo(t),p=a.contextType,c.context=typeof p=="object"&&p!==null?ut(p):Oi,c.state=t.memoizedState,p=a.getDerivedStateFromProps,typeof p=="function"&&(Yo(t,a,p,l),c.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof c.getSnapshotBeforeUpdate=="function"||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(p=c.state,typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount(),p!==c.state&&Go.enqueueReplaceState(c,c.state,null),Lr(t,l,c,u),qr(),c.state=t.memoizedState),typeof c.componentDidMount=="function"&&(t.flags|=4194308),l=!0}else if(e===null){c=t.stateNode;var g=t.memoizedProps,T=Ka(a,g);c.props=T;var x=c.context,k=a.contextType;p=Oi,typeof k=="object"&&k!==null&&(p=ut(k));var H=a.getDerivedStateFromProps;k=typeof H=="function"||typeof c.getSnapshotBeforeUpdate=="function",g=t.pendingProps!==g,k||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(g||x!==p)&&om(t,c,l,p),la=!1;var z=t.memoizedState;c.state=z,Lr(t,l,c,u),qr(),x=t.memoizedState,g||z!==x||la?(typeof H=="function"&&(Yo(t,a,H,l),x=t.memoizedState),(T=la||um(t,a,T,l,z,x,p))?(k||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount()),typeof c.componentDidMount=="function"&&(t.flags|=4194308)):(typeof c.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=l,t.memoizedState=x),c.props=l,c.state=x,c.context=p,l=T):(typeof c.componentDidMount=="function"&&(t.flags|=4194308),l=!1)}else{c=t.stateNode,So(e,t),p=t.memoizedProps,k=Ka(a,p),c.props=k,H=t.pendingProps,z=c.context,x=a.contextType,T=Oi,typeof x=="object"&&x!==null&&(T=ut(x)),g=a.getDerivedStateFromProps,(x=typeof g=="function"||typeof c.getSnapshotBeforeUpdate=="function")||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(p!==H||z!==T)&&om(t,c,l,T),la=!1,z=t.memoizedState,c.state=z,Lr(t,l,c,u),qr();var j=t.memoizedState;p!==H||z!==j||la||e!==null&&e.dependencies!==null&&Wl(e.dependencies)?(typeof g=="function"&&(Yo(t,a,g,l),j=t.memoizedState),(k=la||um(t,a,k,l,z,j,T)||e!==null&&e.dependencies!==null&&Wl(e.dependencies))?(x||typeof c.UNSAFE_componentWillUpdate!="function"&&typeof c.componentWillUpdate!="function"||(typeof c.componentWillUpdate=="function"&&c.componentWillUpdate(l,j,T),typeof c.UNSAFE_componentWillUpdate=="function"&&c.UNSAFE_componentWillUpdate(l,j,T)),typeof c.componentDidUpdate=="function"&&(t.flags|=4),typeof c.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof c.componentDidUpdate!="function"||p===e.memoizedProps&&z===e.memoizedState||(t.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||p===e.memoizedProps&&z===e.memoizedState||(t.flags|=1024),t.memoizedProps=l,t.memoizedState=j),c.props=l,c.state=j,c.context=T,l=k):(typeof c.componentDidUpdate!="function"||p===e.memoizedProps&&z===e.memoizedState||(t.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||p===e.memoizedProps&&z===e.memoizedState||(t.flags|=1024),l=!1)}return c=l,vs(e,t),l=(t.flags&128)!==0,c||l?(c=t.stateNode,a=l&&typeof a.getDerivedStateFromError!="function"?null:c.render(),t.flags|=1,e!==null&&l?(t.child=Za(t,e.child,null,u),t.child=Za(t,null,a,u)):ot(e,t,a,u),t.memoizedState=c.state,e=t.child):e=kn(e,t,u),e}function _m(e,t,a,l){return Va(),t.flags|=256,ot(e,t,a,l),t.child}var Jo={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Ko(e){return{baseLanes:e,cachePool:hh()}}function Io(e,t,a){return e=e!==null?e.childLanes&~a:0,t&&(e|=Vt),e}function wm(e,t,a){var l=t.pendingProps,u=!1,c=(t.flags&128)!==0,p;if((p=c)||(p=e!==null&&e.memoizedState===null?!1:(Ge.current&2)!==0),p&&(u=!0,t.flags&=-129),p=(t.flags&32)!==0,t.flags&=-33,e===null){if(Ee){if(u?oa(t):ca(),(e=je)?(e=Ny(e,Kt),e=e!==null&&e.data!=="&"?e:null,e!==null&&(t.memoizedState={dehydrated:e,treeContext:na!==null?{id:pn,overflow:vn}:null,retryLane:536870912,hydrationErrors:null},a=ih(e),a.return=t,t.child=a,st=t,je=null)):e=null,e===null)throw ia(t);return zc(e)?t.lanes=32:t.lanes=536870912,null}var g=l.children;return l=l.fallback,u?(ca(),u=t.mode,g=gs({mode:"hidden",children:g},u),l=Ba(l,u,a,null),g.return=t,l.return=t,g.sibling=l,t.child=g,l=t.child,l.memoizedState=Ko(a),l.childLanes=Io(e,p,a),t.memoizedState=Jo,Yr(null,l)):(oa(t),$o(t,g))}var T=e.memoizedState;if(T!==null&&(g=T.dehydrated,g!==null)){if(c)t.flags&256?(oa(t),t.flags&=-257,t=Wo(e,t,a)):t.memoizedState!==null?(ca(),t.child=e.child,t.flags|=128,t=null):(ca(),g=l.fallback,u=t.mode,l=gs({mode:"visible",children:l.children},u),g=Ba(g,u,a,null),g.flags|=2,l.return=t,g.return=t,l.sibling=g,t.child=l,Za(t,e.child,null,a),l=t.child,l.memoizedState=Ko(a),l.childLanes=Io(e,p,a),t.memoizedState=Jo,t=Yr(null,l));else if(oa(t),zc(g)){if(p=g.nextSibling&&g.nextSibling.dataset,p)var x=p.dgst;p=x,l=Error(s(419)),l.stack="",l.digest=p,Rr({value:l,source:null,stack:null}),t=Wo(e,t,a)}else if(Ke||Di(e,t,a,!1),p=(a&e.childLanes)!==0,Ke||p){if(p=Ne,p!==null&&(l=wt(p,a),l!==0&&l!==T.retryLane))throw T.retryLane=l,Ha(e,l),zt(p,e,l),Fo;Rc(g)||Ds(),t=Wo(e,t,a)}else Rc(g)?(t.flags|=192,t.child=e.child,t=null):(e=T.treeContext,je=$t(g.nextSibling),st=t,Ee=!0,aa=null,Kt=!1,e!==null&&sh(t,e),t=$o(t,l.children),t.flags|=4096);return t}return u?(ca(),g=l.fallback,u=t.mode,T=e.child,x=T.sibling,l=xn(T,{mode:"hidden",children:l.children}),l.subtreeFlags=T.subtreeFlags&65011712,x!==null?g=xn(x,g):(g=Ba(g,u,a,null),g.flags|=2),g.return=t,l.return=t,l.sibling=g,t.child=l,Yr(null,l),l=t.child,g=e.child.memoizedState,g===null?g=Ko(a):(u=g.cachePool,u!==null?(T=Ze._currentValue,u=u.parent!==T?{parent:T,pool:T}:u):u=hh(),g={baseLanes:g.baseLanes|a,cachePool:u}),l.memoizedState=g,l.childLanes=Io(e,p,a),t.memoizedState=Jo,Yr(e.child,l)):(oa(t),a=e.child,e=a.sibling,a=xn(a,{mode:"visible",children:l.children}),a.return=t,a.sibling=null,e!==null&&(p=t.deletions,p===null?(t.deletions=[e],t.flags|=16):p.push(e)),t.child=a,t.memoizedState=null,a)}function $o(e,t){return t=gs({mode:"visible",children:t},e.mode),t.return=e,e.child=t}function gs(e,t){return e=qt(22,e,null,t),e.lanes=0,e}function Wo(e,t,a){return Za(t,e.child,null,a),e=$o(t,t.pendingProps.children),e.flags|=2,t.memoizedState=null,e}function Am(e,t,a){e.lanes|=t;var l=e.alternate;l!==null&&(l.lanes|=t),ho(e.return,t,a)}function Po(e,t,a,l,u,c){var p=e.memoizedState;p===null?e.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:l,tail:a,tailMode:u,treeForkCount:c}:(p.isBackwards=t,p.rendering=null,p.renderingStartTime=0,p.last=l,p.tail=a,p.tailMode=u,p.treeForkCount=c)}function Dm(e,t,a){var l=t.pendingProps,u=l.revealOrder,c=l.tail;l=l.children;var p=Ge.current,g=(p&2)!==0;if(g?(p=p&1|2,t.flags|=128):p&=1,V(Ge,p),ot(e,t,l,a),l=Ee?xr:0,!g&&e!==null&&(e.flags&128)!==0)e:for(e=t.child;e!==null;){if(e.tag===13)e.memoizedState!==null&&Am(e,a,t);else if(e.tag===19)Am(e,a,t);else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break e;for(;e.sibling===null;){if(e.return===null||e.return===t)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}switch(u){case"forwards":for(a=t.child,u=null;a!==null;)e=a.alternate,e!==null&&ls(e)===null&&(u=a),a=a.sibling;a=u,a===null?(u=t.child,t.child=null):(u=a.sibling,a.sibling=null),Po(t,!1,u,a,c,l);break;case"backwards":case"unstable_legacy-backwards":for(a=null,u=t.child,t.child=null;u!==null;){if(e=u.alternate,e!==null&&ls(e)===null){t.child=u;break}e=u.sibling,u.sibling=a,a=u,u=e}Po(t,!0,a,null,c,l);break;case"together":Po(t,!1,null,null,void 0,l);break;default:t.memoizedState=null}return t.child}function kn(e,t,a){if(e!==null&&(t.dependencies=e.dependencies),ha|=t.lanes,(a&t.childLanes)===0)if(e!==null){if(Di(e,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(e!==null&&t.child!==e.child)throw Error(s(153));if(t.child!==null){for(e=t.child,a=xn(e,e.pendingProps),t.child=a,a.return=t;e.sibling!==null;)e=e.sibling,a=a.sibling=xn(e,e.pendingProps),a.return=t;a.sibling=null}return t.child}function ec(e,t){return(e.lanes&t)!==0?!0:(e=e.dependencies,!!(e!==null&&Wl(e)))}function gb(e,t,a){switch(t.tag){case 3:ce(t,t.stateNode.containerInfo),ra(t,Ze,e.memoizedState.cache),Va();break;case 27:case 5:dn(t);break;case 4:ce(t,t.stateNode.containerInfo);break;case 10:ra(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,wo(t),null;break;case 13:var l=t.memoizedState;if(l!==null)return l.dehydrated!==null?(oa(t),t.flags|=128,null):(a&t.child.childLanes)!==0?wm(e,t,a):(oa(t),e=kn(e,t,a),e!==null?e.sibling:null);oa(t);break;case 19:var u=(e.flags&128)!==0;if(l=(a&t.childLanes)!==0,l||(Di(e,t,a,!1),l=(a&t.childLanes)!==0),u){if(l)return Dm(e,t,a);t.flags|=128}if(u=t.memoizedState,u!==null&&(u.rendering=null,u.tail=null,u.lastEffect=null),V(Ge,Ge.current),l)break;return null;case 22:return t.lanes=0,bm(e,t,a,t.pendingProps);case 24:ra(t,Ze,e.memoizedState.cache)}return kn(e,t,a)}function Mm(e,t,a){if(e!==null)if(e.memoizedProps!==t.pendingProps)Ke=!0;else{if(!ec(e,a)&&(t.flags&128)===0)return Ke=!1,gb(e,t,a);Ke=(e.flags&131072)!==0}else Ke=!1,Ee&&(t.flags&1048576)!==0&&lh(t,xr,t.index);switch(t.lanes=0,t.tag){case 16:e:{var l=t.pendingProps;if(e=Xa(t.elementType),t.type=e,typeof e=="function")io(e)?(l=Ka(e,l),t.tag=1,t=Om(null,t,e,l,a)):(t.tag=0,t=Zo(null,t,e,l,a));else{if(e!=null){var u=e.$$typeof;if(u===X){t.tag=11,t=pm(null,t,e,l,a);break e}else if(u===$){t.tag=14,t=vm(null,t,e,l,a);break e}}throw t=mt(e)||e,Error(s(306,t,""))}}return t;case 0:return Zo(e,t,t.type,t.pendingProps,a);case 1:return l=t.type,u=Ka(l,t.pendingProps),Om(e,t,l,u,a);case 3:e:{if(ce(t,t.stateNode.containerInfo),e===null)throw Error(s(387));l=t.pendingProps;var c=t.memoizedState;u=c.element,So(e,t),Lr(t,l,null,a);var p=t.memoizedState;if(l=p.cache,ra(t,Ze,l),l!==c.cache&&mo(t,[Ze],a,!0),qr(),l=p.element,c.isDehydrated)if(c={element:l,isDehydrated:!1,cache:p.cache},t.updateQueue.baseState=c,t.memoizedState=c,t.flags&256){t=_m(e,t,l,a);break e}else if(l!==u){u=Ft(Error(s(424)),t),Rr(u),t=_m(e,t,l,a);break e}else{switch(e=t.stateNode.containerInfo,e.nodeType){case 9:e=e.body;break;default:e=e.nodeName==="HTML"?e.ownerDocument.body:e}for(je=$t(e.firstChild),st=t,Ee=!0,aa=null,Kt=!0,a=bh(t,null,l,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(Va(),l===u){t=kn(e,t,a);break e}ot(e,t,l,a)}t=t.child}return t;case 26:return vs(e,t),e===null?(a=Hy(t.type,null,t.pendingProps,null))?t.memoizedState=a:Ee||(a=t.type,e=t.pendingProps,l=js(ne.current).createElement(a),l[lt]=t,l[At]=e,ct(l,a,e),tt(l),t.stateNode=l):t.memoizedState=Hy(t.type,e.memoizedProps,t.pendingProps,e.memoizedState),null;case 27:return dn(t),e===null&&Ee&&(l=t.stateNode=ky(t.type,t.pendingProps,ne.current),st=t,Kt=!0,u=je,ga(t.type)?(Nc=u,je=$t(l.firstChild)):je=u),ot(e,t,t.pendingProps.children,a),vs(e,t),e===null&&(t.flags|=4194304),t.child;case 5:return e===null&&Ee&&((u=l=je)&&(l=Jb(l,t.type,t.pendingProps,Kt),l!==null?(t.stateNode=l,st=t,je=$t(l.firstChild),Kt=!1,u=!0):u=!1),u||ia(t)),dn(t),u=t.type,c=t.pendingProps,p=e!==null?e.memoizedProps:null,l=c.children,Mc(u,c)?l=null:p!==null&&Mc(u,p)&&(t.flags|=32),t.memoizedState!==null&&(u=Do(e,t,ob,null,null,a),il._currentValue=u),vs(e,t),ot(e,t,l,a),t.child;case 6:return e===null&&Ee&&((e=a=je)&&(a=Kb(a,t.pendingProps,Kt),a!==null?(t.stateNode=a,st=t,je=null,e=!0):e=!1),e||ia(t)),null;case 13:return wm(e,t,a);case 4:return ce(t,t.stateNode.containerInfo),l=t.pendingProps,e===null?t.child=Za(t,null,l,a):ot(e,t,l,a),t.child;case 11:return pm(e,t,t.type,t.pendingProps,a);case 7:return ot(e,t,t.pendingProps,a),t.child;case 8:return ot(e,t,t.pendingProps.children,a),t.child;case 12:return ot(e,t,t.pendingProps.children,a),t.child;case 10:return l=t.pendingProps,ra(t,t.type,l.value),ot(e,t,l.children,a),t.child;case 9:return u=t.type._context,l=t.pendingProps.children,Ya(t),u=ut(u),l=l(u),t.flags|=1,ot(e,t,l,a),t.child;case 14:return vm(e,t,t.type,t.pendingProps,a);case 15:return gm(e,t,t.type,t.pendingProps,a);case 19:return Dm(e,t,a);case 31:return vb(e,t,a);case 22:return bm(e,t,a,t.pendingProps);case 24:return Ya(t),l=ut(Ze),e===null?(u=vo(),u===null&&(u=Ne,c=yo(),u.pooledCache=c,c.refCount++,c!==null&&(u.pooledCacheLanes|=a),u=c),t.memoizedState={parent:l,cache:u},bo(t),ra(t,Ze,u)):((e.lanes&a)!==0&&(So(e,t),Lr(t,null,null,a),qr()),u=e.memoizedState,c=t.memoizedState,u.parent!==l?(u={parent:l,cache:l},t.memoizedState=u,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=u),ra(t,Ze,l)):(l=c.cache,ra(t,Ze,l),l!==u.cache&&mo(t,[Ze],a,!0))),ot(e,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(s(156,t.tag))}function qn(e){e.flags|=4}function tc(e,t,a,l,u){if((t=(e.mode&32)!==0)&&(t=!1),t){if(e.flags|=16777216,(u&335544128)===u)if(e.stateNode.complete)e.flags|=8192;else if(ty())e.flags|=8192;else throw Fa=ns,go}else e.flags&=-16777217}function Cm(e,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)e.flags&=-16777217;else if(e.flags|=16777216,!Gy(t))if(ty())e.flags|=8192;else throw Fa=ns,go}function bs(e,t){t!==null&&(e.flags|=4),e.flags&16384&&(t=e.tag!==22?pt():536870912,e.lanes|=t,Hi|=t)}function Gr(e,t){if(!Ee)switch(e.tailMode){case"hidden":t=e.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?e.tail=null:a.sibling=null;break;case"collapsed":a=e.tail;for(var l=null;a!==null;)a.alternate!==null&&(l=a),a=a.sibling;l===null?t||e.tail===null?e.tail=null:e.tail.sibling=null:l.sibling=null}}function Ue(e){var t=e.alternate!==null&&e.alternate.child===e.child,a=0,l=0;if(t)for(var u=e.child;u!==null;)a|=u.lanes|u.childLanes,l|=u.subtreeFlags&65011712,l|=u.flags&65011712,u.return=e,u=u.sibling;else for(u=e.child;u!==null;)a|=u.lanes|u.childLanes,l|=u.subtreeFlags,l|=u.flags,u.return=e,u=u.sibling;return e.subtreeFlags|=l,e.childLanes=a,t}function bb(e,t,a){var l=t.pendingProps;switch(uo(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Ue(t),null;case 1:return Ue(t),null;case 3:return a=t.stateNode,l=null,e!==null&&(l=e.memoizedState.cache),t.memoizedState.cache!==l&&(t.flags|=2048),Nn(Ze),Ce(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(e===null||e.child===null)&&(Ai(t)?qn(t):e===null||e.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,co())),Ue(t),null;case 26:var u=t.type,c=t.memoizedState;return e===null?(qn(t),c!==null?(Ue(t),Cm(t,c)):(Ue(t),tc(t,u,null,l,a))):c?c!==e.memoizedState?(qn(t),Ue(t),Cm(t,c)):(Ue(t),t.flags&=-16777217):(e=e.memoizedProps,e!==l&&qn(t),Ue(t),tc(t,u,e,l,a)),null;case 27:if(wn(t),a=ne.current,u=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==l&&qn(t);else{if(!l){if(t.stateNode===null)throw Error(s(166));return Ue(t),null}e=G.current,Ai(t)?uh(t):(e=ky(u,l,a),t.stateNode=e,qn(t))}return Ue(t),null;case 5:if(wn(t),u=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==l&&qn(t);else{if(!l){if(t.stateNode===null)throw Error(s(166));return Ue(t),null}if(c=G.current,Ai(t))uh(t);else{var p=js(ne.current);switch(c){case 1:c=p.createElementNS("http://www.w3.org/2000/svg",u);break;case 2:c=p.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;default:switch(u){case"svg":c=p.createElementNS("http://www.w3.org/2000/svg",u);break;case"math":c=p.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;case"script":c=p.createElement("div"),c.innerHTML="<script><\/script>",c=c.removeChild(c.firstChild);break;case"select":c=typeof l.is=="string"?p.createElement("select",{is:l.is}):p.createElement("select"),l.multiple?c.multiple=!0:l.size&&(c.size=l.size);break;default:c=typeof l.is=="string"?p.createElement(u,{is:l.is}):p.createElement(u)}}c[lt]=t,c[At]=l;e:for(p=t.child;p!==null;){if(p.tag===5||p.tag===6)c.appendChild(p.stateNode);else if(p.tag!==4&&p.tag!==27&&p.child!==null){p.child.return=p,p=p.child;continue}if(p===t)break e;for(;p.sibling===null;){if(p.return===null||p.return===t)break e;p=p.return}p.sibling.return=p.return,p=p.sibling}t.stateNode=c;e:switch(ct(c,u,l),u){case"button":case"input":case"select":case"textarea":l=!!l.autoFocus;break e;case"img":l=!0;break e;default:l=!1}l&&qn(t)}}return Ue(t),tc(t,t.type,e===null?null:e.memoizedProps,t.pendingProps,a),null;case 6:if(e&&t.stateNode!=null)e.memoizedProps!==l&&qn(t);else{if(typeof l!="string"&&t.stateNode===null)throw Error(s(166));if(e=ne.current,Ai(t)){if(e=t.stateNode,a=t.memoizedProps,l=null,u=st,u!==null)switch(u.tag){case 27:case 5:l=u.memoizedProps}e[lt]=t,e=!!(e.nodeValue===a||l!==null&&l.suppressHydrationWarning===!0||wy(e.nodeValue,a)),e||ia(t,!0)}else e=js(e).createTextNode(l),e[lt]=t,t.stateNode=e}return Ue(t),null;case 31:if(a=t.memoizedState,e===null||e.memoizedState!==null){if(l=Ai(t),a!==null){if(e===null){if(!l)throw Error(s(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(s(557));e[lt]=t}else Va(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;Ue(t),e=!1}else a=co(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=a),e=!0;if(!e)return t.flags&256?(Ht(t),t):(Ht(t),null);if((t.flags&128)!==0)throw Error(s(558))}return Ue(t),null;case 13:if(l=t.memoizedState,e===null||e.memoizedState!==null&&e.memoizedState.dehydrated!==null){if(u=Ai(t),l!==null&&l.dehydrated!==null){if(e===null){if(!u)throw Error(s(318));if(u=t.memoizedState,u=u!==null?u.dehydrated:null,!u)throw Error(s(317));u[lt]=t}else Va(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;Ue(t),u=!1}else u=co(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=u),u=!0;if(!u)return t.flags&256?(Ht(t),t):(Ht(t),null)}return Ht(t),(t.flags&128)!==0?(t.lanes=a,t):(a=l!==null,e=e!==null&&e.memoizedState!==null,a&&(l=t.child,u=null,l.alternate!==null&&l.alternate.memoizedState!==null&&l.alternate.memoizedState.cachePool!==null&&(u=l.alternate.memoizedState.cachePool.pool),c=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(c=l.memoizedState.cachePool.pool),c!==u&&(l.flags|=2048)),a!==e&&a&&(t.child.flags|=8192),bs(t,t.updateQueue),Ue(t),null);case 4:return Ce(),e===null&&Oc(t.stateNode.containerInfo),Ue(t),null;case 10:return Nn(t.type),Ue(t),null;case 19:if(L(Ge),l=t.memoizedState,l===null)return Ue(t),null;if(u=(t.flags&128)!==0,c=l.rendering,c===null)if(u)Gr(l,!1);else{if(Qe!==0||e!==null&&(e.flags&128)!==0)for(e=t.child;e!==null;){if(c=ls(e),c!==null){for(t.flags|=128,Gr(l,!1),e=c.updateQueue,t.updateQueue=e,bs(t,e),t.subtreeFlags=0,e=a,a=t.child;a!==null;)ah(a,e),a=a.sibling;return V(Ge,Ge.current&1|2),Ee&&Rn(t,l.treeForkCount),t.child}e=e.sibling}l.tail!==null&&St()>_s&&(t.flags|=128,u=!0,Gr(l,!1),t.lanes=4194304)}else{if(!u)if(e=ls(c),e!==null){if(t.flags|=128,u=!0,e=e.updateQueue,t.updateQueue=e,bs(t,e),Gr(l,!0),l.tail===null&&l.tailMode==="hidden"&&!c.alternate&&!Ee)return Ue(t),null}else 2*St()-l.renderingStartTime>_s&&a!==536870912&&(t.flags|=128,u=!0,Gr(l,!1),t.lanes=4194304);l.isBackwards?(c.sibling=t.child,t.child=c):(e=l.last,e!==null?e.sibling=c:t.child=c,l.last=c)}return l.tail!==null?(e=l.tail,l.rendering=e,l.tail=e.sibling,l.renderingStartTime=St(),e.sibling=null,a=Ge.current,V(Ge,u?a&1|2:a&1),Ee&&Rn(t,l.treeForkCount),e):(Ue(t),null);case 22:case 23:return Ht(t),_o(),l=t.memoizedState!==null,e!==null?e.memoizedState!==null!==l&&(t.flags|=8192):l&&(t.flags|=8192),l?(a&536870912)!==0&&(t.flags&128)===0&&(Ue(t),t.subtreeFlags&6&&(t.flags|=8192)):Ue(t),a=t.updateQueue,a!==null&&bs(t,a.retryQueue),a=null,e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(a=e.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==a&&(t.flags|=2048),e!==null&&L(Ga),null;case 24:return a=null,e!==null&&(a=e.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Nn(Ze),Ue(t),null;case 25:return null;case 30:return null}throw Error(s(156,t.tag))}function Sb(e,t){switch(uo(t),t.tag){case 1:return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 3:return Nn(Ze),Ce(),e=t.flags,(e&65536)!==0&&(e&128)===0?(t.flags=e&-65537|128,t):null;case 26:case 27:case 5:return wn(t),null;case 31:if(t.memoizedState!==null){if(Ht(t),t.alternate===null)throw Error(s(340));Va()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 13:if(Ht(t),e=t.memoizedState,e!==null&&e.dehydrated!==null){if(t.alternate===null)throw Error(s(340));Va()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 19:return L(Ge),null;case 4:return Ce(),null;case 10:return Nn(t.type),null;case 22:case 23:return Ht(t),_o(),e!==null&&L(Ga),e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 24:return Nn(Ze),null;case 25:return null;default:return null}}function xm(e,t){switch(uo(t),t.tag){case 3:Nn(Ze),Ce();break;case 26:case 27:case 5:wn(t);break;case 4:Ce();break;case 31:t.memoizedState!==null&&Ht(t);break;case 13:Ht(t);break;case 19:L(Ge);break;case 10:Nn(t.type);break;case 22:case 23:Ht(t),_o(),e!==null&&L(Ga);break;case 24:Nn(Ze)}}function Xr(e,t){try{var a=t.updateQueue,l=a!==null?a.lastEffect:null;if(l!==null){var u=l.next;a=u;do{if((a.tag&e)===e){l=void 0;var c=a.create,p=a.inst;l=c(),p.destroy=l}a=a.next}while(a!==u)}}catch(g){Me(t,t.return,g)}}function fa(e,t,a){try{var l=t.updateQueue,u=l!==null?l.lastEffect:null;if(u!==null){var c=u.next;l=c;do{if((l.tag&e)===e){var p=l.inst,g=p.destroy;if(g!==void 0){p.destroy=void 0,u=t;var T=a,x=g;try{x()}catch(k){Me(u,T,k)}}}l=l.next}while(l!==c)}}catch(k){Me(t,t.return,k)}}function Rm(e){var t=e.updateQueue;if(t!==null){var a=e.stateNode;try{Eh(t,a)}catch(l){Me(e,e.return,l)}}}function zm(e,t,a){a.props=Ka(e.type,e.memoizedProps),a.state=e.memoizedState;try{a.componentWillUnmount()}catch(l){Me(e,t,l)}}function Fr(e,t){try{var a=e.ref;if(a!==null){switch(e.tag){case 26:case 27:case 5:var l=e.stateNode;break;case 30:l=e.stateNode;break;default:l=e.stateNode}typeof a=="function"?e.refCleanup=a(l):a.current=l}}catch(u){Me(e,t,u)}}function gn(e,t){var a=e.ref,l=e.refCleanup;if(a!==null)if(typeof l=="function")try{l()}catch(u){Me(e,t,u)}finally{e.refCleanup=null,e=e.alternate,e!=null&&(e.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(u){Me(e,t,u)}else a.current=null}function Nm(e){var t=e.type,a=e.memoizedProps,l=e.stateNode;try{e:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&l.focus();break e;case"img":a.src?l.src=a.src:a.srcSet&&(l.srcset=a.srcSet)}}catch(u){Me(e,e.return,u)}}function nc(e,t,a){try{var l=e.stateNode;Qb(l,e.type,a,t),l[At]=t}catch(u){Me(e,e.return,u)}}function jm(e){return e.tag===5||e.tag===3||e.tag===26||e.tag===27&&ga(e.type)||e.tag===4}function ac(e){e:for(;;){for(;e.sibling===null;){if(e.return===null||jm(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;e.tag!==5&&e.tag!==6&&e.tag!==18;){if(e.tag===27&&ga(e.type)||e.flags&2||e.child===null||e.tag===4)continue e;e.child.return=e,e=e.child}if(!(e.flags&2))return e.stateNode}}function ic(e,t,a){var l=e.tag;if(l===5||l===6)e=e.stateNode,t?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(e,t):(t=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,t.appendChild(e),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=Mn));else if(l!==4&&(l===27&&ga(e.type)&&(a=e.stateNode,t=null),e=e.child,e!==null))for(ic(e,t,a),e=e.sibling;e!==null;)ic(e,t,a),e=e.sibling}function Ss(e,t,a){var l=e.tag;if(l===5||l===6)e=e.stateNode,t?a.insertBefore(e,t):a.appendChild(e);else if(l!==4&&(l===27&&ga(e.type)&&(a=e.stateNode),e=e.child,e!==null))for(Ss(e,t,a),e=e.sibling;e!==null;)Ss(e,t,a),e=e.sibling}function Um(e){var t=e.stateNode,a=e.memoizedProps;try{for(var l=e.type,u=t.attributes;u.length;)t.removeAttributeNode(u[0]);ct(t,l,a),t[lt]=e,t[At]=a}catch(c){Me(e,e.return,c)}}var Ln=!1,Ie=!1,rc=!1,km=typeof WeakSet=="function"?WeakSet:Set,nt=null;function Eb(e,t){if(e=e.containerInfo,Ac=Vs,e=Jd(e),$u(e)){if("selectionStart"in e)var a={start:e.selectionStart,end:e.selectionEnd};else e:{a=(a=e.ownerDocument)&&a.defaultView||window;var l=a.getSelection&&a.getSelection();if(l&&l.rangeCount!==0){a=l.anchorNode;var u=l.anchorOffset,c=l.focusNode;l=l.focusOffset;try{a.nodeType,c.nodeType}catch{a=null;break e}var p=0,g=-1,T=-1,x=0,k=0,H=e,z=null;t:for(;;){for(var j;H!==a||u!==0&&H.nodeType!==3||(g=p+u),H!==c||l!==0&&H.nodeType!==3||(T=p+l),H.nodeType===3&&(p+=H.nodeValue.length),(j=H.firstChild)!==null;)z=H,H=j;for(;;){if(H===e)break t;if(z===a&&++x===u&&(g=p),z===c&&++k===l&&(T=p),(j=H.nextSibling)!==null)break;H=z,z=H.parentNode}H=j}a=g===-1||T===-1?null:{start:g,end:T}}else a=null}a=a||{start:0,end:0}}else a=null;for(Dc={focusedElem:e,selectionRange:a},Vs=!1,nt=t;nt!==null;)if(t=nt,e=t.child,(t.subtreeFlags&1028)!==0&&e!==null)e.return=t,nt=e;else for(;nt!==null;){switch(t=nt,c=t.alternate,e=t.flags,t.tag){case 0:if((e&4)!==0&&(e=t.updateQueue,e=e!==null?e.events:null,e!==null))for(a=0;a<e.length;a++)u=e[a],u.ref.impl=u.nextImpl;break;case 11:case 15:break;case 1:if((e&1024)!==0&&c!==null){e=void 0,a=t,u=c.memoizedProps,c=c.memoizedState,l=a.stateNode;try{var J=Ka(a.type,u);e=l.getSnapshotBeforeUpdate(J,c),l.__reactInternalSnapshotBeforeUpdate=e}catch(te){Me(a,a.return,te)}}break;case 3:if((e&1024)!==0){if(e=t.stateNode.containerInfo,a=e.nodeType,a===9)xc(e);else if(a===1)switch(e.nodeName){case"HEAD":case"HTML":case"BODY":xc(e);break;default:e.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((e&1024)!==0)throw Error(s(163))}if(e=t.sibling,e!==null){e.return=t.return,nt=e;break}nt=t.return}}function qm(e,t,a){var l=a.flags;switch(a.tag){case 0:case 11:case 15:Bn(e,a),l&4&&Xr(5,a);break;case 1:if(Bn(e,a),l&4)if(e=a.stateNode,t===null)try{e.componentDidMount()}catch(p){Me(a,a.return,p)}else{var u=Ka(a.type,t.memoizedProps);t=t.memoizedState;try{e.componentDidUpdate(u,t,e.__reactInternalSnapshotBeforeUpdate)}catch(p){Me(a,a.return,p)}}l&64&&Rm(a),l&512&&Fr(a,a.return);break;case 3:if(Bn(e,a),l&64&&(e=a.updateQueue,e!==null)){if(t=null,a.child!==null)switch(a.child.tag){case 27:case 5:t=a.child.stateNode;break;case 1:t=a.child.stateNode}try{Eh(e,t)}catch(p){Me(a,a.return,p)}}break;case 27:t===null&&l&4&&Um(a);case 26:case 5:Bn(e,a),t===null&&l&4&&Nm(a),l&512&&Fr(a,a.return);break;case 12:Bn(e,a);break;case 31:Bn(e,a),l&4&&Bm(e,a);break;case 13:Bn(e,a),l&4&&Vm(e,a),l&64&&(e=a.memoizedState,e!==null&&(e=e.dehydrated,e!==null&&(a=xb.bind(null,a),Ib(e,a))));break;case 22:if(l=a.memoizedState!==null||Ln,!l){t=t!==null&&t.memoizedState!==null||Ie,u=Ln;var c=Ie;Ln=l,(Ie=t)&&!c?Vn(e,a,(a.subtreeFlags&8772)!==0):Bn(e,a),Ln=u,Ie=c}break;case 30:break;default:Bn(e,a)}}function Lm(e){var t=e.alternate;t!==null&&(e.alternate=null,Lm(t)),e.child=null,e.deletions=null,e.sibling=null,e.tag===5&&(t=e.stateNode,t!==null&&ju(t)),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}var Le=null,Mt=!1;function Hn(e,t,a){for(a=a.child;a!==null;)Hm(e,t,a),a=a.sibling}function Hm(e,t,a){if(Et&&typeof Et.onCommitFiberUnmount=="function")try{Et.onCommitFiberUnmount(za,a)}catch{}switch(a.tag){case 26:Ie||gn(a,t),Hn(e,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:Ie||gn(a,t);var l=Le,u=Mt;ga(a.type)&&(Le=a.stateNode,Mt=!1),Hn(e,t,a),tl(a.stateNode),Le=l,Mt=u;break;case 5:Ie||gn(a,t);case 6:if(l=Le,u=Mt,Le=null,Hn(e,t,a),Le=l,Mt=u,Le!==null)if(Mt)try{(Le.nodeType===9?Le.body:Le.nodeName==="HTML"?Le.ownerDocument.body:Le).removeChild(a.stateNode)}catch(c){Me(a,t,c)}else try{Le.removeChild(a.stateNode)}catch(c){Me(a,t,c)}break;case 18:Le!==null&&(Mt?(e=Le,Ry(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,a.stateNode),Zi(e)):Ry(Le,a.stateNode));break;case 4:l=Le,u=Mt,Le=a.stateNode.containerInfo,Mt=!0,Hn(e,t,a),Le=l,Mt=u;break;case 0:case 11:case 14:case 15:fa(2,a,t),Ie||fa(4,a,t),Hn(e,t,a);break;case 1:Ie||(gn(a,t),l=a.stateNode,typeof l.componentWillUnmount=="function"&&zm(a,t,l)),Hn(e,t,a);break;case 21:Hn(e,t,a);break;case 22:Ie=(l=Ie)||a.memoizedState!==null,Hn(e,t,a),Ie=l;break;default:Hn(e,t,a)}}function Bm(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null))){e=e.dehydrated;try{Zi(e)}catch(a){Me(t,t.return,a)}}}function Vm(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null&&(e=e.dehydrated,e!==null))))try{Zi(e)}catch(a){Me(t,t.return,a)}}function Tb(e){switch(e.tag){case 31:case 13:case 19:var t=e.stateNode;return t===null&&(t=e.stateNode=new km),t;case 22:return e=e.stateNode,t=e._retryCache,t===null&&(t=e._retryCache=new km),t;default:throw Error(s(435,e.tag))}}function Es(e,t){var a=Tb(e);t.forEach(function(l){if(!a.has(l)){a.add(l);var u=Rb.bind(null,e,l);l.then(u,u)}})}function Ct(e,t){var a=t.deletions;if(a!==null)for(var l=0;l<a.length;l++){var u=a[l],c=e,p=t,g=p;e:for(;g!==null;){switch(g.tag){case 27:if(ga(g.type)){Le=g.stateNode,Mt=!1;break e}break;case 5:Le=g.stateNode,Mt=!1;break e;case 3:case 4:Le=g.stateNode.containerInfo,Mt=!0;break e}g=g.return}if(Le===null)throw Error(s(160));Hm(c,p,u),Le=null,Mt=!1,c=u.alternate,c!==null&&(c.return=null),u.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)Qm(t,e),t=t.sibling}var sn=null;function Qm(e,t){var a=e.alternate,l=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:Ct(t,e),xt(e),l&4&&(fa(3,e,e.return),Xr(3,e),fa(5,e,e.return));break;case 1:Ct(t,e),xt(e),l&512&&(Ie||a===null||gn(a,a.return)),l&64&&Ln&&(e=e.updateQueue,e!==null&&(l=e.callbacks,l!==null&&(a=e.shared.hiddenCallbacks,e.shared.hiddenCallbacks=a===null?l:a.concat(l))));break;case 26:var u=sn;if(Ct(t,e),xt(e),l&512&&(Ie||a===null||gn(a,a.return)),l&4){var c=a!==null?a.memoizedState:null;if(l=e.memoizedState,a===null)if(l===null)if(e.stateNode===null){e:{l=e.type,a=e.memoizedProps,u=u.ownerDocument||u;t:switch(l){case"title":c=u.getElementsByTagName("title")[0],(!c||c[br]||c[lt]||c.namespaceURI==="http://www.w3.org/2000/svg"||c.hasAttribute("itemprop"))&&(c=u.createElement(l),u.head.insertBefore(c,u.querySelector("head > title"))),ct(c,l,a),c[lt]=e,tt(c),l=c;break e;case"link":var p=Qy("link","href",u).get(l+(a.href||""));if(p){for(var g=0;g<p.length;g++)if(c=p[g],c.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&c.getAttribute("rel")===(a.rel==null?null:a.rel)&&c.getAttribute("title")===(a.title==null?null:a.title)&&c.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){p.splice(g,1);break t}}c=u.createElement(l),ct(c,l,a),u.head.appendChild(c);break;case"meta":if(p=Qy("meta","content",u).get(l+(a.content||""))){for(g=0;g<p.length;g++)if(c=p[g],c.getAttribute("content")===(a.content==null?null:""+a.content)&&c.getAttribute("name")===(a.name==null?null:a.name)&&c.getAttribute("property")===(a.property==null?null:a.property)&&c.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&c.getAttribute("charset")===(a.charSet==null?null:a.charSet)){p.splice(g,1);break t}}c=u.createElement(l),ct(c,l,a),u.head.appendChild(c);break;default:throw Error(s(468,l))}c[lt]=e,tt(c),l=c}e.stateNode=l}else Yy(u,e.type,e.stateNode);else e.stateNode=Vy(u,l,e.memoizedProps);else c!==l?(c===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):c.count--,l===null?Yy(u,e.type,e.stateNode):Vy(u,l,e.memoizedProps)):l===null&&e.stateNode!==null&&nc(e,e.memoizedProps,a.memoizedProps)}break;case 27:Ct(t,e),xt(e),l&512&&(Ie||a===null||gn(a,a.return)),a!==null&&l&4&&nc(e,e.memoizedProps,a.memoizedProps);break;case 5:if(Ct(t,e),xt(e),l&512&&(Ie||a===null||gn(a,a.return)),e.flags&32){u=e.stateNode;try{pi(u,"")}catch(J){Me(e,e.return,J)}}l&4&&e.stateNode!=null&&(u=e.memoizedProps,nc(e,u,a!==null?a.memoizedProps:u)),l&1024&&(rc=!0);break;case 6:if(Ct(t,e),xt(e),l&4){if(e.stateNode===null)throw Error(s(162));l=e.memoizedProps,a=e.stateNode;try{a.nodeValue=l}catch(J){Me(e,e.return,J)}}break;case 3:if(qs=null,u=sn,sn=Us(t.containerInfo),Ct(t,e),sn=u,xt(e),l&4&&a!==null&&a.memoizedState.isDehydrated)try{Zi(t.containerInfo)}catch(J){Me(e,e.return,J)}rc&&(rc=!1,Ym(e));break;case 4:l=sn,sn=Us(e.stateNode.containerInfo),Ct(t,e),xt(e),sn=l;break;case 12:Ct(t,e),xt(e);break;case 31:Ct(t,e),xt(e),l&4&&(l=e.updateQueue,l!==null&&(e.updateQueue=null,Es(e,l)));break;case 13:Ct(t,e),xt(e),e.child.flags&8192&&e.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(Os=St()),l&4&&(l=e.updateQueue,l!==null&&(e.updateQueue=null,Es(e,l)));break;case 22:u=e.memoizedState!==null;var T=a!==null&&a.memoizedState!==null,x=Ln,k=Ie;if(Ln=x||u,Ie=k||T,Ct(t,e),Ie=k,Ln=x,xt(e),l&8192)e:for(t=e.stateNode,t._visibility=u?t._visibility&-2:t._visibility|1,u&&(a===null||T||Ln||Ie||Ia(e)),a=null,t=e;;){if(t.tag===5||t.tag===26){if(a===null){T=a=t;try{if(c=T.stateNode,u)p=c.style,typeof p.setProperty=="function"?p.setProperty("display","none","important"):p.display="none";else{g=T.stateNode;var H=T.memoizedProps.style,z=H!=null&&H.hasOwnProperty("display")?H.display:null;g.style.display=z==null||typeof z=="boolean"?"":(""+z).trim()}}catch(J){Me(T,T.return,J)}}}else if(t.tag===6){if(a===null){T=t;try{T.stateNode.nodeValue=u?"":T.memoizedProps}catch(J){Me(T,T.return,J)}}}else if(t.tag===18){if(a===null){T=t;try{var j=T.stateNode;u?zy(j,!0):zy(T.stateNode,!1)}catch(J){Me(T,T.return,J)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===e)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break e;for(;t.sibling===null;){if(t.return===null||t.return===e)break e;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}l&4&&(l=e.updateQueue,l!==null&&(a=l.retryQueue,a!==null&&(l.retryQueue=null,Es(e,a))));break;case 19:Ct(t,e),xt(e),l&4&&(l=e.updateQueue,l!==null&&(e.updateQueue=null,Es(e,l)));break;case 30:break;case 21:break;default:Ct(t,e),xt(e)}}function xt(e){var t=e.flags;if(t&2){try{for(var a,l=e.return;l!==null;){if(jm(l)){a=l;break}l=l.return}if(a==null)throw Error(s(160));switch(a.tag){case 27:var u=a.stateNode,c=ac(e);Ss(e,c,u);break;case 5:var p=a.stateNode;a.flags&32&&(pi(p,""),a.flags&=-33);var g=ac(e);Ss(e,g,p);break;case 3:case 4:var T=a.stateNode.containerInfo,x=ac(e);ic(e,x,T);break;default:throw Error(s(161))}}catch(k){Me(e,e.return,k)}e.flags&=-3}t&4096&&(e.flags&=-4097)}function Ym(e){if(e.subtreeFlags&1024)for(e=e.child;e!==null;){var t=e;Ym(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),e=e.sibling}}function Bn(e,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)qm(e,t.alternate,t),t=t.sibling}function Ia(e){for(e=e.child;e!==null;){var t=e;switch(t.tag){case 0:case 11:case 14:case 15:fa(4,t,t.return),Ia(t);break;case 1:gn(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&zm(t,t.return,a),Ia(t);break;case 27:tl(t.stateNode);case 26:case 5:gn(t,t.return),Ia(t);break;case 22:t.memoizedState===null&&Ia(t);break;case 30:Ia(t);break;default:Ia(t)}e=e.sibling}}function Vn(e,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var l=t.alternate,u=e,c=t,p=c.flags;switch(c.tag){case 0:case 11:case 15:Vn(u,c,a),Xr(4,c);break;case 1:if(Vn(u,c,a),l=c,u=l.stateNode,typeof u.componentDidMount=="function")try{u.componentDidMount()}catch(x){Me(l,l.return,x)}if(l=c,u=l.updateQueue,u!==null){var g=l.stateNode;try{var T=u.shared.hiddenCallbacks;if(T!==null)for(u.shared.hiddenCallbacks=null,u=0;u<T.length;u++)Sh(T[u],g)}catch(x){Me(l,l.return,x)}}a&&p&64&&Rm(c),Fr(c,c.return);break;case 27:Um(c);case 26:case 5:Vn(u,c,a),a&&l===null&&p&4&&Nm(c),Fr(c,c.return);break;case 12:Vn(u,c,a);break;case 31:Vn(u,c,a),a&&p&4&&Bm(u,c);break;case 13:Vn(u,c,a),a&&p&4&&Vm(u,c);break;case 22:c.memoizedState===null&&Vn(u,c,a),Fr(c,c.return);break;case 30:break;default:Vn(u,c,a)}t=t.sibling}}function lc(e,t){var a=null;e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(a=e.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==a&&(e!=null&&e.refCount++,a!=null&&zr(a))}function sc(e,t){e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&zr(e))}function un(e,t,a,l){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)Gm(e,t,a,l),t=t.sibling}function Gm(e,t,a,l){var u=t.flags;switch(t.tag){case 0:case 11:case 15:un(e,t,a,l),u&2048&&Xr(9,t);break;case 1:un(e,t,a,l);break;case 3:un(e,t,a,l),u&2048&&(e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&zr(e)));break;case 12:if(u&2048){un(e,t,a,l),e=t.stateNode;try{var c=t.memoizedProps,p=c.id,g=c.onPostCommit;typeof g=="function"&&g(p,t.alternate===null?"mount":"update",e.passiveEffectDuration,-0)}catch(T){Me(t,t.return,T)}}else un(e,t,a,l);break;case 31:un(e,t,a,l);break;case 13:un(e,t,a,l);break;case 23:break;case 22:c=t.stateNode,p=t.alternate,t.memoizedState!==null?c._visibility&2?un(e,t,a,l):Zr(e,t):c._visibility&2?un(e,t,a,l):(c._visibility|=2,ki(e,t,a,l,(t.subtreeFlags&10256)!==0||!1)),u&2048&&lc(p,t);break;case 24:un(e,t,a,l),u&2048&&sc(t.alternate,t);break;default:un(e,t,a,l)}}function ki(e,t,a,l,u){for(u=u&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var c=e,p=t,g=a,T=l,x=p.flags;switch(p.tag){case 0:case 11:case 15:ki(c,p,g,T,u),Xr(8,p);break;case 23:break;case 22:var k=p.stateNode;p.memoizedState!==null?k._visibility&2?ki(c,p,g,T,u):Zr(c,p):(k._visibility|=2,ki(c,p,g,T,u)),u&&x&2048&&lc(p.alternate,p);break;case 24:ki(c,p,g,T,u),u&&x&2048&&sc(p.alternate,p);break;default:ki(c,p,g,T,u)}t=t.sibling}}function Zr(e,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=e,l=t,u=l.flags;switch(l.tag){case 22:Zr(a,l),u&2048&&lc(l.alternate,l);break;case 24:Zr(a,l),u&2048&&sc(l.alternate,l);break;default:Zr(a,l)}t=t.sibling}}var Jr=8192;function qi(e,t,a){if(e.subtreeFlags&Jr)for(e=e.child;e!==null;)Xm(e,t,a),e=e.sibling}function Xm(e,t,a){switch(e.tag){case 26:qi(e,t,a),e.flags&Jr&&e.memoizedState!==null&&uS(a,sn,e.memoizedState,e.memoizedProps);break;case 5:qi(e,t,a);break;case 3:case 4:var l=sn;sn=Us(e.stateNode.containerInfo),qi(e,t,a),sn=l;break;case 22:e.memoizedState===null&&(l=e.alternate,l!==null&&l.memoizedState!==null?(l=Jr,Jr=16777216,qi(e,t,a),Jr=l):qi(e,t,a));break;default:qi(e,t,a)}}function Fm(e){var t=e.alternate;if(t!==null&&(e=t.child,e!==null)){t.child=null;do t=e.sibling,e.sibling=null,e=t;while(e!==null)}}function Kr(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var l=t[a];nt=l,Jm(l,e)}Fm(e)}if(e.subtreeFlags&10256)for(e=e.child;e!==null;)Zm(e),e=e.sibling}function Zm(e){switch(e.tag){case 0:case 11:case 15:Kr(e),e.flags&2048&&fa(9,e,e.return);break;case 3:Kr(e);break;case 12:Kr(e);break;case 22:var t=e.stateNode;e.memoizedState!==null&&t._visibility&2&&(e.return===null||e.return.tag!==13)?(t._visibility&=-3,Ts(e)):Kr(e);break;default:Kr(e)}}function Ts(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var l=t[a];nt=l,Jm(l,e)}Fm(e)}for(e=e.child;e!==null;){switch(t=e,t.tag){case 0:case 11:case 15:fa(8,t,t.return),Ts(t);break;case 22:a=t.stateNode,a._visibility&2&&(a._visibility&=-3,Ts(t));break;default:Ts(t)}e=e.sibling}}function Jm(e,t){for(;nt!==null;){var a=nt;switch(a.tag){case 0:case 11:case 15:fa(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var l=a.memoizedState.cachePool.pool;l!=null&&l.refCount++}break;case 24:zr(a.memoizedState.cache)}if(l=a.child,l!==null)l.return=a,nt=l;else e:for(a=e;nt!==null;){l=nt;var u=l.sibling,c=l.return;if(Lm(l),l===a){nt=null;break e}if(u!==null){u.return=c,nt=u;break e}nt=c}}}var Ob={getCacheForType:function(e){var t=ut(Ze),a=t.data.get(e);return a===void 0&&(a=e(),t.data.set(e,a)),a},cacheSignal:function(){return ut(Ze).controller.signal}},_b=typeof WeakMap=="function"?WeakMap:Map,Ae=0,Ne=null,me=null,ve=0,De=0,Bt=null,da=!1,Li=!1,uc=!1,Qn=0,Qe=0,ha=0,$a=0,oc=0,Vt=0,Hi=0,Ir=null,Rt=null,cc=!1,Os=0,Km=0,_s=1/0,ws=null,ma=null,We=0,ya=null,Bi=null,Yn=0,fc=0,dc=null,Im=null,$r=0,hc=null;function Qt(){return(Ae&2)!==0&&ve!==0?ve&-ve:R.T!==null?bc():zu()}function $m(){if(Vt===0)if((ve&536870912)===0||Ee){var e=ui;ui<<=1,(ui&3932160)===0&&(ui=262144),Vt=e}else Vt=536870912;return e=Lt.current,e!==null&&(e.flags|=32),Vt}function zt(e,t,a){(e===Ne&&(De===2||De===9)||e.cancelPendingCommit!==null)&&(Vi(e,0),pa(e,ve,Vt,!1)),Be(e,a),((Ae&2)===0||e!==Ne)&&(e===Ne&&((Ae&2)===0&&($a|=a),Qe===4&&pa(e,ve,Vt,!1)),bn(e))}function Wm(e,t,a){if((Ae&6)!==0)throw Error(s(327));var l=!a&&(t&127)===0&&(t&e.expiredLanes)===0||qe(e,t),u=l?Db(e,t):yc(e,t,!0),c=l;do{if(u===0){Li&&!l&&pa(e,t,0,!1);break}else{if(a=e.current.alternate,c&&!wb(a)){u=yc(e,t,!1),c=!1;continue}if(u===2){if(c=t,e.errorRecoveryDisabledLanes&c)var p=0;else p=e.pendingLanes&-536870913,p=p!==0?p:p&536870912?536870912:0;if(p!==0){t=p;e:{var g=e;u=Ir;var T=g.current.memoizedState.isDehydrated;if(T&&(Vi(g,p).flags|=256),p=yc(g,p,!1),p!==2){if(uc&&!T){g.errorRecoveryDisabledLanes|=c,$a|=c,u=4;break e}c=Rt,Rt=u,c!==null&&(Rt===null?Rt=c:Rt.push.apply(Rt,c))}u=p}if(c=!1,u!==2)continue}}if(u===1){Vi(e,0),pa(e,t,0,!0);break}e:{switch(l=e,c=u,c){case 0:case 1:throw Error(s(345));case 4:if((t&4194048)!==t)break;case 6:pa(l,t,Vt,!da);break e;case 2:Rt=null;break;case 3:case 5:break;default:throw Error(s(329))}if((t&62914560)===t&&(u=Os+300-St(),10<u)){if(pa(l,t,Vt,!da),ie(l,0,!0)!==0)break e;Yn=t,l.timeoutHandle=Cy(Pm.bind(null,l,a,Rt,ws,cc,t,Vt,$a,Hi,da,c,"Throttled",-0,0),u);break e}Pm(l,a,Rt,ws,cc,t,Vt,$a,Hi,da,c,null,-0,0)}}break}while(!0);bn(e)}function Pm(e,t,a,l,u,c,p,g,T,x,k,H,z,j){if(e.timeoutHandle=-1,H=t.subtreeFlags,H&8192||(H&16785408)===16785408){H={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Mn},Xm(t,c,H);var J=(c&62914560)===c?Os-St():(c&4194048)===c?Km-St():0;if(J=oS(H,J),J!==null){Yn=c,e.cancelPendingCommit=J(sy.bind(null,e,t,c,a,l,u,p,g,T,k,H,null,z,j)),pa(e,c,p,!x);return}}sy(e,t,c,a,l,u,p,g,T)}function wb(e){for(var t=e;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var l=0;l<a.length;l++){var u=a[l],c=u.getSnapshot;u=u.value;try{if(!kt(c(),u))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function pa(e,t,a,l){t&=~oc,t&=~$a,e.suspendedLanes|=t,e.pingedLanes&=~t,l&&(e.warmLanes|=t),l=e.expirationTimes;for(var u=t;0<u;){var c=31-yt(u),p=1<<c;l[c]=-1,u&=~p}a!==0&&ja(e,a,t)}function As(){return(Ae&6)===0?(Wr(0),!1):!0}function mc(){if(me!==null){if(De===0)var e=me.return;else e=me,zn=Qa=null,xo(e),Ri=null,jr=0,e=me;for(;e!==null;)xm(e.alternate,e),e=e.return;me=null}}function Vi(e,t){var a=e.timeoutHandle;a!==-1&&(e.timeoutHandle=-1,Xb(a)),a=e.cancelPendingCommit,a!==null&&(e.cancelPendingCommit=null,a()),Yn=0,mc(),Ne=e,me=a=xn(e.current,null),ve=t,De=0,Bt=null,da=!1,Li=qe(e,t),uc=!1,Hi=Vt=oc=$a=ha=Qe=0,Rt=Ir=null,cc=!1,(t&8)!==0&&(t|=t&32);var l=e.entangledLanes;if(l!==0)for(e=e.entanglements,l&=t;0<l;){var u=31-yt(l),c=1<<u;t|=e[u],l&=~c}return Qn=t,Zl(),a}function ey(e,t){ue=null,R.H=Qr,t===xi||t===ts?(t=ph(),De=3):t===go?(t=ph(),De=4):De=t===Fo?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,Bt=t,me===null&&(Qe=1,ys(e,Ft(t,e.current)))}function ty(){var e=Lt.current;return e===null?!0:(ve&4194048)===ve?It===null:(ve&62914560)===ve||(ve&536870912)!==0?e===It:!1}function ny(){var e=R.H;return R.H=Qr,e===null?Qr:e}function ay(){var e=R.A;return R.A=Ob,e}function Ds(){Qe=4,da||(ve&4194048)!==ve&&Lt.current!==null||(Li=!0),(ha&134217727)===0&&($a&134217727)===0||Ne===null||pa(Ne,ve,Vt,!1)}function yc(e,t,a){var l=Ae;Ae|=2;var u=ny(),c=ay();(Ne!==e||ve!==t)&&(ws=null,Vi(e,t)),t=!1;var p=Qe;e:do try{if(De!==0&&me!==null){var g=me,T=Bt;switch(De){case 8:mc(),p=6;break e;case 3:case 2:case 9:case 6:Lt.current===null&&(t=!0);var x=De;if(De=0,Bt=null,Qi(e,g,T,x),a&&Li){p=0;break e}break;default:x=De,De=0,Bt=null,Qi(e,g,T,x)}}Ab(),p=Qe;break}catch(k){ey(e,k)}while(!0);return t&&e.shellSuspendCounter++,zn=Qa=null,Ae=l,R.H=u,R.A=c,me===null&&(Ne=null,ve=0,Zl()),p}function Ab(){for(;me!==null;)iy(me)}function Db(e,t){var a=Ae;Ae|=2;var l=ny(),u=ay();Ne!==e||ve!==t?(ws=null,_s=St()+500,Vi(e,t)):Li=qe(e,t);e:do try{if(De!==0&&me!==null){t=me;var c=Bt;t:switch(De){case 1:De=0,Bt=null,Qi(e,t,c,1);break;case 2:case 9:if(mh(c)){De=0,Bt=null,ry(t);break}t=function(){De!==2&&De!==9||Ne!==e||(De=7),bn(e)},c.then(t,t);break e;case 3:De=7;break e;case 4:De=5;break e;case 7:mh(c)?(De=0,Bt=null,ry(t)):(De=0,Bt=null,Qi(e,t,c,7));break;case 5:var p=null;switch(me.tag){case 26:p=me.memoizedState;case 5:case 27:var g=me;if(p?Gy(p):g.stateNode.complete){De=0,Bt=null;var T=g.sibling;if(T!==null)me=T;else{var x=g.return;x!==null?(me=x,Ms(x)):me=null}break t}}De=0,Bt=null,Qi(e,t,c,5);break;case 6:De=0,Bt=null,Qi(e,t,c,6);break;case 8:mc(),Qe=6;break e;default:throw Error(s(462))}}Mb();break}catch(k){ey(e,k)}while(!0);return zn=Qa=null,R.H=l,R.A=u,Ae=a,me!==null?0:(Ne=null,ve=0,Zl(),Qe)}function Mb(){for(;me!==null&&!bt();)iy(me)}function iy(e){var t=Mm(e.alternate,e,Qn);e.memoizedProps=e.pendingProps,t===null?Ms(e):me=t}function ry(e){var t=e,a=t.alternate;switch(t.tag){case 15:case 0:t=Tm(a,t,t.pendingProps,t.type,void 0,ve);break;case 11:t=Tm(a,t,t.pendingProps,t.type.render,t.ref,ve);break;case 5:xo(t);default:xm(a,t),t=me=ah(t,Qn),t=Mm(a,t,Qn)}e.memoizedProps=e.pendingProps,t===null?Ms(e):me=t}function Qi(e,t,a,l){zn=Qa=null,xo(t),Ri=null,jr=0;var u=t.return;try{if(pb(e,u,t,a,ve)){Qe=1,ys(e,Ft(a,e.current)),me=null;return}}catch(c){if(u!==null)throw me=u,c;Qe=1,ys(e,Ft(a,e.current)),me=null;return}t.flags&32768?(Ee||l===1?e=!0:Li||(ve&536870912)!==0?e=!1:(da=e=!0,(l===2||l===9||l===3||l===6)&&(l=Lt.current,l!==null&&l.tag===13&&(l.flags|=16384))),ly(t,e)):Ms(t)}function Ms(e){var t=e;do{if((t.flags&32768)!==0){ly(t,da);return}e=t.return;var a=bb(t.alternate,t,Qn);if(a!==null){me=a;return}if(t=t.sibling,t!==null){me=t;return}me=t=e}while(t!==null);Qe===0&&(Qe=5)}function ly(e,t){do{var a=Sb(e.alternate,e);if(a!==null){a.flags&=32767,me=a;return}if(a=e.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(e=e.sibling,e!==null)){me=e;return}me=e=a}while(e!==null);Qe=6,me=null}function sy(e,t,a,l,u,c,p,g,T){e.cancelPendingCommit=null;do Cs();while(We!==0);if((Ae&6)!==0)throw Error(s(327));if(t!==null){if(t===e.current)throw Error(s(177));if(c=t.lanes|t.childLanes,c|=no,Ot(e,a,c,p,g,T),e===Ne&&(me=Ne=null,ve=0),Bi=t,ya=e,Yn=a,fc=c,dc=u,Im=l,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(e.callbackNode=null,e.callbackPriority=0,zb(Ra,function(){return dy(),null})):(e.callbackNode=null,e.callbackPriority=0),l=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||l){l=R.T,R.T=null,u=Q.p,Q.p=2,p=Ae,Ae|=4;try{Eb(e,t,a)}finally{Ae=p,Q.p=u,R.T=l}}We=1,uy(),oy(),cy()}}function uy(){if(We===1){We=0;var e=ya,t=Bi,a=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||a){a=R.T,R.T=null;var l=Q.p;Q.p=2;var u=Ae;Ae|=4;try{Qm(t,e);var c=Dc,p=Jd(e.containerInfo),g=c.focusedElem,T=c.selectionRange;if(p!==g&&g&&g.ownerDocument&&Zd(g.ownerDocument.documentElement,g)){if(T!==null&&$u(g)){var x=T.start,k=T.end;if(k===void 0&&(k=x),"selectionStart"in g)g.selectionStart=x,g.selectionEnd=Math.min(k,g.value.length);else{var H=g.ownerDocument||document,z=H&&H.defaultView||window;if(z.getSelection){var j=z.getSelection(),J=g.textContent.length,te=Math.min(T.start,J),ze=T.end===void 0?te:Math.min(T.end,J);!j.extend&&te>ze&&(p=ze,ze=te,te=p);var A=Fd(g,te),w=Fd(g,ze);if(A&&w&&(j.rangeCount!==1||j.anchorNode!==A.node||j.anchorOffset!==A.offset||j.focusNode!==w.node||j.focusOffset!==w.offset)){var C=H.createRange();C.setStart(A.node,A.offset),j.removeAllRanges(),te>ze?(j.addRange(C),j.extend(w.node,w.offset)):(C.setEnd(w.node,w.offset),j.addRange(C))}}}}for(H=[],j=g;j=j.parentNode;)j.nodeType===1&&H.push({element:j,left:j.scrollLeft,top:j.scrollTop});for(typeof g.focus=="function"&&g.focus(),g=0;g<H.length;g++){var q=H[g];q.element.scrollLeft=q.left,q.element.scrollTop=q.top}}Vs=!!Ac,Dc=Ac=null}finally{Ae=u,Q.p=l,R.T=a}}e.current=t,We=2}}function oy(){if(We===2){We=0;var e=ya,t=Bi,a=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||a){a=R.T,R.T=null;var l=Q.p;Q.p=2;var u=Ae;Ae|=4;try{qm(e,t.alternate,t)}finally{Ae=u,Q.p=l,R.T=a}}We=3}}function cy(){if(We===4||We===3){We=0,$n();var e=ya,t=Bi,a=Yn,l=Im;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?We=5:(We=0,Bi=ya=null,fy(e,e.pendingLanes));var u=e.pendingLanes;if(u===0&&(ma=null),rn(a),t=t.stateNode,Et&&typeof Et.onCommitFiberRoot=="function")try{Et.onCommitFiberRoot(za,t,void 0,(t.current.flags&128)===128)}catch{}if(l!==null){t=R.T,u=Q.p,Q.p=2,R.T=null;try{for(var c=e.onRecoverableError,p=0;p<l.length;p++){var g=l[p];c(g.value,{componentStack:g.stack})}}finally{R.T=t,Q.p=u}}(Yn&3)!==0&&Cs(),bn(e),u=e.pendingLanes,(a&261930)!==0&&(u&42)!==0?e===hc?$r++:($r=0,hc=e):$r=0,Wr(0)}}function fy(e,t){(e.pooledCacheLanes&=t)===0&&(t=e.pooledCache,t!=null&&(e.pooledCache=null,zr(t)))}function Cs(){return uy(),oy(),cy(),dy()}function dy(){if(We!==5)return!1;var e=ya,t=fc;fc=0;var a=rn(Yn),l=R.T,u=Q.p;try{Q.p=32>a?32:a,R.T=null,a=dc,dc=null;var c=ya,p=Yn;if(We=0,Bi=ya=null,Yn=0,(Ae&6)!==0)throw Error(s(331));var g=Ae;if(Ae|=4,Zm(c.current),Gm(c,c.current,p,a),Ae=g,Wr(0,!1),Et&&typeof Et.onPostCommitFiberRoot=="function")try{Et.onPostCommitFiberRoot(za,c)}catch{}return!0}finally{Q.p=u,R.T=l,fy(e,t)}}function hy(e,t,a){t=Ft(a,t),t=Xo(e.stateNode,t,2),e=ua(e,t,2),e!==null&&(Be(e,2),bn(e))}function Me(e,t,a){if(e.tag===3)hy(e,e,a);else for(;t!==null;){if(t.tag===3){hy(t,e,a);break}else if(t.tag===1){var l=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof l.componentDidCatch=="function"&&(ma===null||!ma.has(l))){e=Ft(a,e),a=mm(2),l=ua(t,a,2),l!==null&&(ym(a,l,t,e),Be(l,2),bn(l));break}}t=t.return}}function pc(e,t,a){var l=e.pingCache;if(l===null){l=e.pingCache=new _b;var u=new Set;l.set(t,u)}else u=l.get(t),u===void 0&&(u=new Set,l.set(t,u));u.has(a)||(uc=!0,u.add(a),e=Cb.bind(null,e,t,a),t.then(e,e))}function Cb(e,t,a){var l=e.pingCache;l!==null&&l.delete(t),e.pingedLanes|=e.suspendedLanes&a,e.warmLanes&=~a,Ne===e&&(ve&a)===a&&(Qe===4||Qe===3&&(ve&62914560)===ve&&300>St()-Os?(Ae&2)===0&&Vi(e,0):oc|=a,Hi===ve&&(Hi=0)),bn(e)}function my(e,t){t===0&&(t=pt()),e=Ha(e,t),e!==null&&(Be(e,t),bn(e))}function xb(e){var t=e.memoizedState,a=0;t!==null&&(a=t.retryLane),my(e,a)}function Rb(e,t){var a=0;switch(e.tag){case 31:case 13:var l=e.stateNode,u=e.memoizedState;u!==null&&(a=u.retryLane);break;case 19:l=e.stateNode;break;case 22:l=e.stateNode._retryCache;break;default:throw Error(s(314))}l!==null&&l.delete(t),my(e,a)}function zb(e,t){return yr(e,t)}var xs=null,Yi=null,vc=!1,Rs=!1,gc=!1,va=0;function bn(e){e!==Yi&&e.next===null&&(Yi===null?xs=Yi=e:Yi=Yi.next=e),Rs=!0,vc||(vc=!0,jb())}function Wr(e,t){if(!gc&&Rs){gc=!0;do for(var a=!1,l=xs;l!==null;){if(e!==0){var u=l.pendingLanes;if(u===0)var c=0;else{var p=l.suspendedLanes,g=l.pingedLanes;c=(1<<31-yt(42|e)+1)-1,c&=u&~(p&~g),c=c&201326741?c&201326741|1:c?c|2:0}c!==0&&(a=!0,gy(l,c))}else c=ve,c=ie(l,l===Ne?c:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),(c&3)===0||qe(l,c)||(a=!0,gy(l,c));l=l.next}while(a);gc=!1}}function Nb(){yy()}function yy(){Rs=vc=!1;var e=0;va!==0&&Gb()&&(e=va);for(var t=St(),a=null,l=xs;l!==null;){var u=l.next,c=py(l,t);c===0?(l.next=null,a===null?xs=u:a.next=u,u===null&&(Yi=a)):(a=l,(e!==0||(c&3)!==0)&&(Rs=!0)),l=u}We!==0&&We!==5||Wr(e),va!==0&&(va=0)}function py(e,t){for(var a=e.suspendedLanes,l=e.pingedLanes,u=e.expirationTimes,c=e.pendingLanes&-62914561;0<c;){var p=31-yt(c),g=1<<p,T=u[p];T===-1?((g&a)===0||(g&l)!==0)&&(u[p]=et(g,t)):T<=t&&(e.expiredLanes|=g),c&=~g}if(t=Ne,a=ve,a=ie(e,e===t?a:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),l=e.callbackNode,a===0||e===t&&(De===2||De===9)||e.cancelPendingCommit!==null)return l!==null&&l!==null&&pr(l),e.callbackNode=null,e.callbackPriority=0;if((a&3)===0||qe(e,a)){if(t=a&-a,t===e.callbackPriority)return t;switch(l!==null&&pr(l),rn(a)){case 2:case 8:a=jl;break;case 32:a=Ra;break;case 268435456:a=An;break;default:a=Ra}return l=vy.bind(null,e),a=yr(a,l),e.callbackPriority=t,e.callbackNode=a,t}return l!==null&&l!==null&&pr(l),e.callbackPriority=2,e.callbackNode=null,2}function vy(e,t){if(We!==0&&We!==5)return e.callbackNode=null,e.callbackPriority=0,null;var a=e.callbackNode;if(Cs()&&e.callbackNode!==a)return null;var l=ve;return l=ie(e,e===Ne?l:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),l===0?null:(Wm(e,l,t),py(e,St()),e.callbackNode!=null&&e.callbackNode===a?vy.bind(null,e):null)}function gy(e,t){if(Cs())return null;Wm(e,t,!0)}function jb(){Fb(function(){(Ae&6)!==0?yr(xa,Nb):yy()})}function bc(){if(va===0){var e=Mi;e===0&&(e=si,si<<=1,(si&261888)===0&&(si=256)),va=e}return va}function by(e){return e==null||typeof e=="symbol"||typeof e=="boolean"?null:typeof e=="function"?e:Hl(""+e)}function Sy(e,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,e.id&&a.setAttribute("form",e.id),t.parentNode.insertBefore(a,t),e=new FormData(e),a.parentNode.removeChild(a),e}function Ub(e,t,a,l,u){if(t==="submit"&&a&&a.stateNode===u){var c=by((u[At]||null).action),p=l.submitter;p&&(t=(t=p[At]||null)?by(t.formAction):p.getAttribute("formAction"),t!==null&&(c=t,p=null));var g=new Yl("action","action",null,l,u);e.push({event:g,listeners:[{instance:null,listener:function(){if(l.defaultPrevented){if(va!==0){var T=p?Sy(u,p):new FormData(u);Ho(a,{pending:!0,data:T,method:u.method,action:c},null,T)}}else typeof c=="function"&&(g.preventDefault(),T=p?Sy(u,p):new FormData(u),Ho(a,{pending:!0,data:T,method:u.method,action:c},c,T))},currentTarget:u}]})}}for(var Sc=0;Sc<to.length;Sc++){var Ec=to[Sc],kb=Ec.toLowerCase(),qb=Ec[0].toUpperCase()+Ec.slice(1);ln(kb,"on"+qb)}ln($d,"onAnimationEnd"),ln(Wd,"onAnimationIteration"),ln(Pd,"onAnimationStart"),ln("dblclick","onDoubleClick"),ln("focusin","onFocus"),ln("focusout","onBlur"),ln(P0,"onTransitionRun"),ln(eb,"onTransitionStart"),ln(tb,"onTransitionCancel"),ln(eh,"onTransitionEnd"),mi("onMouseEnter",["mouseout","mouseover"]),mi("onMouseLeave",["mouseout","mouseover"]),mi("onPointerEnter",["pointerout","pointerover"]),mi("onPointerLeave",["pointerout","pointerover"]),Ua("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Ua("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Ua("onBeforeInput",["compositionend","keypress","textInput","paste"]),Ua("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Ua("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Ua("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Pr="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Lb=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Pr));function Ey(e,t){t=(t&4)!==0;for(var a=0;a<e.length;a++){var l=e[a],u=l.event;l=l.listeners;e:{var c=void 0;if(t)for(var p=l.length-1;0<=p;p--){var g=l[p],T=g.instance,x=g.currentTarget;if(g=g.listener,T!==c&&u.isPropagationStopped())break e;c=g,u.currentTarget=x;try{c(u)}catch(k){Fl(k)}u.currentTarget=null,c=T}else for(p=0;p<l.length;p++){if(g=l[p],T=g.instance,x=g.currentTarget,g=g.listener,T!==c&&u.isPropagationStopped())break e;c=g,u.currentTarget=x;try{c(u)}catch(k){Fl(k)}u.currentTarget=null,c=T}}}}function ye(e,t){var a=t[Nu];a===void 0&&(a=t[Nu]=new Set);var l=e+"__bubble";a.has(l)||(Ty(t,e,2,!1),a.add(l))}function Tc(e,t,a){var l=0;t&&(l|=4),Ty(a,e,l,t)}var zs="_reactListening"+Math.random().toString(36).slice(2);function Oc(e){if(!e[zs]){e[zs]=!0,yd.forEach(function(a){a!=="selectionchange"&&(Lb.has(a)||Tc(a,!1,e),Tc(a,!0,e))});var t=e.nodeType===9?e:e.ownerDocument;t===null||t[zs]||(t[zs]=!0,Tc("selectionchange",!1,t))}}function Ty(e,t,a,l){switch($y(t)){case 2:var u=dS;break;case 8:u=hS;break;default:u=Lc}a=u.bind(null,t,a,e),u=void 0,!Qu||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(u=!0),l?u!==void 0?e.addEventListener(t,a,{capture:!0,passive:u}):e.addEventListener(t,a,!0):u!==void 0?e.addEventListener(t,a,{passive:u}):e.addEventListener(t,a,!1)}function _c(e,t,a,l,u){var c=l;if((t&1)===0&&(t&2)===0&&l!==null)e:for(;;){if(l===null)return;var p=l.tag;if(p===3||p===4){var g=l.stateNode.containerInfo;if(g===u)break;if(p===4)for(p=l.return;p!==null;){var T=p.tag;if((T===3||T===4)&&p.stateNode.containerInfo===u)return;p=p.return}for(;g!==null;){if(p=fi(g),p===null)return;if(T=p.tag,T===5||T===6||T===26||T===27){l=c=p;continue e}g=g.parentNode}}l=l.return}Dd(function(){var x=c,k=Bu(a),H=[];e:{var z=th.get(e);if(z!==void 0){var j=Yl,J=e;switch(e){case"keypress":if(Vl(a)===0)break e;case"keydown":case"keyup":j=R0;break;case"focusin":J="focus",j=Fu;break;case"focusout":J="blur",j=Fu;break;case"beforeblur":case"afterblur":j=Fu;break;case"click":if(a.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":j=xd;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":j=b0;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":j=j0;break;case $d:case Wd:case Pd:j=T0;break;case eh:j=k0;break;case"scroll":case"scrollend":j=v0;break;case"wheel":j=L0;break;case"copy":case"cut":case"paste":j=_0;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":j=zd;break;case"toggle":case"beforetoggle":j=B0}var te=(t&4)!==0,ze=!te&&(e==="scroll"||e==="scrollend"),A=te?z!==null?z+"Capture":null:z;te=[];for(var w=x,C;w!==null;){var q=w;if(C=q.stateNode,q=q.tag,q!==5&&q!==26&&q!==27||C===null||A===null||(q=Er(w,A),q!=null&&te.push(el(w,q,C))),ze)break;w=w.return}0<te.length&&(z=new j(z,J,null,a,k),H.push({event:z,listeners:te}))}}if((t&7)===0){e:{if(z=e==="mouseover"||e==="pointerover",j=e==="mouseout"||e==="pointerout",z&&a!==Hu&&(J=a.relatedTarget||a.fromElement)&&(fi(J)||J[ci]))break e;if((j||z)&&(z=k.window===k?k:(z=k.ownerDocument)?z.defaultView||z.parentWindow:window,j?(J=a.relatedTarget||a.toElement,j=x,J=J?fi(J):null,J!==null&&(ze=f(J),te=J.tag,J!==ze||te!==5&&te!==27&&te!==6)&&(J=null)):(j=null,J=x),j!==J)){if(te=xd,q="onMouseLeave",A="onMouseEnter",w="mouse",(e==="pointerout"||e==="pointerover")&&(te=zd,q="onPointerLeave",A="onPointerEnter",w="pointer"),ze=j==null?z:Sr(j),C=J==null?z:Sr(J),z=new te(q,w+"leave",j,a,k),z.target=ze,z.relatedTarget=C,q=null,fi(k)===x&&(te=new te(A,w+"enter",J,a,k),te.target=C,te.relatedTarget=ze,q=te),ze=q,j&&J)t:{for(te=Hb,A=j,w=J,C=0,q=A;q;q=te(q))C++;q=0;for(var P=w;P;P=te(P))q++;for(;0<C-q;)A=te(A),C--;for(;0<q-C;)w=te(w),q--;for(;C--;){if(A===w||w!==null&&A===w.alternate){te=A;break t}A=te(A),w=te(w)}te=null}else te=null;j!==null&&Oy(H,z,j,te,!1),J!==null&&ze!==null&&Oy(H,ze,J,te,!0)}}e:{if(z=x?Sr(x):window,j=z.nodeName&&z.nodeName.toLowerCase(),j==="select"||j==="input"&&z.type==="file")var Oe=Bd;else if(Ld(z))if(Vd)Oe=I0;else{Oe=J0;var I=Z0}else j=z.nodeName,!j||j.toLowerCase()!=="input"||z.type!=="checkbox"&&z.type!=="radio"?x&&Lu(x.elementType)&&(Oe=Bd):Oe=K0;if(Oe&&(Oe=Oe(e,x))){Hd(H,Oe,a,k);break e}I&&I(e,z,x),e==="focusout"&&x&&z.type==="number"&&x.memoizedProps.value!=null&&qu(z,"number",z.value)}switch(I=x?Sr(x):window,e){case"focusin":(Ld(I)||I.contentEditable==="true")&&(Si=I,Wu=x,Cr=null);break;case"focusout":Cr=Wu=Si=null;break;case"mousedown":Pu=!0;break;case"contextmenu":case"mouseup":case"dragend":Pu=!1,Kd(H,a,k);break;case"selectionchange":if(W0)break;case"keydown":case"keyup":Kd(H,a,k)}var oe;if(Ju)e:{switch(e){case"compositionstart":var ge="onCompositionStart";break e;case"compositionend":ge="onCompositionEnd";break e;case"compositionupdate":ge="onCompositionUpdate";break e}ge=void 0}else bi?kd(e,a)&&(ge="onCompositionEnd"):e==="keydown"&&a.keyCode===229&&(ge="onCompositionStart");ge&&(Nd&&a.locale!=="ko"&&(bi||ge!=="onCompositionStart"?ge==="onCompositionEnd"&&bi&&(oe=Md()):(ta=k,Yu="value"in ta?ta.value:ta.textContent,bi=!0)),I=Ns(x,ge),0<I.length&&(ge=new Rd(ge,e,null,a,k),H.push({event:ge,listeners:I}),oe?ge.data=oe:(oe=qd(a),oe!==null&&(ge.data=oe)))),(oe=Q0?Y0(e,a):G0(e,a))&&(ge=Ns(x,"onBeforeInput"),0<ge.length&&(I=new Rd("onBeforeInput","beforeinput",null,a,k),H.push({event:I,listeners:ge}),I.data=oe)),Ub(H,e,x,a,k)}Ey(H,t)})}function el(e,t,a){return{instance:e,listener:t,currentTarget:a}}function Ns(e,t){for(var a=t+"Capture",l=[];e!==null;){var u=e,c=u.stateNode;if(u=u.tag,u!==5&&u!==26&&u!==27||c===null||(u=Er(e,a),u!=null&&l.unshift(el(e,u,c)),u=Er(e,t),u!=null&&l.push(el(e,u,c))),e.tag===3)return l;e=e.return}return[]}function Hb(e){if(e===null)return null;do e=e.return;while(e&&e.tag!==5&&e.tag!==27);return e||null}function Oy(e,t,a,l,u){for(var c=t._reactName,p=[];a!==null&&a!==l;){var g=a,T=g.alternate,x=g.stateNode;if(g=g.tag,T!==null&&T===l)break;g!==5&&g!==26&&g!==27||x===null||(T=x,u?(x=Er(a,c),x!=null&&p.unshift(el(a,x,T))):u||(x=Er(a,c),x!=null&&p.push(el(a,x,T)))),a=a.return}p.length!==0&&e.push({event:t,listeners:p})}var Bb=/\r\n?/g,Vb=/\u0000|\uFFFD/g;function _y(e){return(typeof e=="string"?e:""+e).replace(Bb,`
`).replace(Vb,"")}function wy(e,t){return t=_y(t),_y(e)===t}function Re(e,t,a,l,u,c){switch(a){case"children":typeof l=="string"?t==="body"||t==="textarea"&&l===""||pi(e,l):(typeof l=="number"||typeof l=="bigint")&&t!=="body"&&pi(e,""+l);break;case"className":ql(e,"class",l);break;case"tabIndex":ql(e,"tabindex",l);break;case"dir":case"role":case"viewBox":case"width":case"height":ql(e,a,l);break;case"style":wd(e,l,c);break;case"data":if(t!=="object"){ql(e,"data",l);break}case"src":case"href":if(l===""&&(t!=="a"||a!=="href")){e.removeAttribute(a);break}if(l==null||typeof l=="function"||typeof l=="symbol"||typeof l=="boolean"){e.removeAttribute(a);break}l=Hl(""+l),e.setAttribute(a,l);break;case"action":case"formAction":if(typeof l=="function"){e.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof c=="function"&&(a==="formAction"?(t!=="input"&&Re(e,t,"name",u.name,u,null),Re(e,t,"formEncType",u.formEncType,u,null),Re(e,t,"formMethod",u.formMethod,u,null),Re(e,t,"formTarget",u.formTarget,u,null)):(Re(e,t,"encType",u.encType,u,null),Re(e,t,"method",u.method,u,null),Re(e,t,"target",u.target,u,null)));if(l==null||typeof l=="symbol"||typeof l=="boolean"){e.removeAttribute(a);break}l=Hl(""+l),e.setAttribute(a,l);break;case"onClick":l!=null&&(e.onclick=Mn);break;case"onScroll":l!=null&&ye("scroll",e);break;case"onScrollEnd":l!=null&&ye("scrollend",e);break;case"dangerouslySetInnerHTML":if(l!=null){if(typeof l!="object"||!("__html"in l))throw Error(s(61));if(a=l.__html,a!=null){if(u.children!=null)throw Error(s(60));e.innerHTML=a}}break;case"multiple":e.multiple=l&&typeof l!="function"&&typeof l!="symbol";break;case"muted":e.muted=l&&typeof l!="function"&&typeof l!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(l==null||typeof l=="function"||typeof l=="boolean"||typeof l=="symbol"){e.removeAttribute("xlink:href");break}a=Hl(""+l),e.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":l!=null&&typeof l!="function"&&typeof l!="symbol"?e.setAttribute(a,""+l):e.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":l&&typeof l!="function"&&typeof l!="symbol"?e.setAttribute(a,""):e.removeAttribute(a);break;case"capture":case"download":l===!0?e.setAttribute(a,""):l!==!1&&l!=null&&typeof l!="function"&&typeof l!="symbol"?e.setAttribute(a,l):e.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":l!=null&&typeof l!="function"&&typeof l!="symbol"&&!isNaN(l)&&1<=l?e.setAttribute(a,l):e.removeAttribute(a);break;case"rowSpan":case"start":l==null||typeof l=="function"||typeof l=="symbol"||isNaN(l)?e.removeAttribute(a):e.setAttribute(a,l);break;case"popover":ye("beforetoggle",e),ye("toggle",e),kl(e,"popover",l);break;case"xlinkActuate":Dn(e,"http://www.w3.org/1999/xlink","xlink:actuate",l);break;case"xlinkArcrole":Dn(e,"http://www.w3.org/1999/xlink","xlink:arcrole",l);break;case"xlinkRole":Dn(e,"http://www.w3.org/1999/xlink","xlink:role",l);break;case"xlinkShow":Dn(e,"http://www.w3.org/1999/xlink","xlink:show",l);break;case"xlinkTitle":Dn(e,"http://www.w3.org/1999/xlink","xlink:title",l);break;case"xlinkType":Dn(e,"http://www.w3.org/1999/xlink","xlink:type",l);break;case"xmlBase":Dn(e,"http://www.w3.org/XML/1998/namespace","xml:base",l);break;case"xmlLang":Dn(e,"http://www.w3.org/XML/1998/namespace","xml:lang",l);break;case"xmlSpace":Dn(e,"http://www.w3.org/XML/1998/namespace","xml:space",l);break;case"is":kl(e,"is",l);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=y0.get(a)||a,kl(e,a,l))}}function wc(e,t,a,l,u,c){switch(a){case"style":wd(e,l,c);break;case"dangerouslySetInnerHTML":if(l!=null){if(typeof l!="object"||!("__html"in l))throw Error(s(61));if(a=l.__html,a!=null){if(u.children!=null)throw Error(s(60));e.innerHTML=a}}break;case"children":typeof l=="string"?pi(e,l):(typeof l=="number"||typeof l=="bigint")&&pi(e,""+l);break;case"onScroll":l!=null&&ye("scroll",e);break;case"onScrollEnd":l!=null&&ye("scrollend",e);break;case"onClick":l!=null&&(e.onclick=Mn);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!pd.hasOwnProperty(a))e:{if(a[0]==="o"&&a[1]==="n"&&(u=a.endsWith("Capture"),t=a.slice(2,u?a.length-7:void 0),c=e[At]||null,c=c!=null?c[a]:null,typeof c=="function"&&e.removeEventListener(t,c,u),typeof l=="function")){typeof c!="function"&&c!==null&&(a in e?e[a]=null:e.hasAttribute(a)&&e.removeAttribute(a)),e.addEventListener(t,l,u);break e}a in e?e[a]=l:l===!0?e.setAttribute(a,""):kl(e,a,l)}}}function ct(e,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":ye("error",e),ye("load",e);var l=!1,u=!1,c;for(c in a)if(a.hasOwnProperty(c)){var p=a[c];if(p!=null)switch(c){case"src":l=!0;break;case"srcSet":u=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(s(137,t));default:Re(e,t,c,p,a,null)}}u&&Re(e,t,"srcSet",a.srcSet,a,null),l&&Re(e,t,"src",a.src,a,null);return;case"input":ye("invalid",e);var g=c=p=u=null,T=null,x=null;for(l in a)if(a.hasOwnProperty(l)){var k=a[l];if(k!=null)switch(l){case"name":u=k;break;case"type":p=k;break;case"checked":T=k;break;case"defaultChecked":x=k;break;case"value":c=k;break;case"defaultValue":g=k;break;case"children":case"dangerouslySetInnerHTML":if(k!=null)throw Error(s(137,t));break;default:Re(e,t,l,k,a,null)}}Ed(e,c,g,T,x,p,u,!1);return;case"select":ye("invalid",e),l=p=c=null;for(u in a)if(a.hasOwnProperty(u)&&(g=a[u],g!=null))switch(u){case"value":c=g;break;case"defaultValue":p=g;break;case"multiple":l=g;default:Re(e,t,u,g,a,null)}t=c,a=p,e.multiple=!!l,t!=null?yi(e,!!l,t,!1):a!=null&&yi(e,!!l,a,!0);return;case"textarea":ye("invalid",e),c=u=l=null;for(p in a)if(a.hasOwnProperty(p)&&(g=a[p],g!=null))switch(p){case"value":l=g;break;case"defaultValue":u=g;break;case"children":c=g;break;case"dangerouslySetInnerHTML":if(g!=null)throw Error(s(91));break;default:Re(e,t,p,g,a,null)}Od(e,l,u,c);return;case"option":for(T in a)if(a.hasOwnProperty(T)&&(l=a[T],l!=null))switch(T){case"selected":e.selected=l&&typeof l!="function"&&typeof l!="symbol";break;default:Re(e,t,T,l,a,null)}return;case"dialog":ye("beforetoggle",e),ye("toggle",e),ye("cancel",e),ye("close",e);break;case"iframe":case"object":ye("load",e);break;case"video":case"audio":for(l=0;l<Pr.length;l++)ye(Pr[l],e);break;case"image":ye("error",e),ye("load",e);break;case"details":ye("toggle",e);break;case"embed":case"source":case"link":ye("error",e),ye("load",e);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(x in a)if(a.hasOwnProperty(x)&&(l=a[x],l!=null))switch(x){case"children":case"dangerouslySetInnerHTML":throw Error(s(137,t));default:Re(e,t,x,l,a,null)}return;default:if(Lu(t)){for(k in a)a.hasOwnProperty(k)&&(l=a[k],l!==void 0&&wc(e,t,k,l,a,void 0));return}}for(g in a)a.hasOwnProperty(g)&&(l=a[g],l!=null&&Re(e,t,g,l,a,null))}function Qb(e,t,a,l){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var u=null,c=null,p=null,g=null,T=null,x=null,k=null;for(j in a){var H=a[j];if(a.hasOwnProperty(j)&&H!=null)switch(j){case"checked":break;case"value":break;case"defaultValue":T=H;default:l.hasOwnProperty(j)||Re(e,t,j,null,l,H)}}for(var z in l){var j=l[z];if(H=a[z],l.hasOwnProperty(z)&&(j!=null||H!=null))switch(z){case"type":c=j;break;case"name":u=j;break;case"checked":x=j;break;case"defaultChecked":k=j;break;case"value":p=j;break;case"defaultValue":g=j;break;case"children":case"dangerouslySetInnerHTML":if(j!=null)throw Error(s(137,t));break;default:j!==H&&Re(e,t,z,j,l,H)}}ku(e,p,g,T,x,k,c,u);return;case"select":j=p=g=z=null;for(c in a)if(T=a[c],a.hasOwnProperty(c)&&T!=null)switch(c){case"value":break;case"multiple":j=T;default:l.hasOwnProperty(c)||Re(e,t,c,null,l,T)}for(u in l)if(c=l[u],T=a[u],l.hasOwnProperty(u)&&(c!=null||T!=null))switch(u){case"value":z=c;break;case"defaultValue":g=c;break;case"multiple":p=c;default:c!==T&&Re(e,t,u,c,l,T)}t=g,a=p,l=j,z!=null?yi(e,!!a,z,!1):!!l!=!!a&&(t!=null?yi(e,!!a,t,!0):yi(e,!!a,a?[]:"",!1));return;case"textarea":j=z=null;for(g in a)if(u=a[g],a.hasOwnProperty(g)&&u!=null&&!l.hasOwnProperty(g))switch(g){case"value":break;case"children":break;default:Re(e,t,g,null,l,u)}for(p in l)if(u=l[p],c=a[p],l.hasOwnProperty(p)&&(u!=null||c!=null))switch(p){case"value":z=u;break;case"defaultValue":j=u;break;case"children":break;case"dangerouslySetInnerHTML":if(u!=null)throw Error(s(91));break;default:u!==c&&Re(e,t,p,u,l,c)}Td(e,z,j);return;case"option":for(var J in a)if(z=a[J],a.hasOwnProperty(J)&&z!=null&&!l.hasOwnProperty(J))switch(J){case"selected":e.selected=!1;break;default:Re(e,t,J,null,l,z)}for(T in l)if(z=l[T],j=a[T],l.hasOwnProperty(T)&&z!==j&&(z!=null||j!=null))switch(T){case"selected":e.selected=z&&typeof z!="function"&&typeof z!="symbol";break;default:Re(e,t,T,z,l,j)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var te in a)z=a[te],a.hasOwnProperty(te)&&z!=null&&!l.hasOwnProperty(te)&&Re(e,t,te,null,l,z);for(x in l)if(z=l[x],j=a[x],l.hasOwnProperty(x)&&z!==j&&(z!=null||j!=null))switch(x){case"children":case"dangerouslySetInnerHTML":if(z!=null)throw Error(s(137,t));break;default:Re(e,t,x,z,l,j)}return;default:if(Lu(t)){for(var ze in a)z=a[ze],a.hasOwnProperty(ze)&&z!==void 0&&!l.hasOwnProperty(ze)&&wc(e,t,ze,void 0,l,z);for(k in l)z=l[k],j=a[k],!l.hasOwnProperty(k)||z===j||z===void 0&&j===void 0||wc(e,t,k,z,l,j);return}}for(var A in a)z=a[A],a.hasOwnProperty(A)&&z!=null&&!l.hasOwnProperty(A)&&Re(e,t,A,null,l,z);for(H in l)z=l[H],j=a[H],!l.hasOwnProperty(H)||z===j||z==null&&j==null||Re(e,t,H,z,l,j)}function Ay(e){switch(e){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Yb(){if(typeof performance.getEntriesByType=="function"){for(var e=0,t=0,a=performance.getEntriesByType("resource"),l=0;l<a.length;l++){var u=a[l],c=u.transferSize,p=u.initiatorType,g=u.duration;if(c&&g&&Ay(p)){for(p=0,g=u.responseEnd,l+=1;l<a.length;l++){var T=a[l],x=T.startTime;if(x>g)break;var k=T.transferSize,H=T.initiatorType;k&&Ay(H)&&(T=T.responseEnd,p+=k*(T<g?1:(g-x)/(T-x)))}if(--l,t+=8*(c+p)/(u.duration/1e3),e++,10<e)break}}if(0<e)return t/e/1e6}return navigator.connection&&(e=navigator.connection.downlink,typeof e=="number")?e:5}var Ac=null,Dc=null;function js(e){return e.nodeType===9?e:e.ownerDocument}function Dy(e){switch(e){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function My(e,t){if(e===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return e===1&&t==="foreignObject"?0:e}function Mc(e,t){return e==="textarea"||e==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Cc=null;function Gb(){var e=window.event;return e&&e.type==="popstate"?e===Cc?!1:(Cc=e,!0):(Cc=null,!1)}var Cy=typeof setTimeout=="function"?setTimeout:void 0,Xb=typeof clearTimeout=="function"?clearTimeout:void 0,xy=typeof Promise=="function"?Promise:void 0,Fb=typeof queueMicrotask=="function"?queueMicrotask:typeof xy<"u"?function(e){return xy.resolve(null).then(e).catch(Zb)}:Cy;function Zb(e){setTimeout(function(){throw e})}function ga(e){return e==="head"}function Ry(e,t){var a=t,l=0;do{var u=a.nextSibling;if(e.removeChild(a),u&&u.nodeType===8)if(a=u.data,a==="/$"||a==="/&"){if(l===0){e.removeChild(u),Zi(t);return}l--}else if(a==="$"||a==="$?"||a==="$~"||a==="$!"||a==="&")l++;else if(a==="html")tl(e.ownerDocument.documentElement);else if(a==="head"){a=e.ownerDocument.head,tl(a);for(var c=a.firstChild;c;){var p=c.nextSibling,g=c.nodeName;c[br]||g==="SCRIPT"||g==="STYLE"||g==="LINK"&&c.rel.toLowerCase()==="stylesheet"||a.removeChild(c),c=p}}else a==="body"&&tl(e.ownerDocument.body);a=u}while(a);Zi(t)}function zy(e,t){var a=e;e=0;do{var l=a.nextSibling;if(a.nodeType===1?t?(a._stashedDisplay=a.style.display,a.style.display="none"):(a.style.display=a._stashedDisplay||"",a.getAttribute("style")===""&&a.removeAttribute("style")):a.nodeType===3&&(t?(a._stashedText=a.nodeValue,a.nodeValue=""):a.nodeValue=a._stashedText||""),l&&l.nodeType===8)if(a=l.data,a==="/$"){if(e===0)break;e--}else a!=="$"&&a!=="$?"&&a!=="$~"&&a!=="$!"||e++;a=l}while(a)}function xc(e){var t=e.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":xc(a),ju(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}e.removeChild(a)}}function Jb(e,t,a,l){for(;e.nodeType===1;){var u=a;if(e.nodeName.toLowerCase()!==t.toLowerCase()){if(!l&&(e.nodeName!=="INPUT"||e.type!=="hidden"))break}else if(l){if(!e[br])switch(t){case"meta":if(!e.hasAttribute("itemprop"))break;return e;case"link":if(c=e.getAttribute("rel"),c==="stylesheet"&&e.hasAttribute("data-precedence"))break;if(c!==u.rel||e.getAttribute("href")!==(u.href==null||u.href===""?null:u.href)||e.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin)||e.getAttribute("title")!==(u.title==null?null:u.title))break;return e;case"style":if(e.hasAttribute("data-precedence"))break;return e;case"script":if(c=e.getAttribute("src"),(c!==(u.src==null?null:u.src)||e.getAttribute("type")!==(u.type==null?null:u.type)||e.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin))&&c&&e.hasAttribute("async")&&!e.hasAttribute("itemprop"))break;return e;default:return e}}else if(t==="input"&&e.type==="hidden"){var c=u.name==null?null:""+u.name;if(u.type==="hidden"&&e.getAttribute("name")===c)return e}else return e;if(e=$t(e.nextSibling),e===null)break}return null}function Kb(e,t,a){if(t==="")return null;for(;e.nodeType!==3;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!a||(e=$t(e.nextSibling),e===null))return null;return e}function Ny(e,t){for(;e.nodeType!==8;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!t||(e=$t(e.nextSibling),e===null))return null;return e}function Rc(e){return e.data==="$?"||e.data==="$~"}function zc(e){return e.data==="$!"||e.data==="$?"&&e.ownerDocument.readyState!=="loading"}function Ib(e,t){var a=e.ownerDocument;if(e.data==="$~")e._reactRetry=t;else if(e.data!=="$?"||a.readyState!=="loading")t();else{var l=function(){t(),a.removeEventListener("DOMContentLoaded",l)};a.addEventListener("DOMContentLoaded",l),e._reactRetry=l}}function $t(e){for(;e!=null;e=e.nextSibling){var t=e.nodeType;if(t===1||t===3)break;if(t===8){if(t=e.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return e}var Nc=null;function jy(e){e=e.nextSibling;for(var t=0;e;){if(e.nodeType===8){var a=e.data;if(a==="/$"||a==="/&"){if(t===0)return $t(e.nextSibling);t--}else a!=="$"&&a!=="$!"&&a!=="$?"&&a!=="$~"&&a!=="&"||t++}e=e.nextSibling}return null}function Uy(e){e=e.previousSibling;for(var t=0;e;){if(e.nodeType===8){var a=e.data;if(a==="$"||a==="$!"||a==="$?"||a==="$~"||a==="&"){if(t===0)return e;t--}else a!=="/$"&&a!=="/&"||t++}e=e.previousSibling}return null}function ky(e,t,a){switch(t=js(a),e){case"html":if(e=t.documentElement,!e)throw Error(s(452));return e;case"head":if(e=t.head,!e)throw Error(s(453));return e;case"body":if(e=t.body,!e)throw Error(s(454));return e;default:throw Error(s(451))}}function tl(e){for(var t=e.attributes;t.length;)e.removeAttributeNode(t[0]);ju(e)}var Wt=new Map,qy=new Set;function Us(e){return typeof e.getRootNode=="function"?e.getRootNode():e.nodeType===9?e:e.ownerDocument}var Gn=Q.d;Q.d={f:$b,r:Wb,D:Pb,C:eS,L:tS,m:nS,X:iS,S:aS,M:rS};function $b(){var e=Gn.f(),t=As();return e||t}function Wb(e){var t=di(e);t!==null&&t.tag===5&&t.type==="form"?em(t):Gn.r(e)}var Gi=typeof document>"u"?null:document;function Ly(e,t,a){var l=Gi;if(l&&typeof t=="string"&&t){var u=Gt(t);u='link[rel="'+e+'"][href="'+u+'"]',typeof a=="string"&&(u+='[crossorigin="'+a+'"]'),qy.has(u)||(qy.add(u),e={rel:e,crossOrigin:a,href:t},l.querySelector(u)===null&&(t=l.createElement("link"),ct(t,"link",e),tt(t),l.head.appendChild(t)))}}function Pb(e){Gn.D(e),Ly("dns-prefetch",e,null)}function eS(e,t){Gn.C(e,t),Ly("preconnect",e,t)}function tS(e,t,a){Gn.L(e,t,a);var l=Gi;if(l&&e&&t){var u='link[rel="preload"][as="'+Gt(t)+'"]';t==="image"&&a&&a.imageSrcSet?(u+='[imagesrcset="'+Gt(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(u+='[imagesizes="'+Gt(a.imageSizes)+'"]')):u+='[href="'+Gt(e)+'"]';var c=u;switch(t){case"style":c=Xi(e);break;case"script":c=Fi(e)}Wt.has(c)||(e=v({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:e,as:t},a),Wt.set(c,e),l.querySelector(u)!==null||t==="style"&&l.querySelector(nl(c))||t==="script"&&l.querySelector(al(c))||(t=l.createElement("link"),ct(t,"link",e),tt(t),l.head.appendChild(t)))}}function nS(e,t){Gn.m(e,t);var a=Gi;if(a&&e){var l=t&&typeof t.as=="string"?t.as:"script",u='link[rel="modulepreload"][as="'+Gt(l)+'"][href="'+Gt(e)+'"]',c=u;switch(l){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":c=Fi(e)}if(!Wt.has(c)&&(e=v({rel:"modulepreload",href:e},t),Wt.set(c,e),a.querySelector(u)===null)){switch(l){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(al(c)))return}l=a.createElement("link"),ct(l,"link",e),tt(l),a.head.appendChild(l)}}}function aS(e,t,a){Gn.S(e,t,a);var l=Gi;if(l&&e){var u=hi(l).hoistableStyles,c=Xi(e);t=t||"default";var p=u.get(c);if(!p){var g={loading:0,preload:null};if(p=l.querySelector(nl(c)))g.loading=5;else{e=v({rel:"stylesheet",href:e,"data-precedence":t},a),(a=Wt.get(c))&&jc(e,a);var T=p=l.createElement("link");tt(T),ct(T,"link",e),T._p=new Promise(function(x,k){T.onload=x,T.onerror=k}),T.addEventListener("load",function(){g.loading|=1}),T.addEventListener("error",function(){g.loading|=2}),g.loading|=4,ks(p,t,l)}p={type:"stylesheet",instance:p,count:1,state:g},u.set(c,p)}}}function iS(e,t){Gn.X(e,t);var a=Gi;if(a&&e){var l=hi(a).hoistableScripts,u=Fi(e),c=l.get(u);c||(c=a.querySelector(al(u)),c||(e=v({src:e,async:!0},t),(t=Wt.get(u))&&Uc(e,t),c=a.createElement("script"),tt(c),ct(c,"link",e),a.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},l.set(u,c))}}function rS(e,t){Gn.M(e,t);var a=Gi;if(a&&e){var l=hi(a).hoistableScripts,u=Fi(e),c=l.get(u);c||(c=a.querySelector(al(u)),c||(e=v({src:e,async:!0,type:"module"},t),(t=Wt.get(u))&&Uc(e,t),c=a.createElement("script"),tt(c),ct(c,"link",e),a.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},l.set(u,c))}}function Hy(e,t,a,l){var u=(u=ne.current)?Us(u):null;if(!u)throw Error(s(446));switch(e){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=Xi(a.href),a=hi(u).hoistableStyles,l=a.get(t),l||(l={type:"style",instance:null,count:0,state:null},a.set(t,l)),l):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){e=Xi(a.href);var c=hi(u).hoistableStyles,p=c.get(e);if(p||(u=u.ownerDocument||u,p={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},c.set(e,p),(c=u.querySelector(nl(e)))&&!c._p&&(p.instance=c,p.state.loading=5),Wt.has(e)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},Wt.set(e,a),c||lS(u,e,a,p.state))),t&&l===null)throw Error(s(528,""));return p}if(t&&l!==null)throw Error(s(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Fi(a),a=hi(u).hoistableScripts,l=a.get(t),l||(l={type:"script",instance:null,count:0,state:null},a.set(t,l)),l):{type:"void",instance:null,count:0,state:null};default:throw Error(s(444,e))}}function Xi(e){return'href="'+Gt(e)+'"'}function nl(e){return'link[rel="stylesheet"]['+e+"]"}function By(e){return v({},e,{"data-precedence":e.precedence,precedence:null})}function lS(e,t,a,l){e.querySelector('link[rel="preload"][as="style"]['+t+"]")?l.loading=1:(t=e.createElement("link"),l.preload=t,t.addEventListener("load",function(){return l.loading|=1}),t.addEventListener("error",function(){return l.loading|=2}),ct(t,"link",a),tt(t),e.head.appendChild(t))}function Fi(e){return'[src="'+Gt(e)+'"]'}function al(e){return"script[async]"+e}function Vy(e,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var l=e.querySelector('style[data-href~="'+Gt(a.href)+'"]');if(l)return t.instance=l,tt(l),l;var u=v({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return l=(e.ownerDocument||e).createElement("style"),tt(l),ct(l,"style",u),ks(l,a.precedence,e),t.instance=l;case"stylesheet":u=Xi(a.href);var c=e.querySelector(nl(u));if(c)return t.state.loading|=4,t.instance=c,tt(c),c;l=By(a),(u=Wt.get(u))&&jc(l,u),c=(e.ownerDocument||e).createElement("link"),tt(c);var p=c;return p._p=new Promise(function(g,T){p.onload=g,p.onerror=T}),ct(c,"link",l),t.state.loading|=4,ks(c,a.precedence,e),t.instance=c;case"script":return c=Fi(a.src),(u=e.querySelector(al(c)))?(t.instance=u,tt(u),u):(l=a,(u=Wt.get(c))&&(l=v({},a),Uc(l,u)),e=e.ownerDocument||e,u=e.createElement("script"),tt(u),ct(u,"link",l),e.head.appendChild(u),t.instance=u);case"void":return null;default:throw Error(s(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(l=t.instance,t.state.loading|=4,ks(l,a.precedence,e));return t.instance}function ks(e,t,a){for(var l=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),u=l.length?l[l.length-1]:null,c=u,p=0;p<l.length;p++){var g=l[p];if(g.dataset.precedence===t)c=g;else if(c!==u)break}c?c.parentNode.insertBefore(e,c.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(e,t.firstChild))}function jc(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.title==null&&(e.title=t.title)}function Uc(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.integrity==null&&(e.integrity=t.integrity)}var qs=null;function Qy(e,t,a){if(qs===null){var l=new Map,u=qs=new Map;u.set(a,l)}else u=qs,l=u.get(a),l||(l=new Map,u.set(a,l));if(l.has(e))return l;for(l.set(e,null),a=a.getElementsByTagName(e),u=0;u<a.length;u++){var c=a[u];if(!(c[br]||c[lt]||e==="link"&&c.getAttribute("rel")==="stylesheet")&&c.namespaceURI!=="http://www.w3.org/2000/svg"){var p=c.getAttribute(t)||"";p=e+p;var g=l.get(p);g?g.push(c):l.set(p,[c])}}return l}function Yy(e,t,a){e=e.ownerDocument||e,e.head.insertBefore(a,t==="title"?e.querySelector("head > title"):null)}function sS(e,t,a){if(a===1||t.itemProp!=null)return!1;switch(e){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return e=t.disabled,typeof t.precedence=="string"&&e==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Gy(e){return!(e.type==="stylesheet"&&(e.state.loading&3)===0)}function uS(e,t,a,l){if(a.type==="stylesheet"&&(typeof l.media!="string"||matchMedia(l.media).matches!==!1)&&(a.state.loading&4)===0){if(a.instance===null){var u=Xi(l.href),c=t.querySelector(nl(u));if(c){t=c._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(e.count++,e=Ls.bind(e),t.then(e,e)),a.state.loading|=4,a.instance=c,tt(c);return}c=t.ownerDocument||t,l=By(l),(u=Wt.get(u))&&jc(l,u),c=c.createElement("link"),tt(c);var p=c;p._p=new Promise(function(g,T){p.onload=g,p.onerror=T}),ct(c,"link",l),a.instance=c}e.stylesheets===null&&(e.stylesheets=new Map),e.stylesheets.set(a,t),(t=a.state.preload)&&(a.state.loading&3)===0&&(e.count++,a=Ls.bind(e),t.addEventListener("load",a),t.addEventListener("error",a))}}var kc=0;function oS(e,t){return e.stylesheets&&e.count===0&&Bs(e,e.stylesheets),0<e.count||0<e.imgCount?function(a){var l=setTimeout(function(){if(e.stylesheets&&Bs(e,e.stylesheets),e.unsuspend){var c=e.unsuspend;e.unsuspend=null,c()}},6e4+t);0<e.imgBytes&&kc===0&&(kc=62500*Yb());var u=setTimeout(function(){if(e.waitingForImages=!1,e.count===0&&(e.stylesheets&&Bs(e,e.stylesheets),e.unsuspend)){var c=e.unsuspend;e.unsuspend=null,c()}},(e.imgBytes>kc?50:800)+t);return e.unsuspend=a,function(){e.unsuspend=null,clearTimeout(l),clearTimeout(u)}}:null}function Ls(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Bs(this,this.stylesheets);else if(this.unsuspend){var e=this.unsuspend;this.unsuspend=null,e()}}}var Hs=null;function Bs(e,t){e.stylesheets=null,e.unsuspend!==null&&(e.count++,Hs=new Map,t.forEach(cS,e),Hs=null,Ls.call(e))}function cS(e,t){if(!(t.state.loading&4)){var a=Hs.get(e);if(a)var l=a.get(null);else{a=new Map,Hs.set(e,a);for(var u=e.querySelectorAll("link[data-precedence],style[data-precedence]"),c=0;c<u.length;c++){var p=u[c];(p.nodeName==="LINK"||p.getAttribute("media")!=="not all")&&(a.set(p.dataset.precedence,p),l=p)}l&&a.set(null,l)}u=t.instance,p=u.getAttribute("data-precedence"),c=a.get(p)||l,c===l&&a.set(null,u),a.set(p,u),this.count++,l=Ls.bind(this),u.addEventListener("load",l),u.addEventListener("error",l),c?c.parentNode.insertBefore(u,c.nextSibling):(e=e.nodeType===9?e.head:e,e.insertBefore(u,e.firstChild)),t.state.loading|=4}}var il={$$typeof:Y,Provider:null,Consumer:null,_currentValue:W,_currentValue2:W,_threadCount:0};function fS(e,t,a,l,u,c,p,g,T){this.tag=1,this.containerInfo=e,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Pn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Pn(0),this.hiddenUpdates=Pn(null),this.identifierPrefix=l,this.onUncaughtError=u,this.onCaughtError=c,this.onRecoverableError=p,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=T,this.incompleteTransitions=new Map}function Xy(e,t,a,l,u,c,p,g,T,x,k,H){return e=new fS(e,t,a,p,T,x,k,H,g),t=1,c===!0&&(t|=24),c=qt(3,null,null,t),e.current=c,c.stateNode=e,t=yo(),t.refCount++,e.pooledCache=t,t.refCount++,c.memoizedState={element:l,isDehydrated:a,cache:t},bo(c),e}function Fy(e){return e?(e=Oi,e):Oi}function Zy(e,t,a,l,u,c){u=Fy(u),l.context===null?l.context=u:l.pendingContext=u,l=sa(t),l.payload={element:a},c=c===void 0?null:c,c!==null&&(l.callback=c),a=ua(e,l,t),a!==null&&(zt(a,e,t),kr(a,e,t))}function Jy(e,t){if(e=e.memoizedState,e!==null&&e.dehydrated!==null){var a=e.retryLane;e.retryLane=a!==0&&a<t?a:t}}function qc(e,t){Jy(e,t),(e=e.alternate)&&Jy(e,t)}function Ky(e){if(e.tag===13||e.tag===31){var t=Ha(e,67108864);t!==null&&zt(t,e,67108864),qc(e,67108864)}}function Iy(e){if(e.tag===13||e.tag===31){var t=Qt();t=oi(t);var a=Ha(e,t);a!==null&&zt(a,e,t),qc(e,t)}}var Vs=!0;function dS(e,t,a,l){var u=R.T;R.T=null;var c=Q.p;try{Q.p=2,Lc(e,t,a,l)}finally{Q.p=c,R.T=u}}function hS(e,t,a,l){var u=R.T;R.T=null;var c=Q.p;try{Q.p=8,Lc(e,t,a,l)}finally{Q.p=c,R.T=u}}function Lc(e,t,a,l){if(Vs){var u=Hc(l);if(u===null)_c(e,t,l,Qs,a),Wy(e,l);else if(yS(u,e,t,a,l))l.stopPropagation();else if(Wy(e,l),t&4&&-1<mS.indexOf(e)){for(;u!==null;){var c=di(u);if(c!==null)switch(c.tag){case 3:if(c=c.stateNode,c.current.memoizedState.isDehydrated){var p=yn(c.pendingLanes);if(p!==0){var g=c;for(g.pendingLanes|=2,g.entangledLanes|=2;p;){var T=1<<31-yt(p);g.entanglements[1]|=T,p&=~T}bn(c),(Ae&6)===0&&(_s=St()+500,Wr(0))}}break;case 31:case 13:g=Ha(c,2),g!==null&&zt(g,c,2),As(),qc(c,2)}if(c=Hc(l),c===null&&_c(e,t,l,Qs,a),c===u)break;u=c}u!==null&&l.stopPropagation()}else _c(e,t,l,null,a)}}function Hc(e){return e=Bu(e),Bc(e)}var Qs=null;function Bc(e){if(Qs=null,e=fi(e),e!==null){var t=f(e);if(t===null)e=null;else{var a=t.tag;if(a===13){if(e=d(t),e!==null)return e;e=null}else if(a===31){if(e=y(t),e!==null)return e;e=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;e=null}else t!==e&&(e=null)}}return Qs=e,null}function $y(e){switch(e){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(xu()){case xa:return 2;case jl:return 8;case Ra:case vr:return 32;case An:return 268435456;default:return 32}default:return 32}}var Vc=!1,ba=null,Sa=null,Ea=null,rl=new Map,ll=new Map,Ta=[],mS="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function Wy(e,t){switch(e){case"focusin":case"focusout":ba=null;break;case"dragenter":case"dragleave":Sa=null;break;case"mouseover":case"mouseout":Ea=null;break;case"pointerover":case"pointerout":rl.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":ll.delete(t.pointerId)}}function sl(e,t,a,l,u,c){return e===null||e.nativeEvent!==c?(e={blockedOn:t,domEventName:a,eventSystemFlags:l,nativeEvent:c,targetContainers:[u]},t!==null&&(t=di(t),t!==null&&Ky(t)),e):(e.eventSystemFlags|=l,t=e.targetContainers,u!==null&&t.indexOf(u)===-1&&t.push(u),e)}function yS(e,t,a,l,u){switch(t){case"focusin":return ba=sl(ba,e,t,a,l,u),!0;case"dragenter":return Sa=sl(Sa,e,t,a,l,u),!0;case"mouseover":return Ea=sl(Ea,e,t,a,l,u),!0;case"pointerover":var c=u.pointerId;return rl.set(c,sl(rl.get(c)||null,e,t,a,l,u)),!0;case"gotpointercapture":return c=u.pointerId,ll.set(c,sl(ll.get(c)||null,e,t,a,l,u)),!0}return!1}function Py(e){var t=fi(e.target);if(t!==null){var a=f(t);if(a!==null){if(t=a.tag,t===13){if(t=d(a),t!==null){e.blockedOn=t,hd(e.priority,function(){Iy(a)});return}}else if(t===31){if(t=y(a),t!==null){e.blockedOn=t,hd(e.priority,function(){Iy(a)});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){e.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}e.blockedOn=null}function Ys(e){if(e.blockedOn!==null)return!1;for(var t=e.targetContainers;0<t.length;){var a=Hc(e.nativeEvent);if(a===null){a=e.nativeEvent;var l=new a.constructor(a.type,a);Hu=l,a.target.dispatchEvent(l),Hu=null}else return t=di(a),t!==null&&Ky(t),e.blockedOn=a,!1;t.shift()}return!0}function ep(e,t,a){Ys(e)&&a.delete(t)}function pS(){Vc=!1,ba!==null&&Ys(ba)&&(ba=null),Sa!==null&&Ys(Sa)&&(Sa=null),Ea!==null&&Ys(Ea)&&(Ea=null),rl.forEach(ep),ll.forEach(ep)}function Gs(e,t){e.blockedOn===t&&(e.blockedOn=null,Vc||(Vc=!0,i.unstable_scheduleCallback(i.unstable_NormalPriority,pS)))}var Xs=null;function tp(e){Xs!==e&&(Xs=e,i.unstable_scheduleCallback(i.unstable_NormalPriority,function(){Xs===e&&(Xs=null);for(var t=0;t<e.length;t+=3){var a=e[t],l=e[t+1],u=e[t+2];if(typeof l!="function"){if(Bc(l||a)===null)continue;break}var c=di(a);c!==null&&(e.splice(t,3),t-=3,Ho(c,{pending:!0,data:u,method:a.method,action:l},l,u))}}))}function Zi(e){function t(T){return Gs(T,e)}ba!==null&&Gs(ba,e),Sa!==null&&Gs(Sa,e),Ea!==null&&Gs(Ea,e),rl.forEach(t),ll.forEach(t);for(var a=0;a<Ta.length;a++){var l=Ta[a];l.blockedOn===e&&(l.blockedOn=null)}for(;0<Ta.length&&(a=Ta[0],a.blockedOn===null);)Py(a),a.blockedOn===null&&Ta.shift();if(a=(e.ownerDocument||e).$$reactFormReplay,a!=null)for(l=0;l<a.length;l+=3){var u=a[l],c=a[l+1],p=u[At]||null;if(typeof c=="function")p||tp(a);else if(p){var g=null;if(c&&c.hasAttribute("formAction")){if(u=c,p=c[At]||null)g=p.formAction;else if(Bc(u)!==null)continue}else g=p.action;typeof g=="function"?a[l+1]=g:(a.splice(l,3),l-=3),tp(a)}}}function np(){function e(c){c.canIntercept&&c.info==="react-transition"&&c.intercept({handler:function(){return new Promise(function(p){return u=p})},focusReset:"manual",scroll:"manual"})}function t(){u!==null&&(u(),u=null),l||setTimeout(a,20)}function a(){if(!l&&!navigation.transition){var c=navigation.currentEntry;c&&c.url!=null&&navigation.navigate(c.url,{state:c.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var l=!1,u=null;return navigation.addEventListener("navigate",e),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(a,100),function(){l=!0,navigation.removeEventListener("navigate",e),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),u!==null&&(u(),u=null)}}}function Qc(e){this._internalRoot=e}Fs.prototype.render=Qc.prototype.render=function(e){var t=this._internalRoot;if(t===null)throw Error(s(409));var a=t.current,l=Qt();Zy(a,l,e,t,null,null)},Fs.prototype.unmount=Qc.prototype.unmount=function(){var e=this._internalRoot;if(e!==null){this._internalRoot=null;var t=e.containerInfo;Zy(e.current,2,null,e,null,null),As(),t[ci]=null}};function Fs(e){this._internalRoot=e}Fs.prototype.unstable_scheduleHydration=function(e){if(e){var t=zu();e={blockedOn:null,target:e,priority:t};for(var a=0;a<Ta.length&&t!==0&&t<Ta[a].priority;a++);Ta.splice(a,0,e),a===0&&Py(e)}};var ap=n.version;if(ap!=="19.2.3")throw Error(s(527,ap,"19.2.3"));Q.findDOMNode=function(e){var t=e._reactInternals;if(t===void 0)throw typeof e.render=="function"?Error(s(188)):(e=Object.keys(e).join(","),Error(s(268,e)));return e=h(t),e=e!==null?b(e):null,e=e===null?null:e.stateNode,e};var vS={bundleType:0,version:"19.2.3",rendererPackageName:"react-dom",currentDispatcherRef:R,reconcilerVersion:"19.2.3"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Zs=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Zs.isDisabled&&Zs.supportsFiber)try{za=Zs.inject(vS),Et=Zs}catch{}}return ul.createRoot=function(e,t){if(!o(e))throw Error(s(299));var a=!1,l="",u=cm,c=fm,p=dm;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(l=t.identifierPrefix),t.onUncaughtError!==void 0&&(u=t.onUncaughtError),t.onCaughtError!==void 0&&(c=t.onCaughtError),t.onRecoverableError!==void 0&&(p=t.onRecoverableError)),t=Xy(e,1,!1,null,null,a,l,null,u,c,p,np),e[ci]=t.current,Oc(e),new Qc(t)},ul.hydrateRoot=function(e,t,a){if(!o(e))throw Error(s(299));var l=!1,u="",c=cm,p=fm,g=dm,T=null;return a!=null&&(a.unstable_strictMode===!0&&(l=!0),a.identifierPrefix!==void 0&&(u=a.identifierPrefix),a.onUncaughtError!==void 0&&(c=a.onUncaughtError),a.onCaughtError!==void 0&&(p=a.onCaughtError),a.onRecoverableError!==void 0&&(g=a.onRecoverableError),a.formState!==void 0&&(T=a.formState)),t=Xy(e,1,!0,t,a??null,l,u,T,c,p,g,np),t.context=Fy(null),a=t.current,l=Qt(),l=oi(l),u=sa(l),u.callback=null,ua(a,u,l),a=l,t.current.lanes=a,Be(t,a),bn(t),e[ci]=t.current,Oc(e),new Fs(t)},ul.version="19.2.3",ul}var fp;function wS(){if(fp)return Yc.exports;fp=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(n){console.error(n)}}return i(),Yc.exports=_S(),Yc.exports}var AS=wS();const dp=ii(AS);function du(i){return i instanceof Function||typeof i=="function"}const DS=["Head","bodyAttributes","htmlAttributes"];function MS(i,n){return i.includes(n)}function hp(i,n){const r=n._configViaHook?.[i],s=n.config[i],o=f=>du(f)?f(n):f;return MS(DS,i)?[...(s??[]).map(o),...r??[]]:r!==void 0?r:o(s)}var be=Gf();const B=ii(be),CS=Yf({__proto__:null,default:B},[be]);function Bv(i,n){const r=globalThis[mp]=globalThis[mp]||{};return r[i]=r[i]||n}const mp="_vike_react",Vv=Bv("usePageContext.tsx",{reactContext:B.createContext(void 0)});function xS({pageContext:i,children:n}){const{reactContext:r}=Vv;return B.createElement(r.Provider,{value:i},n)}function RS(){const{reactContext:i}=Vv;return be.useContext(i)}function zS(i){const{Page:n,config:{Loading:r}}=i;let s=n?B.createElement(n,null):null;const o=m=>r?.layout?B.createElement(be.Suspense,{fallback:B.createElement(r.layout,null)},s):m;s=o(s),[...i.config.Layout||[],...i.config.Wrapper||[]].forEach(m=>{s=B.createElement(m,null,s),s=o(s)}),s=B.createElement(xS,{pageContext:i},s);let f,d,y=new Promise((m,h)=>{f=m,d=h});return s=B.createElement(NS,{renderPromiseResolve:f},s),i.config.reactStrictMode!==!1&&(s=B.createElement(B.StrictMode,null,s)),{page:s,renderPromise:y,renderPromiseReject:d}}function NS({children:i,renderPromiseResolve:n}){return be.useEffect(n),i}async function yp(i,n){if(!i)return[];const r=i.map(o=>du(o)?(bS(n),o(n)):o);return await Promise.all(r)}function jS(i,n){i!==void 0&&(document.title=i||""),n!==void 0&&(document.documentElement.lang=n||"en")}function pp(i){return Object.entries(i)}function US(i){const n={};return(i.config.react??[]).forEach(r=>{const s=du(r)?r(i):r;s&&pp(s).forEach(([o,f])=>{f&&(n[o]??(n[o]={}),pp(f).forEach(([d,y])=>{var m;if(!du(y))(m=n[o])[d]??(m[d]=y);else{const h=n[o][d];n[o][d]=(...b)=>{h?.(...b),y(...b)}}}))})}),n}function Qv(i){return typeof i=="object"&&i!==null}function kS(i,n){return Object.assign(i,n),i}const _a=Bv("onRenderClient.tsx",{});async function H_(i){i._headAlreadySet=i.isHydration,await yp(i.config.onBeforeRenderClient,i);const{page:n,renderPromise:r,renderPromiseReject:s}=zS(i);i.page=n,_a.onUncaughtErrorLocal=y=>{s(y)};const o=document.getElementById("root"),{hydrateRootOptions:f,createRootOptions:d}=US(i);i.isHydration&&o.innerHTML!==""?_a.root=dp.hydrateRoot(o,n,{...f,onUncaughtError(...y){vp.call(this,y,f)}}):(_a.root||(_a.root=dp.createRoot(o,{...d,onUncaughtError(...y){vp.call(this,y,d)}})),_a.root.render(n)),i.root=_a.root;try{await r}finally{delete _a.onUncaughtErrorLocal}i.isHydration||(i._headAlreadySet=!0,qS(i)),await yp(i.config.onAfterRenderClient,i)}function qS(i){const n=hp("title",i),r=hp("lang",i);jS(n,r)}function vp(i,n){const[r,s]=i,o=LS(r,s);console.error(o),Qv(o)&&(o.isAlreadyLogged=!0),_a.onUncaughtErrorLocal?.(o),n?.onUncaughtError?.call(this,o,s)}function LS(i,n){if(!n?.componentStack||!Qv(i))return i;const r=String(i.stack).split(`
`);let s=r.findIndex(h=>h.includes("react_stack_bottom_frame"));if(s===-1&&(s=r.findIndex(h=>h.includes("node_modules")&&h.includes("react"))),s===-1)return i;const o=r.slice(0,s),f=r.slice(s),d=n.componentStack.split(`
`).filter(Boolean);d[0]===o.at(-1)&&d.shift();const y=[...o,...d,...f].join(`
`);return kS(i,{stack:y})}const HS=async()=>{document.querySelector("body")?.classList.add("page-is-transitioning")},B_=Object.freeze(Object.defineProperty({__proto__:null,onPageTransitionStart:HS},Symbol.toStringTag,{value:"Module"})),BS=async()=>{document.querySelector("body")?.classList.remove("page-is-transitioning")},V_=Object.freeze(Object.defineProperty({__proto__:null,onPageTransitionEnd:BS},Symbol.toStringTag,{value:"Module"}));var Jc={exports:{}},ol={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var gp;function VS(){if(gp)return ol;gp=1;var i=Symbol.for("react.transitional.element"),n=Symbol.for("react.fragment");function r(s,o,f){var d=null;if(f!==void 0&&(d=""+f),o.key!==void 0&&(d=""+o.key),"key"in o){f={};for(var y in o)y!=="key"&&(f[y]=o[y])}else f=o;return o=f.ref,{$$typeof:i,type:s,key:d,ref:o!==void 0?o:null,props:f}}return ol.Fragment=n,ol.jsx=r,ol.jsxs=r,ol}var bp;function QS(){return bp||(bp=1,Jc.exports=VS()),Jc.exports}var at=QS();const YS=ii(at),Q_=Yf({__proto__:null,default:YS},[at]);var Yv=Hv();const Gv=ii(Yv),Y_=Yf({__proto__:null,default:Gv},[Yv]);var Tf=function(i,n){return Tf=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(r,s){r.__proto__=s}||function(r,s){for(var o in s)Object.prototype.hasOwnProperty.call(s,o)&&(r[o]=s[o])},Tf(i,n)};function ri(i,n){if(typeof n!="function"&&n!==null)throw new TypeError("Class extends value "+String(n)+" is not a constructor or null");Tf(i,n);function r(){this.constructor=i}i.prototype=n===null?Object.create(n):(r.prototype=n.prototype,new r)}var Sp=function(){return Sp=Object.assign||function(n){for(var r,s=1,o=arguments.length;s<o;s++){r=arguments[s];for(var f in r)Object.prototype.hasOwnProperty.call(r,f)&&(n[f]=r[f])}return n},Sp.apply(this,arguments)};function G_(i,n){var r={};for(var s in i)Object.prototype.hasOwnProperty.call(i,s)&&n.indexOf(s)<0&&(r[s]=i[s]);if(i!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,s=Object.getOwnPropertySymbols(i);o<s.length;o++)n.indexOf(s[o])<0&&Object.prototype.propertyIsEnumerable.call(i,s[o])&&(r[s[o]]=i[s[o]]);return r}function GS(i,n,r,s){function o(f){return f instanceof r?f:new r(function(d){d(f)})}return new(r||(r=Promise))(function(f,d){function y(b){try{h(s.next(b))}catch(v){d(v)}}function m(b){try{h(s.throw(b))}catch(v){d(v)}}function h(b){b.done?f(b.value):o(b.value).then(y,m)}h((s=s.apply(i,n||[])).next())})}function Xv(i,n){var r={label:0,sent:function(){if(f[0]&1)throw f[1];return f[1]},trys:[],ops:[]},s,o,f,d=Object.create((typeof Iterator=="function"?Iterator:Object).prototype);return d.next=y(0),d.throw=y(1),d.return=y(2),typeof Symbol=="function"&&(d[Symbol.iterator]=function(){return this}),d;function y(h){return function(b){return m([h,b])}}function m(h){if(s)throw new TypeError("Generator is already executing.");for(;d&&(d=0,h[0]&&(r=0)),r;)try{if(s=1,o&&(f=h[0]&2?o.return:h[0]?o.throw||((f=o.return)&&f.call(o),0):o.next)&&!(f=f.call(o,h[1])).done)return f;switch(o=0,f&&(h=[h[0]&2,f.value]),h[0]){case 0:case 1:f=h;break;case 4:return r.label++,{value:h[1],done:!1};case 5:r.label++,o=h[1],h=[0];continue;case 7:h=r.ops.pop(),r.trys.pop();continue;default:if(f=r.trys,!(f=f.length>0&&f[f.length-1])&&(h[0]===6||h[0]===2)){r=0;continue}if(h[0]===3&&(!f||h[1]>f[0]&&h[1]<f[3])){r.label=h[1];break}if(h[0]===6&&r.label<f[1]){r.label=f[1],f=h;break}if(f&&r.label<f[2]){r.label=f[2],r.ops.push(h);break}f[2]&&r.ops.pop(),r.trys.pop();continue}h=n.call(i,r)}catch(b){h=[6,b],o=0}finally{s=f=0}if(h[0]&5)throw h[1];return{value:h[0]?h[1]:void 0,done:!0}}}function rr(i){var n=typeof Symbol=="function"&&Symbol.iterator,r=n&&i[n],s=0;if(r)return r.call(i);if(i&&typeof i.length=="number")return{next:function(){return i&&s>=i.length&&(i=void 0),{value:i&&i[s++],done:!i}}};throw new TypeError(n?"Object is not iterable.":"Symbol.iterator is not defined.")}function Tl(i,n){var r=typeof Symbol=="function"&&i[Symbol.iterator];if(!r)return i;var s=r.call(i),o,f=[],d;try{for(;(n===void 0||n-- >0)&&!(o=s.next()).done;)f.push(o.value)}catch(y){d={error:y}}finally{try{o&&!o.done&&(r=s.return)&&r.call(s)}finally{if(d)throw d.error}}return f}function X_(){for(var i=[],n=0;n<arguments.length;n++)i=i.concat(Tl(arguments[n]));return i}function hu(i,n,r){if(r||arguments.length===2)for(var s=0,o=n.length,f;s<o;s++)(f||!(s in n))&&(f||(f=Array.prototype.slice.call(n,0,s)),f[s]=n[s]);return i.concat(f||Array.prototype.slice.call(n))}function Pi(i){return this instanceof Pi?(this.v=i,this):new Pi(i)}function XS(i,n,r){if(!Symbol.asyncIterator)throw new TypeError("Symbol.asyncIterator is not defined.");var s=r.apply(i,n||[]),o,f=[];return o=Object.create((typeof AsyncIterator=="function"?AsyncIterator:Object).prototype),y("next"),y("throw"),y("return",d),o[Symbol.asyncIterator]=function(){return this},o;function d(S){return function(O){return Promise.resolve(O).then(S,v)}}function y(S,O){s[S]&&(o[S]=function(N){return new Promise(function(M,D){f.push([S,N,M,D])>1||m(S,N)})},O&&(o[S]=O(o[S])))}function m(S,O){try{h(s[S](O))}catch(N){E(f[0][3],N)}}function h(S){S.value instanceof Pi?Promise.resolve(S.value.v).then(b,v):E(f[0][2],S)}function b(S){m("next",S)}function v(S){m("throw",S)}function E(S,O){S(O),f.shift(),f.length&&m(f[0][0],f[0][1])}}function FS(i){if(!Symbol.asyncIterator)throw new TypeError("Symbol.asyncIterator is not defined.");var n=i[Symbol.asyncIterator],r;return n?n.call(i):(i=typeof rr=="function"?rr(i):i[Symbol.iterator](),r={},s("next"),s("throw"),s("return"),r[Symbol.asyncIterator]=function(){return this},r);function s(f){r[f]=i[f]&&function(d){return new Promise(function(y,m){d=i[f](d),o(y,m,d.done,d.value)})}}function o(f,d,y,m){Promise.resolve(m).then(function(h){f({value:h,done:y})},d)}}var ZS=(i,n,r,s,o,f,d,y,m)=>{const h=document.documentElement;function b(O){(Array.isArray(s)?s:[s]).forEach(M=>{const D=M==="class",U=D&&f?o.map(Y=>f[Y]||Y):o;D?(h.classList.remove(...U),h.classList.add(f&&f[O]?f[O]:O)):h.setAttribute(M,O)}),v(O)}function v(O){if(m){const N=O.includes("dark");h.style.colorScheme=N?"dark":"light"}}function E(O,N,M){let D;return O==="system"?D=M?"dark":"light":D=O,N?`liquid-${D}`:D}function S(){try{const O=localStorage.getItem(`${r}-base`),N=localStorage.getItem(`${r}-liquid`);return O!==null&&N!==null?{baseTheme:O,isLiquid:N==="true"}:{baseTheme:i,isLiquid:n}}catch{return{baseTheme:"system",isLiquid:!0}}}if(d)b(d);else{const{baseTheme:O,isLiquid:N}=S(),M=localStorage.getItem(`${r}-base`)!==null,D=localStorage.getItem(`${r}-liquid`)!==null;if(!M||!D)try{M||localStorage.setItem(`${r}-base`,O),D||localStorage.setItem(`${r}-liquid`,String(N))}catch{}const U=window.matchMedia("(prefers-color-scheme: dark)").matches,Y=E(O,N,U);b(Y)}},JS=be.memo(({forcedTheme:i,storageKey:n,attribute:r,enableSystem:s,enableColorScheme:o,defaultBaseTheme:f,defaultIsLiquid:d,value:y,themes:m,nonce:h,scriptProps:b})=>{const v=JSON.stringify([f,d,n,r,m,y,i,s,o]).slice(1,-1);return at.jsx("script",{...b,suppressHydrationWarning:!0,nonce:typeof window>"u"?h:"",dangerouslySetInnerHTML:{__html:`(${ZS.toString()})(${v})`}})}),Ep="(prefers-color-scheme: dark)",Fv=typeof window>"u",Xf=be.createContext(void 0),Tp=(i,n)=>{try{localStorage.setItem(i,n),document.cookie=`vuer:theme=${n}; path=/; max-age=3153600000;`}catch{}},Op=(i,n)=>{if(Fv)return n;try{return localStorage.getItem(i)||n}catch{return n}},KS=(i,n,r)=>{let s;return i==="system"?s=r?"dark":"light":s=i,n?`liquid-${s}`:s};function IS(i){const n=be.useContext(Xf);if(n===void 0)throw new Error("useTheme must be used within a ThemeProvider");return be.useMemo(()=>i?typeof i=="function"?i(n):n[i]:n,[n])}var $S=i=>be.useContext(Xf)?at.jsx(at.Fragment,{children:i.children}):at.jsx(PS,{...i}),WS=["light","dark","liquid-light","liquid-dark"],PS=({forcedTheme:i,disableTransitionOnChange:n=!1,enableSystem:r=!0,enableColorScheme:s=!1,storageKey:o="vuer-uikit-theme",defaultBaseTheme:f=r?"system":"light",defaultIsLiquid:d=!0,attribute:y="class",value:m,children:h,nonce:b,scriptProps:v})=>{const E=WS,S=be.useMemo(()=>({baseTheme:f,isLiquid:d}),[f,d]),[O,N]=be.useState(()=>{const ae=Op(`${o}-base`,"");return ae&&["light","dark","system"].includes(ae)?ae:S.baseTheme}),[M,D]=be.useState(()=>{const ae=Op(`${o}-liquid`,"");return ae?ae==="true":S.isLiquid}),[U,Y]=be.useState(()=>Fv?!1:window.matchMedia(Ep).matches),X=m?Object.values(m):E,K=be.useMemo(()=>KS(O,M,U),[O,M,U]),ee=be.useMemo(()=>i||K,[i,K]),$=be.useCallback(ae=>{if(!ae)return;const Se=m?m[ae]:ae,mt=n?e1(b):null,He=document.documentElement,R=Q=>{Q==="class"?(He.classList.remove(...X),Se&&He.classList.add(Se)):Q.startsWith("data-")&&(Se?He.setAttribute(Q,Se):He.removeAttribute(Q))};if(Array.isArray(y)?y.forEach(R):R(y),s){const Q=ae.includes("dark");He.style.colorScheme=Q?"dark":"light"}mt?.()},[y,X,n,s,b,m]),we=be.useCallback(ae=>{N(ae),Tp(`${o}-base`,ae)},[o]),rt=be.useCallback(()=>{D(ae=>{const Se=!ae;return Tp(`${o}-liquid`,String(Se)),Se})},[o]),dt=be.useCallback(ae=>{const Se=ae.matches;Y(Se)},[]);be.useEffect(()=>{const ae=window.matchMedia(Ep);return ae.addListener(dt),dt(ae),()=>ae.removeListener(dt)},[dt]),be.useEffect(()=>{const ae=Se=>{Se.key===`${o}-base`&&Se.newValue?N(Se.newValue):Se.key===`${o}-liquid`&&Se.newValue!==null&&D(Se.newValue==="true")};return window.addEventListener("storage",ae),()=>window.removeEventListener("storage",ae)},[o]),be.useEffect(()=>{$(ee)},[$,ee]);const ht=be.useMemo(()=>({baseTheme:O,setBaseTheme:we,isLiquid:M,toggleLiquid:rt,computedTheme:K,resolvedTheme:ee,systemTheme:r?U?"dark":"light":void 0,forcedTheme:i,storageKey:o}),[O,we,M,rt,K,ee,U,r,i,o]);return at.jsxs(Xf.Provider,{value:ht,children:[at.jsx(JS,{forcedTheme:i,storageKey:o,attribute:y,enableSystem:r,enableColorScheme:s,defaultBaseTheme:S.baseTheme,defaultIsLiquid:S.isLiquid,value:m,themes:E,nonce:b,scriptProps:v}),h]})},e1=i=>{const n=document.createElement("style");return i&&n.setAttribute("nonce",i),n.appendChild(document.createTextNode("*,*::before,*::after{-webkit-transition:none!important;-moz-transition:none!important;-o-transition:none!important;-ms-transition:none!important;transition:none!important}")),document.head.appendChild(n),()=>{window.getComputedStyle(document.body),setTimeout(()=>{n&&n.parentNode&&n.parentNode.removeChild(n)},1)}};function t1(i){if(typeof document>"u")return;let n=document.head||document.getElementsByTagName("head")[0],r=document.createElement("style");r.type="text/css",n.appendChild(r),r.styleSheet?r.styleSheet.cssText=i:r.appendChild(document.createTextNode(i))}const n1=i=>{switch(i){case"success":return r1;case"info":return s1;case"warning":return l1;case"error":return u1;default:return null}},a1=Array(12).fill(0),i1=({visible:i,className:n})=>B.createElement("div",{className:["sonner-loading-wrapper",n].filter(Boolean).join(" "),"data-visible":i},B.createElement("div",{className:"sonner-spinner"},a1.map((r,s)=>B.createElement("div",{className:"sonner-loading-bar",key:`spinner-bar-${s}`})))),r1=B.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},B.createElement("path",{fillRule:"evenodd",d:"M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z",clipRule:"evenodd"})),l1=B.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",fill:"currentColor",height:"20",width:"20"},B.createElement("path",{fillRule:"evenodd",d:"M9.401 3.003c1.155-2 4.043-2 5.197 0l7.355 12.748c1.154 2-.29 4.5-2.599 4.5H4.645c-2.309 0-3.752-2.5-2.598-4.5L9.4 3.003zM12 8.25a.75.75 0 01.75.75v3.75a.75.75 0 01-1.5 0V9a.75.75 0 01.75-.75zm0 8.25a.75.75 0 100-1.5.75.75 0 000 1.5z",clipRule:"evenodd"})),s1=B.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},B.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zM9 9a.75.75 0 000 1.5h.253a.25.25 0 01.244.304l-.459 2.066A1.75 1.75 0 0010.747 15H11a.75.75 0 000-1.5h-.253a.25.25 0 01-.244-.304l.459-2.066A1.75 1.75 0 009.253 9H9z",clipRule:"evenodd"})),u1=B.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},B.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-5a.75.75 0 01.75.75v4.5a.75.75 0 01-1.5 0v-4.5A.75.75 0 0110 5zm0 10a1 1 0 100-2 1 1 0 000 2z",clipRule:"evenodd"})),o1=B.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"12",height:"12",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round"},B.createElement("line",{x1:"18",y1:"6",x2:"6",y2:"18"}),B.createElement("line",{x1:"6",y1:"6",x2:"18",y2:"18"})),c1=()=>{const[i,n]=B.useState(document.hidden);return B.useEffect(()=>{const r=()=>{n(document.hidden)};return document.addEventListener("visibilitychange",r),()=>window.removeEventListener("visibilitychange",r)},[]),i};let Of=1;class f1{constructor(){this.subscribe=n=>(this.subscribers.push(n),()=>{const r=this.subscribers.indexOf(n);this.subscribers.splice(r,1)}),this.publish=n=>{this.subscribers.forEach(r=>r(n))},this.addToast=n=>{this.publish(n),this.toasts=[...this.toasts,n]},this.create=n=>{var r;const{message:s,...o}=n,f=typeof n?.id=="number"||((r=n.id)==null?void 0:r.length)>0?n.id:Of++,d=this.toasts.find(m=>m.id===f),y=n.dismissible===void 0?!0:n.dismissible;return this.dismissedToasts.has(f)&&this.dismissedToasts.delete(f),d?this.toasts=this.toasts.map(m=>m.id===f?(this.publish({...m,...n,id:f,title:s}),{...m,...n,id:f,dismissible:y,title:s}):m):this.addToast({title:s,...o,dismissible:y,id:f}),f},this.dismiss=n=>(n?(this.dismissedToasts.add(n),requestAnimationFrame(()=>this.subscribers.forEach(r=>r({id:n,dismiss:!0})))):this.toasts.forEach(r=>{this.subscribers.forEach(s=>s({id:r.id,dismiss:!0}))}),n),this.message=(n,r)=>this.create({...r,message:n}),this.error=(n,r)=>this.create({...r,message:n,type:"error"}),this.success=(n,r)=>this.create({...r,type:"success",message:n}),this.info=(n,r)=>this.create({...r,type:"info",message:n}),this.warning=(n,r)=>this.create({...r,type:"warning",message:n}),this.loading=(n,r)=>this.create({...r,type:"loading",message:n}),this.promise=(n,r)=>{if(!r)return;let s;r.loading!==void 0&&(s=this.create({...r,promise:n,type:"loading",message:r.loading,description:typeof r.description!="function"?r.description:void 0}));const o=Promise.resolve(n instanceof Function?n():n);let f=s!==void 0,d;const y=o.then(async h=>{if(d=["resolve",h],B.isValidElement(h))f=!1,this.create({id:s,type:"default",message:h});else if(h1(h)&&!h.ok){f=!1;const v=typeof r.error=="function"?await r.error(`HTTP error! status: ${h.status}`):r.error,E=typeof r.description=="function"?await r.description(`HTTP error! status: ${h.status}`):r.description,O=typeof v=="object"&&!B.isValidElement(v)?v:{message:v};this.create({id:s,type:"error",description:E,...O})}else if(h instanceof Error){f=!1;const v=typeof r.error=="function"?await r.error(h):r.error,E=typeof r.description=="function"?await r.description(h):r.description,O=typeof v=="object"&&!B.isValidElement(v)?v:{message:v};this.create({id:s,type:"error",description:E,...O})}else if(r.success!==void 0){f=!1;const v=typeof r.success=="function"?await r.success(h):r.success,E=typeof r.description=="function"?await r.description(h):r.description,O=typeof v=="object"&&!B.isValidElement(v)?v:{message:v};this.create({id:s,type:"success",description:E,...O})}}).catch(async h=>{if(d=["reject",h],r.error!==void 0){f=!1;const b=typeof r.error=="function"?await r.error(h):r.error,v=typeof r.description=="function"?await r.description(h):r.description,S=typeof b=="object"&&!B.isValidElement(b)?b:{message:b};this.create({id:s,type:"error",description:v,...S})}}).finally(()=>{f&&(this.dismiss(s),s=void 0),r.finally==null||r.finally.call(r)}),m=()=>new Promise((h,b)=>y.then(()=>d[0]==="reject"?b(d[1]):h(d[1])).catch(b));return typeof s!="string"&&typeof s!="number"?{unwrap:m}:Object.assign(s,{unwrap:m})},this.custom=(n,r)=>{const s=r?.id||Of++;return this.create({jsx:n(s),id:s,...r}),s},this.getActiveToasts=()=>this.toasts.filter(n=>!this.dismissedToasts.has(n.id)),this.subscribers=[],this.toasts=[],this.dismissedToasts=new Set}}const Nt=new f1,d1=(i,n)=>{const r=n?.id||Of++;return Nt.addToast({title:i,...n,id:r}),r},h1=i=>i&&typeof i=="object"&&"ok"in i&&typeof i.ok=="boolean"&&"status"in i&&typeof i.status=="number",m1=d1,y1=()=>Nt.toasts,p1=()=>Nt.getActiveToasts(),F_=Object.assign(m1,{success:Nt.success,info:Nt.info,warning:Nt.warning,error:Nt.error,custom:Nt.custom,message:Nt.message,promise:Nt.promise,dismiss:Nt.dismiss,loading:Nt.loading},{getHistory:y1,getToasts:p1});t1("[data-sonner-toaster][dir=ltr],html[dir=ltr]{--toast-icon-margin-start:-3px;--toast-icon-margin-end:4px;--toast-svg-margin-start:-1px;--toast-svg-margin-end:0px;--toast-button-margin-start:auto;--toast-button-margin-end:0;--toast-close-button-start:0;--toast-close-button-end:unset;--toast-close-button-transform:translate(-35%, -35%)}[data-sonner-toaster][dir=rtl],html[dir=rtl]{--toast-icon-margin-start:4px;--toast-icon-margin-end:-3px;--toast-svg-margin-start:0px;--toast-svg-margin-end:-1px;--toast-button-margin-start:0;--toast-button-margin-end:auto;--toast-close-button-start:unset;--toast-close-button-end:0;--toast-close-button-transform:translate(35%, -35%)}[data-sonner-toaster]{position:fixed;width:var(--width);font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji;--gray1:hsl(0, 0%, 99%);--gray2:hsl(0, 0%, 97.3%);--gray3:hsl(0, 0%, 95.1%);--gray4:hsl(0, 0%, 93%);--gray5:hsl(0, 0%, 90.9%);--gray6:hsl(0, 0%, 88.7%);--gray7:hsl(0, 0%, 85.8%);--gray8:hsl(0, 0%, 78%);--gray9:hsl(0, 0%, 56.1%);--gray10:hsl(0, 0%, 52.3%);--gray11:hsl(0, 0%, 43.5%);--gray12:hsl(0, 0%, 9%);--border-radius:8px;box-sizing:border-box;padding:0;margin:0;list-style:none;outline:0;z-index:999999999;transition:transform .4s ease}@media (hover:none) and (pointer:coarse){[data-sonner-toaster][data-lifted=true]{transform:none}}[data-sonner-toaster][data-x-position=right]{right:var(--offset-right)}[data-sonner-toaster][data-x-position=left]{left:var(--offset-left)}[data-sonner-toaster][data-x-position=center]{left:50%;transform:translateX(-50%)}[data-sonner-toaster][data-y-position=top]{top:var(--offset-top)}[data-sonner-toaster][data-y-position=bottom]{bottom:var(--offset-bottom)}[data-sonner-toast]{--y:translateY(100%);--lift-amount:calc(var(--lift) * var(--gap));z-index:var(--z-index);position:absolute;opacity:0;transform:var(--y);touch-action:none;transition:transform .4s,opacity .4s,height .4s,box-shadow .2s;box-sizing:border-box;outline:0;overflow-wrap:anywhere}[data-sonner-toast][data-styled=true]{padding:16px;background:var(--normal-bg);border:1px solid var(--normal-border);color:var(--normal-text);border-radius:var(--border-radius);box-shadow:0 4px 12px rgba(0,0,0,.1);width:var(--width);font-size:13px;display:flex;align-items:center;gap:6px}[data-sonner-toast]:focus-visible{box-shadow:0 4px 12px rgba(0,0,0,.1),0 0 0 2px rgba(0,0,0,.2)}[data-sonner-toast][data-y-position=top]{top:0;--y:translateY(-100%);--lift:1;--lift-amount:calc(1 * var(--gap))}[data-sonner-toast][data-y-position=bottom]{bottom:0;--y:translateY(100%);--lift:-1;--lift-amount:calc(var(--lift) * var(--gap))}[data-sonner-toast][data-styled=true] [data-description]{font-weight:400;line-height:1.4;color:#3f3f3f}[data-rich-colors=true][data-sonner-toast][data-styled=true] [data-description]{color:inherit}[data-sonner-toaster][data-sonner-theme=dark] [data-description]{color:#e8e8e8}[data-sonner-toast][data-styled=true] [data-title]{font-weight:500;line-height:1.5;color:inherit}[data-sonner-toast][data-styled=true] [data-icon]{display:flex;height:16px;width:16px;position:relative;justify-content:flex-start;align-items:center;flex-shrink:0;margin-left:var(--toast-icon-margin-start);margin-right:var(--toast-icon-margin-end)}[data-sonner-toast][data-promise=true] [data-icon]>svg{opacity:0;transform:scale(.8);transform-origin:center;animation:sonner-fade-in .3s ease forwards}[data-sonner-toast][data-styled=true] [data-icon]>*{flex-shrink:0}[data-sonner-toast][data-styled=true] [data-icon] svg{margin-left:var(--toast-svg-margin-start);margin-right:var(--toast-svg-margin-end)}[data-sonner-toast][data-styled=true] [data-content]{display:flex;flex-direction:column;gap:2px}[data-sonner-toast][data-styled=true] [data-button]{border-radius:4px;padding-left:8px;padding-right:8px;height:24px;font-size:12px;color:var(--normal-bg);background:var(--normal-text);margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end);border:none;font-weight:500;cursor:pointer;outline:0;display:flex;align-items:center;flex-shrink:0;transition:opacity .4s,box-shadow .2s}[data-sonner-toast][data-styled=true] [data-button]:focus-visible{box-shadow:0 0 0 2px rgba(0,0,0,.4)}[data-sonner-toast][data-styled=true] [data-button]:first-of-type{margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end)}[data-sonner-toast][data-styled=true] [data-cancel]{color:var(--normal-text);background:rgba(0,0,0,.08)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast][data-styled=true] [data-cancel]{background:rgba(255,255,255,.3)}[data-sonner-toast][data-styled=true] [data-close-button]{position:absolute;left:var(--toast-close-button-start);right:var(--toast-close-button-end);top:0;height:20px;width:20px;display:flex;justify-content:center;align-items:center;padding:0;color:var(--gray12);background:var(--normal-bg);border:1px solid var(--gray4);transform:var(--toast-close-button-transform);border-radius:50%;cursor:pointer;z-index:1;transition:opacity .1s,background .2s,border-color .2s}[data-sonner-toast][data-styled=true] [data-close-button]:focus-visible{box-shadow:0 4px 12px rgba(0,0,0,.1),0 0 0 2px rgba(0,0,0,.2)}[data-sonner-toast][data-styled=true] [data-disabled=true]{cursor:not-allowed}[data-sonner-toast][data-styled=true]:hover [data-close-button]:hover{background:var(--gray2);border-color:var(--gray5)}[data-sonner-toast][data-swiping=true]::before{content:'';position:absolute;left:-100%;right:-100%;height:100%;z-index:-1}[data-sonner-toast][data-y-position=top][data-swiping=true]::before{bottom:50%;transform:scaleY(3) translateY(50%)}[data-sonner-toast][data-y-position=bottom][data-swiping=true]::before{top:50%;transform:scaleY(3) translateY(-50%)}[data-sonner-toast][data-swiping=false][data-removed=true]::before{content:'';position:absolute;inset:0;transform:scaleY(2)}[data-sonner-toast][data-expanded=true]::after{content:'';position:absolute;left:0;height:calc(var(--gap) + 1px);bottom:100%;width:100%}[data-sonner-toast][data-mounted=true]{--y:translateY(0);opacity:1}[data-sonner-toast][data-expanded=false][data-front=false]{--scale:var(--toasts-before) * 0.05 + 1;--y:translateY(calc(var(--lift-amount) * var(--toasts-before))) scale(calc(-1 * var(--scale)));height:var(--front-toast-height)}[data-sonner-toast]>*{transition:opacity .4s}[data-sonner-toast][data-x-position=right]{right:0}[data-sonner-toast][data-x-position=left]{left:0}[data-sonner-toast][data-expanded=false][data-front=false][data-styled=true]>*{opacity:0}[data-sonner-toast][data-visible=false]{opacity:0;pointer-events:none}[data-sonner-toast][data-mounted=true][data-expanded=true]{--y:translateY(calc(var(--lift) * var(--offset)));height:var(--initial-height)}[data-sonner-toast][data-removed=true][data-front=true][data-swipe-out=false]{--y:translateY(calc(var(--lift) * -100%));opacity:0}[data-sonner-toast][data-removed=true][data-front=false][data-swipe-out=false][data-expanded=true]{--y:translateY(calc(var(--lift) * var(--offset) + var(--lift) * -100%));opacity:0}[data-sonner-toast][data-removed=true][data-front=false][data-swipe-out=false][data-expanded=false]{--y:translateY(40%);opacity:0;transition:transform .5s,opacity .2s}[data-sonner-toast][data-removed=true][data-front=false]::before{height:calc(var(--initial-height) + 20%)}[data-sonner-toast][data-swiping=true]{transform:var(--y) translateY(var(--swipe-amount-y,0)) translateX(var(--swipe-amount-x,0));transition:none}[data-sonner-toast][data-swiped=true]{user-select:none}[data-sonner-toast][data-swipe-out=true][data-y-position=bottom],[data-sonner-toast][data-swipe-out=true][data-y-position=top]{animation-duration:.2s;animation-timing-function:ease-out;animation-fill-mode:forwards}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=left]{animation-name:swipe-out-left}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=right]{animation-name:swipe-out-right}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=up]{animation-name:swipe-out-up}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=down]{animation-name:swipe-out-down}@keyframes swipe-out-left{from{transform:var(--y) translateX(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translateX(calc(var(--swipe-amount-x) - 100%));opacity:0}}@keyframes swipe-out-right{from{transform:var(--y) translateX(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translateX(calc(var(--swipe-amount-x) + 100%));opacity:0}}@keyframes swipe-out-up{from{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) - 100%));opacity:0}}@keyframes swipe-out-down{from{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) + 100%));opacity:0}}@media (max-width:600px){[data-sonner-toaster]{position:fixed;right:var(--mobile-offset-right);left:var(--mobile-offset-left);width:100%}[data-sonner-toaster][dir=rtl]{left:calc(var(--mobile-offset-left) * -1)}[data-sonner-toaster] [data-sonner-toast]{left:0;right:0;width:calc(100% - var(--mobile-offset-left) * 2)}[data-sonner-toaster][data-x-position=left]{left:var(--mobile-offset-left)}[data-sonner-toaster][data-y-position=bottom]{bottom:var(--mobile-offset-bottom)}[data-sonner-toaster][data-y-position=top]{top:var(--mobile-offset-top)}[data-sonner-toaster][data-x-position=center]{left:var(--mobile-offset-left);right:var(--mobile-offset-right);transform:none}}[data-sonner-toaster][data-sonner-theme=light]{--normal-bg:#fff;--normal-border:var(--gray4);--normal-text:var(--gray12);--success-bg:hsl(143, 85%, 96%);--success-border:hsl(145, 92%, 87%);--success-text:hsl(140, 100%, 27%);--info-bg:hsl(208, 100%, 97%);--info-border:hsl(221, 91%, 93%);--info-text:hsl(210, 92%, 45%);--warning-bg:hsl(49, 100%, 97%);--warning-border:hsl(49, 91%, 84%);--warning-text:hsl(31, 92%, 45%);--error-bg:hsl(359, 100%, 97%);--error-border:hsl(359, 100%, 94%);--error-text:hsl(360, 100%, 45%)}[data-sonner-toaster][data-sonner-theme=light] [data-sonner-toast][data-invert=true]{--normal-bg:#000;--normal-border:hsl(0, 0%, 20%);--normal-text:var(--gray1)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast][data-invert=true]{--normal-bg:#fff;--normal-border:var(--gray3);--normal-text:var(--gray12)}[data-sonner-toaster][data-sonner-theme=dark]{--normal-bg:#000;--normal-bg-hover:hsl(0, 0%, 12%);--normal-border:hsl(0, 0%, 20%);--normal-border-hover:hsl(0, 0%, 25%);--normal-text:var(--gray1);--success-bg:hsl(150, 100%, 6%);--success-border:hsl(147, 100%, 12%);--success-text:hsl(150, 86%, 65%);--info-bg:hsl(215, 100%, 6%);--info-border:hsl(223, 43%, 17%);--info-text:hsl(216, 87%, 65%);--warning-bg:hsl(64, 100%, 6%);--warning-border:hsl(60, 100%, 9%);--warning-text:hsl(46, 87%, 65%);--error-bg:hsl(358, 76%, 10%);--error-border:hsl(357, 89%, 16%);--error-text:hsl(358, 100%, 81%)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast] [data-close-button]{background:var(--normal-bg);border-color:var(--normal-border);color:var(--normal-text)}[data-sonner-toaster][data-sonner-theme=dark] [data-sonner-toast] [data-close-button]:hover{background:var(--normal-bg-hover);border-color:var(--normal-border-hover)}[data-rich-colors=true][data-sonner-toast][data-type=success]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true][data-sonner-toast][data-type=success] [data-close-button]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true][data-sonner-toast][data-type=info]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true][data-sonner-toast][data-type=info] [data-close-button]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true][data-sonner-toast][data-type=warning]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true][data-sonner-toast][data-type=warning] [data-close-button]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true][data-sonner-toast][data-type=error]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}[data-rich-colors=true][data-sonner-toast][data-type=error] [data-close-button]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}.sonner-loading-wrapper{--size:16px;height:var(--size);width:var(--size);position:absolute;inset:0;z-index:10}.sonner-loading-wrapper[data-visible=false]{transform-origin:center;animation:sonner-fade-out .2s ease forwards}.sonner-spinner{position:relative;top:50%;left:50%;height:var(--size);width:var(--size)}.sonner-loading-bar{animation:sonner-spin 1.2s linear infinite;background:var(--gray11);border-radius:6px;height:8%;left:-10%;position:absolute;top:-3.9%;width:24%}.sonner-loading-bar:first-child{animation-delay:-1.2s;transform:rotate(.0001deg) translate(146%)}.sonner-loading-bar:nth-child(2){animation-delay:-1.1s;transform:rotate(30deg) translate(146%)}.sonner-loading-bar:nth-child(3){animation-delay:-1s;transform:rotate(60deg) translate(146%)}.sonner-loading-bar:nth-child(4){animation-delay:-.9s;transform:rotate(90deg) translate(146%)}.sonner-loading-bar:nth-child(5){animation-delay:-.8s;transform:rotate(120deg) translate(146%)}.sonner-loading-bar:nth-child(6){animation-delay:-.7s;transform:rotate(150deg) translate(146%)}.sonner-loading-bar:nth-child(7){animation-delay:-.6s;transform:rotate(180deg) translate(146%)}.sonner-loading-bar:nth-child(8){animation-delay:-.5s;transform:rotate(210deg) translate(146%)}.sonner-loading-bar:nth-child(9){animation-delay:-.4s;transform:rotate(240deg) translate(146%)}.sonner-loading-bar:nth-child(10){animation-delay:-.3s;transform:rotate(270deg) translate(146%)}.sonner-loading-bar:nth-child(11){animation-delay:-.2s;transform:rotate(300deg) translate(146%)}.sonner-loading-bar:nth-child(12){animation-delay:-.1s;transform:rotate(330deg) translate(146%)}@keyframes sonner-fade-in{0%{opacity:0;transform:scale(.8)}100%{opacity:1;transform:scale(1)}}@keyframes sonner-fade-out{0%{opacity:1;transform:scale(1)}100%{opacity:0;transform:scale(.8)}}@keyframes sonner-spin{0%{opacity:1}100%{opacity:.15}}@media (prefers-reduced-motion){.sonner-loading-bar,[data-sonner-toast],[data-sonner-toast]>*{transition:none!important;animation:none!important}}.sonner-loader{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);transform-origin:center;transition:opacity .2s,transform .2s}.sonner-loader[data-visible=false]{opacity:0;transform:scale(.8) translate(-50%,-50%)}");function Js(i){return i.label!==void 0}const v1=3,g1="24px",b1="16px",_p=4e3,S1=356,E1=14,T1=45,O1=200;function Sn(...i){return i.filter(Boolean).join(" ")}function _1(i){const[n,r]=i.split("-"),s=[];return n&&s.push(n),r&&s.push(r),s}const w1=i=>{var n,r,s,o,f,d,y,m,h;const{invert:b,toast:v,unstyled:E,interacting:S,setHeights:O,visibleToasts:N,heights:M,index:D,toasts:U,expanded:Y,removeToast:X,defaultRichColors:K,closeButton:ee,style:$,cancelButtonStyle:we,actionButtonStyle:rt,className:dt="",descriptionClassName:ht="",duration:ae,position:Se,gap:mt,expandByDefault:He,classNames:R,icons:Q,closeButtonAriaLabel:W="Close toast"}=i,[pe,fe]=B.useState(null),[_,L]=B.useState(null),[V,G]=B.useState(!1),[Z,ne]=B.useState(!1),[he,ce]=B.useState(!1),[Ce,dn]=B.useState(!1),[wn,hn]=B.useState(!1),[Nl,nn]=B.useState(0),[hr,li]=B.useState(0),Ca=B.useRef(v.duration||ae||_p),mr=B.useRef(null),Ut=B.useRef(null),yr=D===0,pr=D+1<=N,bt=v.type,$n=v.dismissible!==!1,St=v.className||"",xu=v.descriptionClassName||"",xa=B.useMemo(()=>M.findIndex(ie=>ie.toastId===v.id)||0,[M,v.id]),jl=B.useMemo(()=>{var ie;return(ie=v.closeButton)!=null?ie:ee},[v.closeButton,ee]),Ra=B.useMemo(()=>v.duration||ae||_p,[v.duration,ae]),vr=B.useRef(0),An=B.useRef(0),Ul=B.useRef(0),Wn=B.useRef(null),[za,Et]=Se.split("-"),an=B.useMemo(()=>M.reduce((ie,qe,et)=>et>=xa?ie:ie+qe.height,0),[M,xa]),yt=c1(),Ru=v.invert||b,gr=bt==="loading";An.current=B.useMemo(()=>xa*mt+an,[xa,an]),B.useEffect(()=>{Ca.current=Ra},[Ra]),B.useEffect(()=>{G(!0)},[]),B.useEffect(()=>{const ie=Ut.current;if(ie){const qe=ie.getBoundingClientRect().height;return li(qe),O(et=>[{toastId:v.id,height:qe,position:v.position},...et]),()=>O(et=>et.filter(pt=>pt.toastId!==v.id))}},[O,v.id]),B.useLayoutEffect(()=>{if(!V)return;const ie=Ut.current,qe=ie.style.height;ie.style.height="auto";const et=ie.getBoundingClientRect().height;ie.style.height=qe,li(et),O(pt=>pt.find(Be=>Be.toastId===v.id)?pt.map(Be=>Be.toastId===v.id?{...Be,height:et}:Be):[{toastId:v.id,height:et,position:v.position},...pt])},[V,v.title,v.description,O,v.id,v.jsx,v.action,v.cancel]);const mn=B.useCallback(()=>{ne(!0),nn(An.current),O(ie=>ie.filter(qe=>qe.toastId!==v.id)),setTimeout(()=>{X(v)},O1)},[v,X,O,An]);B.useEffect(()=>{if(v.promise&&bt==="loading"||v.duration===1/0||v.type==="loading")return;let ie;return Y||S||yt?(()=>{if(Ul.current<vr.current){const pt=new Date().getTime()-vr.current;Ca.current=Ca.current-pt}Ul.current=new Date().getTime()})():(()=>{Ca.current!==1/0&&(vr.current=new Date().getTime(),ie=setTimeout(()=>{v.onAutoClose==null||v.onAutoClose.call(v,v),mn()},Ca.current))})(),()=>clearTimeout(ie)},[Y,S,v,bt,yt,mn]),B.useEffect(()=>{v.delete&&(mn(),v.onDismiss==null||v.onDismiss.call(v,v))},[mn,v.delete]);function si(){var ie;if(Q?.loading){var qe;return B.createElement("div",{className:Sn(R?.loader,v==null||(qe=v.classNames)==null?void 0:qe.loader,"sonner-loader"),"data-visible":bt==="loading"},Q.loading)}return B.createElement(i1,{className:Sn(R?.loader,v==null||(ie=v.classNames)==null?void 0:ie.loader),visible:bt==="loading"})}const ui=v.icon||Q?.[bt]||n1(bt);var Na,yn;return B.createElement("li",{tabIndex:0,ref:Ut,className:Sn(dt,St,R?.toast,v==null||(n=v.classNames)==null?void 0:n.toast,R?.default,R?.[bt],v==null||(r=v.classNames)==null?void 0:r[bt]),"data-sonner-toast":"","data-rich-colors":(Na=v.richColors)!=null?Na:K,"data-styled":!(v.jsx||v.unstyled||E),"data-mounted":V,"data-promise":!!v.promise,"data-swiped":wn,"data-removed":Z,"data-visible":pr,"data-y-position":za,"data-x-position":Et,"data-index":D,"data-front":yr,"data-swiping":he,"data-dismissible":$n,"data-type":bt,"data-invert":Ru,"data-swipe-out":Ce,"data-swipe-direction":_,"data-expanded":!!(Y||He&&V),"data-testid":v.testId,style:{"--index":D,"--toasts-before":D,"--z-index":U.length-D,"--offset":`${Z?Nl:An.current}px`,"--initial-height":He?"auto":`${hr}px`,...$,...v.style},onDragEnd:()=>{ce(!1),fe(null),Wn.current=null},onPointerDown:ie=>{ie.button!==2&&(gr||!$n||(mr.current=new Date,nn(An.current),ie.target.setPointerCapture(ie.pointerId),ie.target.tagName!=="BUTTON"&&(ce(!0),Wn.current={x:ie.clientX,y:ie.clientY})))},onPointerUp:()=>{var ie,qe,et;if(Ce||!$n)return;Wn.current=null;const pt=Number(((ie=Ut.current)==null?void 0:ie.style.getPropertyValue("--swipe-amount-x").replace("px",""))||0),Pn=Number(((qe=Ut.current)==null?void 0:qe.style.getPropertyValue("--swipe-amount-y").replace("px",""))||0),Be=new Date().getTime()-((et=mr.current)==null?void 0:et.getTime()),Ot=pe==="x"?pt:Pn,ja=Math.abs(Ot)/Be;if(Math.abs(Ot)>=T1||ja>.11){nn(An.current),v.onDismiss==null||v.onDismiss.call(v,v),L(pe==="x"?pt>0?"right":"left":Pn>0?"down":"up"),mn(),dn(!0);return}else{var _t,wt;(_t=Ut.current)==null||_t.style.setProperty("--swipe-amount-x","0px"),(wt=Ut.current)==null||wt.style.setProperty("--swipe-amount-y","0px")}hn(!1),ce(!1),fe(null)},onPointerMove:ie=>{var qe,et,pt;if(!Wn.current||!$n||((qe=window.getSelection())==null?void 0:qe.toString().length)>0)return;const Be=ie.clientY-Wn.current.y,Ot=ie.clientX-Wn.current.x;var ja;const _t=(ja=i.swipeDirections)!=null?ja:_1(Se);!pe&&(Math.abs(Ot)>1||Math.abs(Be)>1)&&fe(Math.abs(Ot)>Math.abs(Be)?"x":"y");let wt={x:0,y:0};const oi=rn=>1/(1.5+Math.abs(rn)/20);if(pe==="y"){if(_t.includes("top")||_t.includes("bottom"))if(_t.includes("top")&&Be<0||_t.includes("bottom")&&Be>0)wt.y=Be;else{const rn=Be*oi(Be);wt.y=Math.abs(rn)<Math.abs(Be)?rn:Be}}else if(pe==="x"&&(_t.includes("left")||_t.includes("right")))if(_t.includes("left")&&Ot<0||_t.includes("right")&&Ot>0)wt.x=Ot;else{const rn=Ot*oi(Ot);wt.x=Math.abs(rn)<Math.abs(Ot)?rn:Ot}(Math.abs(wt.x)>0||Math.abs(wt.y)>0)&&hn(!0),(et=Ut.current)==null||et.style.setProperty("--swipe-amount-x",`${wt.x}px`),(pt=Ut.current)==null||pt.style.setProperty("--swipe-amount-y",`${wt.y}px`)}},jl&&!v.jsx&&bt!=="loading"?B.createElement("button",{"aria-label":W,"data-disabled":gr,"data-close-button":!0,onClick:gr||!$n?()=>{}:()=>{mn(),v.onDismiss==null||v.onDismiss.call(v,v)},className:Sn(R?.closeButton,v==null||(s=v.classNames)==null?void 0:s.closeButton)},(yn=Q?.close)!=null?yn:o1):null,(bt||v.icon||v.promise)&&v.icon!==null&&(Q?.[bt]!==null||v.icon)?B.createElement("div",{"data-icon":"",className:Sn(R?.icon,v==null||(o=v.classNames)==null?void 0:o.icon)},v.promise||v.type==="loading"&&!v.icon?v.icon||si():null,v.type!=="loading"?ui:null):null,B.createElement("div",{"data-content":"",className:Sn(R?.content,v==null||(f=v.classNames)==null?void 0:f.content)},B.createElement("div",{"data-title":"",className:Sn(R?.title,v==null||(d=v.classNames)==null?void 0:d.title)},v.jsx?v.jsx:typeof v.title=="function"?v.title():v.title),v.description?B.createElement("div",{"data-description":"",className:Sn(ht,xu,R?.description,v==null||(y=v.classNames)==null?void 0:y.description)},typeof v.description=="function"?v.description():v.description):null),B.isValidElement(v.cancel)?v.cancel:v.cancel&&Js(v.cancel)?B.createElement("button",{"data-button":!0,"data-cancel":!0,style:v.cancelButtonStyle||we,onClick:ie=>{Js(v.cancel)&&$n&&(v.cancel.onClick==null||v.cancel.onClick.call(v.cancel,ie),mn())},className:Sn(R?.cancelButton,v==null||(m=v.classNames)==null?void 0:m.cancelButton)},v.cancel.label):null,B.isValidElement(v.action)?v.action:v.action&&Js(v.action)?B.createElement("button",{"data-button":!0,"data-action":!0,style:v.actionButtonStyle||rt,onClick:ie=>{Js(v.action)&&(v.action.onClick==null||v.action.onClick.call(v.action,ie),!ie.defaultPrevented&&mn())},className:Sn(R?.actionButton,v==null||(h=v.classNames)==null?void 0:h.actionButton)},v.action.label):null)};function wp(){if(typeof window>"u"||typeof document>"u")return"ltr";const i=document.documentElement.getAttribute("dir");return i==="auto"||!i?window.getComputedStyle(document.documentElement).direction:i}function A1(i,n){const r={};return[i,n].forEach((s,o)=>{const f=o===1,d=f?"--mobile-offset":"--offset",y=f?b1:g1;function m(h){["top","right","bottom","left"].forEach(b=>{r[`${d}-${b}`]=typeof h=="number"?`${h}px`:h})}typeof s=="number"||typeof s=="string"?m(s):typeof s=="object"?["top","right","bottom","left"].forEach(h=>{s[h]===void 0?r[`${d}-${h}`]=y:r[`${d}-${h}`]=typeof s[h]=="number"?`${s[h]}px`:s[h]}):m(y)}),r}const D1=B.forwardRef(function(n,r){const{id:s,invert:o,position:f="bottom-right",hotkey:d=["altKey","KeyT"],expand:y,closeButton:m,className:h,offset:b,mobileOffset:v,theme:E="light",richColors:S,duration:O,style:N,visibleToasts:M=v1,toastOptions:D,dir:U=wp(),gap:Y=E1,icons:X,containerAriaLabel:K="Notifications"}=n,[ee,$]=B.useState([]),we=B.useMemo(()=>s?ee.filter(V=>V.toasterId===s):ee.filter(V=>!V.toasterId),[ee,s]),rt=B.useMemo(()=>Array.from(new Set([f].concat(we.filter(V=>V.position).map(V=>V.position)))),[we,f]),[dt,ht]=B.useState([]),[ae,Se]=B.useState(!1),[mt,He]=B.useState(!1),[R,Q]=B.useState(E!=="system"?E:typeof window<"u"&&window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light"),W=B.useRef(null),pe=d.join("+").replace(/Key/g,"").replace(/Digit/g,""),fe=B.useRef(null),_=B.useRef(!1),L=B.useCallback(V=>{$(G=>{var Z;return(Z=G.find(ne=>ne.id===V.id))!=null&&Z.delete||Nt.dismiss(V.id),G.filter(({id:ne})=>ne!==V.id)})},[]);return B.useEffect(()=>Nt.subscribe(V=>{if(V.dismiss){requestAnimationFrame(()=>{$(G=>G.map(Z=>Z.id===V.id?{...Z,delete:!0}:Z))});return}setTimeout(()=>{Gv.flushSync(()=>{$(G=>{const Z=G.findIndex(ne=>ne.id===V.id);return Z!==-1?[...G.slice(0,Z),{...G[Z],...V},...G.slice(Z+1)]:[V,...G]})})})}),[ee]),B.useEffect(()=>{if(E!=="system"){Q(E);return}if(E==="system"&&(window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?Q("dark"):Q("light")),typeof window>"u")return;const V=window.matchMedia("(prefers-color-scheme: dark)");try{V.addEventListener("change",({matches:G})=>{Q(G?"dark":"light")})}catch{V.addListener(({matches:Z})=>{try{Q(Z?"dark":"light")}catch(ne){console.error(ne)}})}},[E]),B.useEffect(()=>{ee.length<=1&&Se(!1)},[ee]),B.useEffect(()=>{const V=G=>{var Z;if(d.every(ce=>G[ce]||G.code===ce)){var he;Se(!0),(he=W.current)==null||he.focus()}G.code==="Escape"&&(document.activeElement===W.current||(Z=W.current)!=null&&Z.contains(document.activeElement))&&Se(!1)};return document.addEventListener("keydown",V),()=>document.removeEventListener("keydown",V)},[d]),B.useEffect(()=>{if(W.current)return()=>{fe.current&&(fe.current.focus({preventScroll:!0}),fe.current=null,_.current=!1)}},[W.current]),B.createElement("section",{ref:r,"aria-label":`${K} ${pe}`,tabIndex:-1,"aria-live":"polite","aria-relevant":"additions text","aria-atomic":"false",suppressHydrationWarning:!0},rt.map((V,G)=>{var Z;const[ne,he]=V.split("-");return we.length?B.createElement("ol",{key:V,dir:U==="auto"?wp():U,tabIndex:-1,ref:W,className:h,"data-sonner-toaster":!0,"data-sonner-theme":R,"data-y-position":ne,"data-x-position":he,style:{"--front-toast-height":`${((Z=dt[0])==null?void 0:Z.height)||0}px`,"--width":`${S1}px`,"--gap":`${Y}px`,...N,...A1(b,v)},onBlur:ce=>{_.current&&!ce.currentTarget.contains(ce.relatedTarget)&&(_.current=!1,fe.current&&(fe.current.focus({preventScroll:!0}),fe.current=null))},onFocus:ce=>{ce.target instanceof HTMLElement&&ce.target.dataset.dismissible==="false"||_.current||(_.current=!0,fe.current=ce.relatedTarget)},onMouseEnter:()=>Se(!0),onMouseMove:()=>Se(!0),onMouseLeave:()=>{mt||Se(!1)},onDragEnd:()=>Se(!1),onPointerDown:ce=>{ce.target instanceof HTMLElement&&ce.target.dataset.dismissible==="false"||He(!0)},onPointerUp:()=>He(!1)},we.filter(ce=>!ce.position&&G===0||ce.position===V).map((ce,Ce)=>{var dn,wn;return B.createElement(w1,{key:ce.id,icons:X,index:Ce,toast:ce,defaultRichColors:S,duration:(dn=D?.duration)!=null?dn:O,className:D?.className,descriptionClassName:D?.descriptionClassName,invert:o,visibleToasts:M,closeButton:(wn=D?.closeButton)!=null?wn:m,interacting:mt,position:V,style:D?.style,unstyled:D?.unstyled,classNames:D?.classNames,cancelButtonStyle:D?.cancelButtonStyle,actionButtonStyle:D?.actionButtonStyle,closeButtonAriaLabel:D?.closeButtonAriaLabel,removeToast:L,toasts:we.filter(hn=>hn.position==ce.position),heights:dt.filter(hn=>hn.position==ce.position),setHeights:ht,expandByDefault:y,gap:Y,expanded:ae,swipeDirections:n.swipeDirections})})):null}))});var M1=({...i})=>{const{baseTheme:n="system"}=IS();return at.jsx(D1,{theme:n,className:"toaster group",style:{"--normal-bg":"var(--bg-primary)","--normal-text":"var(--text-primary)","--normal-border":"var(--bg-secondary)"},...i})};const Zv=!1;function wa(i){try{return i()}catch{}}const _f=wa(()=>globalThis)||wa(()=>window)||wa(()=>self)||wa(()=>global)||wa(function(){return wa.constructor("return this")()}),Ff="4.0.11",Ap=new Map;function Jv(i){const n=Ap.get(i)||1;return Ap.set(i,n+1),`${i}:${n}:${Math.random().toString(36).slice(2)}`}function C1(i,n=0){const r=Jv("stringifyForDisplay");return JSON.stringify(i,(s,o)=>o===void 0?r:o,n).split(JSON.stringify(r)).join("<undefined>")}const Dp="Invariant Violation";class Zf extends Error{constructor(n=Dp){super(n),this.name=Dp,Object.setPrototypeOf(this,Zf.prototype)}}const Kv=["debug","log","warn","error","silent"];let x1=Kv.indexOf("silent");function de(i,...n){if(!i)throw tn(...n)}function bu(i){return function(n,...r){if(Kv.indexOf(i)>=x1){const s=console[i]||console.log;if(typeof n=="number"){const o=n;n=Iv(o),n||(n=$v(o,r),r=[])}s(n,...r)}}}de.debug=bu("debug");de.log=bu("log");de.warn=bu("warn");de.error=bu("error");function tn(i,...n){return new Zf(Iv(i,n)||$v(i,n))}const Mp=Symbol.for("ApolloErrorMessageHandler_"+Ff);function wf(i){if(typeof i=="string")return i;try{return C1(i,2).slice(0,1e3)}catch{return"<non-serializable>"}}function Iv(i,n=[]){if(i)return _f[Mp]&&_f[Mp](i,n.map(wf))}function $v(i,n=[]){if(i)return typeof i=="string"?n.reduce((r,s)=>r.replace(/%[sdfo]/,wf(s)),i):`An error occurred! For more details, see the full error text at https://go.apollo.dev/c/err#${encodeURIComponent(JSON.stringify({version:Ff,message:i,args:n.map(wf)}))}`}const Cp=Symbol.for("__APOLLO_CONTEXT__");function R1(){de("createContext"in CS,37);let i=be.createContext[Cp];return i||(Object.defineProperty(be.createContext,Cp,{value:i=be.createContext({}),enumerable:!1,writable:!1,configurable:!0}),i.displayName="ApolloContext"),i}const z1=({client:i,children:n})=>{const r=R1(),s=be.useContext(r),o=be.useMemo(()=>({...s,client:i||s.client}),[s,i]);return de(o.client,38),be.createElement(r.Provider,{value:o},n)},{toString:xp,hasOwnProperty:N1}=Object.prototype,Rp=Function.prototype.toString,Af=new Map;function $e(i,n){try{return Df(i,n)}finally{Af.clear()}}function Df(i,n){if(i===n)return!0;const r=xp.call(i),s=xp.call(n);if(r!==s)return!1;switch(r){case"[object Array]":if(i.length!==n.length)return!1;case"[object Object]":{if(Np(i,n))return!0;const o=zp(i),f=zp(n),d=o.length;if(d!==f.length)return!1;for(let y=0;y<d;++y)if(!N1.call(n,o[y]))return!1;for(let y=0;y<d;++y){const m=o[y];if(!Df(i[m],n[m]))return!1}return!0}case"[object Error]":return i.name===n.name&&i.message===n.message;case"[object Number]":if(i!==i)return n!==n;case"[object Boolean]":case"[object Date]":return+i==+n;case"[object RegExp]":case"[object String]":return i==`${n}`;case"[object Map]":case"[object Set]":{if(i.size!==n.size)return!1;if(Np(i,n))return!0;const o=i.entries(),f=r==="[object Map]";for(;;){const d=o.next();if(d.done)break;const[y,m]=d.value;if(!n.has(y)||f&&!Df(m,n.get(y)))return!1}return!0}case"[object Uint16Array]":case"[object Uint8Array]":case"[object Uint32Array]":case"[object Int32Array]":case"[object Int8Array]":case"[object Int16Array]":case"[object ArrayBuffer]":i=new Uint8Array(i),n=new Uint8Array(n);case"[object DataView]":{let o=i.byteLength;if(o===n.byteLength)for(;o--&&i[o]===n[o];);return o===-1}case"[object AsyncFunction]":case"[object GeneratorFunction]":case"[object AsyncGeneratorFunction]":case"[object Function]":{const o=Rp.call(i);return o!==Rp.call(n)?!1:!k1(o,U1)}}return!1}function zp(i){return Object.keys(i).filter(j1,i)}function j1(i){return this[i]!==void 0}const U1="{ [native code] }";function k1(i,n){const r=i.length-n.length;return r>=0&&i.indexOf(n,r)===r}function Np(i,n){let r=Af.get(i);if(r){if(r.has(n))return!0}else Af.set(i,r=new Set);return r.add(n),!1}function q1(i,n){if(!!!i)throw new Error(n)}const Wv={Name:[],Document:["definitions"],OperationDefinition:["description","name","variableDefinitions","directives","selectionSet"],VariableDefinition:["description","variable","type","defaultValue","directives"],Variable:["name"],SelectionSet:["selections"],Field:["alias","name","arguments","directives","selectionSet"],Argument:["name","value"],FragmentSpread:["name","directives"],InlineFragment:["typeCondition","directives","selectionSet"],FragmentDefinition:["description","name","variableDefinitions","typeCondition","directives","selectionSet"],IntValue:[],FloatValue:[],StringValue:[],BooleanValue:[],NullValue:[],EnumValue:[],ListValue:["values"],ObjectValue:["fields"],ObjectField:["name","value"],Directive:["name","arguments"],NamedType:["name"],ListType:["type"],NonNullType:["type"],SchemaDefinition:["description","directives","operationTypes"],OperationTypeDefinition:["type"],ScalarTypeDefinition:["description","name","directives"],ObjectTypeDefinition:["description","name","interfaces","directives","fields"],FieldDefinition:["description","name","arguments","type","directives"],InputValueDefinition:["description","name","type","defaultValue","directives"],InterfaceTypeDefinition:["description","name","interfaces","directives","fields"],UnionTypeDefinition:["description","name","directives","types"],EnumTypeDefinition:["description","name","directives","values"],EnumValueDefinition:["description","name","directives"],InputObjectTypeDefinition:["description","name","directives","fields"],DirectiveDefinition:["description","name","arguments","locations"],SchemaExtension:["directives","operationTypes"],ScalarTypeExtension:["name","directives"],ObjectTypeExtension:["name","interfaces","directives","fields"],InterfaceTypeExtension:["name","interfaces","directives","fields"],UnionTypeExtension:["name","directives","types"],EnumTypeExtension:["name","directives","values"],InputObjectTypeExtension:["name","directives","fields"],TypeCoordinate:["name"],MemberCoordinate:["name","memberName"],ArgumentCoordinate:["name","fieldName","argumentName"],DirectiveCoordinate:["name"],DirectiveArgumentCoordinate:["name","argumentName"]},L1=new Set(Object.keys(Wv));function jp(i){const n=i?.kind;return typeof n=="string"&&L1.has(n)}var ei;(function(i){i.QUERY="query",i.MUTATION="mutation",i.SUBSCRIPTION="subscription"})(ei||(ei={}));var Te;(function(i){i.NAME="Name",i.DOCUMENT="Document",i.OPERATION_DEFINITION="OperationDefinition",i.VARIABLE_DEFINITION="VariableDefinition",i.SELECTION_SET="SelectionSet",i.FIELD="Field",i.ARGUMENT="Argument",i.FRAGMENT_SPREAD="FragmentSpread",i.INLINE_FRAGMENT="InlineFragment",i.FRAGMENT_DEFINITION="FragmentDefinition",i.VARIABLE="Variable",i.INT="IntValue",i.FLOAT="FloatValue",i.STRING="StringValue",i.BOOLEAN="BooleanValue",i.NULL="NullValue",i.ENUM="EnumValue",i.LIST="ListValue",i.OBJECT="ObjectValue",i.OBJECT_FIELD="ObjectField",i.DIRECTIVE="Directive",i.NAMED_TYPE="NamedType",i.LIST_TYPE="ListType",i.NON_NULL_TYPE="NonNullType",i.SCHEMA_DEFINITION="SchemaDefinition",i.OPERATION_TYPE_DEFINITION="OperationTypeDefinition",i.SCALAR_TYPE_DEFINITION="ScalarTypeDefinition",i.OBJECT_TYPE_DEFINITION="ObjectTypeDefinition",i.FIELD_DEFINITION="FieldDefinition",i.INPUT_VALUE_DEFINITION="InputValueDefinition",i.INTERFACE_TYPE_DEFINITION="InterfaceTypeDefinition",i.UNION_TYPE_DEFINITION="UnionTypeDefinition",i.ENUM_TYPE_DEFINITION="EnumTypeDefinition",i.ENUM_VALUE_DEFINITION="EnumValueDefinition",i.INPUT_OBJECT_TYPE_DEFINITION="InputObjectTypeDefinition",i.DIRECTIVE_DEFINITION="DirectiveDefinition",i.SCHEMA_EXTENSION="SchemaExtension",i.SCALAR_TYPE_EXTENSION="ScalarTypeExtension",i.OBJECT_TYPE_EXTENSION="ObjectTypeExtension",i.INTERFACE_TYPE_EXTENSION="InterfaceTypeExtension",i.UNION_TYPE_EXTENSION="UnionTypeExtension",i.ENUM_TYPE_EXTENSION="EnumTypeExtension",i.INPUT_OBJECT_TYPE_EXTENSION="InputObjectTypeExtension",i.TYPE_COORDINATE="TypeCoordinate",i.MEMBER_COORDINATE="MemberCoordinate",i.ARGUMENT_COORDINATE="ArgumentCoordinate",i.DIRECTIVE_COORDINATE="DirectiveCoordinate",i.DIRECTIVE_ARGUMENT_COORDINATE="DirectiveArgumentCoordinate"})(Te||(Te={}));function Up(i){return i===9||i===32}function H1(i,n){const r=i.replace(/"""/g,'\\"""'),s=r.split(/\r\n|[\n\r]/g),o=s.length===1,f=s.length>1&&s.slice(1).every(S=>S.length===0||Up(S.charCodeAt(0))),d=r.endsWith('\\"""'),y=i.endsWith('"')&&!d,m=i.endsWith("\\"),h=y||m,b=!o||i.length>70||h||f||d;let v="";const E=o&&Up(i.charCodeAt(0));return(b&&!E||f)&&(v+=`
`),v+=r,(b||h)&&(v+=`
`),'"""'+v+'"""'}const B1=10,Pv=2;function V1(i){return Su(i,[])}function Su(i,n){switch(typeof i){case"string":return JSON.stringify(i);case"function":return i.name?`[function ${i.name}]`:"[function]";case"object":return Q1(i,n);default:return String(i)}}function Q1(i,n){if(i===null)return"null";if(n.includes(i))return"[Circular]";const r=[...n,i];if(Y1(i)){const s=i.toJSON();if(s!==i)return typeof s=="string"?s:Su(s,r)}else if(Array.isArray(i))return X1(i,r);return G1(i,r)}function Y1(i){return typeof i.toJSON=="function"}function G1(i,n){const r=Object.entries(i);return r.length===0?"{}":n.length>Pv?"["+F1(i)+"]":"{ "+r.map(([o,f])=>o+": "+Su(f,n)).join(", ")+" }"}function X1(i,n){if(i.length===0)return"[]";if(n.length>Pv)return"[Array]";const r=Math.min(B1,i.length),s=i.length-r,o=[];for(let f=0;f<r;++f)o.push(Su(i[f],n));return s===1?o.push("... 1 more item"):s>1&&o.push(`... ${s} more items`),"["+o.join(", ")+"]"}function F1(i){const n=Object.prototype.toString.call(i).replace(/^\[object /,"").replace(/]$/,"");if(n==="Object"&&typeof i.constructor=="function"){const r=i.constructor.name;if(typeof r=="string"&&r!=="")return r}return n}function Z1(i){return`"${i.replace(J1,K1)}"`}const J1=/[\x00-\x1f\x22\x5c\x7f-\x9f]/g;function K1(i){return I1[i.charCodeAt(0)]}const I1=["\\u0000","\\u0001","\\u0002","\\u0003","\\u0004","\\u0005","\\u0006","\\u0007","\\b","\\t","\\n","\\u000B","\\f","\\r","\\u000E","\\u000F","\\u0010","\\u0011","\\u0012","\\u0013","\\u0014","\\u0015","\\u0016","\\u0017","\\u0018","\\u0019","\\u001A","\\u001B","\\u001C","\\u001D","\\u001E","\\u001F","","",'\\"',"","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","\\\\","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","\\u007F","\\u0080","\\u0081","\\u0082","\\u0083","\\u0084","\\u0085","\\u0086","\\u0087","\\u0088","\\u0089","\\u008A","\\u008B","\\u008C","\\u008D","\\u008E","\\u008F","\\u0090","\\u0091","\\u0092","\\u0093","\\u0094","\\u0095","\\u0096","\\u0097","\\u0098","\\u0099","\\u009A","\\u009B","\\u009C","\\u009D","\\u009E","\\u009F"],Jf=Object.freeze({});function On(i,n,r=Wv){const s=new Map;for(const D of Object.values(Te))s.set(D,$1(n,D));let o,f=Array.isArray(i),d=[i],y=-1,m=[],h=i,b,v;const E=[],S=[];do{y++;const D=y===d.length,U=D&&m.length!==0;if(D){if(b=S.length===0?void 0:E[E.length-1],h=v,v=S.pop(),U)if(f){h=h.slice();let X=0;for(const[K,ee]of m){const $=K-X;ee===null?(h.splice($,1),X++):h[$]=ee}}else{h={...h};for(const[X,K]of m)h[X]=K}y=o.index,d=o.keys,m=o.edits,f=o.inArray,o=o.prev}else if(v){if(b=f?y:d[y],h=v[b],h==null)continue;E.push(b)}let Y;if(!Array.isArray(h)){var O,N;jp(h)||q1(!1,`Invalid AST Node: ${V1(h)}.`);const X=D?(O=s.get(h.kind))===null||O===void 0?void 0:O.leave:(N=s.get(h.kind))===null||N===void 0?void 0:N.enter;if(Y=X?.call(n,h,b,v,E,S),Y===Jf)break;if(Y===!1){if(!D){E.pop();continue}}else if(Y!==void 0&&(m.push([b,Y]),!D))if(jp(Y))h=Y;else{E.pop();continue}}if(Y===void 0&&U&&m.push([b,h]),D)E.pop();else{var M;o={inArray:f,index:y,keys:d,edits:m,prev:o},f=Array.isArray(h),d=f?h:(M=r[h.kind])!==null&&M!==void 0?M:[],y=-1,m=[],v&&S.push(v),v=h}}while(o!==void 0);return m.length!==0?m[m.length-1][1]:i}function $1(i,n){const r=i[n];return typeof r=="object"?r:typeof r=="function"?{enter:r,leave:void 0}:{enter:i.enter,leave:i.leave}}function W1(i){return On(i,eE)}const P1=80,eE={Name:{leave:i=>i.value},Variable:{leave:i=>"$"+i.name},Document:{leave:i=>F(i.definitions,`

`)},OperationDefinition:{leave(i){const n=Kc(i.variableDefinitions)?le(`(
`,F(i.variableDefinitions,`
`),`
)`):le("(",F(i.variableDefinitions,", "),")"),r=le("",i.description,`
`)+F([i.operation,F([i.name,n]),F(i.directives," ")]," ");return(r==="query"?"":r+" ")+i.selectionSet}},VariableDefinition:{leave:({variable:i,type:n,defaultValue:r,directives:s,description:o})=>le("",o,`
`)+i+": "+n+le(" = ",r)+le(" ",F(s," "))},SelectionSet:{leave:({selections:i})=>on(i)},Field:{leave({alias:i,name:n,arguments:r,directives:s,selectionSet:o}){const f=le("",i,": ")+n;let d=f+le("(",F(r,", "),")");return d.length>P1&&(d=f+le(`(
`,lu(F(r,`
`)),`
)`)),F([d,F(s," "),o]," ")}},Argument:{leave:({name:i,value:n})=>i+": "+n},FragmentSpread:{leave:({name:i,directives:n})=>"..."+i+le(" ",F(n," "))},InlineFragment:{leave:({typeCondition:i,directives:n,selectionSet:r})=>F(["...",le("on ",i),F(n," "),r]," ")},FragmentDefinition:{leave:({name:i,typeCondition:n,variableDefinitions:r,directives:s,selectionSet:o,description:f})=>le("",f,`
`)+`fragment ${i}${le("(",F(r,", "),")")} on ${n} ${le("",F(s," ")," ")}`+o},IntValue:{leave:({value:i})=>i},FloatValue:{leave:({value:i})=>i},StringValue:{leave:({value:i,block:n})=>n?H1(i):Z1(i)},BooleanValue:{leave:({value:i})=>i?"true":"false"},NullValue:{leave:()=>"null"},EnumValue:{leave:({value:i})=>i},ListValue:{leave:({values:i})=>"["+F(i,", ")+"]"},ObjectValue:{leave:({fields:i})=>"{"+F(i,", ")+"}"},ObjectField:{leave:({name:i,value:n})=>i+": "+n},Directive:{leave:({name:i,arguments:n})=>"@"+i+le("(",F(n,", "),")")},NamedType:{leave:({name:i})=>i},ListType:{leave:({type:i})=>"["+i+"]"},NonNullType:{leave:({type:i})=>i+"!"},SchemaDefinition:{leave:({description:i,directives:n,operationTypes:r})=>le("",i,`
`)+F(["schema",F(n," "),on(r)]," ")},OperationTypeDefinition:{leave:({operation:i,type:n})=>i+": "+n},ScalarTypeDefinition:{leave:({description:i,name:n,directives:r})=>le("",i,`
`)+F(["scalar",n,F(r," ")]," ")},ObjectTypeDefinition:{leave:({description:i,name:n,interfaces:r,directives:s,fields:o})=>le("",i,`
`)+F(["type",n,le("implements ",F(r," & ")),F(s," "),on(o)]," ")},FieldDefinition:{leave:({description:i,name:n,arguments:r,type:s,directives:o})=>le("",i,`
`)+n+(Kc(r)?le(`(
`,lu(F(r,`
`)),`
)`):le("(",F(r,", "),")"))+": "+s+le(" ",F(o," "))},InputValueDefinition:{leave:({description:i,name:n,type:r,defaultValue:s,directives:o})=>le("",i,`
`)+F([n+": "+r,le("= ",s),F(o," ")]," ")},InterfaceTypeDefinition:{leave:({description:i,name:n,interfaces:r,directives:s,fields:o})=>le("",i,`
`)+F(["interface",n,le("implements ",F(r," & ")),F(s," "),on(o)]," ")},UnionTypeDefinition:{leave:({description:i,name:n,directives:r,types:s})=>le("",i,`
`)+F(["union",n,F(r," "),le("= ",F(s," | "))]," ")},EnumTypeDefinition:{leave:({description:i,name:n,directives:r,values:s})=>le("",i,`
`)+F(["enum",n,F(r," "),on(s)]," ")},EnumValueDefinition:{leave:({description:i,name:n,directives:r})=>le("",i,`
`)+F([n,F(r," ")]," ")},InputObjectTypeDefinition:{leave:({description:i,name:n,directives:r,fields:s})=>le("",i,`
`)+F(["input",n,F(r," "),on(s)]," ")},DirectiveDefinition:{leave:({description:i,name:n,arguments:r,repeatable:s,locations:o})=>le("",i,`
`)+"directive @"+n+(Kc(r)?le(`(
`,lu(F(r,`
`)),`
)`):le("(",F(r,", "),")"))+(s?" repeatable":"")+" on "+F(o," | ")},SchemaExtension:{leave:({directives:i,operationTypes:n})=>F(["extend schema",F(i," "),on(n)]," ")},ScalarTypeExtension:{leave:({name:i,directives:n})=>F(["extend scalar",i,F(n," ")]," ")},ObjectTypeExtension:{leave:({name:i,interfaces:n,directives:r,fields:s})=>F(["extend type",i,le("implements ",F(n," & ")),F(r," "),on(s)]," ")},InterfaceTypeExtension:{leave:({name:i,interfaces:n,directives:r,fields:s})=>F(["extend interface",i,le("implements ",F(n," & ")),F(r," "),on(s)]," ")},UnionTypeExtension:{leave:({name:i,directives:n,types:r})=>F(["extend union",i,F(n," "),le("= ",F(r," | "))]," ")},EnumTypeExtension:{leave:({name:i,directives:n,values:r})=>F(["extend enum",i,F(n," "),on(r)]," ")},InputObjectTypeExtension:{leave:({name:i,directives:n,fields:r})=>F(["extend input",i,F(n," "),on(r)]," ")},TypeCoordinate:{leave:({name:i})=>i},MemberCoordinate:{leave:({name:i,memberName:n})=>F([i,le(".",n)])},ArgumentCoordinate:{leave:({name:i,fieldName:n,argumentName:r})=>F([i,le(".",n),le("(",r,":)")])},DirectiveCoordinate:{leave:({name:i})=>F(["@",i])},DirectiveArgumentCoordinate:{leave:({name:i,argumentName:n})=>F(["@",i,le("(",n,":)")])}};function F(i,n=""){var r;return(r=i?.filter(s=>s).join(n))!==null&&r!==void 0?r:""}function on(i){return le(`{
`,lu(F(i,`
`)),`
}`)}function le(i,n,r=""){return n!=null&&n!==""?i+n+r:""}function lu(i){return le("  ",i.replace(/\n/g,`
  `))}function Kc(i){var n;return(n=i?.some(r=>r.includes(`
`)))!==null&&n!==void 0?n:!1}function Ye(i){return typeof i=="function"}function Kf(i){var n=function(s){Error.call(s),s.stack=new Error().stack},r=i(n);return r.prototype=Object.create(Error.prototype),r.prototype.constructor=r,r}var Ic=Kf(function(i){return function(r){i(this),this.message=r?r.length+` errors occurred during unsubscription:
`+r.map(function(s,o){return o+1+") "+s.toString()}).join(`
  `):"",this.name="UnsubscriptionError",this.errors=r}});function Mf(i,n){if(i){var r=i.indexOf(n);0<=r&&i.splice(r,1)}}var Eu=(function(){function i(n){this.initialTeardown=n,this.closed=!1,this._parentage=null,this._finalizers=null}return i.prototype.unsubscribe=function(){var n,r,s,o,f;if(!this.closed){this.closed=!0;var d=this._parentage;if(d)if(this._parentage=null,Array.isArray(d))try{for(var y=rr(d),m=y.next();!m.done;m=y.next()){var h=m.value;h.remove(this)}}catch(N){n={error:N}}finally{try{m&&!m.done&&(r=y.return)&&r.call(y)}finally{if(n)throw n.error}}else d.remove(this);var b=this.initialTeardown;if(Ye(b))try{b()}catch(N){f=N instanceof Ic?N.errors:[N]}var v=this._finalizers;if(v){this._finalizers=null;try{for(var E=rr(v),S=E.next();!S.done;S=E.next()){var O=S.value;try{kp(O)}catch(N){f=f??[],N instanceof Ic?f=hu(hu([],Tl(f)),Tl(N.errors)):f.push(N)}}}catch(N){s={error:N}}finally{try{S&&!S.done&&(o=E.return)&&o.call(E)}finally{if(s)throw s.error}}}if(f)throw new Ic(f)}},i.prototype.add=function(n){var r;if(n&&n!==this)if(this.closed)kp(n);else{if(n instanceof i){if(n.closed||n._hasParent(this))return;n._addParent(this)}(this._finalizers=(r=this._finalizers)!==null&&r!==void 0?r:[]).push(n)}},i.prototype._hasParent=function(n){var r=this._parentage;return r===n||Array.isArray(r)&&r.includes(n)},i.prototype._addParent=function(n){var r=this._parentage;this._parentage=Array.isArray(r)?(r.push(n),r):r?[r,n]:n},i.prototype._removeParent=function(n){var r=this._parentage;r===n?this._parentage=null:Array.isArray(r)&&Mf(r,n)},i.prototype.remove=function(n){var r=this._finalizers;r&&Mf(r,n),n instanceof i&&n._removeParent(this)},i.EMPTY=(function(){var n=new i;return n.closed=!0,n})(),i})(),eg=Eu.EMPTY;function tg(i){return i instanceof Eu||i&&"closed"in i&&Ye(i.remove)&&Ye(i.add)&&Ye(i.unsubscribe)}function kp(i){Ye(i)?i():i.unsubscribe()}var tE={Promise:void 0},nE={setTimeout:function(i,n){for(var r=[],s=2;s<arguments.length;s++)r[s-2]=arguments[s];return setTimeout.apply(void 0,hu([i,n],Tl(r)))},clearTimeout:function(i){return clearTimeout(i)},delegate:void 0};function ng(i){nE.setTimeout(function(){throw i})}function qp(){}function su(i){i()}var If=(function(i){ri(n,i);function n(r){var s=i.call(this)||this;return s.isStopped=!1,r?(s.destination=r,tg(r)&&r.add(s)):s.destination=rE,s}return n.create=function(r,s,o){return new Ol(r,s,o)},n.prototype.next=function(r){this.isStopped||this._next(r)},n.prototype.error=function(r){this.isStopped||(this.isStopped=!0,this._error(r))},n.prototype.complete=function(){this.isStopped||(this.isStopped=!0,this._complete())},n.prototype.unsubscribe=function(){this.closed||(this.isStopped=!0,i.prototype.unsubscribe.call(this),this.destination=null)},n.prototype._next=function(r){this.destination.next(r)},n.prototype._error=function(r){try{this.destination.error(r)}finally{this.unsubscribe()}},n.prototype._complete=function(){try{this.destination.complete()}finally{this.unsubscribe()}},n})(Eu),aE=(function(){function i(n){this.partialObserver=n}return i.prototype.next=function(n){var r=this.partialObserver;if(r.next)try{r.next(n)}catch(s){Ks(s)}},i.prototype.error=function(n){var r=this.partialObserver;if(r.error)try{r.error(n)}catch(s){Ks(s)}else Ks(n)},i.prototype.complete=function(){var n=this.partialObserver;if(n.complete)try{n.complete()}catch(r){Ks(r)}},i})(),Ol=(function(i){ri(n,i);function n(r,s,o){var f=i.call(this)||this,d;return Ye(r)||!r?d={next:r??void 0,error:s??void 0,complete:o??void 0}:d=r,f.destination=new aE(d),f}return n})(If);function Ks(i){ng(i)}function iE(i){throw i}var rE={closed:!0,next:qp,error:iE,complete:qp},$f=(function(){return typeof Symbol=="function"&&Symbol.observable||"@@observable"})();function Wf(i){return i}function lE(i){return i.length===0?Wf:i.length===1?i[0]:function(r){return i.reduce(function(s,o){return o(s)},r)}}var Fe=(function(){function i(n){n&&(this._subscribe=n)}return i.prototype.lift=function(n){var r=new i;return r.source=this,r.operator=n,r},i.prototype.subscribe=function(n,r,s){var o=this,f=uE(n)?n:new Ol(n,r,s);return su(function(){var d=o,y=d.operator,m=d.source;f.add(y?y.call(f,m):m?o._subscribe(f):o._trySubscribe(f))}),f},i.prototype._trySubscribe=function(n){try{return this._subscribe(n)}catch(r){n.error(r)}},i.prototype.forEach=function(n,r){var s=this;return r=Lp(r),new r(function(o,f){var d=new Ol({next:function(y){try{n(y)}catch(m){f(m),d.unsubscribe()}},error:f,complete:o});s.subscribe(d)})},i.prototype._subscribe=function(n){var r;return(r=this.source)===null||r===void 0?void 0:r.subscribe(n)},i.prototype[$f]=function(){return this},i.prototype.pipe=function(){for(var n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];return lE(n)(this)},i.prototype.toPromise=function(n){var r=this;return n=Lp(n),new n(function(s,o){var f;r.subscribe(function(d){return f=d},function(d){return o(d)},function(){return s(f)})})},i.create=function(n){return new i(n)},i})();function Lp(i){var n;return(n=i??tE.Promise)!==null&&n!==void 0?n:Promise}function sE(i){return i&&Ye(i.next)&&Ye(i.error)&&Ye(i.complete)}function uE(i){return i&&i instanceof If||sE(i)&&tg(i)}function oE(i){return Ye(i?.lift)}function fn(i){return function(n){if(oE(n))return n.lift(function(r){try{return i(r,this)}catch(s){this.error(s)}});throw new TypeError("Unable to lift unknown Observable type")}}function _n(i,n,r,s,o){return new cE(i,n,r,s,o)}var cE=(function(i){ri(n,i);function n(r,s,o,f,d,y){var m=i.call(this,r)||this;return m.onFinalize=d,m.shouldUnsubscribe=y,m._next=s?function(h){try{s(h)}catch(b){r.error(b)}}:i.prototype._next,m._error=f?function(h){try{f(h)}catch(b){r.error(b)}finally{this.unsubscribe()}}:i.prototype._error,m._complete=o?function(){try{o()}catch(h){r.error(h)}finally{this.unsubscribe()}}:i.prototype._complete,m}return n.prototype.unsubscribe=function(){var r;if(!this.shouldUnsubscribe||this.shouldUnsubscribe()){var s=this.closed;i.prototype.unsubscribe.call(this),!s&&((r=this.onFinalize)===null||r===void 0||r.call(this))}},n})(If),fE=Kf(function(i){return function(){i(this),this.name="ObjectUnsubscribedError",this.message="object unsubscribed"}}),fr=(function(i){ri(n,i);function n(){var r=i.call(this)||this;return r.closed=!1,r.currentObservers=null,r.observers=[],r.isStopped=!1,r.hasError=!1,r.thrownError=null,r}return n.prototype.lift=function(r){var s=new Hp(this,this);return s.operator=r,s},n.prototype._throwIfClosed=function(){if(this.closed)throw new fE},n.prototype.next=function(r){var s=this;su(function(){var o,f;if(s._throwIfClosed(),!s.isStopped){s.currentObservers||(s.currentObservers=Array.from(s.observers));try{for(var d=rr(s.currentObservers),y=d.next();!y.done;y=d.next()){var m=y.value;m.next(r)}}catch(h){o={error:h}}finally{try{y&&!y.done&&(f=d.return)&&f.call(d)}finally{if(o)throw o.error}}}})},n.prototype.error=function(r){var s=this;su(function(){if(s._throwIfClosed(),!s.isStopped){s.hasError=s.isStopped=!0,s.thrownError=r;for(var o=s.observers;o.length;)o.shift().error(r)}})},n.prototype.complete=function(){var r=this;su(function(){if(r._throwIfClosed(),!r.isStopped){r.isStopped=!0;for(var s=r.observers;s.length;)s.shift().complete()}})},n.prototype.unsubscribe=function(){this.isStopped=this.closed=!0,this.observers=this.currentObservers=null},Object.defineProperty(n.prototype,"observed",{get:function(){var r;return((r=this.observers)===null||r===void 0?void 0:r.length)>0},enumerable:!1,configurable:!0}),n.prototype._trySubscribe=function(r){return this._throwIfClosed(),i.prototype._trySubscribe.call(this,r)},n.prototype._subscribe=function(r){return this._throwIfClosed(),this._checkFinalizedStatuses(r),this._innerSubscribe(r)},n.prototype._innerSubscribe=function(r){var s=this,o=this,f=o.hasError,d=o.isStopped,y=o.observers;return f||d?eg:(this.currentObservers=null,y.push(r),new Eu(function(){s.currentObservers=null,Mf(y,r)}))},n.prototype._checkFinalizedStatuses=function(r){var s=this,o=s.hasError,f=s.thrownError,d=s.isStopped;o?r.error(f):d&&r.complete()},n.prototype.asObservable=function(){var r=new Fe;return r.source=this,r},n.create=function(r,s){return new Hp(r,s)},n})(Fe),Hp=(function(i){ri(n,i);function n(r,s){var o=i.call(this)||this;return o.destination=r,o.source=s,o}return n.prototype.next=function(r){var s,o;(o=(s=this.destination)===null||s===void 0?void 0:s.next)===null||o===void 0||o.call(s,r)},n.prototype.error=function(r){var s,o;(o=(s=this.destination)===null||s===void 0?void 0:s.error)===null||o===void 0||o.call(s,r)},n.prototype.complete=function(){var r,s;(s=(r=this.destination)===null||r===void 0?void 0:r.complete)===null||s===void 0||s.call(r)},n.prototype._subscribe=function(r){var s,o;return(o=(s=this.source)===null||s===void 0?void 0:s.subscribe(r))!==null&&o!==void 0?o:eg},n})(fr),dE=(function(i){ri(n,i);function n(r){var s=i.call(this)||this;return s._value=r,s}return Object.defineProperty(n.prototype,"value",{get:function(){return this.getValue()},enumerable:!1,configurable:!0}),n.prototype._subscribe=function(r){var s=i.prototype._subscribe.call(this,r);return!s.closed&&r.next(this._value),s},n.prototype.getValue=function(){var r=this,s=r.hasError,o=r.thrownError,f=r._value;if(s)throw o;return this._throwIfClosed(),f},n.prototype.next=function(r){i.prototype.next.call(this,this._value=r)},n})(fr),ag={now:function(){return(ag.delegate||Date).now()},delegate:void 0},hE=(function(i){ri(n,i);function n(r,s,o){r===void 0&&(r=1/0),s===void 0&&(s=1/0),o===void 0&&(o=ag);var f=i.call(this)||this;return f._bufferSize=r,f._windowTime=s,f._timestampProvider=o,f._buffer=[],f._infiniteTimeWindow=!0,f._infiniteTimeWindow=s===1/0,f._bufferSize=Math.max(1,r),f._windowTime=Math.max(1,s),f}return n.prototype.next=function(r){var s=this,o=s.isStopped,f=s._buffer,d=s._infiniteTimeWindow,y=s._timestampProvider,m=s._windowTime;o||(f.push(r),!d&&f.push(y.now()+m)),this._trimBuffer(),i.prototype.next.call(this,r)},n.prototype._subscribe=function(r){this._throwIfClosed(),this._trimBuffer();for(var s=this._innerSubscribe(r),o=this,f=o._infiniteTimeWindow,d=o._buffer,y=d.slice(),m=0;m<y.length&&!r.closed;m+=f?1:2)r.next(y[m]);return this._checkFinalizedStatuses(r),s},n.prototype._trimBuffer=function(){var r=this,s=r._bufferSize,o=r._timestampProvider,f=r._buffer,d=r._infiniteTimeWindow,y=(d?1:2)*s;if(s<1/0&&y<f.length&&f.splice(0,f.length-y),!d){for(var m=o.now(),h=0,b=1;b<f.length&&f[b]<=m;b+=2)h=b;h&&f.splice(0,h+1)}},n})(fr),mu=new Fe(function(i){return i.complete()});function mE(i){return i&&Ye(i.schedule)}function yE(i){return i[i.length-1]}function ig(i){return mE(yE(i))?i.pop():void 0}var rg=(function(i){return i&&typeof i.length=="number"&&typeof i!="function"});function lg(i){return Ye(i?.then)}function sg(i){return Ye(i[$f])}function ug(i){return Symbol.asyncIterator&&Ye(i?.[Symbol.asyncIterator])}function og(i){return new TypeError("You provided "+(i!==null&&typeof i=="object"?"an invalid object":"'"+i+"'")+" where a stream was expected. You can provide an Observable, Promise, ReadableStream, Array, AsyncIterable, or Iterable.")}function pE(){return typeof Symbol!="function"||!Symbol.iterator?"@@iterator":Symbol.iterator}var cg=pE();function fg(i){return Ye(i?.[cg])}function dg(i){return XS(this,arguments,function(){var r,s,o,f;return Xv(this,function(d){switch(d.label){case 0:r=i.getReader(),d.label=1;case 1:d.trys.push([1,,9,10]),d.label=2;case 2:return[4,Pi(r.read())];case 3:return s=d.sent(),o=s.value,f=s.done,f?[4,Pi(void 0)]:[3,5];case 4:return[2,d.sent()];case 5:return[4,Pi(o)];case 6:return[4,d.sent()];case 7:return d.sent(),[3,2];case 8:return[3,10];case 9:return r.releaseLock(),[7];case 10:return[2]}})})}function hg(i){return Ye(i?.getReader)}function Kn(i){if(i instanceof Fe)return i;if(i!=null){if(sg(i))return vE(i);if(rg(i))return gE(i);if(lg(i))return bE(i);if(ug(i))return mg(i);if(fg(i))return SE(i);if(hg(i))return EE(i)}throw og(i)}function vE(i){return new Fe(function(n){var r=i[$f]();if(Ye(r.subscribe))return r.subscribe(n);throw new TypeError("Provided object does not correctly implement Symbol.observable")})}function gE(i){return new Fe(function(n){for(var r=0;r<i.length&&!n.closed;r++)n.next(i[r]);n.complete()})}function bE(i){return new Fe(function(n){i.then(function(r){n.closed||(n.next(r),n.complete())},function(r){return n.error(r)}).then(null,ng)})}function SE(i){return new Fe(function(n){var r,s;try{for(var o=rr(i),f=o.next();!f.done;f=o.next()){var d=f.value;if(n.next(d),n.closed)return}}catch(y){r={error:y}}finally{try{f&&!f.done&&(s=o.return)&&s.call(o)}finally{if(r)throw r.error}}n.complete()})}function mg(i){return new Fe(function(n){TE(i,n).catch(function(r){return n.error(r)})})}function EE(i){return mg(dg(i))}function TE(i,n){var r,s,o,f;return GS(this,void 0,void 0,function(){var d,y;return Xv(this,function(m){switch(m.label){case 0:m.trys.push([0,5,6,11]),r=FS(i),m.label=1;case 1:return[4,r.next()];case 2:if(s=m.sent(),!!s.done)return[3,4];if(d=s.value,n.next(d),n.closed)return[2];m.label=3;case 3:return[3,1];case 4:return[3,11];case 5:return y=m.sent(),o={error:y},[3,11];case 6:return m.trys.push([6,,9,10]),s&&!s.done&&(f=r.return)?[4,f.call(r)]:[3,8];case 7:m.sent(),m.label=8;case 8:return[3,10];case 9:if(o)throw o.error;return[7];case 10:return[7];case 11:return n.complete(),[2]}})})}function ai(i,n,r,s,o){s===void 0&&(s=0),o===void 0&&(o=!1);var f=n.schedule(function(){r(),o?i.add(this.schedule(null,s)):this.unsubscribe()},s);if(i.add(f),!o)return f}function yg(i,n){return n===void 0&&(n=0),fn(function(r,s){r.subscribe(_n(s,function(o){return ai(s,i,function(){return s.next(o)},n)},function(){return ai(s,i,function(){return s.complete()},n)},function(o){return ai(s,i,function(){return s.error(o)},n)}))})}function pg(i,n){return n===void 0&&(n=0),fn(function(r,s){s.add(i.schedule(function(){return r.subscribe(s)},n))})}function OE(i,n){return Kn(i).pipe(pg(n),yg(n))}function _E(i,n){return Kn(i).pipe(pg(n),yg(n))}function wE(i,n){return new Fe(function(r){var s=0;return n.schedule(function(){s===i.length?r.complete():(r.next(i[s++]),r.closed||this.schedule())})})}function AE(i,n){return new Fe(function(r){var s;return ai(r,n,function(){s=i[cg](),ai(r,n,function(){var o,f,d;try{o=s.next(),f=o.value,d=o.done}catch(y){r.error(y);return}d?r.complete():r.next(f)},0,!0)}),function(){return Ye(s?.return)&&s.return()}})}function vg(i,n){if(!i)throw new Error("Iterable cannot be null");return new Fe(function(r){ai(r,n,function(){var s=i[Symbol.asyncIterator]();ai(r,n,function(){s.next().then(function(o){o.done?r.complete():r.next(o.value)})},0,!0)})})}function DE(i,n){return vg(dg(i),n)}function ME(i,n){if(i!=null){if(sg(i))return OE(i,n);if(rg(i))return wE(i,n);if(lg(i))return _E(i,n);if(ug(i))return vg(i,n);if(fg(i))return AE(i,n);if(hg(i))return DE(i,n)}throw og(i)}function Xn(i,n){return n?ME(i,n):Kn(i)}function Pa(){for(var i=[],n=0;n<arguments.length;n++)i[n]=arguments[n];var r=ig(i);return Xn(i,r)}function gg(i,n){var r=Ye(i)?i:function(){return i},s=function(o){return o.error(r())};return new Fe(s)}var Bp;(function(i){i.NEXT="N",i.ERROR="E",i.COMPLETE="C"})(Bp||(Bp={}));var $c=(function(){function i(n,r,s){this.kind=n,this.value=r,this.error=s,this.hasValue=n==="N"}return i.prototype.observe=function(n){return CE(this,n)},i.prototype.do=function(n,r,s){var o=this,f=o.kind,d=o.value,y=o.error;return f==="N"?n?.(d):f==="E"?r?.(y):s?.()},i.prototype.accept=function(n,r,s){var o;return Ye((o=n)===null||o===void 0?void 0:o.next)?this.observe(n):this.do(n,r,s)},i.prototype.toObservable=function(){var n=this,r=n.kind,s=n.value,o=n.error,f=r==="N"?Pa(s):r==="E"?gg(function(){return o}):r==="C"?mu:0;if(!f)throw new TypeError("Unexpected notification kind "+r);return f},i.createNext=function(n){return new i("N",n)},i.createError=function(n){return new i("E",void 0,n)},i.createComplete=function(){return i.completeNotification},i.completeNotification=new i("C"),i})();function CE(i,n){var r,s,o,f=i,d=f.kind,y=f.value,m=f.error;if(typeof d!="string")throw new TypeError('Invalid notification, missing "kind"');d==="N"?(r=n.next)===null||r===void 0||r.call(n,y):d==="E"?(s=n.error)===null||s===void 0||s.call(n,m):(o=n.complete)===null||o===void 0||o.call(n)}var xE=Kf(function(i){return function(){i(this),this.name="EmptyError",this.message="no elements in sequence"}});function RE(i,n){var r=typeof n=="object";return new Promise(function(s,o){var f=!1,d;i.subscribe({next:function(y){d=y,f=!0},error:o,complete:function(){f?s(d):r?s(n.defaultValue):o(new xE)}})})}function ti(i,n){return fn(function(r,s){var o=0;r.subscribe(_n(s,function(f){s.next(i.call(n,f,o++))}))})}function zE(i,n,r,s,o,f,d,y){var m=[],h=0,b=0,v=!1,E=function(){v&&!m.length&&!h&&n.complete()},S=function(N){return h<s?O(N):m.push(N)},O=function(N){h++;var M=!1;Kn(r(N,b++)).subscribe(_n(n,function(D){n.next(D)},function(){M=!0},void 0,function(){if(M)try{h--;for(var D=function(){var U=m.shift();d||O(U)};m.length&&h<s;)D();E()}catch(U){n.error(U)}}))};return i.subscribe(_n(n,S,function(){v=!0,E()})),function(){}}function ni(i,n,r){return r===void 0&&(r=1/0),Ye(n)?ni(function(s,o){return ti(function(f,d){return n(s,f,o,d)})(Kn(i(s,o)))},r):(typeof n=="number"&&(r=n),fn(function(s,o){return zE(s,o,i,r)}))}function NE(i){return ni(Wf,i)}function jE(){return NE(1)}function Wc(){for(var i=[],n=0;n<arguments.length;n++)i[n]=arguments[n];return jE()(Xn(i,ig(i)))}function UE(i,n){return fn(function(r,s){var o=0;r.subscribe(_n(s,function(f){return i.call(n,f,o++)&&s.next(f)}))})}function bl(i){return fn(function(n,r){var s=null,o=!1,f;s=n.subscribe(_n(r,void 0,void 0,function(d){f=Kn(i(d,bl(i)(n))),s?(s.unsubscribe(),s=null,f.subscribe(r)):o=!0})),o&&(s.unsubscribe(),s=null,f.subscribe(r))})}function kE(i){return fn(function(n,r){try{n.subscribe(r)}finally{r.add(i)}})}function qE(){return fn(function(i,n){i.subscribe(_n(n,function(r){n.next($c.createNext(r))},function(){n.next($c.createComplete()),n.complete()},function(r){n.next($c.createError(r)),n.complete()}))})}function yu(i){i===void 0&&(i={});var n=i.connector,r=n===void 0?function(){return new fr}:n,s=i.resetOnError,o=s===void 0?!0:s,f=i.resetOnComplete,d=f===void 0?!0:f,y=i.resetOnRefCountZero,m=y===void 0?!0:y;return function(h){var b,v,E,S=0,O=!1,N=!1,M=function(){v?.unsubscribe(),v=void 0},D=function(){M(),b=E=void 0,O=N=!1},U=function(){var Y=b;D(),Y?.unsubscribe()};return fn(function(Y,X){S++,!N&&!O&&M();var K=E=E??r();X.add(function(){S--,S===0&&!N&&!O&&(v=Pc(U,m))}),K.subscribe(X),!b&&S>0&&(b=new Ol({next:function(ee){return K.next(ee)},error:function(ee){N=!0,M(),v=Pc(D,o,ee),K.error(ee)},complete:function(){O=!0,M(),v=Pc(D,d),K.complete()}}),Kn(Y).subscribe(b))})(h)}}function Pc(i,n){for(var r=[],s=2;s<arguments.length;s++)r[s-2]=arguments[s];if(n===!0){i();return}if(n!==!1){var o=new Ol({next:function(){o.unsubscribe(),i()}});return Kn(n.apply(void 0,hu([],Tl(r)))).subscribe(o)}}function LE(i,n,r){var s,o,f,d,y=!1;return i&&typeof i=="object"?(s=i.bufferSize,d=s===void 0?1/0:s,o=i.windowTime,n=o===void 0?1/0:o,f=i.refCount,y=f===void 0?!1:f,r=i.scheduler):d=i??1/0,yu({connector:function(){return new hE(d,n,r)},resetOnError:!0,resetOnComplete:!1,resetOnRefCountZero:y})}function HE(i,n){return fn(function(r,s){var o=null,f=0,d=!1,y=function(){return d&&!o&&s.complete()};r.subscribe(_n(s,function(m){o?.unsubscribe();var h=0,b=f++;Kn(i(m,b)).subscribe(o=_n(s,function(v){return s.next(n?n(m,v,b,h++):v)},function(){o=null,y()}))},function(){d=!0,y()}))})}function pu(i,n,r){var s=Ye(i)||n||r?{next:i,error:n,complete:r}:i;return s?fn(function(o,f){var d;(d=s.subscribe)===null||d===void 0||d.call(s);var y=!0;o.subscribe(_n(f,function(m){var h;(h=s.next)===null||h===void 0||h.call(s,m),f.next(m)},function(){var m;y=!1,(m=s.complete)===null||m===void 0||m.call(s),f.complete()},function(m){var h;y=!1,(h=s.error)===null||h===void 0||h.call(s,m),f.error(m)},function(){var m,h;y&&((m=s.unsubscribe)===null||m===void 0||m.call(s)),(h=s.finalize)===null||h===void 0||h.call(s)}))}):Wf}function lr(i,n,r,s){if(r.kind===Te.INT||r.kind===Te.FLOAT)i[n.value]=Number(r.value);else if(r.kind===Te.BOOLEAN||r.kind===Te.STRING)i[n.value]=r.value;else if(r.kind===Te.OBJECT){const o={};r.fields.map(f=>lr(o,f.name,f.value,s)),i[n.value]=o}else if(r.kind===Te.VARIABLE){const o=(s||{})[r.name.value];i[n.value]=o}else if(r.kind===Te.LIST)i[n.value]=r.values.map(o=>{const f={};return lr(f,n,o,s),f[n.value]});else if(r.kind===Te.ENUM)i[n.value]=r.value;else if(r.kind===Te.NULL)i[n.value]=null;else throw tn(19,n.value,r.kind)}function Pf(i,n){if(i.arguments&&i.arguments.length){const r={};return i.arguments.forEach(({name:s,value:o})=>lr(r,s,o,n)),r}return null}const BE=Symbol.for("apollo.cacheSize"),Zn={..._f[BE]};function sr(i,n){return i.definitions.find(r=>r.kind==="OperationDefinition"&&!!r.name)?.name.value??n}const VE=()=>Object.create(null),{forEach:QE,slice:Vp}=Array.prototype,{hasOwnProperty:YE}=Object.prototype;class In{constructor(n=!0,r=VE){this.weakness=n,this.makeData=r}lookup(){return this.lookupArray(arguments)}lookupArray(n){let r=this;return QE.call(n,s=>r=r.getChildTrie(s)),YE.call(r,"data")?r.data:r.data=this.makeData(Vp.call(n))}peek(){return this.peekArray(arguments)}peekArray(n){let r=this;for(let s=0,o=n.length;r&&s<o;++s){const f=r.mapFor(n[s],!1);r=f&&f.get(n[s])}return r&&r.data}remove(){return this.removeArray(arguments)}removeArray(n){let r;if(n.length){const s=n[0],o=this.mapFor(s,!1),f=o&&o.get(s);f&&(r=f.removeArray(Vp.call(n,1)),!f.data&&!f.weak&&!(f.strong&&f.strong.size)&&o.delete(s))}else r=this.data,delete this.data;return r}getChildTrie(n){const r=this.mapFor(n,!0);let s=r.get(n);return s||r.set(n,s=new In(this.weakness,this.makeData)),s}mapFor(n,r){return this.weakness&&GE(n)?this.weak||(r?this.weak=new WeakMap:void 0):this.strong||(r?this.strong=new Map:void 0)}}function GE(i){switch(typeof i){case"object":if(i===null)break;case"function":return!0}return!1}function XE(){}class Cf{constructor(n=1/0,r=XE){this.max=n,this.dispose=r,this.map=new Map,this.newest=null,this.oldest=null}has(n){return this.map.has(n)}get(n){const r=this.getNode(n);return r&&r.value}get size(){return this.map.size}getNode(n){const r=this.map.get(n);if(r&&r!==this.newest){const{older:s,newer:o}=r;o&&(o.older=s),s&&(s.newer=o),r.older=this.newest,r.older.newer=r,r.newer=null,this.newest=r,r===this.oldest&&(this.oldest=o)}return r}set(n,r){let s=this.getNode(n);return s?s.value=r:(s={key:n,value:r,newer:null,older:this.newest},this.newest&&(this.newest.newer=s),this.newest=s,this.oldest=this.oldest||s,this.map.set(n,s),s.value)}clean(){for(;this.oldest&&this.map.size>this.max;)this.delete(this.oldest.key)}delete(n){const r=this.map.get(n);return r?(r===this.newest&&(this.newest=r.older),r===this.oldest&&(this.oldest=r.newer),r.newer&&(r.newer.older=r.older),r.older&&(r.older.newer=r.newer),this.map.delete(n),this.dispose(r.value,n),!0):!1}}function xf(){}const FE=xf,ZE=typeof WeakRef<"u"?WeakRef:function(i){return{deref:()=>i}},JE=typeof WeakMap<"u"?WeakMap:Map,KE=typeof FinalizationRegistry<"u"?FinalizationRegistry:function(){return{register:xf,unregister:xf}},IE=10024;class vu{constructor(n=1/0,r=FE){this.max=n,this.dispose=r,this.map=new JE,this.newest=null,this.oldest=null,this.unfinalizedNodes=new Set,this.finalizationScheduled=!1,this.size=0,this.finalize=()=>{const s=this.unfinalizedNodes.values();for(let o=0;o<IE;o++){const f=s.next().value;if(!f)break;this.unfinalizedNodes.delete(f);const d=f.key;delete f.key,f.keyRef=new ZE(d),this.registry.register(d,f,f)}this.unfinalizedNodes.size>0?queueMicrotask(this.finalize):this.finalizationScheduled=!1},this.registry=new KE(this.deleteNode.bind(this))}has(n){return this.map.has(n)}get(n){const r=this.getNode(n);return r&&r.value}getNode(n){const r=this.map.get(n);if(r&&r!==this.newest){const{older:s,newer:o}=r;o&&(o.older=s),s&&(s.newer=o),r.older=this.newest,r.older.newer=r,r.newer=null,this.newest=r,r===this.oldest&&(this.oldest=o)}return r}set(n,r){let s=this.getNode(n);return s?s.value=r:(s={key:n,value:r,newer:null,older:this.newest},this.newest&&(this.newest.newer=s),this.newest=s,this.oldest=this.oldest||s,this.scheduleFinalization(s),this.map.set(n,s),this.size++,s.value)}clean(){for(;this.oldest&&this.size>this.max;)this.deleteNode(this.oldest)}deleteNode(n){n===this.newest&&(this.newest=n.older),n===this.oldest&&(this.oldest=n.newer),n.newer&&(n.newer.older=n.older),n.older&&(n.older.newer=n.newer),this.size--;const r=n.key||n.keyRef&&n.keyRef.deref();this.dispose(n.value,r),n.keyRef?this.registry.unregister(n):this.unfinalizedNodes.delete(n),r&&this.map.delete(r)}delete(n){const r=this.map.get(n);return r?(this.deleteNode(r),!0):!1}scheduleFinalization(n){this.unfinalizedNodes.add(n),this.finalizationScheduled||(this.finalizationScheduled=!0,queueMicrotask(this.finalize))}}const ef=new WeakSet;function bg(i){i.size<=(i.max||-1)||ef.has(i)||(ef.add(i),setTimeout(()=>{i.clean(),ef.delete(i)},100))}const ed=function(i,n){const r=new vu(i,n);return r.set=function(s,o){const f=vu.prototype.set.call(this,s,o);return bg(this),f},r},$E=function(i,n){const r=new Cf(i,n);return r.set=function(s,o){const f=Cf.prototype.set.call(this,s,o);return bg(this),f},r};function WE(i,{max:n}){const r=new In(!0),s=new ed(n);return(...o)=>{const f=r.lookupArray(o),d=s.get(f);if(d){if(d.error)throw d.error;return d.result}const y=s.set(f,{});try{return y.result=i(...o)}catch(m){throw y.error=m,m}}}const Aa=WE((i,n)=>{de(i&&i.kind==="Document",1);const r=i.definitions.filter(s=>s.kind==="OperationDefinition");n&&de(r.length==1&&r[0].operation===n,4,n,n,r[0].operation),On(i,{Field(s,o,f,d){if(s.alias&&(s.alias.value==="__typename"||s.alias.value.startsWith("__ac_"))&&s.alias.value!==s.name.value){let y=i,m=[];for(const h of d)y=y[h],y.kind===Te.FIELD&&m.push(y.alias?.value||y.name.value);throw m.splice(-1,1,s.name.value),tn(5,s.alias.value,m.join("."),r[0].operation,sr(i,"(anonymous)"))}}})},{max:Zn.checkDocument||2e3});function en(...i){const n={};return i.forEach(r=>{r&&Object.keys(r).forEach(s=>{const o=r[s];o!==void 0&&(n[s]=o)})}),n}function Ml(i=[]){const n={};return i.forEach(r=>{n[r.name.value]=r}),n}function jt(i){return i!==null&&typeof i=="object"}const{hasOwnProperty:PE}=Object.prototype,eT=function(i,n,r){return this.merge(i[r],n[r])};class ur{reconciler;constructor(n=eT){this.reconciler=n}merge(n,r,...s){return jt(r)&&jt(n)?(Object.keys(r).forEach(o=>{if(PE.call(n,o)){const f=n[o];if(r[o]!==f){const d=this.reconciler(n,r,o,...s);d!==f&&(n=this.shallowCopyForMerge(n),n[o]=d)}}else n=this.shallowCopyForMerge(n),n[o]=r[o]}),n):r}isObject=jt;pastCopies=new Set;shallowCopyForMerge(n){return jt(n)&&(this.pastCopies.has(n)||(Array.isArray(n)?n=n.slice(0):n={__proto__:Object.getPrototypeOf(n),...n},this.pastCopies.add(n))),n}}function td(i){const n={},r=i&&i.variableDefinitions;return r&&r.length&&r.forEach(s=>{s.defaultValue&&lr(n,s.variable.name,s.defaultValue)}),n}function Tu(i,n){switch(i.kind){case"InlineFragment":return i;case"FragmentSpread":{const r=i.name.value;if(typeof n=="function")return n(r);const s=n&&n[r];return de(s,9,r),s||null}default:return null}}function tT(i,n){let r=n;const s=[];return i.definitions.forEach(f=>{if(f.kind==="OperationDefinition")throw tn(10,f.operation,f.name?` named '${f.name.value}'`:"");f.kind==="FragmentDefinition"&&s.push(f)}),typeof r>"u"&&(de(s.length===1,11,s.length),r=s[0].name.value),{...i,definitions:[{kind:"OperationDefinition",operation:"query",selectionSet:{kind:"SelectionSet",selections:[{kind:"FragmentSpread",name:{kind:"Name",value:r}}]}},...i.definitions]}}function nT(i){de(i.kind==="Document",6),de(i.definitions.length<=1,7);const n=i.definitions[0];return de(n.kind==="FragmentDefinition",8),n}function Cl(i){return i.definitions.filter(n=>n.kind==="FragmentDefinition")}function Sg(i){Aa(i);let n;for(let r of i.definitions){if(r.kind==="OperationDefinition")return r;r.kind==="FragmentDefinition"&&!n&&(n=r)}if(n)return n;throw tn(12)}function Jn(i){return Aa(i),i.definitions.filter(n=>n.kind==="OperationDefinition")[0]}function aT(i){const n=Jn(i);return de(n&&n.operation==="query",13),n}const Da=Object.assign(function(n){return JSON.stringify(n,iT)},{reset(){pl=new $E(Zn.canonicalStringify||1e3)}});let pl;Da.reset();function iT(i,n){if(n&&typeof n=="object"){const r=Object.getPrototypeOf(n);if(r===Object.prototype||r===null){const s=Object.keys(n);if(s.every(rT))return n;const o=JSON.stringify(s);let f=pl.get(o);if(!f){s.sort();const y=JSON.stringify(s);f=pl.get(y)||s,pl.set(o,f),pl.set(y,f)}const d=Object.create(r);return f.forEach(y=>{d[y]=n[y]}),d}}return n}function rT(i,n,r){return n===0||r[n-1]<=i}const lT=["connection","include","skip","client","rest","export","nonreactive"];let cl=Da;const Eg=Object.assign(function(i,n,r){if(n&&r&&r.connection&&r.connection.key){if(r.connection.filter&&r.connection.filter.length>0){const o=r.connection.filter?r.connection.filter:[];o.sort();const f={};o.forEach(y=>{f[y]=n[y]});const d=cl(f);if(d!=="{}")return`${r.connection.key}(${d})`}return r.connection.key}let s=i;if(n){const o=cl(n);o!=="{}"&&(s+=`(${o})`)}return r&&Object.keys(r).forEach(o=>{lT.indexOf(o)===-1&&(r[o]&&Object.keys(r[o]).length?s+=`@${o}(${cl(r[o])})`:s+=`@${o}`)}),s},{setStringify(i){const n=cl;return cl=i,n}});function Ii(i){return!!i.errors?.length}function vl(i,n,r){const s=new Set(i),o=s.size;return On(n,{Directive(f){if(s.delete(f.name.value)&&(!r||!s.size))return Jf}}),r?!s.size:s.size<o}function sT(i){let n=!1;return On(i,{Directive:{enter(r){if(r.name.value==="client"&&r.arguments&&(n=r.arguments.some(s=>s.name.value==="always"&&s.value.kind==="BooleanValue"&&s.value.value===!0),n))return Jf}}}),n}const Pe=Array.isArray;function uT(i){return jt(i)&&i.kind==="Document"&&Array.isArray(i.definitions)}function xl(i){return i.kind==="Field"}function nd(i){return Array.isArray(i)&&i.length>0}function er(i){return{__ref:String(i)}}function Z_(i){return i}function oT(i){let n=i[0]||{};const r=i.length;if(r>1){const s=new ur;for(let o=1;o<r;++o)n=s.merge(n,i[o])}return n}function tf(i,n){return en(i,n,n.variables&&{variables:en({...i&&i.variables,...n.variables})})}function cT(i){return i.catch(()=>{}),i}function fT(i,n){Aa(n);const r=Qp(""),s=Qp(""),o=M=>{for(let D=0,U;D<M.length&&(U=M[D]);++D)if(!Pe(U)){if(U.kind===Te.OPERATION_DEFINITION)return r(U.name&&U.name.value);if(U.kind===Te.FRAGMENT_DEFINITION)return s(U.name.value)}return de.error(14),null};let f=0;for(let M=n.definitions.length-1;M>=0;--M)n.definitions[M].kind===Te.OPERATION_DEFINITION&&++f;const d=dT(i),y=M=>nd(M)&&M.map(d).some(D=>D&&D.remove),m=new Map;let h=!1;const b={enter(M){if(y(M.directives))return h=!0,null}},v=On(n,{Field:b,InlineFragment:b,VariableDefinition:{enter(){return!1}},Variable:{enter(M,D,U,Y,X){const K=o(X);K&&K.variables.add(M.name.value)}},FragmentSpread:{enter(M,D,U,Y,X){if(y(M.directives))return h=!0,null;const K=o(X);K&&K.fragmentSpreads.add(M.name.value)}},FragmentDefinition:{enter(M,D,U,Y){m.set(JSON.stringify(Y),M)},leave(M,D,U,Y){const X=m.get(JSON.stringify(Y));if(M===X)return M;if(f>0&&M.selectionSet.selections.every(K=>K.kind===Te.FIELD&&K.name.value==="__typename"))return s(M.name.value).removed=!0,h=!0,null}},Directive:{leave(M){if(d(M))return h=!0,null}}});if(!h)return n;const E=M=>(M.transitiveVars||(M.transitiveVars=new Set(M.variables),M.removed||M.fragmentSpreads.forEach(D=>{E(s(D)).transitiveVars.forEach(U=>{M.transitiveVars.add(U)})})),M),S=new Set;v.definitions.forEach(M=>{M.kind===Te.OPERATION_DEFINITION?E(r(M.name&&M.name.value)).fragmentSpreads.forEach(D=>{S.add(D)}):M.kind===Te.FRAGMENT_DEFINITION&&f===0&&!s(M.name.value).removed&&S.add(M.name.value)}),S.forEach(M=>{E(s(M)).fragmentSpreads.forEach(D=>{S.add(D)})});const O=M=>!!(!S.has(M)||s(M).removed),N={enter(M){if(O(M.name.value))return null}};return hT(On(v,{FragmentSpread:N,FragmentDefinition:N,OperationDefinition:{leave(M){if(M.variableDefinitions){const D=E(r(M.name&&M.name.value)).transitiveVars;if(D.size<M.variableDefinitions.length)return{...M,variableDefinitions:M.variableDefinitions.filter(U=>D.has(U.variable.name.value))}}}}}))}function Qp(i){const n=new Map;return function(s=i){let o=n.get(s);return o||n.set(s,o={variables:new Set,fragmentSpreads:new Set}),o}}function dT(i){const n=new Map,r=new Map;return i.forEach(s=>{s&&(s.name?n.set(s.name,s):s.test&&r.set(s.test,s))}),s=>{let o=n.get(s.name.value);return!o&&r.size&&r.forEach((f,d)=>{d(s)&&(o=f)}),o}}function Tg(i,n){return!i||i.selectionSet.selections.every(r=>r.kind===Te.FRAGMENT_SPREAD&&Tg(n[r.name.value],n))}function hT(i){return Tg(Jn(i)||nT(i),Ml(Cl(i)))?null:i}function mT(i){return On(i,{FragmentSpread(n){if(!n.directives?.some(({name:r})=>r.value==="unmask"))return null}})}function dr(i){return i.alias?i.alias.value:i.name.value}function Ou({directives:i},n){return!i||!i.length?!0:pT(i).every(({directive:r,ifArgument:s})=>{let o=!1;return s.value.kind==="Variable"?(o=n&&n[s.value.name.value],de(o!==void 0,15,r.name.value)):o=s.value.value,r.name.value==="skip"?!o:o})}function yT({name:{value:i}}){return i==="skip"||i==="include"}function pT(i){const n=[];return i&&i.length&&i.forEach(r=>{if(!yT(r))return;const s=r.arguments,o=r.name.value;de(s&&s.length===1,16,o);const f=s[0];de(f.name&&f.name.value==="if",17,o);const d=f.value;de(d&&(d.kind==="Variable"||d.kind==="BooleanValue"),18,o),n.push({directive:r,ifArgument:f})}),n}function vT(i,n){let r=null;i.directives&&(r={},i.directives.forEach(o=>{r[o.name.value]={},o.arguments&&o.arguments.forEach(({name:f,value:d})=>lr(r[o.name.value],f,d,n))}));let s=null;return i.arguments&&i.arguments.length&&(s={},i.arguments.forEach(({name:o,value:f})=>lr(s,o,f,n))),Eg(i.name.value,s,r)}function uu(i){const n={data:i.data};return i.error&&(n.error=i.error),n}function Rf(i,n=()=>{}){return r=>new Fe(s=>{let o=n();return r.subscribe({next(f){let d;try{d=i(f,o)}catch(y){s.error(y)}d!==void 0&&s.next(d)},error(f){s.error(f)},complete(){s.complete()}})})}function Og(i,{data:n,...r},{data:s,...o},f){return $e(r,o)&&ou(Sg(i).selectionSet,n,s,{fragmentMap:Ml(Cl(i)),variables:f})}function ou(i,n,r,s){if(n===r)return!0;const o=new Set;return i.selections.every(f=>{if(o.has(f)||(o.add(f),!Ou(f,s.variables))||Yp(f))return!0;if(xl(f)){const d=dr(f),y=n&&n[d],m=r&&r[d],h=f.selectionSet;if(!h)return $e(y,m);const b=Array.isArray(y),v=Array.isArray(m);if(b!==v)return!1;if(b&&v){const E=y.length;if(m.length!==E)return!1;for(let S=0;S<E;++S)if(!ou(h,y[S],m[S],s))return!1;return!0}return ou(h,y,m,s)}else{const d=Tu(f,s.fragmentMap);if(d)return Yp(d)?!0:ou(d.selectionSet,n,r,s)}})}function Yp(i){return!!i.directives&&i.directives.some(gT)}function gT(i){return i.name.value==="nonreactive"}const bT=Symbol.for("apollo.observableQuery.variablesUnknown");class ST{isIncrementalResult(n){return!1}prepareRequest(n){return de(!vl(["defer"],n.query),64),n}extractErrors(){}startRequest=void 0}function ET(i,{client:n}){const r={query:i.query,variables:i.variables||{},extensions:i.extensions||{},operationName:sr(i.query),operationType:Jn(i.query).operation};let s={...i.context};const o=d=>{typeof d=="function"?s={...s,...d(f())}:s={...s,...d}},f=()=>Object.freeze({...s});return Object.defineProperty(r,"setContext",{enumerable:!1,value:o}),Object.defineProperty(r,"getContext",{enumerable:!1,value:f}),Object.defineProperty(r,"client",{enumerable:!1,value:n}),r}function TT(i,n){const r={...i},s=new Set(Object.keys(i));return On(n,{Variable(o,f,d){d&&d.kind!=="VariableDefinition"&&s.delete(o.name.value)}}),s.forEach(o=>{delete r[o]}),r}class gt{static empty(){return new gt(()=>mu)}static from(n){if(n.length===0)return gt.empty();const[r,...s]=n;return r.concat(...s)}static split(n,r,s=new gt((o,f)=>f(o))){const o=new gt((f,d)=>n(f)?r.request(f,d):s.request(f,d));return Object.assign(o,{left:r,right:s})}static execute(n,r,s){return n.request(ET(r,s),()=>mu)}static concat(...n){return gt.from(n)}constructor(n){n&&(this.request=n)}split(n,r,s){return this.concat(gt.split(n,r,s))}concat(...n){return n.length===0?this:n.reduce(this.combine.bind(this),this)}combine(n,r){const s=new gt((o,f)=>n.request(o,d=>r.request(d,f)));return Object.assign(s,{left:n,right:r})}request(n,r){throw tn(63)}left;right}const zf=gt.execute;let ft=null;const Gp={};let OT=1;const _T=()=>class{constructor(){this.id=["slot",OT++,Date.now(),Math.random().toString(36).slice(2)].join(":")}hasValue(){for(let n=ft;n;n=n.parent)if(this.id in n.slots){const r=n.slots[this.id];if(r===Gp)break;return n!==ft&&(ft.slots[this.id]=r),!0}return ft&&(ft.slots[this.id]=Gp),!1}getValue(){if(this.hasValue())return ft.slots[this.id]}withValue(n,r,s,o){const f={__proto__:null,[this.id]:n},d=ft;ft={parent:d,slots:f};try{return r.apply(o,s)}finally{ft=d}}static bind(n){const r=ft;return function(){const s=ft;try{return ft=r,n.apply(this,arguments)}finally{ft=s}}}static noContext(n,r,s){if(ft){const o=ft;try{return ft=null,n.apply(s,r)}finally{ft=o}}else return n.apply(s,r)}};function Xp(i){try{return i()}catch{}}const nf="@wry/context:Slot",wT=Xp(()=>globalThis)||Xp(()=>global)||Object.create(null),Fp=wT,_u=Fp[nf]||Array[nf]||(function(i){try{Object.defineProperty(Fp,nf,{value:i,enumerable:!1,writable:!1,configurable:!0})}finally{return i}})(_T()),{bind:K_,noContext:I_}=_u,wu=new _u,{hasOwnProperty:AT}=Object.prototype,ad=Array.from||function(i){const n=[];return i.forEach(r=>n.push(r)),n};function id(i){const{unsubscribe:n}=i;typeof n=="function"&&(i.unsubscribe=void 0,n())}const _l=[],DT=100;function or(i,n){if(!i)throw new Error(n||"assertion failure")}function _g(i,n){const r=i.length;return r>0&&r===n.length&&i[r-1]===n[r-1]}function wg(i){switch(i.length){case 0:throw new Error("unknown value");case 1:return i[0];case 2:throw i[1]}}function Ag(i){return i.slice(0)}class Au{constructor(n){this.fn=n,this.parents=new Set,this.childValues=new Map,this.dirtyChildren=null,this.dirty=!0,this.recomputing=!1,this.value=[],this.deps=null,++Au.count}peek(){if(this.value.length===1&&!Ma(this))return Zp(this),this.value[0]}recompute(n){return or(!this.recomputing,"already recomputing"),Zp(this),Ma(this)?MT(this,n):wg(this.value)}setDirty(){this.dirty||(this.dirty=!0,Dg(this),id(this))}dispose(){this.setDirty(),zg(this),rd(this,(n,r)=>{n.setDirty(),Ng(n,this)})}forget(){this.dispose()}dependOn(n){n.add(this),this.deps||(this.deps=_l.pop()||new Set),this.deps.add(n)}forgetDeps(){this.deps&&(ad(this.deps).forEach(n=>n.delete(this)),this.deps.clear(),_l.push(this.deps),this.deps=null)}}Au.count=0;function Zp(i){const n=wu.getValue();if(n)return i.parents.add(n),n.childValues.has(i)||n.childValues.set(i,[]),Ma(i)?Cg(n,i):xg(n,i),n}function MT(i,n){return zg(i),wu.withValue(i,CT,[i,n]),RT(i,n)&&xT(i),wg(i.value)}function CT(i,n){i.recomputing=!0;const{normalizeResult:r}=i;let s;r&&i.value.length===1&&(s=Ag(i.value)),i.value.length=0;try{if(i.value[0]=i.fn.apply(null,n),r&&s&&!_g(s,i.value))try{i.value[0]=r(i.value[0],s[0])}catch{}}catch(o){i.value[1]=o}i.recomputing=!1}function Ma(i){return i.dirty||!!(i.dirtyChildren&&i.dirtyChildren.size)}function xT(i){i.dirty=!1,!Ma(i)&&Mg(i)}function Dg(i){rd(i,Cg)}function Mg(i){rd(i,xg)}function rd(i,n){const r=i.parents.size;if(r){const s=ad(i.parents);for(let o=0;o<r;++o)n(s[o],i)}}function Cg(i,n){or(i.childValues.has(n)),or(Ma(n));const r=!Ma(i);if(!i.dirtyChildren)i.dirtyChildren=_l.pop()||new Set;else if(i.dirtyChildren.has(n))return;i.dirtyChildren.add(n),r&&Dg(i)}function xg(i,n){or(i.childValues.has(n)),or(!Ma(n));const r=i.childValues.get(n);r.length===0?i.childValues.set(n,Ag(n.value)):_g(r,n.value)||i.setDirty(),Rg(i,n),!Ma(i)&&Mg(i)}function Rg(i,n){const r=i.dirtyChildren;r&&(r.delete(n),r.size===0&&(_l.length<DT&&_l.push(r),i.dirtyChildren=null))}function zg(i){i.childValues.size>0&&i.childValues.forEach((n,r)=>{Ng(i,r)}),i.forgetDeps(),or(i.dirtyChildren===null)}function Ng(i,n){n.parents.delete(i),i.childValues.delete(n),Rg(i,n)}function RT(i,n){if(typeof i.subscribe=="function")try{id(i),i.unsubscribe=i.subscribe.apply(null,n)}catch{return i.setDirty(),!1}return!0}const zT={setDirty:!0,dispose:!0,forget:!0};function jg(i){const n=new Map;function r(s){const o=wu.getValue();if(o){let f=n.get(s);f||n.set(s,f=new Set),o.dependOn(f)}}return r.dirty=function(o,f){const d=n.get(o);if(d){const y=f&&AT.call(zT,f)?f:"setDirty";ad(d).forEach(m=>m[y]()),n.delete(o),id(d)}},r}let Jp;function NT(...i){return(Jp||(Jp=new In(typeof WeakMap=="function"))).lookupArray(i)}const af=new Set;function wl(i,{max:n=Math.pow(2,16),keyArgs:r,makeCacheKey:s=NT,normalizeResult:o,subscribe:f,cache:d=Cf}=Object.create(null)){const y=typeof d=="function"?new d(n,E=>E.dispose()):d,m=function(){const E=s.apply(null,r?r.apply(null,arguments):arguments);if(E===void 0)return i.apply(null,arguments);let S=y.get(E);S||(y.set(E,S=new Au(i)),S.normalizeResult=o,S.subscribe=f,S.forget=()=>y.delete(E));const O=S.recompute(Array.prototype.slice.call(arguments));return y.set(E,S),af.add(y),wu.hasValue()||(af.forEach(N=>N.clean()),af.clear()),O};Object.defineProperty(m,"size",{get:()=>y.size,configurable:!1,enumerable:!1}),Object.freeze(m.options={max:n,keyArgs:r,makeCacheKey:s,normalizeResult:o,subscribe:f,cache:y});function h(E){const S=E&&y.get(E);S&&S.setDirty()}m.dirtyKey=h,m.dirty=function(){h(s.apply(null,arguments))};function b(E){const S=E&&y.get(E);if(S)return S.peek()}m.peekKey=b,m.peek=function(){return b(s.apply(null,arguments))};function v(E){return E?y.delete(E):!1}return m.forgetKey=v,m.forget=function(){return v(s.apply(null,arguments))},m.makeCacheKey=s,m.getKey=r?function(){return s.apply(null,r.apply(null,arguments))}:s,Object.freeze(m)}function jT(i){return i}class Fn{transform;cached;resultCache=new WeakSet;getCacheKey(n){return[n]}static identity(){return new Fn(jT,{cache:!1})}static split(n,r,s=Fn.identity()){return Object.assign(new Fn(o=>(n(o)?r:s).transformDocument(o),{cache:!1}),{left:r,right:s})}constructor(n,r={}){this.transform=n,r.getCacheKey&&(this.getCacheKey=r.getCacheKey),this.cached=r.cache!==!1,this.resetCache()}resetCache(){if(this.cached){const n=new In;this.performWork=wl(Fn.prototype.performWork.bind(this),{makeCacheKey:r=>{const s=this.getCacheKey(r);if(s)return de(Array.isArray(s),20),n.lookupArray(s)},max:Zn["documentTransform.cache"],cache:vu})}}performWork(n){return Aa(n),this.transform(n)}transformDocument(n){if(this.resultCache.has(n))return n;const r=this.performWork(n);return this.resultCache.add(r),r}concat(n){return Object.assign(new Fn(r=>n.transformDocument(this.transformDocument(r)),{cache:!1}),{left:this,right:n})}left;right}let rf;const tr=Object.assign(i=>{let n=rf.get(i);return n||(n=W1(i),rf.set(i,n)),n},{reset(){rf=new ed(Zn.print||2e3)}});tr.reset();function ke(i){return!!(i&&typeof i=="object"&&typeof i.__ref=="string")}const Kp={kind:Te.FIELD,name:{kind:Te.NAME,value:"__typename"}},Ug=Object.assign(function(i){return On(i,{SelectionSet:{enter(n,r,s){if(s&&s.kind===Te.OPERATION_DEFINITION)return;const{selections:o}=n;if(!o||o.some(y=>y.kind===Te.FIELD&&(y.name.value==="__typename"||y.name.value.lastIndexOf("__",0)===0)))return;const d=s;if(!(d.kind===Te.FIELD&&d.directives&&d.directives.some(y=>y.name.value==="export")))return{...n,selections:[...o,Kp]}}}})},{added(i){return i===Kp}});function kg(i,n){return Jn(i)?.operation===n}function UT(i){return kg(i,"mutation")}function kT(i){return kg(i,"subscription")}function qT(i){return i===7||i===8}function Nf(i){return!qT(i)}class LT{assumeImmutableResults=!1;lookupFragment(n){return null}batch(n){const r=typeof n.optimistic=="string"?n.optimistic:n.optimistic===!1?null:void 0;let s;return this.performTransaction(()=>s=n.update(this),r),s}recordOptimisticTransaction(n,r){this.performTransaction(n,r)}transformDocument(n){return n}transformForLink(n){return n}identify(n){}gc(){return[]}modify(n){return!1}readQuery(n,r=!!n.optimistic){return this.read({...n,rootId:n.id||"ROOT_QUERY",optimistic:r})}watchFragment(n){const{fragment:r,fragmentName:s,from:o,optimistic:f=!0,...d}=n,y=this.getFragmentDoc(r,s),m=typeof o>"u"||typeof o=="string"?o:this.identify(o),h={...d,returnPartialData:!0,id:m,query:y,optimistic:f};let b;return new Fe(v=>this.watch({...h,immediate:!0,callback:E=>{let S=E.result;if(S===null&&(S={}),b&&Og(y,{data:b.result},{data:S},n.variables))return;const O={data:S,dataState:E.complete?"complete":"partial",complete:!!E.complete};E.missing&&(O.missing=E.missing.missing),b={...E,result:S},v.next(O)}}))}getFragmentDoc=wl(tT,{max:Zn["cache.fragmentQueryDocuments"]||1e3,cache:vu});readFragment(n,r=!!n.optimistic){return this.read({...n,query:this.getFragmentDoc(n.fragment,n.fragmentName),rootId:n.id,optimistic:r})}writeQuery({id:n,data:r,...s}){return this.write(Object.assign(s,{dataId:n||"ROOT_QUERY",result:r}))}writeFragment({id:n,data:r,fragment:s,fragmentName:o,...f}){return this.write(Object.assign(f,{query:this.getFragmentDoc(s,o),dataId:n,result:r}))}updateQuery(n,r){return this.batch({update(s){const o=s.readQuery(n),f=r(o);return f==null?o:(s.writeQuery({...n,data:f}),f)}})}updateFragment(n,r){return this.batch({update(s){const o=s.readFragment(n),f=r(o);return f==null?o:(s.writeFragment({...n,data:f}),f)}})}}class ld extends Error{message;path;query;variables;constructor(n,r,s,o){if(super(n),this.message=n,this.path=r,this.query=s,this.variables=o,this.name="MissingFieldError",Array.isArray(this.path)){this.missing=this.message;for(let f=this.path.length-1;f>=0;--f)this.missing={[this.path[f]]:this.missing}}else this.missing=this.path;this.__proto__=ld.prototype}missing}const{hasOwnProperty:it}=Object.prototype;function qg({__typename:i,id:n,_id:r},s){if(typeof i=="string"&&(s&&(s.keyObject=n!=null?{id:n}:r!=null?{_id:r}:void 0),n==null&&r!=null&&(n=r),n!=null))return`${i}:${typeof n=="number"||typeof n=="string"?n:JSON.stringify(n)}`}const HT={dataIdFromObject:qg,resultCaching:!0};function BT(i){return en(HT,i)}const Lg=/^[_a-z][_0-9a-z]*/i;function cr(i){const n=i.match(Lg);return n?n[0]:i}function jf(i,n,r){return jt(n)?Pe(n)?n.every(s=>jf(i,s,r)):i.selections.every(s=>{if(xl(s)&&Ou(s,r)){const o=dr(s);return it.call(n,o)&&(!s.selectionSet||jf(s.selectionSet,n[o],r))}return!0}):!1}function $i(i){return jt(i)&&!ke(i)&&!Pe(i)}function VT(){return new ur}function Hg(i,n){const r=Ml(Cl(i));return{fragmentMap:r,lookupFragment(s){let o=r[s];return!o&&n&&(o=n.lookup(s)),o||null}}}const cu={},lf=()=>cu,Ip={};class Du{policies;group;data={};constructor(n,r){this.policies=n,this.group=r}toObject(){return{...this.data}}has(n){return this.lookup(n,!0)!==void 0}get(n,r){if(this.group.depend(n,r),it.call(this.data,n)){const s=this.data[n];if(s&&it.call(s,r))return s[r]}if(r==="__typename"&&it.call(this.policies.rootTypenamesById,n))return this.policies.rootTypenamesById[n];if(this instanceof En)return this.parent.get(n,r)}lookup(n,r){if(r&&this.group.depend(n,"__exists"),it.call(this.data,n))return this.data[n];if(this instanceof En)return this.parent.lookup(n,r);if(this.policies.rootTypenamesById[n])return{}}merge(n,r){let s;ke(n)&&(n=n.__ref),ke(r)&&(r=r.__ref);const o=typeof n=="string"?this.lookup(s=n):n,f=typeof r=="string"?this.lookup(s=r):r;if(!f)return;de(typeof s=="string",96);const d=new ur(GT).merge(o,f);if(this.data[s]=d,d!==o&&(delete this.refs[s],this.group.caching)){const y={};o||(y.__exists=1),Object.keys(f).forEach(m=>{if(!o||o[m]!==d[m]){y[m]=1;const h=cr(m);h!==m&&!this.policies.hasKeyArgs(d.__typename,h)&&(y[h]=1),d[m]===void 0&&!(this instanceof En)&&delete d[m]}}),y.__typename&&!(o&&o.__typename)&&this.policies.rootTypenamesById[s]===d.__typename&&delete y.__typename,Object.keys(y).forEach(m=>this.group.dirty(s,m))}}modify(n,r,s){const o=this.lookup(n);if(o){const f={};let d=!1,y=!0;const m={DELETE:cu,INVALIDATE:Ip,isReference:ke,toReference:this.toReference,canRead:this.canRead,readField:(h,b)=>this.policies.readField(typeof h=="string"?{fieldName:h,from:b||er(n)}:h,{store:this})};if(Object.keys(o).forEach(h=>{const b=cr(h);let v=o[h];if(v===void 0)return;const E=typeof r=="function"?r:r[h]||(s?void 0:r[b]);if(E){let S=E===lf?cu:E(v,{...m,fieldName:b,storeFieldName:h,storage:this.getStorage(n,h)});S===Ip?this.group.dirty(n,h):(S===cu&&(S=void 0),S!==v&&(f[h]=S,d=!0,v=S))}v!==void 0&&(y=!1)}),d)return this.merge(n,f),y&&(this instanceof En?this.data[n]=void 0:delete this.data[n],this.group.dirty(n,"__exists")),!0}return!1}delete(n,r,s){const o=this.lookup(n);if(o){const f=this.getFieldValue(o,"__typename"),d=r&&s?this.policies.getStoreFieldName({typename:f,fieldName:r,args:s}):r;return this.modify(n,d?{[d]:lf}:lf,!!s)}return!1}evict(n,r){let s=!1;return n.id&&(it.call(this.data,n.id)&&(s=this.delete(n.id,n.fieldName,n.args)),this instanceof En&&this!==r&&(s=this.parent.evict(n,r)||s),(n.fieldName||s)&&this.group.dirty(n.id,n.fieldName||"__exists")),s}clear(){this.replace(null)}extract(){const n=this.toObject(),r=[];return this.getRootIdSet().forEach(s=>{it.call(this.policies.rootTypenamesById,s)||r.push(s)}),r.length&&(n.__META={extraRootIds:r.sort()}),n}replace(n){if(Object.keys(this.data).forEach(r=>{n&&it.call(n,r)||this.delete(r)}),n){const{__META:r,...s}=n;Object.keys(s).forEach(o=>{this.merge(o,s[o])}),r&&r.extraRootIds.forEach(this.retain,this)}}rootIds={};retain(n){return this.rootIds[n]=(this.rootIds[n]||0)+1}release(n){if(this.rootIds[n]>0){const r=--this.rootIds[n];return r||delete this.rootIds[n],r}return 0}getRootIdSet(n=new Set){return Object.keys(this.rootIds).forEach(n.add,n),this instanceof En?this.parent.getRootIdSet(n):Object.keys(this.policies.rootTypenamesById).forEach(n.add,n),n}gc(){const n=this.getRootIdSet(),r=this.toObject();n.forEach(o=>{it.call(r,o)&&(Object.keys(this.findChildRefIds(o)).forEach(n.add,n),delete r[o])});const s=Object.keys(r);if(s.length){let o=this;for(;o instanceof En;)o=o.parent;s.forEach(f=>o.delete(f))}return s}refs={};findChildRefIds(n){if(!it.call(this.refs,n)){const r=this.refs[n]={},s=this.data[n];if(!s)return r;const o=new Set([s]);o.forEach(f=>{ke(f)&&(r[f.__ref]=!0),jt(f)&&Object.keys(f).forEach(d=>{const y=f[d];jt(y)&&o.add(y)})})}return this.refs[n]}makeCacheKey(){return this.group.keyMaker.lookupArray(arguments)}getFieldValue=(n,r)=>ke(n)?this.get(n.__ref,r):n&&n[r];canRead=n=>ke(n)?this.has(n.__ref):typeof n=="object";toReference=(n,r)=>{if(typeof n=="string")return er(n);if(ke(n))return n;const[s]=this.policies.identify(n);if(s){const o=er(s);return r&&this.merge(s,n),o}};get supportsResultCaching(){return this.group.caching}}class Bg{caching;parent;d=null;keyMaker;constructor(n,r=null){this.caching=n,this.parent=r,this.resetCaching()}resetCaching(){this.d=this.caching?jg():null,this.keyMaker=new In}depend(n,r){if(this.d){this.d(sf(n,r));const s=cr(r);s!==r&&this.d(sf(n,s)),this.parent&&this.parent.depend(n,r)}}dirty(n,r){this.d&&this.d.dirty(sf(n,r),r==="__exists"?"forget":"setDirty")}}function sf(i,n){return n+"#"+i}function $p(i,n){Sl(i)&&i.group.depend(n,"__exists")}class QT extends Du{constructor({policies:n,resultCaching:r=!0,seed:s}){super(n,new Bg(r)),s&&this.replace(s)}stump=new YT(this);addLayer(n,r){return this.stump.addLayer(n,r)}removeLayer(){return this}storageTrie=new In;getStorage(){return this.storageTrie.lookupArray(arguments)}}Du.Root=QT;class En extends Du{id;parent;replay;group;constructor(n,r,s,o){super(r.policies,o),this.id=n,this.parent=r,this.replay=s,this.group=o,s(this)}addLayer(n,r){return new En(n,this,r,this.group)}removeLayer(n){const r=this.parent.removeLayer(n);return n===this.id?(this.group.caching&&Object.keys(this.data).forEach(s=>{const o=this.data[s],f=r.lookup(s);f?o?o!==f&&Object.keys(o).forEach(d=>{$e(o[d],f[d])||this.group.dirty(s,d)}):(this.group.dirty(s,"__exists"),Object.keys(f).forEach(d=>{this.group.dirty(s,d)})):this.delete(s)}),r):r===this.parent?this:r.addLayer(this.id,this.replay)}toObject(){return{...this.parent.toObject(),...this.data}}findChildRefIds(n){const r=this.parent.findChildRefIds(n);return it.call(this.data,n)?{...r,...super.findChildRefIds(n)}:r}getStorage(...n){let r=this.parent;for(;r.parent;)r=r.parent;return r.getStorage(...n)}}class YT extends En{constructor(n){super("EntityStore.Stump",n,()=>{},new Bg(n.group.caching,n.group))}removeLayer(){return this}merge(n,r){return this.parent.merge(n,r)}}function GT(i,n,r){const s=i[r],o=n[r];return $e(s,o)?s:o}function Sl(i){return!!(i&&i.supportsResultCaching)}const Vg=new _u;function XT(i){const n=i.directives?.find(({name:s})=>s.value==="unmask");if(!n)return"mask";const r=n.arguments?.find(({name:s})=>s.value==="mode");return r&&"value"in r.value&&r.value.value==="migrate"?"migrate":"unmask"}function Qg(i,n,r){return Vg.withValue(!0,()=>gl(i,n,r,!1))}function FT(i,n){if(n.has(i))return n.get(i);const r=Array.isArray(i)?[]:{};return n.set(i,r),r}function gl(i,n,r,s,o){const{knownChanged:f}=r,d=FT(i,r.mutableTargets);if(Array.isArray(i)){for(const[y,m]of Array.from(i.entries())){if(m===null){d[y]=null;continue}const h=gl(m,n,r,s);f.has(h)&&f.add(d),d[y]=h}return f.has(d)?d:i}for(const y of n.selections){let m;if(s&&f.add(d),y.kind===Te.FIELD){const h=dr(y),b=y.selectionSet;if(m=d[h]||i[h],m===void 0)continue;if(b&&m!==null){const v=gl(i[h],b,r,s);f.has(v)&&(m=v)}d[h]=m}if(y.kind===Te.INLINE_FRAGMENT&&(!y.typeCondition||r.cache.fragmentMatches(y,i.__typename))&&(m=gl(i,y.selectionSet,r,s)),y.kind===Te.FRAGMENT_SPREAD){const h=y.name.value,b=r.fragmentMap[h]||(r.fragmentMap[h]=r.cache.lookupFragment(h));de(b,39,h);const v=XT(y);v!=="mask"&&(m=gl(i,b.selectionSet,r,v==="migrate"))}f.has(m)&&f.add(d)}return"__typename"in i&&!("__typename"in d)&&(d.__typename=i.__typename),Object.keys(d).length!==Object.keys(i).length&&f.add(d),f.has(d)?d:i}function ZT(i,n,r,s){const o=n.definitions.filter(d=>d.kind===Te.FRAGMENT_DEFINITION);typeof s>"u"&&(de(o.length===1,41,o.length),s=o[0].name.value);const f=o.find(d=>d.name.value===s);return de(!!f,42,s),i==null||$e(i,{})?i:Qg(i,f.selectionSet,{operationName:f.name.value,fragmentMap:Ml(Cl(n)),cache:r,mutableTargets:new WeakMap,knownChanged:new WeakSet})}function JT(i,n,r){const s=Jn(n);return de(s,43),i==null?i:Qg(i,s.selectionSet,{operationType:s.operation,operationName:s.name?.value,fragmentMap:Ml(Cl(n)),cache:r,mutableTargets:new WeakMap,knownChanged:new WeakSet})}const Wp={};function sd(i){const n=JSON.stringify(i);return Wp[n]||(Wp[n]={})}function Pp(i){const n=sd(i);return n.keyFieldsFn||(n.keyFieldsFn=(r,s)=>{const o=(d,y)=>s.readField(y,d),f=s.keyObject=ud(i,d=>{let y=nr(s.storeObject,d,o);return y===void 0&&r!==s.storeObject&&it.call(r,d[0])&&(y=nr(r,d,Gg)),de(y!==void 0,99,d.join("."),r),y});return`${s.typename}:${JSON.stringify(f)}`})}function ev(i){const n=sd(i);return n.keyArgsFn||(n.keyArgsFn=(r,{field:s,variables:o,fieldName:f})=>{const d=ud(i,m=>{const h=m[0],b=h.charAt(0);if(b==="@"){if(s&&nd(s.directives)){const v=h.slice(1),E=s.directives.find(O=>O.name.value===v),S=E&&Pf(E,o);return S&&nr(S,m.slice(1))}return}if(b==="$"){const v=h.slice(1);if(o&&it.call(o,v)){const E=m.slice(0);return E[0]=v,nr(o,E)}return}if(r)return nr(r,m)}),y=JSON.stringify(d);return(r||y!=="{}")&&(f+=":"+y),f})}function ud(i,n){const r=new ur;return Yg(i).reduce((s,o)=>{let f=n(o);if(f!==void 0){for(let d=o.length-1;d>=0;--d)f={[o[d]]:f};s=r.merge(s,f)}return s},{})}function Yg(i){const n=sd(i);if(!n.paths){const r=n.paths=[],s=[];i.forEach((o,f)=>{Pe(o)?(Yg(o).forEach(d=>r.push(s.concat(d))),s.length=0):(s.push(o),Pe(i[f+1])||(r.push(s.slice(0)),s.length=0))})}return n.paths}function Gg(i,n){return i[n]}function nr(i,n,r){return r=r||Gg,Xg(n.reduce(function s(o,f){return Pe(o)?o.map(d=>s(d,f)):o&&r(o,f)},i))}function Xg(i){return jt(i)?Pe(i)?i.map(Xg):ud(Object.keys(i).sort(),n=>nr(i,n)):i}const Fg=new _u,tv=new WeakMap;function El(i){let n=tv.get(i);return n||tv.set(i,n={vars:new Set,dep:jg()}),n}function nv(i){El(i).vars.forEach(n=>n.forgetCache(i))}function KT(i){El(i).vars.forEach(n=>n.attachCache(i))}function IT(i){const n=new Set,r=new Set,s=function(f){if(arguments.length>0){if(i!==f){i=f,n.forEach(y=>{El(y).dep.dirty(s),$T(y)});const d=Array.from(r);r.clear(),d.forEach(y=>y(i))}}else{const d=Fg.getValue();d&&(o(d),El(d).dep(s))}return i};s.onNextChange=f=>(r.add(f),()=>{r.delete(f)});const o=s.attachCache=f=>(n.add(f),El(f).vars.add(s),s);return s.forgetCache=f=>n.delete(f),s}function $T(i){i.broadcastWatches&&i.broadcastWatches()}function Uf(i){return i.args!==void 0?i.args:i.field?Pf(i.field,i.variables):null}const WT=()=>{},av=(i,n)=>n.fieldName,iv=(i,n,{mergeObjects:r})=>r(i,n),rv=(i,n)=>n;class PT{config;typePolicies={};toBeAdded={};supertypeMap=new Map;fuzzySubtypes=new Map;cache;rootIdsByTypename={};rootTypenamesById={};usingPossibleTypes=!1;constructor(n){this.config=n,this.config={dataIdFromObject:qg,...n},this.cache=this.config.cache,this.setRootTypename("Query"),this.setRootTypename("Mutation"),this.setRootTypename("Subscription"),n.possibleTypes&&this.addPossibleTypes(n.possibleTypes),n.typePolicies&&this.addTypePolicies(n.typePolicies)}identify(n,r){const s=this,o=r&&(r.typename||r.storeObject?.__typename)||n.__typename;if(o===this.rootTypenamesById.ROOT_QUERY)return["ROOT_QUERY"];const f=r&&r.storeObject||n,d={...r,typename:o,storeObject:f,readField:r&&r.readField||((...b)=>{const v=od(b,f);return s.readField(v,{store:s.cache.data,variables:v.variables})})};let y;const m=o&&this.getTypePolicy(o);let h=m&&m.keyFn||this.config.dataIdFromObject;return Vg.withValue(!0,()=>{for(;h;){const b=h({...n,...f},d);if(Pe(b))h=Pp(b);else{y=b;break}}}),y=y?String(y):void 0,d.keyObject?[y,d.keyObject]:[y]}addTypePolicies(n){Object.keys(n).forEach(r=>{const{queryType:s,mutationType:o,subscriptionType:f,...d}=n[r];s&&this.setRootTypename("Query",r),o&&this.setRootTypename("Mutation",r),f&&this.setRootTypename("Subscription",r),it.call(this.toBeAdded,r)?this.toBeAdded[r].push(d):this.toBeAdded[r]=[d]})}updateTypePolicy(n,r,s){const o=this.getTypePolicy(n),{keyFields:f,fields:d}=r;function y(m,h){m.merge=typeof h=="function"?h:h===!0?iv:h===!1?rv:m.merge}y(o,r.merge),o.keyFn=f===!1?WT:Pe(f)?Pp(f):typeof f=="function"?f:o.keyFn,d&&Object.keys(d).forEach(m=>{let h=s[m];(!h||h?.typename!==n)&&(h=s[m]={typename:n});const b=d[m];if(typeof b=="function")h.read=b;else{const{keyArgs:v,read:E,merge:S}=b;h.keyFn=v===!1?av:Pe(v)?ev(v):typeof v=="function"?v:h.keyFn,typeof E=="function"&&(h.read=E),y(h,S)}h.read&&h.merge&&(h.keyFn=h.keyFn||av)})}setRootTypename(n,r=n){const s="ROOT_"+n.toUpperCase(),o=this.rootTypenamesById[s];r!==o&&(de(!o||o===n,100,n),o&&delete this.rootIdsByTypename[o],this.rootIdsByTypename[r]=s,this.rootTypenamesById[s]=r)}addPossibleTypes(n){this.usingPossibleTypes=!0,Object.keys(n).forEach(r=>{this.getSupertypeSet(r,!0),n[r].forEach(s=>{this.getSupertypeSet(s,!0).add(r);const o=s.match(Lg);(!o||o[0]!==s)&&this.fuzzySubtypes.set(s,new RegExp(s))})})}getTypePolicy(n){if(!it.call(this.typePolicies,n)){const s=this.typePolicies[n]={};s.fields={};let o=this.supertypeMap.get(n);!o&&this.fuzzySubtypes.size&&(o=this.getSupertypeSet(n,!0),this.fuzzySubtypes.forEach((f,d)=>{if(f.test(n)){const y=this.supertypeMap.get(d);y&&y.forEach(m=>o.add(m))}})),o&&o.size&&o.forEach(f=>{const{fields:d,...y}=this.getTypePolicy(f);Object.assign(s,y),Object.assign(s.fields,d)})}const r=this.toBeAdded[n];return r&&r.length&&r.splice(0).forEach(s=>{this.updateTypePolicy(n,s,this.typePolicies[n].fields)}),this.typePolicies[n]}getFieldPolicy(n,r){if(n)return this.getTypePolicy(n).fields[r]}getSupertypeSet(n,r){let s=this.supertypeMap.get(n);return!s&&r&&this.supertypeMap.set(n,s=new Set),s}fragmentMatches(n,r,s,o){if(!n.typeCondition)return!0;if(!r)return!1;const f=n.typeCondition.name.value;if(r===f)return!0;if(this.usingPossibleTypes&&this.supertypeMap.has(f)){const d=this.getSupertypeSet(r,!0),y=[d],m=b=>{const v=this.getSupertypeSet(b,!1);v&&v.size&&y.indexOf(v)<0&&y.push(v)};let h=!!(s&&this.fuzzySubtypes.size);for(let b=0;b<y.length;++b){const v=y[b];if(v.has(f))return d.has(f)||d.add(f),!0;v.forEach(m),h&&b===y.length-1&&jf(n.selectionSet,s,o)&&(h=!1,this.fuzzySubtypes.forEach((E,S)=>{const O=r.match(E);O&&O[0]===r&&m(S)}))}}return!1}hasKeyArgs(n,r){const s=this.getFieldPolicy(n,r);return!!(s&&s.keyFn)}getStoreFieldName(n){const{typename:r,fieldName:s}=n,o=this.getFieldPolicy(r,s);let f,d=o&&o.keyFn;if(d&&r){const y={typename:r,fieldName:s,field:n.field||null,variables:n.variables},m=Uf(n);for(;d;){const h=d(m,y);if(Pe(h))d=ev(h);else{f=h||s;break}}}return f===void 0&&(f=n.field?vT(n.field,n.variables):Eg(s,Uf(n))),f===!1?s:s===cr(f)?f:s+":"+f}readField(n,r){const s=n.from;if(!s||!(n.field||n.fieldName))return;if(n.typename===void 0){const b=r.store.getFieldValue(s,"__typename");b&&(n.typename=b)}const f=this.getStoreFieldName(n),d=cr(f),y=r.store.getFieldValue(s,f),m=this.getFieldPolicy(n.typename,d),h=m&&m.read;if(h){const b=lv(this,s,n,r,r.store.getStorage(ke(s)?s.__ref:s,f));return Fg.withValue(this.cache,h,[y,b])}return y}getReadFunction(n,r){const s=this.getFieldPolicy(n,r);return s&&s.read}getMergeFunction(n,r,s){let o=this.getFieldPolicy(n,r),f=o&&o.merge;return!f&&s&&(o=this.getTypePolicy(s),f=o&&o.merge),f}runMergeFunction(n,r,{field:s,typename:o,merge:f},d,y){return f===iv?Zg(d.store)(n,r):f===rv?r:(d.overwrite&&(n=void 0),f(n,r,lv(this,void 0,{typename:o,fieldName:s.name.value,field:s,variables:d.variables},d,y||{})))}}function lv(i,n,r,s,o){const f=i.getStoreFieldName(r),d=cr(f),y=r.variables||s.variables,{toReference:m,canRead:h}=s.store;return{args:Uf(r),field:r.field||null,fieldName:d,storeFieldName:f,variables:y,isReference:ke,toReference:m,storage:o,cache:i.cache,canRead:h,readField(...b){return i.readField(od(b,n,y),s)},mergeObjects:Zg(s.store)}}function od(i,n,r){const{0:s,1:o,length:f}=i;let d;return typeof s=="string"?d={fieldName:s,from:f>1?o:n}:(d={...s},it.call(d,"from")||(d.from=n)),d.variables===void 0&&(d.variables=r),d}function Zg(i){return function(r,s){if(Pe(r)||Pe(s))throw tn(103);if(jt(r)&&jt(s)){const o=i.getFieldValue(r,"__typename"),f=i.getFieldValue(s,"__typename");if(o&&f&&o!==f)return s;if(ke(r)&&$i(s))return i.merge(r.__ref,s),r;if($i(r)&&ke(s))return i.merge(r,s.__ref),s;if($i(r)&&$i(s))return{...r,...s}}return s}}function sv(i){return[i.selectionSet,i.objectOrReference,i.context]}class eO{executeSelectionSet;executeSubSelectedArray;config;knownResults=new WeakMap;constructor(n){this.config=n,this.executeSelectionSet=wl(r=>{const s=sv(r),o=this.executeSelectionSet.peek(...s);return o||($p(r.context.store,r.enclosingRef.__ref),this.execSelectionSetImpl(r))},{max:Zn["inMemoryCache.executeSelectionSet"]||5e4,keyArgs:sv,makeCacheKey(r,s,o){if(Sl(o.store))return o.store.makeCacheKey(r,ke(s)?s.__ref:s,o.varString)}}),this.executeSubSelectedArray=wl(r=>($p(r.context.store,r.enclosingRef.__ref),this.execSubSelectedArrayImpl(r)),{max:Zn["inMemoryCache.executeSubSelectedArray"]||1e4,makeCacheKey({field:r,array:s,context:o}){if(Sl(o.store))return o.store.makeCacheKey(r,s,o.varString)}})}diffQueryAgainstStore({store:n,query:r,rootId:s="ROOT_QUERY",variables:o,returnPartialData:f=!0}){const d=this.config.cache.policies;o={...td(aT(r)),...o};const y=er(s),m=this.executeSelectionSet({selectionSet:Sg(r).selectionSet,objectOrReference:y,enclosingRef:y,context:{store:n,query:r,policies:d,variables:o,varString:Da(o),...Hg(r,this.config.fragments)}});let h;m.missing&&(h=new ld(tO(m.missing),m.missing,r,o));const b=!h,{result:v}=m;return{result:b||f?Object.keys(v).length===0?null:v:null,complete:b,missing:h}}isFresh(n,r,s,o){if(Sl(o.store)&&this.knownResults.get(n)===s){const f=this.executeSelectionSet.peek(s,r,o);if(f&&n===f.result)return!0}return!1}execSelectionSetImpl({selectionSet:n,objectOrReference:r,enclosingRef:s,context:o}){if(ke(r)&&!o.policies.rootTypenamesById[r.__ref]&&!o.store.has(r.__ref))return{result:{},missing:`Dangling reference to missing ${r.__ref} object`};const{variables:f,policies:d,store:y}=o,m=y.getFieldValue(r,"__typename"),h=[];let b;const v=new ur;typeof m=="string"&&!d.rootIdsByTypename[m]&&h.push({__typename:m});function E(D,U){return D.missing&&(b=v.merge(b,{[U]:D.missing})),D.result}const S=new Set(n.selections);S.forEach(D=>{if(Ou(D,f))if(xl(D)){let U=d.readField({fieldName:D.name.value,field:D,variables:o.variables,from:r},o);const Y=dr(D);U===void 0?Ug.added(D)||(b=v.merge(b,{[Y]:`Can't find field '${D.name.value}' on ${ke(r)?r.__ref+" object":"object "+JSON.stringify(r,null,2)}`})):Pe(U)?U.length>0&&(U=E(this.executeSubSelectedArray({field:D,array:U,enclosingRef:s,context:o}),Y)):D.selectionSet&&U!=null&&(U=E(this.executeSelectionSet({selectionSet:D.selectionSet,objectOrReference:U,enclosingRef:ke(U)?U:s,context:o}),Y)),U!==void 0&&h.push({[Y]:U})}else{const U=Tu(D,o.lookupFragment);if(!U&&D.kind===Te.FRAGMENT_SPREAD)throw tn(104,D.name.value);U&&d.fragmentMatches(U,m)&&U.selectionSet.selections.forEach(S.add,S)}});const N={result:oT(h),missing:b},M=N;return M.result&&this.knownResults.set(M.result,n),M}execSubSelectedArrayImpl({field:n,array:r,enclosingRef:s,context:o}){let f,d=new ur;function y(m,h){return m.missing&&(f=d.merge(f,{[h]:m.missing})),m.result}return n.selectionSet&&(r=r.filter(o.store.canRead)),r=r.map((m,h)=>m===null?null:Pe(m)?y(this.executeSubSelectedArray({field:n,array:m,enclosingRef:s,context:o}),h):n.selectionSet?y(this.executeSelectionSet({selectionSet:n.selectionSet,objectOrReference:m,enclosingRef:ke(m)?m:s,context:o}),h):m),{result:r,missing:f}}}function tO(i){try{JSON.stringify(i,(n,r)=>{if(typeof r=="string")throw r;return r})}catch(n){return n}}function uf(i,n,r){const s=`${n}${r}`;let o=i.flavors.get(s);return o||i.flavors.set(s,o=i.clientOnly===n&&i.deferred===r?i:{...i,clientOnly:n,deferred:r}),o}class nO{cache;reader;fragments;constructor(n,r,s){this.cache=n,this.reader=r,this.fragments=s}writeToStore(n,{query:r,result:s,dataId:o,variables:f,overwrite:d}){const y=Jn(r),m=VT();f={...td(y),...f};const h={store:n,written:{},merge(v,E){return m.merge(v,E)},variables:f,varString:Da(f),...Hg(r,this.fragments),overwrite:!!d,incomingById:new Map,clientOnly:!1,deferred:!1,flavors:new Map},b=this.processSelectionSet({result:s||{},dataId:o,selectionSet:y.selectionSet,mergeTree:{map:new Map},context:h});if(!ke(b))throw tn(106,s);return h.incomingById.forEach(({storeObject:v,mergeTree:E,fieldNodeSet:S},O)=>{const N=er(O);if(E&&E.map.size){const M=this.applyMerges(E,N,v,h);if(ke(M))return;v=M}n.merge(O,v)}),n.retain(b.__ref),b}processSelectionSet({dataId:n,result:r,selectionSet:s,context:o,mergeTree:f}){const{policies:d}=this.cache;let y={};const m=n&&d.rootTypenamesById[n]||qf(r,s,o.fragmentMap)||n&&o.store.get(n,"__typename");typeof m=="string"&&(y.__typename=m);const h=(...v)=>{const E=od(v,y,o.variables);if(ke(E.from)){const S=o.incomingById.get(E.from.__ref);if(S){const O=d.readField({...E,from:S.storeObject},o);if(O!==void 0)return O}}return d.readField(E,o)},b=new Set;this.flattenFields(s,r,o,m).forEach((v,E)=>{const S=dr(E),O=r[S];if(b.add(E),O!==void 0){const N=d.getStoreFieldName({typename:m,fieldName:E.name.value,field:E,variables:v.variables}),M=uv(f,N);let D=this.processFieldValue(O,E,E.selectionSet?uf(v,!1,!1):v,M),U;E.selectionSet&&(ke(D)||$i(D))&&(U=h("__typename",D));const Y=d.getMergeFunction(m,E.name.value,U);Y?M.info={field:E,typename:m,merge:Y}:ov(f,N),y=v.merge(y,{[N]:D})}});try{const[v,E]=d.identify(r,{typename:m,selectionSet:s,fragmentMap:o.fragmentMap,storeObject:y,readField:h});n=n||v,E&&(y=o.merge(y,E))}catch(v){if(!n)throw v}if(typeof n=="string"){const v=er(n),E=o.written[n]||(o.written[n]=[]);if(E.indexOf(s)>=0||(E.push(s),this.reader&&this.reader.isFresh(r,v,s,o)))return v;const S=o.incomingById.get(n);return S?(S.storeObject=o.merge(S.storeObject,y),S.mergeTree=kf(S.mergeTree,f),b.forEach(O=>S.fieldNodeSet.add(O))):o.incomingById.set(n,{storeObject:y,mergeTree:gu(f)?void 0:f,fieldNodeSet:b}),v}return y}processFieldValue(n,r,s,o){return!r.selectionSet||n===null?n:Pe(n)?n.map((f,d)=>{const y=this.processFieldValue(f,r,s,uv(o,d));return ov(o,d),y}):this.processSelectionSet({result:n,selectionSet:r.selectionSet,context:s,mergeTree:o})}flattenFields(n,r,s,o=qf(r,n,s.fragmentMap)){const f=new Map,{policies:d}=this.cache,y=new In(!1);return(function m(h,b){const v=y.lookup(h,b.clientOnly,b.deferred);v.visited||(v.visited=!0,h.selections.forEach(E=>{if(!Ou(E,s.variables))return;let{clientOnly:S,deferred:O}=b;if(!(S&&O)&&nd(E.directives)&&E.directives.forEach(N=>{const M=N.name.value;if(M==="client"&&(S=!0),M==="defer"){const D=Pf(N,s.variables);(!D||D.if!==!1)&&(O=!0)}}),xl(E)){const N=f.get(E);N&&(S=S&&N.clientOnly,O=O&&N.deferred),f.set(E,uf(s,S,O))}else{const N=Tu(E,s.lookupFragment);if(!N&&E.kind===Te.FRAGMENT_SPREAD)throw tn(108,E.name.value);N&&d.fragmentMatches(N,o,r,s.variables)&&m(N.selectionSet,uf(s,S,O))}}))})(n,s),f}applyMerges(n,r,s,o,f){if(n.map.size&&!ke(s)){const d=!Pe(s)&&(ke(r)||$i(r))?r:void 0,y=s;d&&!f&&(f=[ke(d)?d.__ref:d]);let m;const h=(b,v)=>Pe(b)?typeof v=="number"?b[v]:void 0:o.store.getFieldValue(b,String(v));n.map.forEach((b,v)=>{const E=h(d,v),S=h(y,v);if(S===void 0)return;f&&f.push(v);const O=this.applyMerges(b,E,S,o,f);O!==S&&(m=m||new Map,m.set(v,O)),f&&de(f.pop()===v)}),m&&(s=Pe(y)?y.slice(0):{...y},m.forEach((b,v)=>{s[v]=b}))}return n.info?this.cache.policies.runMergeFunction(r,s,n.info,o,f&&o.store.getStorage(...f)):s}}const Jg=[];function uv({map:i},n){return i.has(n)||i.set(n,Jg.pop()||{map:new Map}),i.get(n)}function kf(i,n){if(i===n||!n||gu(n))return i;if(!i||gu(i))return n;const r=i.info&&n.info?{...i.info,...n.info}:i.info||n.info,s=i.map.size&&n.map.size,o=s?new Map:i.map.size?i.map:n.map,f={info:r,map:o};if(s){const d=new Set(n.map.keys());i.map.forEach((y,m)=>{f.map.set(m,kf(y,n.map.get(m))),d.delete(m)}),d.forEach(y=>{f.map.set(y,kf(n.map.get(y),i.map.get(y)))})}return f}function gu(i){return!i||!(i.info||i.map.size)}function ov({map:i},n){const r=i.get(n);r&&gu(r)&&(Jg.push(r),i.delete(n))}function qf(i,n,r){let s;for(const o of n.selections)if(xl(o)){if(o.name.value==="__typename")return i[dr(o)]}else s?s.push(o):s=[o];if(typeof i.__typename=="string")return i.__typename;if(s)for(const o of s){const f=qf(i,Tu(o,r).selectionSet,r);if(typeof f=="string")return f}}class aO extends LT{data;optimisticData;config;watches=new Set;storeReader;storeWriter;addTypenameTransform=new Fn(Ug);maybeBroadcastWatch;assumeImmutableResults=!0;policies;makeVar=IT;constructor(n={}){super(),this.config=BT(n),this.policies=new PT({cache:this,dataIdFromObject:this.config.dataIdFromObject,possibleTypes:this.config.possibleTypes,typePolicies:this.config.typePolicies}),this.init()}init(){const n=this.data=new Du.Root({policies:this.policies,resultCaching:this.config.resultCaching});this.optimisticData=n.stump,this.resetResultCache()}resetResultCache(){const{fragments:n}=this.config;this.addTypenameTransform.resetCache(),n?.resetCaches(),this.storeWriter=new nO(this,this.storeReader=new eO({cache:this,fragments:n}),n),this.maybeBroadcastWatch=wl((r,s)=>this.broadcastWatch(r,s),{max:Zn["inMemoryCache.maybeBroadcastWatch"]||5e3,makeCacheKey:r=>{const s=r.optimistic?this.optimisticData:this.data;if(Sl(s)){const{optimistic:o,id:f,variables:d}=r;return s.makeCacheKey(r.query,r.callback,Da({optimistic:o,id:f,variables:d}))}}}),new Set([this.data.group,this.optimisticData.group]).forEach(r=>r.resetCaching())}restore(n){return this.init(),n&&this.data.replace(n),this}extract(n=!1){return(n?this.optimisticData:this.data).extract()}read(n){const{returnPartialData:r=!1}=n;return this.storeReader.diffQueryAgainstStore({...n,store:n.optimistic?this.optimisticData:this.data,config:this.config,returnPartialData:r}).result}write(n){try{return++this.txCount,this.storeWriter.writeToStore(this.data,n)}finally{!--this.txCount&&n.broadcast!==!1&&this.broadcastWatches()}}modify(n){if(it.call(n,"id")&&!n.id)return!1;const r=n.optimistic?this.optimisticData:this.data;try{return++this.txCount,r.modify(n.id||"ROOT_QUERY",n.fields,!1)}finally{!--this.txCount&&n.broadcast!==!1&&this.broadcastWatches()}}diff(n){return this.storeReader.diffQueryAgainstStore({...n,store:n.optimistic?this.optimisticData:this.data,rootId:n.id||"ROOT_QUERY",config:this.config})}watch(n){return this.watches.size||KT(this),this.watches.add(n),n.immediate&&this.maybeBroadcastWatch(n),()=>{this.watches.delete(n)&&!this.watches.size&&nv(this),this.maybeBroadcastWatch.forget(n)}}gc(n){Da.reset(),tr.reset();const r=this.optimisticData.gc();return n&&!this.txCount&&n.resetResultCache&&this.resetResultCache(),r}retain(n,r){return(r?this.optimisticData:this.data).retain(n)}release(n,r){return(r?this.optimisticData:this.data).release(n)}identify(n){if(ke(n))return n.__ref;try{return this.policies.identify(n)[0]}catch{}}evict(n){if(!n.id){if(it.call(n,"id"))return!1;n={...n,id:"ROOT_QUERY"}}try{return++this.txCount,this.optimisticData.evict(n,this.data)}finally{!--this.txCount&&n.broadcast!==!1&&this.broadcastWatches()}}reset(n){return this.init(),Da.reset(),n&&n.discardWatches?(this.watches.forEach(r=>this.maybeBroadcastWatch.forget(r)),this.watches.clear(),nv(this)):this.broadcastWatches(),Promise.resolve()}removeOptimistic(n){const r=this.optimisticData.removeLayer(n);r!==this.optimisticData&&(this.optimisticData=r,this.broadcastWatches())}txCount=0;batch(n){const{update:r,optimistic:s=!0,removeOptimistic:o,onWatchUpdated:f}=n;let d;const y=h=>{const{data:b,optimisticData:v}=this;++this.txCount,h&&(this.data=this.optimisticData=h);try{return d=r(this)}finally{--this.txCount,this.data=b,this.optimisticData=v}},m=new Set;return f&&!this.txCount&&this.broadcastWatches({...n,onWatchUpdated(h){return m.add(h),!1}}),typeof s=="string"?this.optimisticData=this.optimisticData.addLayer(s,y):s===!1?y(this.data):y(),typeof o=="string"&&(this.optimisticData=this.optimisticData.removeLayer(o)),f&&m.size?(this.broadcastWatches({...n,onWatchUpdated(h,b){const v=f.call(this,h,b);return v!==!1&&m.delete(h),v}}),m.size&&m.forEach(h=>this.maybeBroadcastWatch.dirty(h))):this.broadcastWatches(n),d}performTransaction(n,r){return this.batch({update:n,optimistic:r||r!==null})}transformDocument(n){return this.addTypenameTransform.transformDocument(this.addFragmentsToDocument(n))}fragmentMatches(n,r){return this.policies.fragmentMatches(n,r)}lookupFragment(n){return this.config.fragments?.lookup(n)||null}broadcastWatches(n){this.txCount||this.watches.forEach(r=>this.maybeBroadcastWatch(r,n))}addFragmentsToDocument(n){const{fragments:r}=this.config;return r?r.transform(n):n}broadcastWatch(n,r){const{lastDiff:s}=n,o=this.diff(n);r&&(n.optimistic&&typeof r.optimistic=="string"&&(o.fromOptimisticTransaction=!0),r.onWatchUpdated&&r.onWatchUpdated.call(this,n,o,s)===!1)||(!s||!$e(s.result,o.result))&&n.callback(n.lastDiff=o,s)}}function Rl(i,n){return typeof i=="object"&&i!==null&&i[Symbol.for("apollo.error")]===n}function zl(i){Object.defineProperty(i,Symbol.for("apollo.error"),{value:i.name,enumerable:!1,writable:!1,configurable:!1})}function cv(i){return i.map(n=>n.message||"Error message not found.").join(`
`)}class Al extends Error{static is(n){return Rl(n,"CombinedProtocolErrors")}static formatMessage=cv;errors;constructor(n){super(Al.formatMessage(n,{defaultFormatMessage:cv})),this.name="CombinedProtocolErrors",this.errors=n,zl(this),Object.setPrototypeOf(this,Al.prototype)}}function iO(i){return i!==null&&typeof i=="object"&&typeof i.message=="string"&&typeof i.name=="string"&&(typeof i.stack=="string"||typeof i.stack>"u")}class cd extends Error{static is(n){return Rl(n,"UnconventionalError")}constructor(n){super("An error of unexpected shape occurred.",{cause:n}),this.name="UnconventionalError",zl(this),Object.setPrototypeOf(this,cd.prototype)}}function fv(i){return i.filter(n=>n).map(n=>n.message||"Error message not found.").join(`
`)}class Tn extends Error{static is(n){return Rl(n,"CombinedGraphQLErrors")}static formatMessage=fv;errors;data;extensions;constructor(n,r=n.errors||[]){super(Tn.formatMessage(r,{result:n,defaultFormatMessage:fv})),this.errors=r,this.data=n.data,this.extensions=n.extensions,this.name="CombinedGraphQLErrors",zl(this),Object.setPrototypeOf(this,Tn.prototype)}}const rO=new WeakSet;function lO(i){rO.add(i)}class Mu extends Error{static is(n){return Rl(n,"ServerError")}response;statusCode;bodyText;constructor(n,r){super(n),this.name="ServerError",this.response=r.response,this.statusCode=r.response.status,this.bodyText=r.bodyText,zl(this),Object.setPrototypeOf(this,Mu.prototype)}}class Cu extends Error{static is(n){return Rl(n,"ServerParseError")}response;statusCode;bodyText;constructor(n,r){super(n instanceof Error?n.message:"Could not parse server response",{cause:n}),this.name="ServerParseError",this.response=r.response,this.statusCode=r.response.status,this.bodyText=r.bodyText,zl(this),Object.setPrototypeOf(this,Cu.prototype)}}const Dl=Symbol();function Kg(i){return"extensions"in i?Al.is(i.extensions[Dl]):!1}function Lf(i){return iO(i)?i:typeof i=="string"?new Error(i,{cause:i}):new cd(i)}var se;(function(i){i[i.loading=1]="loading",i[i.setVariables=2]="setVariables",i[i.fetchMore=3]="fetchMore",i[i.refetch=4]="refetch",i[i.poll=6]="poll",i[i.ready=7]="ready",i[i.error=8]="error",i[i.streaming=9]="streaming"})(se||(se={}));const{assign:dv}=Object,Ji={loading:!0,networkStatus:se.loading,data:void 0,dataState:"empty",partial:!0},of={loading:!1,networkStatus:se.ready,data:void 0,dataState:"empty",partial:!0};class cf{options;queryName;variablesUnknown=!1;_lastWrite;get query(){return this.lastQuery}get variables(){return this.options.variables}unsubscribeFromCache;input;subject;isTornDown;queryManager;subscriptions=new Set;waitForNetworkResult;lastQuery;linkSubscription;pollingInfo;get networkStatus(){return this.subject.getValue().result.networkStatus}constructor({queryManager:n,options:r,transformedQuery:s=n.transform(r.query)}){this.queryManager=n,this.waitForNetworkResult=r.fetchPolicy==="network-only",this.isTornDown=!1,this.subscribeToMore=this.subscribeToMore.bind(this),this.maskResult=this.maskResult.bind(this);const{watchQuery:{fetchPolicy:o="cache-first"}={}}=n.defaultOptions,{fetchPolicy:f=o,initialFetchPolicy:d=f==="standby"?o:f}=r;r[bT]&&(de(f==="standby",77),this.variablesUnknown=!0),this.lastQuery=s,this.options={...r,initialFetchPolicy:d,fetchPolicy:f,variables:this.getVariablesWithDefaults(r.variables)},this.initializeObservablesQueue(),this["@@observable"]=()=>this,Symbol.observable&&(this[Symbol.observable]=()=>this);const y=Jn(this.query);this.queryName=y&&y.name&&y.name.value}initializeObservablesQueue(){this.subject=new dE({query:this.query,variables:this.variables,result:Ji,meta:{}});const n=this.subject.pipe(pu({subscribe:()=>{this.subject.observed||(this.reobserve(),setTimeout(()=>this.updatePolling()))},unsubscribe:()=>{this.subject.observed||this.tearDownQuery()}}),Rf(({query:r,variables:s,result:o,meta:f},d)=>{const{shouldEmit:y}=f;if(o===Ji&&(d.previous=void 0,d.previousVariables=void 0),this.options.fetchPolicy==="standby"||y===2)return;if(y===1)return b();const{previous:m,previousVariables:h}=d;if(m){const v=this.queryManager.getDocumentInfo(r),E=this.queryManager.dataMasking,S=E?v.nonReactiveQuery:r;if((E||v.hasNonreactiveDirective?Og(S,m,o,s):$e(m,o))&&$e(h,s))return}if(y===3&&(!this.options.notifyOnNetworkStatusChange||$e(m,o)))return;return b();function b(){return d.previous=o,d.previousVariables=s,o}},()=>({})));this.pipe=n.pipe.bind(n),this.subscribe=n.subscribe.bind(n),this.input=new fr,this.input.complete=()=>{},this.input.pipe(this.operator).subscribe(this.subject)}subscribe;pipe;[Symbol.observable];"@@observable";getCacheDiff({optimistic:n=!0}={}){return this.queryManager.cache.diff({query:this.query,variables:this.variables,returnPartialData:!0,optimistic:n})}getInitialResult(n){const r=this.queryManager.prioritizeCacheValues?"cache-first":n||this.options.fetchPolicy,s=()=>{const o=this.getCacheDiff(),f=this.options.returnPartialData||o.complete?o.result??void 0:void 0;return this.maskResult({data:f,dataState:o.complete?"complete":f===void 0?"empty":"partial",loading:!o.complete,networkStatus:o.complete?se.ready:se.loading,partial:!o.complete})};switch(r){case"cache-only":return{...s(),loading:!1,networkStatus:se.ready};case"cache-first":return s();case"cache-and-network":return{...s(),loading:!0,networkStatus:se.loading};case"standby":return of;default:return Ji}}resubscribeCache(){const{variables:n,fetchPolicy:r}=this.options,s=this.query,o=r==="standby"||r==="no-cache"||this.waitForNetworkResult,f=!fl({query:s,variables:n},this.unsubscribeFromCache)&&!this.waitForNetworkResult;if((o||f)&&this.unsubscribeFromCache?.(),o||!f)return;const d={query:s,variables:n,optimistic:!0,watcher:this,callback:m=>{const h=this.queryManager.getDocumentInfo(s);if((h.hasClientExports||h.hasForcedResolvers)&&(d.lastDiff=void 0),d.lastOwnDiff===m)return;const{result:b}=this.subject.getValue();!m.complete&&(b.error||b===Ji||b===of)||$e(b.data,m.result)||this.scheduleNotify()}},y=this.queryManager.cache.watch(d);this.unsubscribeFromCache=Object.assign(()=>{this.unsubscribeFromCache=void 0,y()},{query:s,variables:n})}stableLastResult;getCurrentResult(){const{result:n}=this.subject.getValue();let r=n.networkStatus===se.error||this.hasObservers()||this.options.fetchPolicy==="no-cache"?n:this.getInitialResult();return r===Ji&&(r=this.getInitialResult()),$e(this.stableLastResult,r)||(this.stableLastResult=r),this.stableLastResult}refetch(n){const{fetchPolicy:r}=this.options,s={pollInterval:0};return r==="no-cache"?s.fetchPolicy="no-cache":s.fetchPolicy="network-only",n&&!$e(this.variables,n)&&(s.variables=this.options.variables=this.getVariablesWithDefaults({...this.variables,...n})),this._lastWrite=void 0,this._reobserve(s,{newNetworkStatus:se.refetch})}fetchMore({query:n,variables:r,context:s,errorPolicy:o,updateQuery:f}){de(this.options.fetchPolicy!=="cache-only",79,sr(this.query,"(anonymous)"));const d={...en(this.options,{errorPolicy:"none"},{query:n,context:s,errorPolicy:o}),variables:n?r:{...this.variables,...r},fetchPolicy:"no-cache",notifyOnNetworkStatusChange:this.options.notifyOnNetworkStatusChange};d.query=this.transformDocument(d.query),this.lastQuery=n?this.transformDocument(this.options.query):d.query;let y=!1;const m=this.options.fetchPolicy!=="no-cache";m||de(f,80);const{finalize:h,pushNotification:b}=this.pushOperation(se.fetchMore);return b({source:"newNetworkStatus",kind:"N",value:{}},{shouldEmit:3}),this.queryManager.fetchQuery(d,se.fetchMore).then(v=>{if(h(),m){const E=this.getCacheDiff();this.queryManager.cache.batch({update:S=>{f?S.updateQuery({query:this.query,variables:this.variables,returnPartialData:!0,optimistic:!1},O=>f(O,{fetchMoreResult:v.data,variables:d.variables})):S.writeQuery({query:d.query,variables:d.variables,data:v.data})},onWatchUpdated:(S,O)=>{S.watcher===this&&!$e(O.result,E.result)&&(y=!0)}})}else{const E=this.getCurrentResult(),S=f(E.data,{fetchMoreResult:v.data,variables:d.variables});b({kind:"N",value:{...E,networkStatus:se.ready,loading:!1,data:S,dataState:E.dataState==="streaming"?"streaming":"complete"},source:"network"})}return this.maskResult(v)}).finally(()=>{h(),m&&!y&&b({kind:"N",source:"newNetworkStatus",value:{}},{shouldEmit:1})})}subscribeToMore(n){const r=this.queryManager.startGraphQLSubscription({query:n.document,variables:n.variables,context:n.context}).subscribe({next:s=>{const{updateQuery:o,onError:f}=n,{error:d}=s;if(d){f?f(d):de.error(81,d);return}o&&this.updateQuery((y,m)=>o(y,{subscriptionData:s,...m}))}});return this.subscriptions.add(r),()=>{this.subscriptions.delete(r)&&r.unsubscribe()}}applyOptions(n){const r=en(this.options,n||{});dv(this.options,r),this.updatePolling()}async setVariables(n){return n=this.getVariablesWithDefaults(n),$e(this.variables,n)?uu(this.getCurrentResult()):(this.options.variables=n,this.hasObservers()?this._reobserve({fetchPolicy:this.options.initialFetchPolicy,variables:n},{newNetworkStatus:se.setVariables}):uu(this.getCurrentResult()))}updateQuery(n){const{queryManager:r}=this,{result:s,complete:o}=this.getCacheDiff({optimistic:!1}),f=n(s,{variables:this.variables,complete:!!o,previousData:s});f&&(r.cache.writeQuery({query:this.options.query,data:f,variables:this.variables}),r.broadcastQueries())}startPolling(n){this.options.pollInterval=n,this.updatePolling()}stopPolling(){this.options.pollInterval=0,this.updatePolling()}applyNextFetchPolicy(n,r){if(r.nextFetchPolicy){const{fetchPolicy:s="cache-first",initialFetchPolicy:o=s}=r;s==="standby"||(typeof r.nextFetchPolicy=="function"?r.fetchPolicy=r.nextFetchPolicy.call(r,s,{reason:n,options:r,observable:this,initialFetchPolicy:o}):n==="variables-changed"?r.fetchPolicy=o:r.fetchPolicy=r.nextFetchPolicy)}return r.fetchPolicy}fetch(n,r,s,o){const f=this.options.fetchPolicy;n.context??={};let d=!1;const y=()=>{d=!0},m=M=>new Fe(D=>{try{return M.subscribe({next(U){d=!0,D.next(U)},error:U=>D.error(U),complete:()=>D.complete()})}finally{d||(S.override=r,this.input.next({kind:"N",source:"newNetworkStatus",value:{resetError:!0},query:v,variables:E,meta:{shouldEmit:3,fetchPolicy:f}}))}});let{observable:h,fromLink:b}=this.queryManager.fetchObservableWithInfo(n,{networkStatus:r,query:s,onCacheHit:y,fetchQueryOperator:m,observableQuery:this});const{query:v,variables:E}=this,S={abort:()=>{N.unsubscribe()},query:v,variables:E};this.activeOperations.add(S);let O=r==se.refetch||r==se.setVariables;h=h.pipe(o,yu());const N=h.pipe(pu({next:M=>{M.source==="newNetworkStatus"||M.kind==="N"&&M.value.loading?S.override=r:delete S.override},finalize:()=>this.activeOperations.delete(S)})).subscribe({next:M=>{const D={};O&&M.kind==="N"&&"loading"in M.value&&!M.value.loading&&(O=!1,D.shouldEmit=1),this.input.next({...M,query:v,variables:E,meta:D})}});return{fromLink:b,subscription:N,observable:h}}didWarnCacheOnlyPolling=!1;updatePolling(){if(this.queryManager.ssrMode)return;const{pollingInfo:n,options:{fetchPolicy:r,pollInterval:s}}=this;if(!s||!this.hasObservers()||r==="cache-only"){this.cancelPolling();return}if(n?.interval===s)return;const o=n||(this.pollingInfo={});o.interval=s;const f=()=>{this.pollingInfo&&(!Nf(this.networkStatus)&&!this.options.skipPollAttempt?.()?this._reobserve({fetchPolicy:this.options.initialFetchPolicy==="no-cache"?"no-cache":"network-only"},{newNetworkStatus:se.poll}).then(d,d):d())},d=()=>{const y=this.pollingInfo;y&&(clearTimeout(y.timeout),y.timeout=setTimeout(f,y.interval))};d()}cancelPolling(){this.pollingInfo&&(clearTimeout(this.pollingInfo.timeout),delete this.pollingInfo)}reobserve(n){return this._reobserve(n)}_reobserve(n,r){this.isTornDown=!1;let{newNetworkStatus:s}=r||{};this.queryManager.obsQueries.add(this);const o=s===se.refetch||s===se.poll,f=this.variables,d=this.options.fetchPolicy,y=en(this.options,n||{});this.variablesUnknown&&=y.fetchPolicy==="standby";const m=o?y:dv(this.options,y),h=this.transformDocument(m.query);this.lastQuery=h,n&&"variables"in n&&(m.variables=this.getVariablesWithDefaults(n.variables)),o||(this.updatePolling(),n&&n.variables&&!$e(n.variables,f)&&m.fetchPolicy!=="standby"&&(m.fetchPolicy===d||typeof m.nextFetchPolicy=="function")&&(this.applyNextFetchPolicy("variables-changed",m),s===void 0&&(s=se.setVariables)));const b=this.networkStatus;s||(s=se.loading,b!==se.loading&&n?.variables&&!$e(n.variables,f)&&(s=se.setVariables),m.fetchPolicy==="standby"&&(s=se.ready)),m.fetchPolicy==="standby"&&this.cancelPolling(),this.resubscribeCache();const{promise:v,operator:E}=sO(D=>{switch(D.kind){case"E":throw D.error;case"N":if(D.source!=="newNetworkStatus"&&!D.value.loading)return D.value}},m.fetchPolicy==="standby"?{data:void 0}:void 0),{subscription:S,observable:O,fromLink:N}=this.fetch(m,s,h,E);!o&&(N||!this.linkSubscription)&&(this.linkSubscription&&this.linkSubscription.unsubscribe(),this.linkSubscription=S);const M=Object.assign(cT(v.then(D=>uu(this.maskResult(D))).finally(()=>{!this.hasObservers()&&this.activeOperations.size===0&&this.tearDownQuery()})),{retain:()=>{const D=O.subscribe({}),U=()=>D.unsubscribe();return v.then(U,U),M}});return M}hasObservers(){return this.subject.observed}stop(){this.subject.complete(),this.initializeObservablesQueue(),this.tearDownQuery()}tearDownQuery(){this.isTornDown||(this.resetNotifications(),this.unsubscribeFromCache?.(),this.linkSubscription&&(this.linkSubscription.unsubscribe(),delete this.linkSubscription),this.stopPolling(),this.subscriptions.forEach(n=>n.unsubscribe()),this.subscriptions.clear(),this.queryManager.obsQueries.delete(this),this.isTornDown=!0,this.abortActiveOperations(),this._lastWrite=void 0)}transformDocument(n){return this.queryManager.transform(n)}maskResult(n){const r=this.queryManager.maskOperation({document:this.query,data:n.data,fetchPolicy:this.options.fetchPolicy,cause:this});return r===n.data?n:{...n,data:r}}dirty=!1;notifyTimeout;resetNotifications(){this.notifyTimeout&&(clearTimeout(this.notifyTimeout),this.notifyTimeout=void 0),this.dirty=!1}scheduleNotify(){this.dirty||(this.dirty=!0,this.notifyTimeout||(this.notifyTimeout=setTimeout(()=>this.notify(!0),0)))}notify(n=!1){if(!n){const s=this.queryManager.getDocumentInfo(this.query);if(s.hasClientExports||s.hasForcedResolvers)return}const{dirty:r}=this;if(this.resetNotifications(),r&&(this.options.fetchPolicy=="cache-only"||this.options.fetchPolicy=="cache-and-network"||!this.activeOperations.size)){const s=this.getCacheDiff();$e(s.result,this.getCacheDiff({optimistic:!1}).result)?this.reobserveCacheFirst():this.input.next({kind:"N",value:{data:s.result,dataState:s.complete?"complete":s.result?"partial":"empty",networkStatus:se.ready,loading:!1,error:void 0,partial:!s.complete},source:"cache",query:this.query,variables:this.variables,meta:{}})}}activeOperations=new Set;pushOperation(n){let r=!1;const{query:s,variables:o}=this,f=()=>{this.activeOperations.delete(d)},d={override:n,abort:()=>{r=!0,f()},query:s,variables:o};return this.activeOperations.add(d),{finalize:f,pushNotification:(y,m)=>{r||this.input.next({...y,query:s,variables:o,meta:{...m}})}}}calculateNetworkStatus(n){return n===se.streaming?n:Array.from(this.activeOperations.values()).reverse().find(s=>fl(s,this)&&s.override!==void 0)?.override??n}abortActiveOperations(){this.activeOperations.forEach(n=>n.abort())}reset(){const n=this.options.fetchPolicy==="cache-only";this.setResult(n?of:Ji,{shouldEmit:n?1:2}),this.abortActiveOperations()}setResult(n,r){this.input.next({source:"setResult",kind:"N",value:n,query:this.query,variables:this.variables,meta:{...r}})}operator=Rf(n=>{const{query:r,variables:s,meta:o}=n;if(n.source==="setResult")return{query:r,variables:s,result:n.value,meta:o};if(n.kind==="C"||!fl(n,this))return;let f;const d=this.subject.getValue();if(n.source==="cache"){if(f=n.value,f.networkStatus===se.ready&&f.partial&&(!this.options.returnPartialData||d.result.networkStatus===se.error)&&this.options.fetchPolicy!=="cache-only")return}else if(n.source==="network")this.waitForNetworkResult&&(this.waitForNetworkResult=!1,this.resubscribeCache()),f=n.kind==="E"?{...fl(d,n)?d.result:{data:void 0,dataState:"empty",partial:!0},error:n.error,networkStatus:se.error,loading:!1}:n.value,n.kind==="E"&&f.dataState==="streaming"&&(f.dataState="complete"),f.error&&(o.shouldEmit=1);else if(n.source==="newNetworkStatus"){const y=fl(d,n)?d.result:this.getInitialResult(o.fetchPolicy),{resetError:m}=n.value,h=m?void 0:y.error,b=h?se.error:se.ready;f={...y,error:h,networkStatus:b}}return de(f),f.error||delete f.error,f.networkStatus=this.calculateNetworkStatus(f.networkStatus),f.loading=Nf(f.networkStatus),f=this.maskResult(f),{query:r,variables:s,result:f,meta:o}});reobserveCacheFirst(){const{fetchPolicy:n,nextFetchPolicy:r}=this.options;n==="cache-and-network"||n==="network-only"?this.reobserve({fetchPolicy:"cache-first",nextFetchPolicy(s,o){return this.nextFetchPolicy=r,typeof this.nextFetchPolicy=="function"?this.nextFetchPolicy(s,o):n}}):this.reobserve()}getVariablesWithDefaults(n){return this.queryManager.getVariables(this.query,n)}}function fl(i,n){return!!(i&&n&&i.query===n.query&&$e(i.variables,n.variables))}function sO(i,n){let r=n,s,o;const f=new Promise((y,m)=>{s=y,o=m}),d=pu({next(y){try{const m=i(y);m!==void 0&&(r=m)}catch(m){o(m)}},finalize:()=>{if(r)s(r);else{const y="The operation was aborted.",m="AbortError";o(typeof DOMException<"u"?new DOMException(y,m):Object.assign(new Error(y),{name:m}))}}});return{promise:f,operator:d}}const hv={},Wi=new WeakMap;function ff(i,n){const r=i[n];typeof r=="function"&&(i[n]=function(){return Wi.set(i,(Wi.get(i)+1)%1e15),r.apply(this,arguments)})}const mv=new WeakMap;class df{lastRequestId=1;cache;queryManager;id;observableQuery;incremental;constructor(n,r){const s=this.cache=n.cache,o=(mv.get(n)||0)+1;mv.set(n,o),this.id=o+"",this.observableQuery=r,this.queryManager=n,Wi.has(s)||(Wi.set(s,0),ff(s,"evict"),ff(s,"modify"),ff(s,"reset"))}_lastWrite;get lastWrite(){return(this.observableQuery||this)._lastWrite}set lastWrite(n){(this.observableQuery||this)._lastWrite=n}resetLastWrite(){this.lastWrite=void 0}shouldWrite(n,r){const{lastWrite:s}=this;return!(s&&s.dmCount===Wi.get(this.cache)&&$e(r,s.variables)&&$e(n.data,s.result.data))}get hasNext(){return this.incremental?this.incremental.hasNext:!1}maybeHandleIncrementalResult(n,r,s){const{incrementalHandler:o}=this.queryManager;return o.isIncrementalResult(r)?(this.incremental||=o.startRequest({query:s}),this.incremental.handle(n,r)):r}markQueryResult(n,{document:r,variables:s,errorPolicy:o,cacheWriteBehavior:f}){const d={query:r,variables:s,returnPartialData:!0,optimistic:!0};this.observableQuery?.resetNotifications();const y=f===0,m=y?void 0:this.cache.diff(d);let h=this.maybeHandleIncrementalResult(m?.result,n,r);return y||(hf(h,o)?this.cache.batch({onWatchUpdated:(b,v)=>{b.watcher===this.observableQuery&&(b.lastOwnDiff=v)},update:b=>{if(this.shouldWrite(h,s))b.writeQuery({query:r,data:h.data,variables:s,overwrite:f===1}),this.lastWrite={result:h,variables:s,dmCount:Wi.get(this.cache)};else if(m&&m.complete){h={...h,data:m.result};return}const v=b.diff(d);v.complete&&(h={...h,data:v.result})}}):this.lastWrite=void 0),h}markMutationResult(n,r,s=this.cache){const o=[],f=r.cacheWriteBehavior===0;let d=this.maybeHandleIncrementalResult(f?void 0:s.diff({id:"ROOT_MUTATION",query:this.queryManager.getDocumentInfo(r.document).asQuery,variables:r.variables,optimistic:!1,returnPartialData:!0}).result,n,r.document);if(r.errorPolicy==="ignore"&&(d={...d,errors:[]}),Ii(d)&&r.errorPolicy==="none")return Promise.resolve(d);const y=()=>({...d,dataState:this.hasNext?"streaming":"complete"});if(!f&&hf(d,r.errorPolicy)){o.push({result:d.data,dataId:"ROOT_MUTATION",query:r.document,variables:r.variables});const{updateQueries:h}=r;h&&this.queryManager.getObservableQueries("all").forEach(b=>{const v=b&&b.queryName;if(!v||!Object.hasOwnProperty.call(h,v))return;const E=h[v],{query:S,variables:O}=b,{result:N,complete:M}=b.getCacheDiff({optimistic:!1});if(M&&N){const D=E(N,{mutationResult:y(),queryName:S&&sr(S)||void 0,queryVariables:O});D&&o.push({result:D,dataId:"ROOT_QUERY",query:S,variables:O})}})}let m=r.refetchQueries;if(typeof m=="function"&&(m=m(y())),o.length>0||(m||"").length>0||r.update||r.onQueryUpdated||r.removeOptimistic){const h=[];if(this.queryManager.refetchQueries({updateCache:b=>{f||o.forEach(E=>b.write(E));const{update:v}=r;if(v){if(!f){const E=b.diff({id:"ROOT_MUTATION",query:this.queryManager.getDocumentInfo(r.document).asQuery,variables:r.variables,optimistic:!1,returnPartialData:!0});E.complete&&(d={...d,data:E.result})}this.hasNext||v(b,d,{context:r.context,variables:r.variables})}!f&&!r.keepRootFields&&!this.hasNext&&b.modify({id:"ROOT_MUTATION",fields(E,{fieldName:S,DELETE:O}){return S==="__typename"?E:O}})},include:m,optimistic:!1,removeOptimistic:r.removeOptimistic,onQueryUpdated:r.onQueryUpdated||null}).forEach(b=>h.push(b)),r.awaitRefetchQueries||r.onQueryUpdated)return Promise.all(h).then(()=>d)}return Promise.resolve(d)}markMutationOptimistic(n,r){const s=typeof n=="function"?n(r.variables,{IGNORE:hv}):n;return s===hv?!1:(this.cache.recordOptimisticTransaction(o=>{try{this.markMutationResult({data:s},r,o)}catch(f){de.error(f)}},this.id),!0)}markSubscriptionResult(n,{document:r,variables:s,errorPolicy:o,cacheWriteBehavior:f}){f!==0&&(hf(n,o)&&this.cache.write({query:r,result:n.data,dataId:"ROOT_SUBSCRIPTION",variables:s}),this.queryManager.broadcastQueries())}}function hf(i,n="none"){const r=n==="ignore"||n==="all";let s=!Ii(i);return!s&&r&&i.data&&(s=!0),s}class uO{defaultOptions;client;clientOptions;assumeImmutableResults;documentTransform;ssrMode;defaultContext;dataMasking;incrementalHandler;localState;queryDeduplication;prioritizeCacheValues=!1;onBroadcast;mutationStore;obsQueries=new Set;fetchCancelFns=new Map;constructor(n){const r=new Fn(o=>this.cache.transformDocument(o),{cache:!1});this.client=n.client,this.defaultOptions=n.defaultOptions,this.queryDeduplication=n.queryDeduplication,this.clientOptions=n.clientOptions,this.ssrMode=n.ssrMode,this.assumeImmutableResults=n.assumeImmutableResults,this.dataMasking=n.dataMasking,this.localState=n.localState,this.incrementalHandler=n.incrementalHandler;const s=n.documentTransform;this.documentTransform=s?r.concat(s).concat(r):r,this.defaultContext=n.defaultContext||{},(this.onBroadcast=n.onBroadcast)&&(this.mutationStore={})}get link(){return this.client.link}get cache(){return this.client.cache}stop(){this.obsQueries.forEach(n=>n.stop()),this.cancelPendingFetches(tn(84))}cancelPendingFetches(n){this.fetchCancelFns.forEach(r=>r(n)),this.fetchCancelFns.clear()}async mutate({mutation:n,variables:r,optimisticResponse:s,updateQueries:o,refetchQueries:f=[],awaitRefetchQueries:d=!1,update:y,onQueryUpdated:m,fetchPolicy:h,errorPolicy:b,keepRootFields:v,context:E}){const S=new df(this);n=this.cache.transformForLink(this.transform(n));const{hasClientExports:O}=this.getDocumentInfo(n);r=this.getVariables(n,r),O&&(r=await this.localState.getExportedVariables({client:this.client,document:n,variables:r,context:E}));const N=this.mutationStore&&(this.mutationStore[S.id]={mutation:n,variables:r,loading:!0,error:null}),M=s&&S.markMutationOptimistic(s,{document:n,variables:r,cacheWriteBehavior:h==="no-cache"?0:2,errorPolicy:b,context:E,updateQueries:o,update:y,keepRootFields:v});return this.broadcastQueries(),new Promise((D,U)=>{const Y={};return this.getObservableFromLink(n,{...E,optimisticResponse:M?s:void 0},r,{},!1).observable.pipe(yv(),ni(X=>{const K={...X};return Xn(S.markMutationResult(K,{document:n,variables:r,cacheWriteBehavior:h==="no-cache"?0:2,errorPolicy:b,context:E,update:y,updateQueries:o,awaitRefetchQueries:d,refetchQueries:f,removeOptimistic:M?S.id:void 0,onQueryUpdated:m,keepRootFields:v}))})).pipe(ti(X=>{if(Ii(X)&&b==="none")throw new Tn(X);return N&&(N.loading=!1,N.error=null),X})).subscribe({next:X=>{if(this.broadcastQueries(),!S.hasNext){const K={data:this.maskOperation({document:n,data:X.data,fetchPolicy:h,cause:Y})};Ii(X)&&(K.error=new Tn(X)),Object.keys(X.extensions||{}).length&&(K.extensions=X.extensions),D(K)}},error:X=>{if(N&&(N.loading=!1,N.error=X),M&&this.cache.removeOptimistic(S.id),this.broadcastQueries(),b==="ignore")return D({data:void 0});if(b==="all")return D({data:void 0,error:X});U(X)}})})}fetchQuery(n,r){return Aa(n.query,ei.QUERY),(async()=>RE(this.fetchObservableWithInfo(n,{networkStatus:r}).observable.pipe(Rf(s=>{switch(s.kind){case"E":throw s.error;case"N":if(s.source!=="newNetworkStatus")return uu(s.value)}})),{defaultValue:{data:void 0}}))()}transform(n){return this.documentTransform.transformDocument(n)}transformCache=new ed(Zn["queryManager.getDocumentInfo"]||2e3);getDocumentInfo(n){const{transformCache:r}=this;if(!r.has(n)){const o=Jn(n),f={hasClientExports:vl(["client","export"],n,!0),hasForcedResolvers:sT(n),hasNonreactiveDirective:vl(["nonreactive"],n),hasIncrementalDirective:vl(["defer"],n),nonReactiveQuery:oO(n),clientQuery:vl(["client"],n)?n:null,serverQuery:fT([{name:"client",remove:!0},{name:"connection"},{name:"nonreactive"},{name:"unmask"}],n),operationType:o?.operation,defaultVars:td(o),asQuery:{...n,definitions:n.definitions.map(d=>d.kind==="OperationDefinition"&&d.operation!=="query"?{...d,operation:"query"}:d)}};r.set(n,f)}const s=r.get(n);if(s.violation)throw s.violation;return s}getVariables(n,r){const s=this.getDocumentInfo(n).defaultVars,o=Object.entries(r??{}).map(([f,d])=>[f,d===void 0?s[f]:d]);return{...s,...Object.fromEntries(o)}}watchQuery(n){Aa(n.query,ei.QUERY);const r=this.transform(n.query);return n={...n,variables:this.getVariables(r,n.variables)},typeof n.notifyOnNetworkStatusChange>"u"&&(n.notifyOnNetworkStatusChange=!0),new cf({queryManager:this,options:n,transformedQuery:r})}query(n){const r=this.transform(n.query);return this.fetchQuery({...n,query:r}).then(s=>({...s,data:this.maskOperation({document:r,data:s?.data,fetchPolicy:n.fetchPolicy})}))}requestIdCounter=1;generateRequestId(){return this.requestIdCounter++}clearStore(n={discardWatches:!0}){return this.cancelPendingFetches(tn(86)),this.obsQueries.forEach(r=>{r.reset()}),this.mutationStore&&(this.mutationStore={}),this.cache.reset(n)}getObservableQueries(n="active"){const r=new Set,s=new Map,o=new Map,f=new Set;return Array.isArray(n)&&n.forEach(d=>{if(typeof d=="string")s.set(d,d),o.set(d,!1);else if(uT(d)){const y=tr(this.transform(d));s.set(y,sr(d)),o.set(y,!1)}else jt(d)&&d.query&&f.add(d)}),this.obsQueries.forEach(d=>{const y=tr(this.transform(d.options.query));if(n==="all"){r.add(d);return}const{queryName:m,options:{fetchPolicy:h}}=d;n==="active"&&h==="standby"||(n==="active"||m&&o.has(m)||y&&o.has(y))&&(r.add(d),m&&o.set(m,!0),y&&o.set(y,!0))}),f.size&&f.forEach(d=>{const y=new cf({queryManager:this,options:{...d,fetchPolicy:"network-only"}});r.add(y)}),r}refetchObservableQueries(n=!1){const r=[];return this.getObservableQueries(n?"all":"active").forEach(s=>{const{fetchPolicy:o}=s.options;(n||o!=="standby")&&o!=="cache-only"&&r.push(s.refetch())}),this.broadcastQueries(),Promise.all(r)}startGraphQLSubscription(n){let{query:r,variables:s}=n;const{fetchPolicy:o,errorPolicy:f="none",context:d={},extensions:y={}}=n;Aa(r,ei.SUBSCRIPTION),r=this.transform(r),s=this.getVariables(r,s);let m;const h=(this.getDocumentInfo(r).hasClientExports?Xn(this.localState.getExportedVariables({client:this.client,document:r,variables:s,context:d})):Pa(s)).pipe(ni(b=>{const{observable:v,restart:E}=this.getObservableFromLink(r,d,b,y),S=new df(this);return m=E,v.pipe(ti(O=>{S.markSubscriptionResult(O,{document:r,variables:b,errorPolicy:f,cacheWriteBehavior:o==="no-cache"?0:2});const N={data:O.data??void 0};return Ii(O)?N.error=new Tn(O):Kg(O)&&(N.error=O.extensions[Dl],delete O.extensions[Dl]),O.extensions&&Object.keys(O.extensions).length&&(N.extensions=O.extensions),N.error&&f==="none"&&(N.data=void 0),f==="ignore"&&delete N.error,N}),bl(O=>Pa(f==="ignore"?{data:void 0}:{data:void 0,error:O})),UE(O=>!!(O.data||O.error)))}));return Object.assign(h,{restart:()=>m?.()})}broadcastQueries(){this.onBroadcast&&this.onBroadcast(),this.obsQueries.forEach(n=>n.notify())}inFlightLinkObservables=new In(!1);getObservableFromLink(n,r,s,o,f=r?.queryDeduplication??this.queryDeduplication){let d={};const{serverQuery:y,clientQuery:m,operationType:h,hasIncrementalDirective:b}=this.getDocumentInfo(n),v=sr(n),E={client:this.client};if(y){const{inFlightLinkObservables:S,link:O}=this;try{let M=function(D){return new Fe(U=>{function Y(){return D.subscribe({next:U.next.bind(U),complete:U.complete.bind(U),error:U.error.bind(U)})}let X=Y();return d.restart||=()=>{X.unsubscribe(),X=Y()},()=>{X.unsubscribe(),d.restart=void 0}})};const N=this.incrementalHandler.prepareRequest({query:y,variables:s,context:{...this.defaultContext,...r,queryDeduplication:f},extensions:o});if(r=N.context,f){const D=tr(y),U=Da(s);d=S.lookup(D,U),d.observable||(d.observable=zf(O,N,E).pipe(M,kE(()=>{S.peek(D,U)===d&&S.remove(D,U)}),h===ei.SUBSCRIPTION?yu():LE({refCount:!0})))}else d.observable=zf(O,N,E).pipe(M)}catch(N){d.observable=gg(()=>N)}}else d.observable=Pa({data:{}});if(m){const{operation:S}=Jn(n);de(!b,91,S[0].toUpperCase()+S.slice(1),v??"(anonymous)"),d.observable=d.observable.pipe(ni(O=>Xn(this.localState.execute({client:this.client,document:m,remoteResult:O,context:r,variables:s}))))}return{restart:()=>d.restart?.(),observable:d.observable.pipe(bl(S=>{throw S=Lf(S),lO(S),S}))}}getResultsFromLink(n,{queryInfo:r,cacheWriteBehavior:s,observableQuery:o}){const f=r.lastRequestId=this.generateRequestId(),{errorPolicy:d}=n,y=this.cache.transformForLink(n.query);return this.getObservableFromLink(y,n.context,n.variables).observable.pipe(ti(m=>{const h=r.markQueryResult(m,{...n,document:y,cacheWriteBehavior:s}),b=Ii(h);if(b&&d==="none")throw r.resetLastWrite(),o?.resetNotifications(),new Tn(h);const v={data:h.data,...r.hasNext?{loading:!0,networkStatus:se.streaming,dataState:"streaming",partial:!0}:{dataState:h.data?"complete":"empty",loading:!1,networkStatus:se.ready,partial:!h.data}};return b&&(d==="none"&&(v.data=void 0,v.dataState="empty"),d!=="ignore"&&(v.error=new Tn(h),v.dataState!=="streaming"&&(v.networkStatus=se.error))),v}),bl(m=>{if(f>=r.lastRequestId&&d==="none")throw r.resetLastWrite(),o?.resetNotifications(),m;const h={data:void 0,dataState:"empty",loading:!1,networkStatus:se.ready,partial:!0};return d!=="ignore"&&(h.error=m,h.networkStatus=se.error),Pa(h)}))}fetchObservableWithInfo(n,{networkStatus:r=se.loading,query:s=n.query,fetchQueryOperator:o=y=>y,onCacheHit:f=()=>{},observableQuery:d}){const y=this.getVariables(s,n.variables),m=this.defaultOptions.watchQuery;let{fetchPolicy:h=m&&m.fetchPolicy||"cache-first",errorPolicy:b=m&&m.errorPolicy||"none",returnPartialData:v=!1,notifyOnNetworkStatusChange:E=!0,context:S={}}=n;this.prioritizeCacheValues&&(h==="network-only"||h==="cache-and-network")&&(h="cache-first");const O=Object.assign({},n,{query:s,variables:y,fetchPolicy:h,errorPolicy:b,returnPartialData:v,notifyOnNetworkStatusChange:E,context:S}),N=new df(this,d),M=K=>{O.variables=K;const ee=h==="no-cache"?0:r===se.refetch&&O.refetchWritePolicy!=="merge"?1:2,$=this.fetchQueryByPolicy(O,{queryInfo:N,cacheWriteBehavior:ee,onCacheHit:f,observableQuery:d});return $.observable=$.observable.pipe(o),O.fetchPolicy!=="standby"&&d?.applyNextFetchPolicy("after-fetch",n),$},D=()=>{this.fetchCancelFns.delete(N.id)};this.fetchCancelFns.set(N.id,K=>{U.next({kind:"E",error:K,source:"network"})});const U=new fr;let Y,X;if(this.getDocumentInfo(O.query).hasClientExports)Y=Xn(this.localState.getExportedVariables({client:this.client,document:O.query,variables:O.variables,context:O.context})).pipe(ni(K=>M(K).observable)),X=!0;else{const K=M(O.variables);X=K.fromLink,Y=K.observable}return{observable:new Fe(K=>{K.add(D),Y.subscribe(K),U.subscribe(K)}).pipe(yu()),fromLink:X}}refetchQueries({updateCache:n,include:r,optimistic:s=!1,removeOptimistic:o=s?Jv("refetchQueries"):void 0,onQueryUpdated:f}){const d=new Map;r&&this.getObservableQueries(r).forEach(m=>{if(m.options.fetchPolicy==="cache-only"||m.variablesUnknown)return;const h=m.getCurrentResult();d.set(m,{oq:m,lastDiff:{result:h?.data,complete:!h?.partial}})});const y=new Map;if(n){const m=new Set;this.cache.batch({update:n,optimistic:s&&o||!1,removeOptimistic:o,onWatchUpdated(h,b,v){const E=h.watcher;if(E instanceof cf&&!m.has(E)){if(m.add(E),f){d.delete(E);let S=f(E,b,v);return S===!0&&(S=E.refetch().retain()),S!==!1&&y.set(E,S),S}f!==null&&E.options.fetchPolicy!=="cache-only"&&d.set(E,{oq:E,lastDiff:v,diff:b})}}})}return d.size&&d.forEach(({oq:m,lastDiff:h,diff:b})=>{let v;f&&(b||(b=m.getCacheDiff()),v=f(m,b,h)),(!f||v===!0)&&(v=m.refetch().retain()),v!==!1&&y.set(m,v)}),o&&this.cache.removeOptimistic(o),y}noCacheWarningsByCause=new WeakSet;maskOperation(n){const{document:r,data:s}=n;return this.dataMasking?JT(s,r,this.cache):s}maskFragment(n){const{data:r,fragment:s,fragmentName:o}=n;return this.dataMasking?ZT(r,s,this.cache,o):r}fetchQueryByPolicy({query:n,variables:r,fetchPolicy:s,errorPolicy:o,returnPartialData:f,context:d},{cacheWriteBehavior:y,onCacheHit:m,queryInfo:h,observableQuery:b}){const v=()=>this.cache.diff({query:n,variables:r,returnPartialData:!0,optimistic:!0}),E=(O,N)=>{const M=O.result,D=Y=>(!O.complete&&!f&&(Y=void 0),{data:Y,dataState:O.complete?"complete":Y?"partial":"empty",loading:Nf(N),networkStatus:N,partial:!O.complete}),U=Y=>Pa({kind:"N",value:D(Y),source:"cache"});return(O.complete||f)&&this.getDocumentInfo(n).hasForcedResolvers?(m(),Xn(this.localState.execute({client:this.client,document:n,remoteResult:M?{data:M}:void 0,context:d,variables:r,onlyRunForcedResolvers:!0,returnPartialData:!0}).then(Y=>({kind:"N",value:D(Y.data||void 0),source:"cache"})))):o==="none"&&N===se.refetch&&O.missing?U(void 0):U(M||void 0)},S=()=>this.getResultsFromLink({query:n,variables:r,context:d,fetchPolicy:s,errorPolicy:o},{cacheWriteBehavior:y,queryInfo:h,observableQuery:b}).pipe(yv(),qE(),ti(O=>({...O,source:"network"})));switch(s){default:case"cache-first":{const O=v();return O.complete?{fromLink:!1,observable:E(O,se.ready)}:f?{fromLink:!0,observable:Wc(E(O,se.loading),S())}:{fromLink:!0,observable:S()}}case"cache-and-network":{const O=v();return O.complete||f?{fromLink:!0,observable:Wc(E(O,se.loading),S())}:{fromLink:!0,observable:S()}}case"cache-only":return{fromLink:!1,observable:Wc(E(v(),se.ready))};case"network-only":return{fromLink:!0,observable:S()};case"no-cache":return{fromLink:!0,observable:S()};case"standby":return{fromLink:!1,observable:mu}}}}function yv(){let i=!1;return pu({next(){i=!0},complete(){de(i,95)}})}function oO(i){return On(i,{FragmentSpread:n=>{if(!n.directives?.some(r=>r.name.value==="unmask"))return{...n,directives:[...n.directives||[],{kind:Te.DIRECTIVE,name:{kind:Te.NAME,value:"nonreactive"}}]}}})}class cO{link;cache;disableNetworkFetches;set prioritizeCacheValues(n){this.queryManager.prioritizeCacheValues=n}get prioritizeCacheValues(){return this.queryManager.prioritizeCacheValues}version;queryDeduplication;defaultOptions;devtoolsConfig;queryManager;devToolsHookCb;resetStoreCallbacks=[];clearStoreCallbacks=[];constructor(n){const{cache:r,documentTransform:s,ssrMode:o=!1,ssrForceFetchDelay:f=0,queryDeduplication:d=!0,defaultOptions:y,defaultContext:m,assumeImmutableResults:h=r.assumeImmutableResults,localState:b,devtools:v,dataMasking:E,link:S,incrementalHandler:O=new ST}=n;this.link=S,this.cache=r,this.queryDeduplication=d,this.defaultOptions=y||{},this.devtoolsConfig={...v,enabled:v?.enabled??Zv},this.watchQuery=this.watchQuery.bind(this),this.query=this.query.bind(this),this.mutate=this.mutate.bind(this),this.watchFragment=this.watchFragment.bind(this),this.resetStore=this.resetStore.bind(this),this.reFetchObservableQueries=this.refetchObservableQueries=this.refetchObservableQueries.bind(this),this.version=Ff,this.queryManager=new uO({client:this,defaultOptions:this.defaultOptions,defaultContext:m,documentTransform:s,queryDeduplication:d,ssrMode:o,dataMasking:!!E,clientOptions:n,incrementalHandler:O,assumeImmutableResults:h,onBroadcast:this.devtoolsConfig.enabled?()=>{this.devToolsHookCb&&this.devToolsHookCb()}:void 0,localState:b}),this.prioritizeCacheValues=o||f>0,f&&setTimeout(()=>{this.prioritizeCacheValues=!1},f),this.devtoolsConfig.enabled&&this.connectToDevTools()}connectToDevTools(){if(typeof window>"u")return;const n=window,r=Symbol.for("apollo.devtools");(n[r]=n[r]||[]).push(this),n.__APOLLO_CLIENT__=this}get documentTransform(){return this.queryManager.documentTransform}get localState(){return this.queryManager.localState}set localState(n){this.queryManager.localState=n}stop(){this.queryManager.stop()}watchQuery(n){return this.defaultOptions.watchQuery&&(n=tf(this.defaultOptions.watchQuery,n)),this.queryManager.watchQuery(n)}query(n){return this.defaultOptions.query&&(n=tf(this.defaultOptions.query,n)),this.queryManager.query(n)}mutate(n){const r=tf(en({fetchPolicy:"network-only",errorPolicy:"none"},this.defaultOptions.mutate),n);return Aa(r.mutation,ei.MUTATION),this.queryManager.mutate(r)}subscribe(n){const r={},s=this.queryManager.startGraphQLSubscription(n),o=s.pipe(ti(f=>({...f,data:this.queryManager.maskOperation({document:n.query,data:f.data,fetchPolicy:n.fetchPolicy,cause:r})})));return Object.assign(o,{restart:s.restart})}readQuery(n,r=!1){return this.cache.readQuery({...n,query:this.transform(n.query)},r)}watchFragment(n){const r=this.queryManager.dataMasking;return this.cache.watchFragment({...n,fragment:this.transform(n.fragment,r)}).pipe(ti(s=>s))}readFragment(n,r=!1){return this.cache.readFragment({...n,fragment:this.transform(n.fragment)},r)}writeQuery(n){const r=this.cache.writeQuery(n);return n.broadcast!==!1&&this.queryManager.broadcastQueries(),r}writeFragment(n){const r=this.cache.writeFragment(n);return n.broadcast!==!1&&this.queryManager.broadcastQueries(),r}__actionHookForDevTools(n){this.devToolsHookCb=n}__requestRaw(n){return zf(this.link,n,{client:this})}resetStore(){return Promise.resolve().then(()=>this.queryManager.clearStore({discardWatches:!1})).then(()=>Promise.all(this.resetStoreCallbacks.map(n=>n()))).then(()=>this.refetchObservableQueries())}clearStore(){return Promise.resolve().then(()=>this.queryManager.clearStore({discardWatches:!0})).then(()=>Promise.all(this.clearStoreCallbacks.map(n=>n())))}onResetStore(n){return this.resetStoreCallbacks.push(n),()=>{this.resetStoreCallbacks=this.resetStoreCallbacks.filter(r=>r!==n)}}onClearStore(n){return this.clearStoreCallbacks.push(n),()=>{this.clearStoreCallbacks=this.clearStoreCallbacks.filter(r=>r!==n)}}reFetchObservableQueries;refetchObservableQueries(n){return this.queryManager.refetchObservableQueries(n)}refetchQueries(n){const r=this.queryManager.refetchQueries(n),s=[],o=[];r.forEach((d,y)=>{s.push(y),o.push(d)});const f=Promise.all(o);return f.queries=s,f.results=o,f.catch(d=>{}),f}getObservableQueries(n="active"){return this.queryManager.getObservableQueries(n)}extract(n){return this.cache.extract(n)}restore(n){return this.cache.restore(n)}setLink(n){this.link=n}get defaultContext(){return this.queryManager.defaultContext}maskedFragmentTransform=new Fn(mT);transform(n,r=!1){const s=this.queryManager.transform(n);return r?this.maskedFragmentTransform.transformDocument(s):s}}const{hasOwnProperty:pv}=Object.prototype;function fO(i){return jt(i)&&"payload"in i}async function*dO(i){const n=new TextDecoder("utf-8"),s=i.headers?.get("content-type")?.match(/;\s*boundary=(?:'([^']+)'|"([^"]+)"|([^"'].+?))\s*(?:;|$)/i),o=`\r
--`+(s?s[1]??s[2]??s[3]??"-":"-");let f="";de(i.body&&typeof i.body.getReader=="function",60);const y=i.body.getReader();let m=!1,h=!1,b;const v=()=>h&&f[0]=="-"&&f[1]=="-";try{for(;!m;){({value:b,done:m}=await y.read());const E=typeof b=="string"?b:n.decode(b),S=f.length-o.length+1;f+=E;let O=f.indexOf(o,S);for(;O>-1&&!v();){h=!0;let N;[N,f]=[f.slice(0,O),f.slice(O+o.length)];const M=N.indexOf(`\r
\r
`),U=mO(N.slice(0,M))["content-type"];if(U&&U.toLowerCase().indexOf("application/json")===-1)throw new Error("Unsupported patch content type: application/json is required.");const Y=N.slice(M);Y&&(yield Y),O=f.indexOf(o)}if(v())return}throw new Error("premature end of multipart body")}finally{y.cancel()}}async function hO(i,n){for await(const r of dO(i)){const s=Ig(i,r);if(Object.keys(s).length!=0)if(fO(s)){if(Object.keys(s).length===1&&s.payload===null)return;let o={...s.payload};"errors"in s&&(o.extensions={...o.extensions,[Dl]:new Al(s.errors??[])}),n(o)}else n(s)}}function mO(i){const n={};return i.split(`
`).forEach(r=>{const s=r.indexOf(":");if(s>-1){const o=r.slice(0,s).trim().toLowerCase(),f=r.slice(s+1).trim();n[o]=f}}),n}function Ig(i,n){if(i.status>=300)throw new Mu(`Response not successful: Received status code ${i.status}`,{response:i,bodyText:n});try{return JSON.parse(n)}catch(r){throw new Cu(r,{response:i,bodyText:n})}}function yO(i,n){try{return JSON.parse(n)}catch(r){throw new Cu(r,{response:i,bodyText:n})}}function pO(i,n){return i.headers.get("content-type")?.includes("application/graphql-response+json")?yO(i,n):Ig(i,n)}function vO(i){return n=>n.text().then(r=>{const s=pO(n,r);if(!Array.isArray(s)&&!pv.call(s,"data")&&!pv.call(s,"errors"))throw new Mu(`Server response was malformed for query '${Array.isArray(i)?i.map(o=>o.operationName):i.operationName}'.`,{response:n,bodyText:r});return s})}const gO={includeQuery:!0,includeExtensions:!0,preserveHeaderCase:!1},bO={accept:"application/graphql-response+json,application/json;q=0.9","content-type":"application/json"},SO={method:"POST"},EO={http:gO,headers:bO,options:SO},TO=(i,n)=>n(i);function OO(i,n,...r){let s={},o={};r.forEach(b=>{s={...s,...b.options,headers:{...s.headers,...b.headers}},b.credentials&&(s.credentials=b.credentials),s.headers.accept=(b.http?.accept||[]).concat(s.headers.accept).join(","),o={...o,...b.http}}),s.headers=_O(s.headers,o.preserveHeaderCase);const{operationName:f,extensions:d,variables:y,query:m}=i,h={operationName:f,variables:y};return o.includeExtensions&&Object.keys(d||{}).length&&(h.extensions=d),o.includeQuery&&(h.query=n(m,tr)),{options:s,body:h}}function _O(i,n){if(!n){const o={};return Object.keys(Object(i)).forEach(f=>{o[f.toLowerCase()]=i[f]}),o}const r={};Object.keys(Object(i)).forEach(o=>{r[o.toLowerCase()]={originalName:o,value:i[o]}});const s={};return Object.keys(r).forEach(o=>{s[r[o].originalName]=r[o].value}),s}const wO=(i,n)=>{const s=i.getContext().uri;return s||(typeof n=="function"?n(i):n||"/graphql")};function AO(i,n){const r=[],s=(h,b)=>{r.push(`${h}=${encodeURIComponent(b)}`)};if("query"in n&&s("query",n.query),n.operationName&&s("operationName",n.operationName),n.variables){let h;try{h=JSON.stringify(n.variables)}catch(b){return{parseError:b}}s("variables",h)}if(n.extensions){let h;try{h=JSON.stringify(n.extensions)}catch(b){return{parseError:b}}s("extensions",h)}let o="",f=i;const d=i.indexOf("#");d!==-1&&(o=i.substr(d),f=i.substr(0,d));const y=f.indexOf("?")===-1?"?":"&";return{newURI:f+y+r.join("&")+o}}const DO=wa(()=>fetch);function MO(){}class CO extends gt{constructor(n={}){let{uri:r="/graphql",fetch:s,print:o=TO,includeExtensions:f,preserveHeaderCase:d,useGETForQueries:y,includeUnusedVariables:m=!1,...h}=n;const b={http:en({includeExtensions:f,preserveHeaderCase:d}),options:h.fetchOptions,credentials:h.credentials,headers:h.headers};super(v=>{let E=wO(v,r);const S=v.getContext(),O={...S.http};kT(v.query)&&(O.accept=["multipart/mixed;boundary=graphql;subscriptionSpec=1.0",...O.accept||[]]);const N={http:O,options:S.fetchOptions,credentials:S.credentials,headers:S.headers},{options:M,body:D}=OO(v,o,EO,b,N);D.variables&&!m&&(D.variables=TT(D.variables,v.query));let U=new AbortController,Y=()=>{U=void 0};if(M.signal){const X=M.signal,K=()=>{U?.abort(X.reason)};X.addEventListener("abort",K,{once:!0}),Y=()=>{U?.signal.removeEventListener("abort",Y),U=void 0,X.removeEventListener("abort",K),Y=MO},U.signal.addEventListener("abort",Y,{once:!0})}return M.signal=U.signal,y&&!UT(v.query)&&(M.method="GET"),new Fe(X=>{if(M.method==="GET"){const{newURI:$,parseError:we}=AO(E,D);if(we)throw we;E=$}else M.body=JSON.stringify(D);const K=s||wa(()=>fetch)||DO,ee=X.next.bind(X);return K(E,M).then($=>{v.setContext({response:$});const we=$.headers?.get("content-type");return we!==null&&/^multipart\/mixed/i.test(we)?hO($,ee):vO(v)($).then(ee)}).then(()=>{Y(),X.complete()}).catch($=>{Y(),X.error($)}),()=>{U&&U.abort()}})})}}class xO extends gt{constructor(n={}){super((r,s)=>{const o=r.client,f=o.queryManager.clientOptions,d=r.getContext();{const{name:y,version:m,transport:h="headers"}=en({},f.clientAwareness,n.clientAwareness,d.clientAwareness);h==="headers"&&r.setContext(({headers:b,extensions:v})=>({headers:en({"apollographql-client-name":y,"apollographql-client-version":m},b)}))}{const{transport:y="extensions"}=en({},f.enhancedClientAwareness,n.enhancedClientAwareness);y==="extensions"&&(r.extensions=en({clientLibrary:{name:"@apollo/client",version:o.version}},r.extensions))}return s(r)})}}class RO extends gt{constructor(n={}){const{left:r,right:s,request:o}=gt.from([new xO(n),new CO(n)]);super(o),Object.assign(this,{left:r,right:s})}}const vv=i=>{let n;const r=new Set,s=(h,b)=>{const v=typeof h=="function"?h(n):h;if(!Object.is(v,n)){const E=n;n=b??(typeof v!="object"||v===null)?v:Object.assign({},n,v),r.forEach(S=>S(n,E))}},o=()=>n,y={setState:s,getState:o,getInitialState:()=>m,subscribe:h=>(r.add(h),()=>r.delete(h))},m=n=i(s,o,y);return y},zO=(i=>i?vv(i):vv),NO=i=>i;function jO(i,n=NO){const r=B.useSyncExternalStore(i.subscribe,B.useCallback(()=>n(i.getState()),[i,n]),B.useCallback(()=>n(i.getInitialState()),[i,n]));return B.useDebugValue(r),r}const gv=i=>{const n=zO(i),r=s=>jO(n,s);return Object.assign(r,n),r},UO=(i=>i?gv(i):gv);var kO=(i=>(i.Popup="popup",i.Redirect="redirect",i))(kO||{}),dl="vuer_token",mf="vuer_callback_url";function qO(i,n){return async(r,s)=>{try{const o=await fetch(new URL(r,i),{...n,...s,headers:{...n?.headers,...s?.headers}}),f=await o.json().catch(()=>null);return o.ok?{data:f,error:null}:{data:null,error:{message:f?.message||o.statusText||`HTTP ${o.status}`,status:o.status,statusText:o.statusText,data:f}}}catch(o){return{data:null,error:{message:o instanceof Error?o.message:"Network error"}}}}}function bv(i){const n="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~",r=new Uint8Array(i);if(typeof crypto>"u"||!crypto.getRandomValues)throw new Error("crypto.getRandomValues is not available. This library requires a browser environment.");return crypto.getRandomValues(r),Array.from(r).map(s=>n[s%n.length]).join("")}async function LO(i){if(typeof crypto>"u"||!crypto.subtle)throw new Error("crypto.subtle is not available. This library requires a secure context (HTTPS).");const r=new TextEncoder().encode(i),s=await crypto.subtle.digest("SHA-256",r),o=Array.from(new Uint8Array(s));return window.btoa(String.fromCharCode(...o)).replace(/\+/g,"-").replace(/\//g,"_").replace(/=/g,"")}var HO=i=>{const s=(window.screen.width-500)/2,o=(window.screen.height-600)/2,f=window.open(i,"vuer-auth-popup",`width=500,height=600,top=${o},left=${s}`);return f?new Promise((d,y)=>{const m=setTimeout(()=>{f?.close(),window.removeEventListener("message",h),y(new Error("Authentication timeout. Please try again."))},3e5),h=v=>{if(v.origin!==window.location.origin){console.warn(`Rejected message from untrusted origin: ${v.origin}`);return}if(v.data.type==="AUTH_TOKEN"){clearTimeout(m);const E=v.data.token;d(E),f?.close(),window.removeEventListener("message",h)}else v.data.type==="AUTH_ERROR"&&(clearTimeout(m),f?.close(),window.removeEventListener("message",h),y(new Error(v.data.error||"Failed to retrieve token")))};window.addEventListener("message",h);const b=setInterval(()=>{f.closed&&(clearInterval(b),clearTimeout(m),window.removeEventListener("message",h),y(new Error("Authentication cancelled by user")))},1e3)}):Promise.reject(new Error("Failed to open popup window. Please allow popups for this site."))},BO=class{config;$fetch;authToken=null;constructor(i={}){this.config={baseURL:i.baseURL??"/",clientId:i.clientId||"",redirectUri:i.redirectUri??"/",fetchOptions:i.fetchOptions||{}},this.$fetch=qO(this.config.baseURL,this.config.fetchOptions)}get token(){if(!this.authToken)try{const i=localStorage.getItem(dl);this.authToken=i?JSON.parse(i):null}catch(i){console.error("Failed to parse stored token:",i),localStorage.removeItem(dl),this.authToken=null}return this.authToken}set token(i){if(this.authToken=i,i)try{localStorage.setItem(dl,JSON.stringify(i))}catch(n){console.error("Failed to store token in localStorage:",n)}else localStorage.removeItem(dl)}async signIn(i){try{const n=bv(32),r=bv(64),s=await LO(r);sessionStorage.setItem("pkce_state",n),sessionStorage.setItem("pkce_verifier",r),sessionStorage.setItem(mf,i?.callbackUrl??"");const o=new URLSearchParams([["state",n],["response_type","code"],["code_challenge_method","S256"],["code_challenge",s],["redirect_uri",`${window.location.origin}${this.config.redirectUri}`],["scope","openid profile email offline_access"],["client_id",this.config.clientId]]),f=`${this.config.baseURL}/api/auth/oauth2/authorize?${o.toString()}`;return i.authMode==="popup"?await HO(f):(window.location.href=f,null)}catch(n){throw console.error("Sign in failed:",n),n instanceof Error?n:new Error("Sign in failed")}}async getToken(i,n){const r=sessionStorage.getItem("pkce_state"),s=sessionStorage.getItem("pkce_verifier"),o=sessionStorage.getItem(mf);if(!r)throw new Error("Missing PKCE state. Please restart the authentication flow.");if(n!==r)throw new Error("Invalid OAuth state: state parameter does not match. Possible CSRF attack.");if(!s)throw new Error("Missing PKCE verifier. Please restart the authentication flow.");const{data:f,error:d}=await this.$fetch("/api/auth/oauth2/token",{method:"POST",headers:{"Content-Type":"application/x-www-form-urlencoded"},body:new URLSearchParams({client_id:this.config.clientId,redirect_uri:`${window.location.origin}${this.config.redirectUri}`,grant_type:"authorization_code",code_verifier:s,code:i})}),y=!!window.opener||window!==window.parent;if(!d&&f){const m=f.token_type;f.token_type=`${m.charAt(0).toUpperCase()}${m.slice(1)}`,this.token=f,sessionStorage.removeItem("pkce_state"),sessionStorage.removeItem("pkce_verifier"),y?window.opener.postMessage({type:"AUTH_TOKEN",token:f},window.location.origin):o&&(window.location.href=o)}else{const m=d?.message||"Failed to retrieve token";if(console.error("Token exchange failed:",m),y)window.opener.postMessage({type:"AUTH_ERROR",error:m},window.location.origin);else throw new Error(`Token exchange failed: ${m}`)}}async refreshToken(){if(!this.token?.refresh_token)throw new Error("No refresh token available. Please sign in again.");const{data:i,error:n}=await this.$fetch("/api/auth/oauth2/token",{method:"POST",headers:{"Content-Type":"application/x-www-form-urlencoded"},body:new URLSearchParams([["grant_type","refresh_token"],["refresh_token",this.token.refresh_token],["client_id",this.config.clientId]])});if(n)return console.error("Token refresh failed:",n.message),this.token=null,null;if(i){const r=i.token_type;return i.token_type=`${r.charAt(0).toUpperCase()}${r.slice(1)}`,this.token=i,i}return null}signOut(i){try{localStorage.removeItem(dl),sessionStorage.removeItem("pkce_state"),sessionStorage.removeItem("pkce_verifier"),sessionStorage.removeItem(mf),this.authToken=null}catch(n){console.error("Error during sign out:",n)}finally{window.location.href=i??"/"}}async getUserinfo(){if(!this.token?.access_token)throw new Error("No access token available. Please sign in first.");const{data:i,error:n}=await this.$fetch("/api/auth/oauth2/userinfo",{headers:{authorization:`${this.token.token_type} ${this.token.access_token}`}});if(n)throw n.status===401&&(console.warn("Access token expired or invalid"),this.token=null),new Error(`Failed to get user info: ${n.message}`);return i}getConfig(){return this.config}authFetch(i,n){if(!this.token?.access_token)throw new Error("No access token available. Please sign in first.");return fetch(new URL(i,this.config.baseURL),{...this.config.fetchOptions,...n,headers:{...this.config.fetchOptions?.headers,authorization:`${this.token.token_type} ${this.token.access_token}`,...n?.headers}})}},Sv={data:null,isPending:!0,isRefetching:!1,error:null},VO=()=>UO(i=>({...Sv,setUser:n=>i({data:n,isPending:!1,isRefetching:!1,error:null}),setLoading:n=>i({isPending:n}),setRefetching:n=>i({isRefetching:n}),setError:n=>i({error:n,isPending:!1,isRefetching:!1}),reset:()=>i(Sv)}));function QO(i){const n=new BO(i),r=VO();return{signIn:o=>n.signIn(o),signOut:o=>n.signOut(o),getToken:(o,f)=>n.getToken(o,f),getUserinfo:()=>n.getUserinfo(),refreshToken:()=>n.refreshToken(),token:()=>n.token,$fetch:(o,f)=>n.authFetch(o,f),$store:r}}function YO(i){return function(r){const s=r?.query?.enabled!==!1,o=i.$store(S=>S.data),f=i.$store(S=>S.isPending),d=i.$store(S=>S.isRefetching),y=i.$store(S=>S.error),m=i.$store(S=>S.setUser),h=i.$store(S=>S.setLoading),b=i.$store(S=>S.setRefetching),v=i.$store(S=>S.setError);be.useEffect(()=>{if(!s)return;(async()=>{try{h(!0);const O=await i.getUserinfo();m(O)}catch(O){const N=O instanceof Error?O:new Error("Failed to fetch user info");console.error("Failed to fetch user info:",N),v(N)}finally{h(!1)}})()},[s,h,m,v]);const E=be.useCallback(async()=>{try{b(!0),v(null);const S=await i.getUserinfo();m(S)}catch(S){const O=S instanceof Error?S:new Error("Failed to refetch user info");console.error("Failed to refetch user info:",O),v(O)}finally{b(!1)}},[b,m,v]);return{data:o,isPending:f,isRefetching:d,error:y,refetch:E}}}function GO(i){return function(){const r=i.$store(o=>o.data),s=i.$store(o=>o.isPending);return{user:r,isAuthenticated:!!r,isPending:s,signIn:i.signIn,signOut:i.signOut}}}function XO(i){const n=QO(i),r=YO(n),s=GO(n);return{...n,useUserinfo:r,useAuth:s}}const $g=XO({baseURL:"https://staging-auth.vuer.ai/api/auth",clientId:"WekknTvzzlJgHsXjjocGqhsxcbuOCeAa",redirectUri:"/sign-in"});var yf,Ev;function FO(){if(Ev)return yf;Ev=1;var i=typeof Element<"u",n=typeof Map=="function",r=typeof Set=="function",s=typeof ArrayBuffer=="function"&&!!ArrayBuffer.isView;function o(f,d){if(f===d)return!0;if(f&&d&&typeof f=="object"&&typeof d=="object"){if(f.constructor!==d.constructor)return!1;var y,m,h;if(Array.isArray(f)){if(y=f.length,y!=d.length)return!1;for(m=y;m--!==0;)if(!o(f[m],d[m]))return!1;return!0}var b;if(n&&f instanceof Map&&d instanceof Map){if(f.size!==d.size)return!1;for(b=f.entries();!(m=b.next()).done;)if(!d.has(m.value[0]))return!1;for(b=f.entries();!(m=b.next()).done;)if(!o(m.value[1],d.get(m.value[0])))return!1;return!0}if(r&&f instanceof Set&&d instanceof Set){if(f.size!==d.size)return!1;for(b=f.entries();!(m=b.next()).done;)if(!d.has(m.value[0]))return!1;return!0}if(s&&ArrayBuffer.isView(f)&&ArrayBuffer.isView(d)){if(y=f.length,y!=d.length)return!1;for(m=y;m--!==0;)if(f[m]!==d[m])return!1;return!0}if(f.constructor===RegExp)return f.source===d.source&&f.flags===d.flags;if(f.valueOf!==Object.prototype.valueOf&&typeof f.valueOf=="function"&&typeof d.valueOf=="function")return f.valueOf()===d.valueOf();if(f.toString!==Object.prototype.toString&&typeof f.toString=="function"&&typeof d.toString=="function")return f.toString()===d.toString();if(h=Object.keys(f),y=h.length,y!==Object.keys(d).length)return!1;for(m=y;m--!==0;)if(!Object.prototype.hasOwnProperty.call(d,h[m]))return!1;if(i&&f instanceof Element)return!1;for(m=y;m--!==0;)if(!((h[m]==="_owner"||h[m]==="__v"||h[m]==="__o")&&f.$$typeof)&&!o(f[h[m]],d[h[m]]))return!1;return!0}return f!==f&&d!==d}return yf=function(d,y){try{return o(d,y)}catch(m){if((m.message||"").match(/stack|recursion/i))return console.warn("react-fast-compare cannot handle circular refs"),!1;throw m}},yf}var ZO=FO();const JO=ii(ZO);var pf,Tv;function KO(){if(Tv)return pf;Tv=1;var i=function(n,r,s,o,f,d,y,m){if(!n){var h;if(r===void 0)h=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var b=[s,o,f,d,y,m],v=0;h=new Error(r.replace(/%s/g,function(){return b[v++]})),h.name="Invariant Violation"}throw h.framesToPop=1,h}};return pf=i,pf}var IO=KO();const Ov=ii(IO);var vf,_v;function $O(){return _v||(_v=1,vf=function(n,r,s,o){var f=s?s.call(o,n,r):void 0;if(f!==void 0)return!!f;if(n===r)return!0;if(typeof n!="object"||!n||typeof r!="object"||!r)return!1;var d=Object.keys(n),y=Object.keys(r);if(d.length!==y.length)return!1;for(var m=Object.prototype.hasOwnProperty.bind(r),h=0;h<d.length;h++){var b=d[h];if(!m(b))return!1;var v=n[b],E=r[b];if(f=s?s.call(o,v,E,b):void 0,f===!1||f===void 0&&v!==E)return!1}return!0}),vf}var WO=$O();const PO=ii(WO);var Wg=(i=>(i.BASE="base",i.BODY="body",i.HEAD="head",i.HTML="html",i.LINK="link",i.META="meta",i.NOSCRIPT="noscript",i.SCRIPT="script",i.STYLE="style",i.TITLE="title",i.FRAGMENT="Symbol(react.fragment)",i))(Wg||{}),gf={link:{rel:["amphtml","canonical","alternate"]},script:{type:["application/ld+json"]},meta:{charset:"",name:["generator","robots","description"],property:["og:type","og:title","og:url","og:image","og:image:alt","og:description","twitter:url","twitter:title","twitter:description","twitter:image","twitter:image:alt","twitter:card","twitter:site"]}},wv=Object.values(Wg),fd={accesskey:"accessKey",charset:"charSet",class:"className",contenteditable:"contentEditable",contextmenu:"contextMenu","http-equiv":"httpEquiv",itemprop:"itemProp",tabindex:"tabIndex"},e_=Object.entries(fd).reduce((i,[n,r])=>(i[r]=n,i),{}),cn="data-rh",ar={DEFAULT_TITLE:"defaultTitle",DEFER:"defer",ENCODE_SPECIAL_CHARACTERS:"encodeSpecialCharacters",ON_CHANGE_CLIENT_STATE:"onChangeClientState",TITLE_TEMPLATE:"titleTemplate",PRIORITIZE_SEO_TAGS:"prioritizeSeoTags"},ir=(i,n)=>{for(let r=i.length-1;r>=0;r-=1){const s=i[r];if(Object.prototype.hasOwnProperty.call(s,n))return s[n]}return null},t_=i=>{let n=ir(i,"title");const r=ir(i,ar.TITLE_TEMPLATE);if(Array.isArray(n)&&(n=n.join("")),r&&n)return r.replace(/%s/g,()=>n);const s=ir(i,ar.DEFAULT_TITLE);return n||s||void 0},n_=i=>ir(i,ar.ON_CHANGE_CLIENT_STATE)||(()=>{}),bf=(i,n)=>n.filter(r=>typeof r[i]<"u").map(r=>r[i]).reduce((r,s)=>({...r,...s}),{}),a_=(i,n)=>n.filter(r=>typeof r.base<"u").map(r=>r.base).reverse().reduce((r,s)=>{if(!r.length){const o=Object.keys(s);for(let f=0;f<o.length;f+=1){const y=o[f].toLowerCase();if(i.indexOf(y)!==-1&&s[y])return r.concat(s)}}return r},[]),i_=i=>console&&typeof console.warn=="function"&&console.warn(i),hl=(i,n,r)=>{const s={};return r.filter(o=>Array.isArray(o[i])?!0:(typeof o[i]<"u"&&i_(`Helmet: ${i} should be of type "Array". Instead found type "${typeof o[i]}"`),!1)).map(o=>o[i]).reverse().reduce((o,f)=>{const d={};f.filter(m=>{let h;const b=Object.keys(m);for(let E=0;E<b.length;E+=1){const S=b[E],O=S.toLowerCase();n.indexOf(O)!==-1&&!(h==="rel"&&m[h].toLowerCase()==="canonical")&&!(O==="rel"&&m[O].toLowerCase()==="stylesheet")&&(h=O),n.indexOf(S)!==-1&&(S==="innerHTML"||S==="cssText"||S==="itemprop")&&(h=S)}if(!h||!m[h])return!1;const v=m[h].toLowerCase();return s[h]||(s[h]={}),d[h]||(d[h]={}),s[h][v]?!1:(d[h][v]=!0,!0)}).reverse().forEach(m=>o.push(m));const y=Object.keys(d);for(let m=0;m<y.length;m+=1){const h=y[m],b={...s[h],...d[h]};s[h]=b}return o},[]).reverse()},r_=(i,n)=>{if(Array.isArray(i)&&i.length){for(let r=0;r<i.length;r+=1)if(i[r][n])return!0}return!1},l_=i=>({baseTag:a_(["href"],i),bodyAttributes:bf("bodyAttributes",i),defer:ir(i,ar.DEFER),encode:ir(i,ar.ENCODE_SPECIAL_CHARACTERS),htmlAttributes:bf("htmlAttributes",i),linkTags:hl("link",["rel","href"],i),metaTags:hl("meta",["name","charset","http-equiv","property","itemprop"],i),noscriptTags:hl("noscript",["innerHTML"],i),onChangeClientState:n_(i),scriptTags:hl("script",["src","innerHTML"],i),styleTags:hl("style",["cssText"],i),title:t_(i),titleAttributes:bf("titleAttributes",i),prioritizeSeoTags:r_(i,ar.PRIORITIZE_SEO_TAGS)}),Pg=i=>Array.isArray(i)?i.join(""):i,s_=(i,n)=>{const r=Object.keys(i);for(let s=0;s<r.length;s+=1)if(n[r[s]]&&n[r[s]].includes(i[r[s]]))return!0;return!1},Sf=(i,n)=>Array.isArray(i)?i.reduce((r,s)=>(s_(s,n)?r.priority.push(s):r.default.push(s),r),{priority:[],default:[]}):{default:i,priority:[]},Av=(i,n)=>({...i,[n]:void 0}),u_=["noscript","script","style"],Hf=(i,n=!0)=>n===!1?String(i):String(i).replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;"),e0=i=>Object.keys(i).reduce((n,r)=>{const s=typeof i[r]<"u"?`${r}="${i[r]}"`:`${r}`;return n?`${n} ${s}`:s},""),o_=(i,n,r,s)=>{const o=e0(r),f=Pg(n);return o?`<${i} ${cn}="true" ${o}>${Hf(f,s)}</${i}>`:`<${i} ${cn}="true">${Hf(f,s)}</${i}>`},c_=(i,n,r=!0)=>n.reduce((s,o)=>{const f=o,d=Object.keys(f).filter(h=>!(h==="innerHTML"||h==="cssText")).reduce((h,b)=>{const v=typeof f[b]>"u"?b:`${b}="${Hf(f[b],r)}"`;return h?`${h} ${v}`:v},""),y=f.innerHTML||f.cssText||"",m=u_.indexOf(i)===-1;return`${s}<${i} ${cn}="true" ${d}${m?"/>":`>${y}</${i}>`}`},""),t0=(i,n={})=>Object.keys(i).reduce((r,s)=>{const o=fd[s];return r[o||s]=i[s],r},n),f_=(i,n,r)=>{const s={key:n,[cn]:!0},o=t0(r,s);return[B.createElement("title",o,n)]},fu=(i,n)=>n.map((r,s)=>{const o={key:s,[cn]:!0};return Object.keys(r).forEach(f=>{const y=fd[f]||f;if(y==="innerHTML"||y==="cssText"){const m=r.innerHTML||r.cssText;o.dangerouslySetInnerHTML={__html:m}}else o[y]=r[f]}),B.createElement(i,o)}),Pt=(i,n,r=!0)=>{switch(i){case"title":return{toComponent:()=>f_(i,n.title,n.titleAttributes),toString:()=>o_(i,n.title,n.titleAttributes,r)};case"bodyAttributes":case"htmlAttributes":return{toComponent:()=>t0(n),toString:()=>e0(n)};default:return{toComponent:()=>fu(i,n),toString:()=>c_(i,n,r)}}},d_=({metaTags:i,linkTags:n,scriptTags:r,encode:s})=>{const o=Sf(i,gf.meta),f=Sf(n,gf.link),d=Sf(r,gf.script);return{priorityMethods:{toComponent:()=>[...fu("meta",o.priority),...fu("link",f.priority),...fu("script",d.priority)],toString:()=>`${Pt("meta",o.priority,s)} ${Pt("link",f.priority,s)} ${Pt("script",d.priority,s)}`},metaTags:o.default,linkTags:f.default,scriptTags:d.default}},h_=i=>{const{baseTag:n,bodyAttributes:r,encode:s=!0,htmlAttributes:o,noscriptTags:f,styleTags:d,title:y="",titleAttributes:m,prioritizeSeoTags:h}=i;let{linkTags:b,metaTags:v,scriptTags:E}=i,S={toComponent:()=>{},toString:()=>""};return h&&({priorityMethods:S,linkTags:b,metaTags:v,scriptTags:E}=d_(i)),{priority:S,base:Pt("base",n,s),bodyAttributes:Pt("bodyAttributes",r,s),htmlAttributes:Pt("htmlAttributes",o,s),link:Pt("link",b,s),meta:Pt("meta",v,s),noscript:Pt("noscript",f,s),script:Pt("script",E,s),style:Pt("style",d,s),title:Pt("title",{title:y,titleAttributes:m},s)}},Bf=h_,Is=[],n0=!!(typeof window<"u"&&window.document&&window.document.createElement),Vf=class{instances=[];canUseDOM=n0;context;value={setHelmet:i=>{this.context.helmet=i},helmetInstances:{get:()=>this.canUseDOM?Is:this.instances,add:i=>{(this.canUseDOM?Is:this.instances).push(i)},remove:i=>{const n=(this.canUseDOM?Is:this.instances).indexOf(i);(this.canUseDOM?Is:this.instances).splice(n,1)}}};constructor(i,n){this.context=i,this.canUseDOM=n||!1,n||(i.helmet=Bf({baseTag:[],bodyAttributes:{},htmlAttributes:{},linkTags:[],metaTags:[],noscriptTags:[],scriptTags:[],styleTags:[],title:"",titleAttributes:{}}))}},m_={},a0=B.createContext(m_),i0=class r0 extends be.Component{static canUseDOM=n0;helmetData;constructor(n){super(n),this.helmetData=new Vf(this.props.context||{},r0.canUseDOM)}render(){return B.createElement(a0.Provider,{value:this.helmetData.value},this.props.children)}},Ki=(i,n)=>{const r=document.head||document.querySelector("head"),s=r.querySelectorAll(`${i}[${cn}]`),o=[].slice.call(s),f=[];let d;return n&&n.length&&n.forEach(y=>{const m=document.createElement(i);for(const h in y)if(Object.prototype.hasOwnProperty.call(y,h))if(h==="innerHTML")m.innerHTML=y.innerHTML;else if(h==="cssText")m.styleSheet?m.styleSheet.cssText=y.cssText:m.appendChild(document.createTextNode(y.cssText));else{const b=h,v=typeof y[b]>"u"?"":y[b];m.setAttribute(h,v)}m.setAttribute(cn,"true"),o.some((h,b)=>(d=b,m.isEqualNode(h)))?o.splice(d,1):f.push(m)}),o.forEach(y=>y.parentNode?.removeChild(y)),f.forEach(y=>r.appendChild(y)),{oldTags:o,newTags:f}},Qf=(i,n)=>{const r=document.getElementsByTagName(i)[0];if(!r)return;const s=r.getAttribute(cn),o=s?s.split(","):[],f=[...o],d=Object.keys(n);for(const y of d){const m=n[y]||"";r.getAttribute(y)!==m&&r.setAttribute(y,m),o.indexOf(y)===-1&&o.push(y);const h=f.indexOf(y);h!==-1&&f.splice(h,1)}for(let y=f.length-1;y>=0;y-=1)r.removeAttribute(f[y]);o.length===f.length?r.removeAttribute(cn):r.getAttribute(cn)!==d.join(",")&&r.setAttribute(cn,d.join(","))},y_=(i,n)=>{typeof i<"u"&&document.title!==i&&(document.title=Pg(i)),Qf("title",n)},Dv=(i,n)=>{const{baseTag:r,bodyAttributes:s,htmlAttributes:o,linkTags:f,metaTags:d,noscriptTags:y,onChangeClientState:m,scriptTags:h,styleTags:b,title:v,titleAttributes:E}=i;Qf("body",s),Qf("html",o),y_(v,E);const S={baseTag:Ki("base",r),linkTags:Ki("link",f),metaTags:Ki("meta",d),noscriptTags:Ki("noscript",y),scriptTags:Ki("script",h),styleTags:Ki("style",b)},O={},N={};Object.keys(S).forEach(M=>{const{newTags:D,oldTags:U}=S[M];D.length&&(O[M]=D),U.length&&(N[M]=S[M].oldTags)}),n&&n(),m(i,O,N)},ml=null,p_=i=>{ml&&cancelAnimationFrame(ml),i.defer?ml=requestAnimationFrame(()=>{Dv(i,()=>{ml=null})}):(Dv(i),ml=null)},v_=p_,Mv=class extends be.Component{rendered=!1;shouldComponentUpdate(i){return!PO(i,this.props)}componentDidUpdate(){this.emitChange()}componentWillUnmount(){const{helmetInstances:i}=this.props.context;i.remove(this),this.emitChange()}emitChange(){const{helmetInstances:i,setHelmet:n}=this.props.context;let r=null;const s=l_(i.get().map(o=>{const f={...o.props};return delete f.context,f}));i0.canUseDOM?v_(s):Bf&&(r=Bf(s)),n(r)}init(){if(this.rendered)return;this.rendered=!0;const{helmetInstances:i}=this.props.context;i.add(this),this.emitChange()}render(){return this.init(),null}},g_=class extends be.Component{static defaultProps={defer:!0,encodeSpecialCharacters:!0,prioritizeSeoTags:!1};shouldComponentUpdate(i){return!JO(Av(this.props,"helmetData"),Av(i,"helmetData"))}mapNestedChildrenToProps(i,n){if(!n)return null;switch(i.type){case"script":case"noscript":return{innerHTML:n};case"style":return{cssText:n};default:throw new Error(`<${i.type} /> elements are self-closing and can not contain children. Refer to our API for more information.`)}}flattenArrayTypeChildren(i,n,r,s){return{...n,[i.type]:[...n[i.type]||[],{...r,...this.mapNestedChildrenToProps(i,s)}]}}mapObjectTypeChildren(i,n,r,s){switch(i.type){case"title":return{...n,[i.type]:s,titleAttributes:{...r}};case"body":return{...n,bodyAttributes:{...r}};case"html":return{...n,htmlAttributes:{...r}};default:return{...n,[i.type]:{...r}}}}mapArrayTypeChildrenToProps(i,n){let r={...n};return Object.keys(i).forEach(s=>{r={...r,[s]:i[s]}}),r}warnOnInvalidChildren(i,n){return Ov(wv.some(r=>i.type===r),typeof i.type=="function"?"You may be attempting to nest <Helmet> components within each other, which is not allowed. Refer to our API for more information.":`Only elements types ${wv.join(", ")} are allowed. Helmet does not support rendering <${i.type}> elements. Refer to our API for more information.`),Ov(!n||typeof n=="string"||Array.isArray(n)&&!n.some(r=>typeof r!="string"),`Helmet expects a string as a child of <${i.type}>. Did you forget to wrap your children in braces? ( <${i.type}>{\`\`}</${i.type}> ) Refer to our API for more information.`),!0}mapChildrenToProps(i,n){let r={};return B.Children.forEach(i,s=>{if(!s||!s.props)return;const{children:o,...f}=s.props,d=Object.keys(f).reduce((m,h)=>(m[e_[h]||h]=f[h],m),{});let{type:y}=s;switch(typeof y=="symbol"?y=y.toString():this.warnOnInvalidChildren(s,o),y){case"Symbol(react.fragment)":n=this.mapChildrenToProps(o,n);break;case"link":case"meta":case"noscript":case"script":case"style":r=this.flattenArrayTypeChildren(s,r,d,o);break;default:n=this.mapObjectTypeChildren(s,n,d,o);break}}),this.mapArrayTypeChildrenToProps(r,n)}render(){const{children:i,...n}=this.props;let r={...n},{helmetData:s}=n;if(i&&(r=this.mapChildrenToProps(i,r)),s&&!(s instanceof Vf)){const o=s;s=new Vf(o.context,!0),delete r.helmetData}return s?B.createElement(Mv,{...r,context:s.value}):B.createElement(a0.Consumer,null,o=>B.createElement(Mv,{...r,context:o}))}};function b_(){return RS()?.data}const S_=new RO({uri:"https://staging-api.vuer.ai/graphql"});class E_ extends gt{constructor(n){super((r,s)=>{const{...o}=r;return Object.defineProperty(o,"client",{enumerable:!1,value:r.client}),new Fe(f=>{let d=!1;return Promise.resolve(o).then(y=>n(r.getContext(),y)).then(r.setContext).then(()=>{d||s(r).subscribe(f)}).catch(f.error.bind(f)),()=>{d=!0}})})}}var Ef={},Wa={},$s={},Cv;function T_(){if(Cv)return $s;Cv=1,Object.defineProperty($s,"__esModule",{value:!0}),$s.isObjectLike=i;function i(n){return typeof n=="object"&&n!==null}return $s}var Ws={},Ps={},xv;function O_(){if(xv)return Ps;xv=1,Object.defineProperty(Ps,"__esModule",{value:!0}),Ps.invariant=i;function i(n,r){if(!!!n)throw new Error(r??"Unexpected invariant triggered.")}return Ps}var Rv;function l0(){if(Rv)return Ws;Rv=1,Object.defineProperty(Ws,"__esModule",{value:!0}),Ws.getLocation=r;var i=O_();const n=/\r\n|[\n\r]/g;function r(s,o){let f=0,d=1;for(const y of s.body.matchAll(n)){if(typeof y.index=="number"||(0,i.invariant)(!1),y.index>=o)break;f=y.index+y[0].length,d+=1}return{line:d,column:o+1-f}}return Ws}var yl={},zv;function __(){if(zv)return yl;zv=1,Object.defineProperty(yl,"__esModule",{value:!0}),yl.printLocation=n,yl.printSourceLocation=r;var i=l0();function n(o){return r(o.source,(0,i.getLocation)(o.source,o.start))}function r(o,f){const d=o.locationOffset.column-1,y="".padStart(d)+o.body,m=f.line-1,h=o.locationOffset.line-1,b=f.line+h,v=f.line===1?d:0,E=f.column+v,S=`${o.name}:${b}:${E}
`,O=y.split(/\r\n|[\n\r]/g),N=O[m];if(N.length>120){const M=Math.floor(E/80),D=E%80,U=[];for(let Y=0;Y<N.length;Y+=80)U.push(N.slice(Y,Y+80));return S+s([[`${b} |`,U[0]],...U.slice(1,M+1).map(Y=>["|",Y]),["|","^".padStart(D)],["|",U[M+1]]])}return S+s([[`${b-1} |`,O[m-1]],[`${b} |`,N],["|","^".padStart(E)],[`${b+1} |`,O[m+1]]])}function s(o){const f=o.filter(([y,m])=>m!==void 0),d=Math.max(...f.map(([y])=>y.length));return f.map(([y,m])=>y.padStart(d)+(m?" "+m:"")).join(`
`)}return yl}var Nv;function dd(){if(Nv)return Wa;Nv=1,Object.defineProperty(Wa,"__esModule",{value:!0}),Wa.GraphQLError=void 0,Wa.formatError=y,Wa.printError=d;var i=T_(),n=l0(),r=__();function s(m){const h=m[0];return h==null||"kind"in h||"length"in h?{nodes:h,source:m[1],positions:m[2],path:m[3],originalError:m[4],extensions:m[5]}:h}let o=class s0 extends Error{constructor(h,...b){var v,E,S;const{nodes:O,source:N,positions:M,path:D,originalError:U,extensions:Y}=s(b);super(h),this.name="GraphQLError",this.path=D??void 0,this.originalError=U??void 0,this.nodes=f(Array.isArray(O)?O:O?[O]:void 0);const X=f((v=this.nodes)===null||v===void 0?void 0:v.map(ee=>ee.loc).filter(ee=>ee!=null));this.source=N??(X==null||(E=X[0])===null||E===void 0?void 0:E.source),this.positions=M??X?.map(ee=>ee.start),this.locations=M&&N?M.map(ee=>(0,n.getLocation)(N,ee)):X?.map(ee=>(0,n.getLocation)(ee.source,ee.start));const K=(0,i.isObjectLike)(U?.extensions)?U?.extensions:void 0;this.extensions=(S=Y??K)!==null&&S!==void 0?S:Object.create(null),Object.defineProperties(this,{message:{writable:!0,enumerable:!0},name:{enumerable:!1},nodes:{enumerable:!1},source:{enumerable:!1},positions:{enumerable:!1},originalError:{enumerable:!1}}),U!=null&&U.stack?Object.defineProperty(this,"stack",{value:U.stack,writable:!0,configurable:!0}):Error.captureStackTrace?Error.captureStackTrace(this,s0):Object.defineProperty(this,"stack",{value:Error().stack,writable:!0,configurable:!0})}get[Symbol.toStringTag](){return"GraphQLError"}toString(){let h=this.message;if(this.nodes)for(const b of this.nodes)b.loc&&(h+=`

`+(0,r.printLocation)(b.loc));else if(this.source&&this.locations)for(const b of this.locations)h+=`

`+(0,r.printSourceLocation)(this.source,b);return h}toJSON(){const h={message:this.message};return this.locations!=null&&(h.locations=this.locations),this.path!=null&&(h.path=this.path),this.extensions!=null&&Object.keys(this.extensions).length>0&&(h.extensions=this.extensions),h}};Wa.GraphQLError=o;function f(m){return m===void 0||m.length===0?void 0:m}function d(m){return m.toString()}function y(m){return m.toJSON()}return Wa}var eu={},jv;function w_(){if(jv)return eu;jv=1,Object.defineProperty(eu,"__esModule",{value:!0}),eu.syntaxError=n;var i=dd();function n(r,s,o){return new i.GraphQLError(`Syntax Error: ${o}`,{source:r,positions:[s]})}return eu}var tu={},nu={},au={},Uv;function A_(){if(Uv)return au;Uv=1,Object.defineProperty(au,"__esModule",{value:!0}),au.inspect=r;const i=10,n=2;function r(h){return s(h,[])}function s(h,b){switch(typeof h){case"string":return JSON.stringify(h);case"function":return h.name?`[function ${h.name}]`:"[function]";case"object":return o(h,b);default:return String(h)}}function o(h,b){if(h===null)return"null";if(b.includes(h))return"[Circular]";const v=[...b,h];if(f(h)){const E=h.toJSON();if(E!==h)return typeof E=="string"?E:s(E,v)}else if(Array.isArray(h))return y(h,v);return d(h,v)}function f(h){return typeof h.toJSON=="function"}function d(h,b){const v=Object.entries(h);return v.length===0?"{}":b.length>n?"["+m(h)+"]":"{ "+v.map(([S,O])=>S+": "+s(O,b)).join(", ")+" }"}function y(h,b){if(h.length===0)return"[]";if(b.length>n)return"[Array]";const v=Math.min(i,h.length),E=h.length-v,S=[];for(let O=0;O<v;++O)S.push(s(h[O],b));return E===1?S.push("... 1 more item"):E>1&&S.push(`... ${E} more items`),"["+S.join(", ")+"]"}function m(h){const b=Object.prototype.toString.call(h).replace(/^\[object /,"").replace(/]$/,"");if(b==="Object"&&typeof h.constructor=="function"){const v=h.constructor.name;if(typeof v=="string"&&v!=="")return v}return b}return au}var kv;function D_(){if(kv)return nu;kv=1,Object.defineProperty(nu,"__esModule",{value:!0}),nu.toError=n;var i=A_();function n(s){return s instanceof Error?s:new r(s)}class r extends Error{constructor(o){super("Unexpected error value: "+(0,i.inspect)(o)),this.name="NonErrorThrown",this.thrownValue=o}}return nu}var qv;function M_(){if(qv)return tu;qv=1,Object.defineProperty(tu,"__esModule",{value:!0}),tu.locatedError=r;var i=D_(),n=dd();function r(o,f,d){var y;const m=(0,i.toError)(o);return s(m)?m:new n.GraphQLError(m.message,{nodes:(y=m.nodes)!==null&&y!==void 0?y:f,source:m.source,positions:m.positions,path:d,originalError:m})}function s(o){return Array.isArray(o.path)}return tu}var Lv;function C_(){return Lv||(Lv=1,(function(i){Object.defineProperty(i,"__esModule",{value:!0}),Object.defineProperty(i,"GraphQLError",{enumerable:!0,get:function(){return n.GraphQLError}}),Object.defineProperty(i,"formatError",{enumerable:!0,get:function(){return n.formatError}}),Object.defineProperty(i,"locatedError",{enumerable:!0,get:function(){return s.locatedError}}),Object.defineProperty(i,"printError",{enumerable:!0,get:function(){return n.printError}}),Object.defineProperty(i,"syntaxError",{enumerable:!0,get:function(){return r.syntaxError}});var n=dd(),r=w_(),s=M_()})(Ef)),Ef}var x_=C_();const R_=new E_(async i=>{console.log("=========> apollo authLink => ",typeof window>"u"?"server":"client");const n=$g.token();if(console.log("AUTH_TOKEN_STORAGE_KEY",!!n),n)return{headers:{authorization:`${n.token_type} ${n.access_token}`,...i.headers},...i};throw new x_.GraphQLError("Not authenticated",{extensions:{code:"UNAUTHENTICATED"}})});class z_ extends gt{constructor(n){super((r,s)=>new Fe(o=>{let f,d,y;try{f=s(r).subscribe({next:m=>{const h=r.client.queryManager.incrementalHandler,b=h.isIncrementalResult(m)?h.extractErrors(m):m.errors;b?y=n({error:new Tn(m,b),result:m,operation:r,forward:s}):Kg(m)&&(y=n({error:m.extensions[Dl],result:m,operation:r,forward:s})),d=y?.subscribe(o),d||o.next(m)},error:m=>{y=n({operation:r,error:Lf(m),forward:s}),d=y?.subscribe(o),d||o.error(m)},complete:()=>{y||o.complete()}})}catch(m){n({error:Lf(m),operation:r,forward:s}),o.error(m)}return()=>{f&&f.unsubscribe(),d&&d.unsubscribe()}}))}}let iu=!1,ru=[];const N_=new z_(({error:i,operation:n,forward:r})=>{if(Tn.is(i))for(const s of i.errors)switch(s.extensions.code){case"UNAUTHENTICATED":return iu?Xn(new Promise(f=>{ru.push(d=>{f(d)})})).pipe(ni(f=>{const d=n.getContext().headers;return n.setContext({headers:{...d,authorization:`${f.token_type} ${f.access_token}`}}),r(n)})):(iu=!0,Xn($g.refreshToken()).pipe(HE(o=>{ru.forEach(d=>d(o));const f=n.getContext().headers;return n.setContext({headers:{...f,authorization:`${o.token_type} ${o.access_token}`}}),iu=!1,ru=[],r(n)}),bl(o=>(iu=!1,ru=[],o))))}console.log(`[Error]: ${i.message}`)}),j_=new cO({link:gt.from([R_,N_,S_]),cache:new aO});function U_({children:i}){const{theme:n="system"}=b_();return at.jsx(i0,{children:at.jsxs(be.StrictMode,{children:[at.jsxs(g_,{children:[at.jsx("title",{children:"Vuer Studio"}),at.jsx("meta",{name:"description",content:"Modern Physical AI Studio for XR"}),null,at.jsx("script",{src:"/env-config.js"})]}),null,at.jsx($S,{storageKey:"vuer-web-theme",defaultBaseTheme:n,children:at.jsxs(z1,{client:j_,children:[i,at.jsx(M1,{})]})})]})})}const $_=Object.freeze(Object.defineProperty({__proto__:null,default:U_},Symbol.toStringTag,{value:"Module"})),W_={component:k_};function k_(){return B.createElement(B.Fragment,null,B.createElement("div",{style:{width:"100%",height:"100%",maxHeight:"100%",background:"linear-gradient(110deg, #ececec 8%, #f5f5f5 18%, #ececec 33%)",borderRadius:"5px",backgroundSize:"200% 100%",animation:"1.3s vike-react-loading linear infinite",aspectRatio:"2.5/1"}}),B.createElement("style",{href:"vike-react-loading",precedence:"default"},`
          @keyframes vike-react-loading {
            to {
              background-position-x: -200%;
            }
          }
        `))}export{kO as A,yg as B,Yv as C,AS as D,ii as E,Gf as F,GS as G,g_ as H,Xv as I,Q_ as J,X_ as K,JO as L,CS as M,se as N,Ov as O,PO as P,Sp as Q,Y_ as R,Eu as S,G_ as T,ES as U,ri as _,$_ as a,V_ as b,B_ as c,$g as d,IS as e,Gv as f,i0 as g,$e as h,W_ as i,at as j,de as k,tf as l,Z_ as m,R1 as n,H_ as o,cT as p,hu as q,be as r,Tl as s,F_ as t,RS as u,bT as v,Mf as w,ag as x,wa as y,B as z};
